// Copyright (c) 2013-2016 CoolGames

/******************************************************************************
 * Spine Runtimes Software License
 * Version 2.3
 * 
 * Copyright (c) 2013-2015, Esoteric Software
 * All rights reserved.
 * 
 * You are granted a perpetual, non-exclusive, non-sublicensable and
 * non-transferable license to use, install, execute and perform the Spine
 * Runtimes Software (the "Software") and derivative works solely for personal
 * or internal use. Without the written permission of Esoteric Software (see
 * Section 2 of the Spine Software License Agreement), you may not (a) modify,
 * translate, adapt or otherwise create derivative works, improvements of the
 * Software or develop new applications using the Software or (b) remove,
 * delete, alter or obscure any trademarks or any copyright, trademark, patent
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 * 
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

var spine = {
	radDeg: 180 / Math.PI,
	degRad: Math.PI / 180,
	temp: [],
    Float32Array: (typeof(Float32Array) === 'undefined') ? Array : Float32Array,
    Uint16Array: (typeof(Uint16Array) === 'undefined') ? Array : Uint16Array
};

spine.BoneData = function (name, parent) {
	this.name = name;
	this.parent = parent;
};
spine.BoneData.prototype = {
	length: 0,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	inheritScale: true,
	inheritRotation: true,
	flipX: false, flipY: false
};

spine.BlendMode = {
	normal: 0,
	additive: 1,
	multiply: 2,
	screen: 3
};

spine.SlotData = function (name, boneData) {
	this.name = name;
	this.boneData = boneData;
};
spine.SlotData.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	attachmentName: null,
	blendMode: spine.BlendMode.normal
};

spine.IkConstraintData = function (name) {
	this.name = name;
	this.bones = [];
};
spine.IkConstraintData.prototype = {
	target: null,
	bendDirection: 1,
	mix: 1
};

spine.Bone = function (boneData, skeleton, parent) {
	this.data = boneData;
	this.skeleton = skeleton;
	this.parent = parent;
	this.setToSetupPose();
};
spine.Bone.yDown = false;
spine.Bone.prototype = {
	x: 0, y: 0,
	rotation: 0, rotationIK: 0,
	scaleX: 1, scaleY: 1,
	flipX: false, flipY: false,
	m00: 0, m01: 0, worldX: 0, // a b x
	m10: 0, m11: 0, worldY: 0, // c d y
	worldRotation: 0,
	worldScaleX: 1, worldScaleY: 1,
	worldFlipX: false, worldFlipY: false,
	updateWorldTransform: function () {
		var parent = this.parent;
		if (parent) {
			this.worldX = this.x * parent.m00 + this.y * parent.m01 + parent.worldX;
			this.worldY = this.x * parent.m10 + this.y * parent.m11 + parent.worldY;
			if (this.data.inheritScale) {
				this.worldScaleX = parent.worldScaleX * this.scaleX;
				this.worldScaleY = parent.worldScaleY * this.scaleY;
			} else {
				this.worldScaleX = this.scaleX;
				this.worldScaleY = this.scaleY;
			}
			this.worldRotation = this.data.inheritRotation ? (parent.worldRotation + this.rotationIK) : this.rotationIK;
			this.worldFlipX = parent.worldFlipX != this.flipX;
			this.worldFlipY = parent.worldFlipY != this.flipY;
		} else {
			var skeletonFlipX = this.skeleton.flipX, skeletonFlipY = this.skeleton.flipY;
			this.worldX = skeletonFlipX ? -this.x : this.x;
			this.worldY = (skeletonFlipY != spine.Bone.yDown) ? -this.y : this.y;
			this.worldScaleX = this.scaleX;
			this.worldScaleY = this.scaleY;
			this.worldRotation = this.rotationIK;
			this.worldFlipX = skeletonFlipX != this.flipX;
			this.worldFlipY = skeletonFlipY != this.flipY;
		}
		var radians = this.worldRotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		if (this.worldFlipX) {
			this.m00 = -cos * this.worldScaleX;
			this.m01 = sin * this.worldScaleY;
		} else {
			this.m00 = cos * this.worldScaleX;
			this.m01 = -sin * this.worldScaleY;
		}
		if (this.worldFlipY != spine.Bone.yDown) {
			this.m10 = -sin * this.worldScaleX;
			this.m11 = -cos * this.worldScaleY;
		} else {
			this.m10 = sin * this.worldScaleX;
			this.m11 = cos * this.worldScaleY;
		}
	},
	setToSetupPose: function () {
		var data = this.data;
		this.x = data.x;
		this.y = data.y;
		this.rotation = data.rotation;
		this.rotationIK = this.rotation;
		this.scaleX = data.scaleX;
		this.scaleY = data.scaleY;
		this.flipX = data.flipX;
		this.flipY = data.flipY;
	},
	worldToLocal: function (world) {
		var dx = world[0] - this.worldX, dy = world[1] - this.worldY;
		var m00 = this.m00, m10 = this.m10, m01 = this.m01, m11 = this.m11;
		if (this.worldFlipX != (this.worldFlipY != spine.Bone.yDown)) {
			m00 = -m00;
			m11 = -m11;
		}
		var invDet = 1 / (m00 * m11 - m01 * m10);
		world[0] = dx * m00 * invDet - dy * m01 * invDet;
		world[1] = dy * m11 * invDet - dx * m10 * invDet;
	},
	localToWorld: function (local) {
		var localX = local[0], localY = local[1];
		local[0] = localX * this.m00 + localY * this.m01 + this.worldX;
		local[1] = localX * this.m10 + localY * this.m11 + this.worldY;
	}
};

spine.Slot = function (slotData, bone) {
	this.data = slotData;
	this.bone = bone;
	this.setToSetupPose();
};
spine.Slot.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	_attachmentTime: 0,
	attachment: null,
	attachmentVertices: [],
	setAttachment: function (attachment) {
		if (this.attachment == attachment) return;
		this.attachment = attachment;
		this._attachmentTime = this.bone.skeleton.time;
		this.attachmentVertices.length = 0;
	},
	setAttachmentTime: function (time) {
		this._attachmentTime = this.bone.skeleton.time - time;
	},
	getAttachmentTime: function () {
		return this.bone.skeleton.time - this._attachmentTime;
	},
	setToSetupPose: function () {
		var data = this.data;
		this.r = data.r;
		this.g = data.g;
		this.b = data.b;
		this.a = data.a;

		if (!data.attachmentName)
			this.setAttachment(null);
		else {
			var slotDatas = this.bone.skeleton.data.slots;
			for (var i = 0, n = slotDatas.length; i < n; i++) {
				if (slotDatas[i] == data) {
					this.attachment = null;
					this.setAttachment(this.bone.skeleton.getAttachmentBySlotIndex(i, data.attachmentName));
					break;
				}
			}
		}
	}
};

spine.IkConstraint = function (data, skeleton) {
	this.data = data;
	this.mix = data.mix;
	this.bendDirection = data.bendDirection;

	this.bones = [];
	for (var i = 0, n = data.bones.length; i < n; i++)
		this.bones.push(skeleton.findBone(data.bones[i].name));
	this.target = skeleton.findBone(data.target.name);
};
spine.IkConstraint.prototype = {
	apply: function () {
		var target = this.target;
		var bones = this.bones;
		switch (bones.length) {
		case 1:
			spine.IkConstraint.apply1(bones[0], target.worldX, target.worldY, this.mix);
			break;
		case 2:
			spine.IkConstraint.apply2(bones[0], bones[1], target.worldX, target.worldY, this.bendDirection, this.mix);
			break;
		}
	}
};
/** Adjusts the bone rotation so the tip is as close to the target position as possible. The target is specified in the world
 * coordinate system. */
spine.IkConstraint.apply1 = function (bone, targetX, targetY, alpha) {
	var parentRotation = (!bone.data.inheritRotation || !bone.parent) ? 0 : bone.parent.worldRotation;
	var rotation = bone.rotation;
	var rotationIK = Math.atan2(targetY - bone.worldY, targetX - bone.worldX) * spine.radDeg;
	if (bone.worldFlipX != (bone.worldFlipY != spine.Bone.yDown)) rotationIK = -rotationIK;
	rotationIK -= parentRotation;
	bone.rotationIK = rotation + (rotationIK - rotation) * alpha;
};
/** Adjusts the parent and child bone rotations so the tip of the child is as close to the target position as possible. The
 * target is specified in the world coordinate system.
 * @param child Any descendant bone of the parent. */
spine.IkConstraint.apply2 = function (parent, child, targetX, targetY, bendDirection, alpha) {
	var childRotation = child.rotation, parentRotation = parent.rotation;
	if (!alpha) {
		child.rotationIK = childRotation;
		parent.rotationIK = parentRotation;
		return;
	}
	var positionX, positionY, tempPosition = spine.temp;
	var parentParent = parent.parent;
	if (parentParent) {
		tempPosition[0] = targetX;
		tempPosition[1] = targetY;
		parentParent.worldToLocal(tempPosition);
		targetX = (tempPosition[0] - parent.x) * parentParent.worldScaleX;
		targetY = (tempPosition[1] - parent.y) * parentParent.worldScaleY;
	} else {
		targetX -= parent.x;
		targetY -= parent.y;
	}
	if (child.parent == parent) {
		positionX = child.x;
		positionY = child.y;
	} else {
		tempPosition[0] = child.x;
		tempPosition[1] = child.y;
		child.parent.localToWorld(tempPosition);
		parent.worldToLocal(tempPosition);
		positionX = tempPosition[0];
		positionY = tempPosition[1];
	}
	var childX = positionX * parent.worldScaleX, childY = positionY * parent.worldScaleY;
	var offset = Math.atan2(childY, childX);
	var len1 = Math.sqrt(childX * childX + childY * childY), len2 = child.data.length * child.worldScaleX;
	// Based on code by Ryan Juckett with permission: Copyright (c) 2008-2009 Ryan Juckett, http://www.ryanjuckett.com/
	var cosDenom = 2 * len1 * len2;
	if (cosDenom < 0.0001) {
		child.rotationIK = childRotation + (Math.atan2(targetY, targetX) * spine.radDeg - parentRotation - childRotation) * alpha;
		return;
	}
	var cos = (targetX * targetX + targetY * targetY - len1 * len1 - len2 * len2) / cosDenom;
	if (cos < -1)
		cos = -1;
	else if (cos > 1)
		cos = 1;
	var childAngle = Math.acos(cos) * bendDirection;
	var adjacent = len1 + len2 * cos, opposite = len2 * Math.sin(childAngle);
	var parentAngle = Math.atan2(targetY * adjacent - targetX * opposite, targetX * adjacent + targetY * opposite);
	var rotation = (parentAngle - offset) * spine.radDeg - parentRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	parent.rotationIK = parentRotation + rotation * alpha;
	rotation = (childAngle + offset) * spine.radDeg - childRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	child.rotationIK = childRotation + (rotation + parent.worldRotation - child.parent.worldRotation) * alpha;
};

spine.Skin = function (name) {
	this.name = name;
	this.attachments = {};
};
spine.Skin.prototype = {
	addAttachment: function (slotIndex, name, attachment) {
		this.attachments[slotIndex + ":" + name] = attachment;
	},
	getAttachment: function (slotIndex, name) {
		return this.attachments[slotIndex + ":" + name];
	},
	_attachAll: function (skeleton, oldSkin) {
		for (var key in oldSkin.attachments) {
			var colon = key.indexOf(":");
			var slotIndex = parseInt(key.substring(0, colon));
			var name = key.substring(colon + 1);
			var slot = skeleton.slots[slotIndex];
			if (slot.attachment && slot.attachment.name == name) {
				var attachment = this.getAttachment(slotIndex, name);
				if (attachment) slot.setAttachment(attachment);
			}
		}
	}
};

spine.Animation = function (name, timelines, duration) {
	this.name = name;
	this.timelines = timelines;
	this.duration = duration;
};
spine.Animation.prototype = {
	apply: function (skeleton, lastTime, time, loop, events) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, 1);
	},
	mix: function (skeleton, lastTime, time, loop, events, alpha) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, alpha);
	}
};
spine.Animation.binarySearch = function (values, target, step) {
	var low = 0;
	var high = Math.floor(values.length / step) - 2;
	if (!high) return step;
	var current = high >>> 1;
	while (true) {
		if (values[(current + 1) * step] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return (low + 1) * step;
		current = (low + high) >>> 1;
	}
};
spine.Animation.binarySearch1 = function (values, target) {
	var low = 0;
	var high = values.length - 2;
	if (!high) return 1;
	var current = high >>> 1;
	while (true) {
		if (values[current + 1] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return low + 1;
		current = (low + high) >>> 1;
	}
};
spine.Animation.linearSearch = function (values, target, step) {
	for (var i = 0, last = values.length - step; i <= last; i += step)
		if (values[i] > target) return i;
	return -1;
};

spine.Curves = function (frameCount) {
	this.curves = []; // type, x, y, ...
	//this.curves.length = (frameCount - 1) * 19/*BEZIER_SIZE*/;
};
spine.Curves.prototype = {
	setLinear: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 0/*LINEAR*/;
	},
	setStepped: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 1/*STEPPED*/;
	},
	/** Sets the control handle positions for an interpolation bezier curve used to transition from this keyframe to the next.
	 * cx1 and cx2 are from 0 to 1, representing the percent of time between the two keyframes. cy1 and cy2 are the percent of
	 * the difference between the keyframe's values. */
	setCurve: function (frameIndex, cx1, cy1, cx2, cy2) {
		var subdiv1 = 1 / 10/*BEZIER_SEGMENTS*/, subdiv2 = subdiv1 * subdiv1, subdiv3 = subdiv2 * subdiv1;
		var pre1 = 3 * subdiv1, pre2 = 3 * subdiv2, pre4 = 6 * subdiv2, pre5 = 6 * subdiv3;
		var tmp1x = -cx1 * 2 + cx2, tmp1y = -cy1 * 2 + cy2, tmp2x = (cx1 - cx2) * 3 + 1, tmp2y = (cy1 - cy2) * 3 + 1;
		var dfx = cx1 * pre1 + tmp1x * pre2 + tmp2x * subdiv3, dfy = cy1 * pre1 + tmp1y * pre2 + tmp2y * subdiv3;
		var ddfx = tmp1x * pre4 + tmp2x * pre5, ddfy = tmp1y * pre4 + tmp2y * pre5;
		var dddfx = tmp2x * pre5, dddfy = tmp2y * pre5;

		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var curves = this.curves;
		curves[i++] = 2/*BEZIER*/;
		
		var x = dfx, y = dfy;
		for (var n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			curves[i] = x;
			curves[i + 1] = y;
			dfx += ddfx;
			dfy += ddfy;
			ddfx += dddfx;
			ddfy += dddfy;
			x += dfx;
			y += dfy;
		}
	},
	getCurvePercent: function (frameIndex, percent) {
		percent = percent < 0 ? 0 : (percent > 1 ? 1 : percent);
		var curves = this.curves;
		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var type = curves[i];
		if (type === 0/*LINEAR*/) return percent;
		if (type == 1/*STEPPED*/) return 0;
		i++;
		var x = 0;
		for (var start = i, n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			x = curves[i];
			if (x >= percent) {
				var prevX, prevY;
				if (i == start) {
					prevX = 0;
					prevY = 0;
				} else {
					prevX = curves[i - 2];
					prevY = curves[i - 1];
				}
				return prevY + (curves[i + 1] - prevY) * (percent - prevX) / (x - prevX);
			}
		}
		var y = curves[i - 1];
		return y + (1 - y) * (percent - x) / (1 - x); // Last point is 1,1.
	}
};

spine.RotateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, angle, ...
	this.frames.length = frameCount * 2;
};
spine.RotateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, angle) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = angle;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 2]) { // Time is after last frame.
			var amount = bone.data.rotation + frames[frames.length - 1] - bone.rotation;
			while (amount > 180)
				amount -= 360;
			while (amount < -180)
				amount += 360;
			bone.rotation += amount * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 2);
		var prevFrameValue = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 2/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 2 - 1, percent);

		var amount = frames[frameIndex + 1/*FRAME_VALUE*/] - prevFrameValue;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		amount = bone.data.rotation + (prevFrameValue + amount * percent) - bone.rotation;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		bone.rotation += amount * alpha;
	}
};

spine.TranslateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.TranslateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.x += (bone.data.x + frames[frames.length - 2] - bone.x) * alpha;
			bone.y += (bone.data.y + frames[frames.length - 1] - bone.y) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.x += (bone.data.x + prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent - bone.x) * alpha;
		bone.y += (bone.data.y + prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent - bone.y) * alpha;
	}
};

spine.ScaleTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.ScaleTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.scaleX += (bone.data.scaleX * frames[frames.length - 2] - bone.scaleX) * alpha;
			bone.scaleY += (bone.data.scaleY * frames[frames.length - 1] - bone.scaleY) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.scaleX += (bone.data.scaleX * (prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent) - bone.scaleX) * alpha;
		bone.scaleY += (bone.data.scaleY * (prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent) - bone.scaleY) * alpha;
	}
};

spine.ColorTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, r, g, b, a, ...
	this.frames.length = frameCount * 5;
};
spine.ColorTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 5;
	},
	setFrame: function (frameIndex, time, r, g, b, a) {
		frameIndex *= 5;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = r;
		this.frames[frameIndex + 2] = g;
		this.frames[frameIndex + 3] = b;
		this.frames[frameIndex + 4] = a;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var r, g, b, a;
		if (time >= frames[frames.length - 5]) {
			// Time is after last frame.
			var i = frames.length - 1;
			r = frames[i - 3];
			g = frames[i - 2];
			b = frames[i - 1];
			a = frames[i];
		} else {
			// Interpolate between the previous frame and the current frame.
			var frameIndex = spine.Animation.binarySearch(frames, time, 5);
			var prevFrameR = frames[frameIndex - 4];
			var prevFrameG = frames[frameIndex - 3];
			var prevFrameB = frames[frameIndex - 2];
			var prevFrameA = frames[frameIndex - 1];
			var frameTime = frames[frameIndex];
			var percent = 1 - (time - frameTime) / (frames[frameIndex - 5/*PREV_FRAME_TIME*/] - frameTime);
			percent = this.curves.getCurvePercent(frameIndex / 5 - 1, percent);

			r = prevFrameR + (frames[frameIndex + 1/*FRAME_R*/] - prevFrameR) * percent;
			g = prevFrameG + (frames[frameIndex + 2/*FRAME_G*/] - prevFrameG) * percent;
			b = prevFrameB + (frames[frameIndex + 3/*FRAME_B*/] - prevFrameB) * percent;
			a = prevFrameA + (frames[frameIndex + 4/*FRAME_A*/] - prevFrameA) * percent;
		}
		var slot = skeleton.slots[this.slotIndex];
		if (alpha < 1) {
			slot.r += (r - slot.r) * alpha;
			slot.g += (g - slot.g) * alpha;
			slot.b += (b - slot.b) * alpha;
			slot.a += (a - slot.a) * alpha;
		} else {
			slot.r = r;
			slot.g = g;
			slot.b = b;
			slot.a = a;
		}
	}
};

spine.AttachmentTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.attachmentNames = [];
	this.attachmentNames.length = frameCount;
};
spine.AttachmentTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, attachmentName) {
		this.frames[frameIndex] = time;
		this.attachmentNames[frameIndex] = attachmentName;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;

		var frameIndex = time >= frames[frames.length - 1] ? frames.length - 1 : spine.Animation.binarySearch1(frames, time) - 1;
		if (frames[frameIndex] < lastTime) return;

		var attachmentName = this.attachmentNames[frameIndex];
		skeleton.slots[this.slotIndex].setAttachment(
			!attachmentName ? null : skeleton.getAttachmentBySlotIndex(this.slotIndex, attachmentName));
	}
};

spine.EventTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.events = [];
	this.events.length = frameCount;
};
spine.EventTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, event) {
		this.frames[frameIndex] = time;
		this.events[frameIndex] = event;
	},
	/** Fires events for frames > lastTime and <= time. */
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		if (!firedEvents) return;

		var frames = this.frames;
		var frameCount = frames.length;

		if (lastTime > time) { // Fire events after last time for looped animations.
			this.apply(skeleton, lastTime, Number.MAX_VALUE, firedEvents, alpha);
			lastTime = -1;
		} else if (lastTime >= frames[frameCount - 1]) // Last time is after last frame.
			return;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (lastTime < frames[0])
			frameIndex = 0;
		else {
			frameIndex = spine.Animation.binarySearch1(frames, lastTime);
			var frame = frames[frameIndex];
			while (frameIndex > 0) { // Fire multiple events with the same frame.
				if (frames[frameIndex - 1] != frame) break;
				frameIndex--;
			}
		}
		var events = this.events;
		for (; frameIndex < frameCount && time >= frames[frameIndex]; frameIndex++)
			firedEvents.push(events[frameIndex]);
	}
};

spine.DrawOrderTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.drawOrders = [];
	this.drawOrders.length = frameCount;
};
spine.DrawOrderTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, drawOrder) {
		this.frames[frameIndex] = time;
		this.drawOrders[frameIndex] = drawOrder;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (time >= frames[frames.length - 1]) // Time is after last frame.
			frameIndex = frames.length - 1;
		else
			frameIndex = spine.Animation.binarySearch1(frames, time) - 1;

		var drawOrder = skeleton.drawOrder;
		var slots = skeleton.slots;
		var drawOrderToSetupIndex = this.drawOrders[frameIndex];
		if (!drawOrderToSetupIndex) {
			for (var i = 0, n = slots.length; i < n; i++)
				drawOrder[i] = slots[i];
		} else {
			for (var i = 0, n = drawOrderToSetupIndex.length; i < n; i++)
				drawOrder[i] = skeleton.slots[drawOrderToSetupIndex[i]];
		}

	}
};

spine.FfdTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = [];
	this.frames.length = frameCount;
	this.frameVertices = [];
	this.frameVertices.length = frameCount;
};
spine.FfdTimeline.prototype = {
	slotIndex: 0,
	attachment: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, vertices) {
		this.frames[frameIndex] = time;
		this.frameVertices[frameIndex] = vertices;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var slot = skeleton.slots[this.slotIndex];
		if (slot.attachment != this.attachment) return;

		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameVertices = this.frameVertices;
		var vertexCount = frameVertices[0].length;

		var vertices = slot.attachmentVertices;
		if (vertices.length != vertexCount) alpha = 1;
		vertices.length = vertexCount;

		if (time >= frames[frames.length - 1]) { // Time is after last frame.
			var lastVertices = frameVertices[frames.length - 1];
			if (alpha < 1) {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] += (lastVertices[i] - vertices[i]) * alpha;
			} else {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] = lastVertices[i];
			}
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch1(frames, time);
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 1] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex - 1, percent < 0 ? 0 : (percent > 1 ? 1 : percent));

		var prevVertices = frameVertices[frameIndex - 1];
		var nextVertices = frameVertices[frameIndex];

		if (alpha < 1) {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] += (prev + (nextVertices[i] - prev) * percent - vertices[i]) * alpha;
			}
		} else {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] = prev + (nextVertices[i] - prev) * percent;
			}
		}
	}
};

spine.IkConstraintTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, mix, bendDirection, ...
	this.frames.length = frameCount * 3;
};
spine.IkConstraintTimeline.prototype = {
	ikConstraintIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, mix, bendDirection) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = mix;
		this.frames[frameIndex + 2] = bendDirection;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var ikConstraint = skeleton.ikConstraints[this.ikConstraintIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			ikConstraint.mix += (frames[frames.length - 2] - ikConstraint.mix) * alpha;
			ikConstraint.bendDirection = frames[frames.length - 1];
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameMix = frames[frameIndex + -2/*PREV_FRAME_MIX*/];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		var mix = prevFrameMix + (frames[frameIndex + 1/*FRAME_MIX*/] - prevFrameMix) * percent;
		ikConstraint.mix += (mix - ikConstraint.mix) * alpha;
		ikConstraint.bendDirection = frames[frameIndex + -1/*PREV_FRAME_BEND_DIRECTION*/];
	}
};

spine.FlipXTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipXTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipX = frames[frameIndex + 1] != 0;
	}
};

spine.FlipYTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipYTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipY = frames[frameIndex + 1] != 0;
	}
};

spine.SkeletonData = function () {
	this.bones = [];
	this.slots = [];
	this.skins = [];
	this.events = [];
	this.animations = [];
	this.ikConstraints = [];
};
spine.SkeletonData.prototype = {
	name: null,
	defaultSkin: null,
	width: 0, height: 0,
	version: null, hash: null,
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			if (slots[i].name == slotName) return slot[i];
		}
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].name == slotName) return i;
		return -1;
	},
	/** @return May be null. */
	findSkin: function (skinName) {
		var skins = this.skins;
		for (var i = 0, n = skins.length; i < n; i++)
			if (skins[i].name == skinName) return skins[i];
		return null;
	},
	/** @return May be null. */
	findEvent: function (eventName) {
		var events = this.events;
		for (var i = 0, n = events.length; i < n; i++)
			if (events[i].name == eventName) return events[i];
		return null;
	},
	/** @return May be null. */
	findAnimation: function (animationName) {
		var animations = this.animations;
		for (var i = 0, n = animations.length; i < n; i++)
			if (animations[i].name == animationName) return animations[i];
		return null;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].name == ikConstraintName) return ikConstraints[i];
		return null;
	}
};

spine.Skeleton = function (skeletonData) {
	this.data = skeletonData;

	this.bones = [];
	for (var i = 0, n = skeletonData.bones.length; i < n; i++) {
		var boneData = skeletonData.bones[i];
		var parent = !boneData.parent ? null : this.bones[skeletonData.bones.indexOf(boneData.parent)];
		this.bones.push(new spine.Bone(boneData, this, parent));
	}

	this.slots = [];
	this.drawOrder = [];
	for (var i = 0, n = skeletonData.slots.length; i < n; i++) {
		var slotData = skeletonData.slots[i];
		var bone = this.bones[skeletonData.bones.indexOf(slotData.boneData)];
		var slot = new spine.Slot(slotData, bone);
		this.slots.push(slot);
		this.drawOrder.push(slot);
	}
	
	this.ikConstraints = [];
	for (var i = 0, n = skeletonData.ikConstraints.length; i < n; i++)
		this.ikConstraints.push(new spine.IkConstraint(skeletonData.ikConstraints[i], this));

	this.boneCache = [];
	this.updateCache();
};
spine.Skeleton.prototype = {
	x: 0, y: 0,
	skin: null,
	r: 1, g: 1, b: 1, a: 1,
	time: 0,
	flipX: false, flipY: false,
	/** Caches information about bones and IK constraints. Must be called if bones or IK constraints are added or removed. */
	updateCache: function () {
		var ikConstraints = this.ikConstraints;
		var ikConstraintsCount = ikConstraints.length;

		var arrayCount = ikConstraintsCount + 1;
		var boneCache = this.boneCache;
		if (boneCache.length > arrayCount) boneCache.length = arrayCount;
		for (var i = 0, n = boneCache.length; i < n; i++)
			boneCache[i].length = 0;
		while (boneCache.length < arrayCount)
			boneCache[boneCache.length] = [];

		var nonIkBones = boneCache[0];
		var bones = this.bones;

		outer:
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			var current = bone;
			do {
				for (var ii = 0; ii < ikConstraintsCount; ii++) {
					var ikConstraint = ikConstraints[ii];
					var parent = ikConstraint.bones[0];
					var child= ikConstraint.bones[ikConstraint.bones.length - 1];
					while (true) {
						if (current == child) {
							boneCache[ii].push(bone);
							boneCache[ii + 1].push(bone);
							continue outer;
						}
						if (child == parent) break;
						child = child.parent;
					}
				}
				current = current.parent;
			} while (current);
			nonIkBones[nonIkBones.length] = bone;
		}
	},
	/** Updates the world transform for each bone. */
	updateWorldTransform: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			bone.rotationIK = bone.rotation;
		}
		var i = 0, last = this.boneCache.length - 1;
		while (true) {
			var cacheBones = this.boneCache[i];
			for (var ii = 0, nn = cacheBones.length; ii < nn; ii++)
				cacheBones[ii].updateWorldTransform();
			if (i == last) break;
			this.ikConstraints[i].apply();
			i++;
		}
	},
	/** Sets the bones and slots to their setup pose values. */
	setToSetupPose: function () {
		this.setBonesToSetupPose();
		this.setSlotsToSetupPose();
	},
	setBonesToSetupPose: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			bones[i].setToSetupPose();

		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++) {
			var ikConstraint = ikConstraints[i];
			ikConstraint.bendDirection = ikConstraint.data.bendDirection;
			ikConstraint.mix = ikConstraint.data.mix;
		}
	},
	setSlotsToSetupPose: function () {
		var slots = this.slots;
		var drawOrder = this.drawOrder;
		for (var i = 0, n = slots.length; i < n; i++) {
			drawOrder[i] = slots[i];
			slots[i].setToSetupPose(i);
		}
	},
	/** @return May return null. */
	getRootBone: function () {
		return this.bones.length ? this.bones[0] : null;
	},
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return slots[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return i;
		return -1;
	},
	setSkinByName: function (skinName) {
		var skin = this.data.findSkin(skinName);
		if (!skin) throw "Skin not found: " + skinName;
		this.setSkin(skin);
	},
	/** Sets the skin used to look up attachments before looking in the {@link SkeletonData#getDefaultSkin() default skin}. 
	 * Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was 
	 * no old skin, each slot's setup mode attachment is attached from the new skin.
	 * @param newSkin May be null. */
	setSkin: function (newSkin) {
		if (newSkin) {
			if (this.skin)
				newSkin._attachAll(this, this.skin);
			else {
				var slots = this.slots;
				for (var i = 0, n = slots.length; i < n; i++) {
					var slot = slots[i];
					var name = slot.data.attachmentName;
					if (name) {
						var attachment = newSkin.getAttachment(i, name);
						if (attachment) slot.setAttachment(attachment);
					}
				}
			}
		}
		this.skin = newSkin;
	},
	/** @return May be null. */
	getAttachmentBySlotName: function (slotName, attachmentName) {
		return this.getAttachmentBySlotIndex(this.data.findSlotIndex(slotName), attachmentName);
	},
	/** @return May be null. */
	getAttachmentBySlotIndex: function (slotIndex, attachmentName) {
		if (this.skin) {
			var attachment = this.skin.getAttachment(slotIndex, attachmentName);
			if (attachment) return attachment;
		}
		if (this.data.defaultSkin) return this.data.defaultSkin.getAttachment(slotIndex, attachmentName);
		return null;
	},
	/** @param attachmentName May be null. */
	setAttachment: function (slotName, attachmentName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			var slot = slots[i];
			if (slot.data.name == slotName) {
				var attachment = null;
				if (attachmentName) {
					attachment = this.getAttachmentBySlotIndex(i, attachmentName);
					if (!attachment) throw "Attachment not found: " + attachmentName + ", for slot: " + slotName;
				}
				slot.setAttachment(attachment);
				return;
			}
		}
		throw "Slot not found: " + slotName;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].data.name == ikConstraintName) return ikConstraints[i];
		return null;
	},
	update: function (delta) {
		this.time += delta;
	}
};

spine.EventData = function (name) {
	this.name = name;
};
spine.EventData.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.Event = function (data) {
	this.data = data;
};
spine.Event.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.AttachmentType = {
	region: 0,
	boundingbox: 1,
	mesh: 2,
	skinnedmesh: 3
};

spine.RegionAttachment = function (name) {
	this.name = name;
	this.offset = [];
	this.offset.length = 8;
	this.uvs = [];
	this.uvs.length = 8;
};
spine.RegionAttachment.prototype = {
	type: spine.AttachmentType.region,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	width: 0, height: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	setUVs: function (u, v, u2, v2, rotate) {
		var uvs = this.uvs;
		if (rotate) {
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v2;
			uvs[4/*X3*/] = u;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v;
			uvs[0/*X1*/] = u2;
			uvs[1/*Y1*/] = v2;
		} else {
			uvs[0/*X1*/] = u;
			uvs[1/*Y1*/] = v2;
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v;
			uvs[4/*X3*/] = u2;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v2;
		}
	},
	updateOffset: function () {
		var regionScaleX = this.width / this.regionOriginalWidth * this.scaleX;
		var regionScaleY = this.height / this.regionOriginalHeight * this.scaleY;
		var localX = -this.width / 2 * this.scaleX + this.regionOffsetX * regionScaleX;
		var localY = -this.height / 2 * this.scaleY + this.regionOffsetY * regionScaleY;
		var localX2 = localX + this.regionWidth * regionScaleX;
		var localY2 = localY + this.regionHeight * regionScaleY;
		var radians = this.rotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		var localXCos = localX * cos + this.x;
		var localXSin = localX * sin;
		var localYCos = localY * cos + this.y;
		var localYSin = localY * sin;
		var localX2Cos = localX2 * cos + this.x;
		var localX2Sin = localX2 * sin;
		var localY2Cos = localY2 * cos + this.y;
		var localY2Sin = localY2 * sin;
		var offset = this.offset;
		offset[0/*X1*/] = localXCos - localYSin;
		offset[1/*Y1*/] = localYCos + localXSin;
		offset[2/*X2*/] = localXCos - localY2Sin;
		offset[3/*Y2*/] = localY2Cos + localXSin;
		offset[4/*X3*/] = localX2Cos - localY2Sin;
		offset[5/*Y3*/] = localY2Cos + localX2Sin;
		offset[6/*X4*/] = localX2Cos - localYSin;
		offset[7/*Y4*/] = localYCos + localX2Sin;
	},
	computeVertices: function (x, y, bone, vertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var offset = this.offset;
		vertices[0/*X1*/] = offset[0/*X1*/] * m00 + offset[1/*Y1*/] * m01 + x;
		vertices[1/*Y1*/] = offset[0/*X1*/] * m10 + offset[1/*Y1*/] * m11 + y;
		vertices[2/*X2*/] = offset[2/*X2*/] * m00 + offset[3/*Y2*/] * m01 + x;
		vertices[3/*Y2*/] = offset[2/*X2*/] * m10 + offset[3/*Y2*/] * m11 + y;
		vertices[4/*X3*/] = offset[4/*X3*/] * m00 + offset[5/*X3*/] * m01 + x;
		vertices[5/*X3*/] = offset[4/*X3*/] * m10 + offset[5/*X3*/] * m11 + y;
		vertices[6/*X4*/] = offset[6/*X4*/] * m00 + offset[7/*Y4*/] * m01 + x;
		vertices[7/*Y4*/] = offset[6/*X4*/] * m10 + offset[7/*Y4*/] * m11 + y;
	}
};

spine.MeshAttachment = function (name) {
	this.name = name;
};
spine.MeshAttachment.prototype = {
	type: spine.AttachmentType.mesh,
	vertices: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function () {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var bone = slot.bone;
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		var verticesCount = vertices.length;
		if (slot.attachmentVertices.length == verticesCount) vertices = slot.attachmentVertices;
		for (var i = 0; i < verticesCount; i += 2) {
			var vx = vertices[i];
			var vy = vertices[i + 1];
			worldVertices[i] = vx * m00 + vy * m01 + x;
			worldVertices[i + 1] = vx * m10 + vy * m11 + y;
		}
	}
};

spine.SkinnedMeshAttachment = function (name) {
	this.name = name;
};
spine.SkinnedMeshAttachment.prototype = {
	type: spine.AttachmentType.skinnedmesh,
	bones: null,
	weights: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function (u, v, u2, v2, rotate) {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var skeletonBones = slot.bone.skeleton.bones;
		var weights = this.weights;
		var bones = this.bones;

		var w = 0, v = 0, b = 0, f = 0, n = bones.length, nn;
		var wx, wy, bone, vx, vy, weight;
		if (!slot.attachmentVertices.length) {
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3) {
					bone = skeletonBones[bones[v]];
					vx = weights[b];
					vy = weights[b + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		} else {
			var ffd = slot.attachmentVertices;
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3, f += 2) {
					bone = skeletonBones[bones[v]];
					vx = weights[b] + ffd[f];
					vy = weights[b + 1] + ffd[f + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		}
	}
};

spine.BoundingBoxAttachment = function (name) {
	this.name = name;
	this.vertices = [];
};
spine.BoundingBoxAttachment.prototype = {
	type: spine.AttachmentType.boundingbox,
	computeWorldVertices: function (x, y, bone, worldVertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		for (var i = 0, n = vertices.length; i < n; i += 2) {
			var px = vertices[i];
			var py = vertices[i + 1];
			worldVertices[i] = px * m00 + py * m01 + x;
			worldVertices[i + 1] = px * m10 + py * m11 + y;
		}
	}
};

spine.AnimationStateData = function (skeletonData) {
	this.skeletonData = skeletonData;
	this.animationToMixTime = {};
};
spine.AnimationStateData.prototype = {
	defaultMix: 0,
	setMixByName: function (fromName, toName, duration) {
		var from = this.skeletonData.findAnimation(fromName);
		if (!from) throw "Animation not found: " + fromName;
		var to = this.skeletonData.findAnimation(toName);
		if (!to) throw "Animation not found: " + toName;
		this.setMix(from, to, duration);
	},
	setMix: function (from, to, duration) {
		this.animationToMixTime[from.name + ":" + to.name] = duration;
	},
	getMix: function (from, to) {
		var key = from.name + ":" + to.name;
		return this.animationToMixTime.hasOwnProperty(key) ? this.animationToMixTime[key] : this.defaultMix;
	}
};

spine.TrackEntry = function () {};
spine.TrackEntry.prototype = {
	next: null, previous: null,
	animation: null,
	loop: false,
	delay: 0, time: 0, lastTime: -1, endTime: 0,
	timeScale: 1,
	mixTime: 0, mixDuration: 0, mix: 1,
	onStart: null, onEnd: null, onComplete: null, onEvent: null
};

spine.AnimationState = function (stateData) {
	this.data = stateData;
	this.tracks = [];
	this.events = [];
};
spine.AnimationState.prototype = {
	onStart: null,
	onEnd: null,
	onComplete: null,
	onEvent: null,
	timeScale: 1,
	update: function (delta) {
		delta *= this.timeScale;
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			current.time += delta * current.timeScale;
			if (current.previous) {
				var previousDelta = delta * current.previous.timeScale;
				current.previous.time += previousDelta;
				current.mixTime += previousDelta;
			}

			var next = current.next;
			if (next) {
				next.time = current.lastTime - next.delay;
				if (next.time >= 0) this.setCurrent(i, next);
			} else {
				// End non-looping animation when it reaches its end time and there is no next entry.
				if (!current.loop && current.lastTime >= current.endTime) this.clearTrack(i);
			}
		}
	},
	apply: function (skeleton) {
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			this.events.length = 0;

			var time = current.time;
			var lastTime = current.lastTime;
			var endTime = current.endTime;
			var loop = current.loop;
			if (!loop && time > endTime) time = endTime;

			var previous = current.previous;
			if (!previous) {
				if (current.mix == 1)
					current.animation.apply(skeleton, current.lastTime, time, loop, this.events);
				else
					current.animation.mix(skeleton, current.lastTime, time, loop, this.events, current.mix);
			} else {
				var previousTime = previous.time;
				if (!previous.loop && previousTime > previous.endTime) previousTime = previous.endTime;
				previous.animation.apply(skeleton, previousTime, previousTime, previous.loop, null);

				var alpha = current.mixTime / current.mixDuration * current.mix;
				if (alpha >= 1) {
					alpha = 1;
					current.previous = null;
				}
				current.animation.mix(skeleton, current.lastTime, time, loop, this.events, alpha);
			}

			for (var ii = 0, nn = this.events.length; ii < nn; ii++) {
				var event = this.events[ii];
				if (current.onEvent) current.onEvent(i, event);
				if (this.onEvent) this.onEvent(i, event);
			}

			// Check if completed the animation or a loop iteration.
			if (loop ? (lastTime % endTime > time % endTime) : (lastTime < endTime && time >= endTime)) {
				var count = Math.floor(time / endTime);
				if (current.onComplete) current.onComplete(i, count);
				if (this.onComplete) this.onComplete(i, count);
			}

			current.lastTime = current.time;
		}
	},
	clearTracks: function () {
		for (var i = 0, n = this.tracks.length; i < n; i++)
			this.clearTrack(i);
		this.tracks.length = 0; 
	},
	clearTrack: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return;
		var current = this.tracks[trackIndex];
		if (!current) return;

		if (current.onEnd) current.onEnd(trackIndex);
		if (this.onEnd) this.onEnd(trackIndex);

		this.tracks[trackIndex] = null;
	},
	_expandToIndex: function (index) {
		if (index < this.tracks.length) return this.tracks[index];
		while (index >= this.tracks.length)
			this.tracks.push(null);
		return null;
	},
	setCurrent: function (index, entry) {
		var current = this._expandToIndex(index);
		if (current) {
			var previous = current.previous;
			current.previous = null;

			if (current.onEnd) current.onEnd(index);
			if (this.onEnd) this.onEnd(index);

			entry.mixDuration = this.data.getMix(current.animation, entry.animation);
			if (entry.mixDuration > 0) {
				entry.mixTime = 0;
				// If a mix is in progress, mix from the closest animation.
				if (previous && current.mixTime / current.mixDuration < 0.5)
					entry.previous = previous;
				else
					entry.previous = current;
			}
		}

		this.tracks[index] = entry;

		if (entry.onStart) entry.onStart(index);
		if (this.onStart) this.onStart(index);
	},
	setAnimationByName: function (trackIndex, animationName, loop) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.setAnimation(trackIndex, animation, loop);
	},
	/** Set the current animation. Any queued animations are cleared. */
	setAnimation: function (trackIndex, animation, loop) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;
		this.setCurrent(trackIndex, entry);
		return entry;
	},
	addAnimationByName: function (trackIndex, animationName, loop, delay) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.addAnimation(trackIndex, animation, loop, delay);
	},
	/** Adds an animation to be played delay seconds after the current or last queued animation.
	 * @param delay May be <= 0 to use duration of previous animation minus any mix duration plus the negative delay. */
	addAnimation: function (trackIndex, animation, loop, delay) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;

		var last = this._expandToIndex(trackIndex);
		if (last) {
			while (last.next)
				last = last.next;
			last.next = entry;
		} else
			this.tracks[trackIndex] = entry;

		if (delay <= 0) {
			if (last)
				delay += last.endTime - this.data.getMix(last.animation, animation);
			else
				delay = 0;
		}
		entry.delay = delay;

		return entry;
	},
	/** May be null. */
	getCurrent: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return null;
		return this.tracks[trackIndex];
	}
};

spine.SkeletonJson = function (attachmentLoader) {
	this.attachmentLoader = attachmentLoader;
};
spine.SkeletonJson.prototype = {
	scale: 1,
	readSkeletonData: function (root, name) {
		var skeletonData = new spine.SkeletonData();
		skeletonData.name = name;

		// Skeleton.
		var skeletonMap = root["skeleton"];
		if (skeletonMap) {
			skeletonData.hash = skeletonMap["hash"];
			skeletonData.version = skeletonMap["spine"];
			skeletonData.width = skeletonMap["width"] || 0;
			skeletonData.height = skeletonMap["height"] || 0;
		}

		// Bones.
		var bones = root["bones"];
		for (var i = 0, n = bones.length; i < n; i++) {
			var boneMap = bones[i];
			var parent = null;
			if (boneMap["parent"]) {
				parent = skeletonData.findBone(boneMap["parent"]);
				if (!parent) throw "Parent bone not found: " + boneMap["parent"];
			}
			var boneData = new spine.BoneData(boneMap["name"], parent);
			boneData.length = (boneMap["length"] || 0) * this.scale;
			boneData.x = (boneMap["x"] || 0) * this.scale;
			boneData.y = (boneMap["y"] || 0) * this.scale;
			boneData.rotation = (boneMap["rotation"] || 0);
			boneData.scaleX = boneMap.hasOwnProperty("scaleX") ? boneMap["scaleX"] : 1;
			boneData.scaleY = boneMap.hasOwnProperty("scaleY") ? boneMap["scaleY"] : 1;
			boneData.inheritScale = boneMap.hasOwnProperty("inheritScale") ? boneMap["inheritScale"] : true;
			boneData.inheritRotation = boneMap.hasOwnProperty("inheritRotation") ? boneMap["inheritRotation"] : true;
			skeletonData.bones.push(boneData);
		}

		// IK constraints.
		var ik = root["ik"];
		if (ik) {
			for (var i = 0, n = ik.length; i < n; i++) {
				var ikMap = ik[i];
				var ikConstraintData = new spine.IkConstraintData(ikMap["name"]);

				var bones = ikMap["bones"];
				for (var ii = 0, nn = bones.length; ii < nn; ii++) {
					var bone = skeletonData.findBone(bones[ii]);
					if (!bone) throw "IK bone not found: " + bones[ii];
					ikConstraintData.bones.push(bone);
				}

				ikConstraintData.target = skeletonData.findBone(ikMap["target"]);
				if (!ikConstraintData.target) throw "Target bone not found: " + ikMap["target"];

				ikConstraintData.bendDirection = (!ikMap.hasOwnProperty("bendPositive") || ikMap["bendPositive"]) ? 1 : -1;
				ikConstraintData.mix = ikMap.hasOwnProperty("mix") ? ikMap["mix"] : 1;

				skeletonData.ikConstraints.push(ikConstraintData);
			}
		}

		// Slots.
		var slots = root["slots"];
		for (var i = 0, n = slots.length; i < n; i++) {
			var slotMap = slots[i];
			var boneData = skeletonData.findBone(slotMap["bone"]);
			if (!boneData) throw "Slot bone not found: " + slotMap["bone"];
			var slotData = new spine.SlotData(slotMap["name"], boneData);

			var color = slotMap["color"];
			if (color) {
				slotData.r = this.toColor(color, 0);
				slotData.g = this.toColor(color, 1);
				slotData.b = this.toColor(color, 2);
				slotData.a = this.toColor(color, 3);
			}

			slotData.attachmentName = slotMap["attachment"];
			slotData.blendMode = spine.BlendMode[slotMap["blend"] || "normal"];

			skeletonData.slots.push(slotData);
		}

		// Skins.
		var skins = root["skins"];
		for (var skinName in skins) {
			if (!skins.hasOwnProperty(skinName)) continue;
			var skinMap = skins[skinName];
			var skin = new spine.Skin(skinName);
			for (var slotName in skinMap) {
				if (!skinMap.hasOwnProperty(slotName)) continue;
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var slotEntry = skinMap[slotName];
				for (var attachmentName in slotEntry) {
					if (!slotEntry.hasOwnProperty(attachmentName)) continue;
					var attachment = this.readAttachment(skin, attachmentName, slotEntry[attachmentName]);
					if (attachment) skin.addAttachment(slotIndex, attachmentName, attachment);
				}
			}
			skeletonData.skins.push(skin);
			if (skin.name == "default") skeletonData.defaultSkin = skin;
		}

		// Events.
		var events = root["events"];
		for (var eventName in events) {
			if (!events.hasOwnProperty(eventName)) continue;
			var eventMap = events[eventName];
			var eventData = new spine.EventData(eventName);
			eventData.intValue = eventMap["int"] || 0;
			eventData.floatValue = eventMap["float"] || 0;
			eventData.stringValue = eventMap["string"] || null;
			skeletonData.events.push(eventData);
		}

		// Animations.
		var animations = root["animations"];
		for (var animationName in animations) {
			if (!animations.hasOwnProperty(animationName)) continue;
			this.readAnimation(animationName, animations[animationName], skeletonData);
		}

		return skeletonData;
	},
	readAttachment: function (skin, name, map) {
		name = map["name"] || name;

		var type = spine.AttachmentType[map["type"] || "region"];
		var path = map["path"] || name;
		
		var scale = this.scale;
		if (type == spine.AttachmentType.region) {
			var region = this.attachmentLoader.newRegionAttachment(skin, name, path);
			if (!region) return null;
			region.path = path;
			region.x = (map["x"] || 0) * scale;
			region.y = (map["y"] || 0) * scale;
			region.scaleX = map.hasOwnProperty("scaleX") ? map["scaleX"] : 1;
			region.scaleY = map.hasOwnProperty("scaleY") ? map["scaleY"] : 1;
			region.rotation = map["rotation"] || 0;
			region.width = (map["width"] || 0) * scale;
			region.height = (map["height"] || 0) * scale;

			var color = map["color"];
			if (color) {
				region.r = this.toColor(color, 0);
				region.g = this.toColor(color, 1);
				region.b = this.toColor(color, 2);
				region.a = this.toColor(color, 3);
			}

			region.updateOffset();
			return region;
		} else if (type == spine.AttachmentType.mesh) {
			var mesh = this.attachmentLoader.newMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path; 
			mesh.vertices = this.getFloatArray(map, "vertices", scale);
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = this.getFloatArray(map, "uvs", 1);
			mesh.updateUVs();

			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}

			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.skinnedmesh) {
			var mesh = this.attachmentLoader.newSkinnedMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path;

			var uvs = this.getFloatArray(map, "uvs", 1);
			var vertices = this.getFloatArray(map, "vertices", 1);
			var weights = [];
			var bones = [];
			for (var i = 0, n = vertices.length; i < n; ) {
				var boneCount = vertices[i++] | 0;
				bones[bones.length] = boneCount;
				for (var nn = i + boneCount * 4; i < nn; ) {
					bones[bones.length] = vertices[i];
					weights[weights.length] = vertices[i + 1] * scale;
					weights[weights.length] = vertices[i + 2] * scale;
					weights[weights.length] = vertices[i + 3];
					i += 4;
				}
			}
			mesh.bones = bones;
			mesh.weights = weights;
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = uvs;
			mesh.updateUVs();
			
			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}
			
			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.boundingbox) {
			var attachment = this.attachmentLoader.newBoundingBoxAttachment(skin, name);
			var vertices = map["vertices"];
			for (var i = 0, n = vertices.length; i < n; i++)
				attachment.vertices.push(vertices[i] * scale);
			return attachment;
		}
		throw "Unknown attachment type: " + type;
	},
	readAnimation: function (name, map, skeletonData) {
		var timelines = [];
		var duration = 0;

		var slots = map["slots"];
		for (var slotName in slots) {
			if (!slots.hasOwnProperty(slotName)) continue;
			var slotMap = slots[slotName];
			var slotIndex = skeletonData.findSlotIndex(slotName);

			for (var timelineName in slotMap) {
				if (!slotMap.hasOwnProperty(timelineName)) continue;
				var values = slotMap[timelineName];
				if (timelineName == "color") {
					var timeline = new spine.ColorTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var color = valueMap["color"];
						var r = this.toColor(color, 0);
						var g = this.toColor(color, 1);
						var b = this.toColor(color, 2);
						var a = this.toColor(color, 3);
						timeline.setFrame(frameIndex, valueMap["time"], r, g, b, a);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 5 - 5]);

				} else if (timelineName == "attachment") {
					var timeline = new spine.AttachmentTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex++, valueMap["time"], valueMap["name"]);
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);

				} else
					throw "Invalid timeline type for a slot: " + timelineName + " (" + slotName + ")";
			}
		}

		var bones = map["bones"];
		for (var boneName in bones) {
			if (!bones.hasOwnProperty(boneName)) continue;
			var boneIndex = skeletonData.findBoneIndex(boneName);
			if (boneIndex == -1) throw "Bone not found: " + boneName;
			var boneMap = bones[boneName];

			for (var timelineName in boneMap) {
				if (!boneMap.hasOwnProperty(timelineName)) continue;
				var values = boneMap[timelineName];
				if (timelineName == "rotate") {
					var timeline = new spine.RotateTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap["angle"]);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);

				} else if (timelineName == "translate" || timelineName == "scale") {
					var timeline;
					var timelineScale = 1;
					if (timelineName == "scale")
						timeline = new spine.ScaleTimeline(values.length);
					else {
						timeline = new spine.TranslateTimeline(values.length);
						timelineScale = this.scale;
					}
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var x = (valueMap["x"] || 0) * timelineScale;
						var y = (valueMap["y"] || 0) * timelineScale;
						timeline.setFrame(frameIndex, valueMap["time"], x, y);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 3 - 3]);

				} else if (timelineName == "flipX" || timelineName == "flipY") {
					var x = timelineName == "flipX";
					var timeline = x ? new spine.FlipXTimeline(values.length) : new spine.FlipYTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var field = x ? "x" : "y";
					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap[field] || false);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);
				} else
					throw "Invalid timeline type for a bone: " + timelineName + " (" + boneName + ")";
			}
		}

		var ikMap = map["ik"];
		for (var ikConstraintName in ikMap) {
			if (!ikMap.hasOwnProperty(ikConstraintName)) continue;
			var ikConstraint = skeletonData.findIkConstraint(ikConstraintName);
			var values = ikMap[ikConstraintName];
			var timeline = new spine.IkConstraintTimeline(values.length);
			timeline.ikConstraintIndex = skeletonData.ikConstraints.indexOf(ikConstraint);
			var frameIndex = 0;
			for (var i = 0, n = values.length; i < n; i++) {
				var valueMap = values[i];
				var mix = valueMap.hasOwnProperty("mix") ? valueMap["mix"] : 1;
				var bendDirection = (!valueMap.hasOwnProperty("bendPositive") || valueMap["bendPositive"]) ? 1 : -1;
				timeline.setFrame(frameIndex, valueMap["time"], mix, bendDirection);
				this.readCurve(timeline, frameIndex, valueMap);
				frameIndex++;
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.frameCount * 3 - 3]);
		}

		var ffd = map["ffd"];
		for (var skinName in ffd) {
			var skin = skeletonData.findSkin(skinName);
			var slotMap = ffd[skinName];
			for (slotName in slotMap) {
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var meshMap = slotMap[slotName];
				for (var meshName in meshMap) {
					var values = meshMap[meshName];
					var timeline = new spine.FfdTimeline(values.length);
					var attachment = skin.getAttachment(slotIndex, meshName);
					if (!attachment) throw "FFD attachment not found: " + meshName;
					timeline.slotIndex = slotIndex;
					timeline.attachment = attachment;
					
					var isMesh = attachment.type == spine.AttachmentType.mesh;
					var vertexCount;
					if (isMesh)
						vertexCount = attachment.vertices.length;
					else
						vertexCount = attachment.weights.length / 3 * 2;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var vertices;
						if (!valueMap["vertices"]) {
							if (isMesh)
								vertices = attachment.vertices;
							else {
								vertices = [];
								vertices.length = vertexCount;
							}
						} else {
							var verticesValue = valueMap["vertices"];
							var vertices = [];
							vertices.length = vertexCount;
							var start = valueMap["offset"] || 0;
							var nn = verticesValue.length;
							if (this.scale == 1) {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii];
							} else {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii] * this.scale;
							}
							if (isMesh) {
								var meshVertices = attachment.vertices;
								for (var ii = 0, nn = vertices.length; ii < nn; ii++)
									vertices[ii] += meshVertices[ii];
							}
						}
						
						timeline.setFrame(frameIndex, valueMap["time"], vertices);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines[timelines.length] = timeline;
					duration = Math.max(duration, timeline.frames[timeline.frameCount - 1]);
				}
			}
		}

		var drawOrderValues = map["drawOrder"];
		if (!drawOrderValues) drawOrderValues = map["draworder"];
		if (drawOrderValues) {
			var timeline = new spine.DrawOrderTimeline(drawOrderValues.length);
			var slotCount = skeletonData.slots.length;
			var frameIndex = 0;
			for (var i = 0, n = drawOrderValues.length; i < n; i++) {
				var drawOrderMap = drawOrderValues[i];
				var drawOrder = null;
				if (drawOrderMap["offsets"]) {
					drawOrder = [];
					drawOrder.length = slotCount;
					for (var ii = slotCount - 1; ii >= 0; ii--)
						drawOrder[ii] = -1;
					var offsets = drawOrderMap["offsets"];
					var unchanged = [];
					unchanged.length = slotCount - offsets.length;
					var originalIndex = 0, unchangedIndex = 0;
					for (var ii = 0, nn = offsets.length; ii < nn; ii++) {
						var offsetMap = offsets[ii];
						var slotIndex = skeletonData.findSlotIndex(offsetMap["slot"]);
						if (slotIndex == -1) throw "Slot not found: " + offsetMap["slot"];
						// Collect unchanged items.
						while (originalIndex != slotIndex)
							unchanged[unchangedIndex++] = originalIndex++;
						// Set changed items.
						drawOrder[originalIndex + offsetMap["offset"]] = originalIndex++;
					}
					// Collect remaining unchanged items.
					while (originalIndex < slotCount)
						unchanged[unchangedIndex++] = originalIndex++;
					// Fill in unchanged items.
					for (var ii = slotCount - 1; ii >= 0; ii--)
						if (drawOrder[ii] == -1) drawOrder[ii] = unchanged[--unchangedIndex];
				}
				timeline.setFrame(frameIndex++, drawOrderMap["time"], drawOrder);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		var events = map["events"];
		if (events) {
			var timeline = new spine.EventTimeline(events.length);
			var frameIndex = 0;
			for (var i = 0, n = events.length; i < n; i++) {
				var eventMap = events[i];
				var eventData = skeletonData.findEvent(eventMap["name"]);
				if (!eventData) throw "Event not found: " + eventMap["name"];
				var event = new spine.Event(eventData);
				event.intValue = eventMap.hasOwnProperty("int") ? eventMap["int"] : eventData.intValue;
				event.floatValue = eventMap.hasOwnProperty("float") ? eventMap["float"] : eventData.floatValue;
				event.stringValue = eventMap.hasOwnProperty("string") ? eventMap["string"] : eventData.stringValue;
				timeline.setFrame(frameIndex++, eventMap["time"], event);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		skeletonData.animations.push(new spine.Animation(name, timelines, duration));
	},
	readCurve: function (timeline, frameIndex, valueMap) {
		var curve = valueMap["curve"];
		if (!curve) 
			timeline.curves.setLinear(frameIndex);
		else if (curve == "stepped")
			timeline.curves.setStepped(frameIndex);
		else if (curve instanceof Array)
			timeline.curves.setCurve(frameIndex, curve[0], curve[1], curve[2], curve[3]);
	},
	toColor: function (hexString, colorIndex) {
		if (hexString.length != 8) throw "Color hexidecimal length must be 8, recieved: " + hexString;
		return parseInt(hexString.substring(colorIndex * 2, (colorIndex * 2) + 2), 16) / 255;
	},
	getFloatArray: function (map, name, scale) {
		var list = map[name];
		var values = new spine.Float32Array(list.length);
		var i = 0, n = list.length;
		if (scale == 1) {
			for (; i < n; i++)
				values[i] = list[i];
		} else {
			for (; i < n; i++)
				values[i] = list[i] * scale;
		}
		return values;
	},
	getIntArray: function (map, name) {
		var list = map[name];
		var values = new spine.Uint16Array(list.length);
		for (var i = 0, n = list.length; i < n; i++)
			values[i] = list[i] | 0;
		return values;
	}
};

spine.Atlas = function (atlasText, textureLoader) {
	this.textureLoader = textureLoader;
	this.pages = [];
	this.regions = [];

	var reader = new spine.AtlasReader(atlasText);
	var tuple = [];
	tuple.length = 4;
	var page = null;
	while (true) {
		var line = reader.readLine();
		if (line === null) break;
		line = reader.trim(line);
		if (!line.length)
			page = null;
		else if (!page) {
			page = new spine.AtlasPage();
			page.name = line;

			if (reader.readTuple(tuple) == 2) { // size is only optional for an atlas packed with an old TexturePacker.
				page.width = parseInt(tuple[0]);
				page.height = parseInt(tuple[1]);
				reader.readTuple(tuple);
			}
			page.format = spine.Atlas.Format[tuple[0]];

			reader.readTuple(tuple);
			page.minFilter = spine.Atlas.TextureFilter[tuple[0]];
			page.magFilter = spine.Atlas.TextureFilter[tuple[1]];

			var direction = reader.readValue();
			page.uWrap = spine.Atlas.TextureWrap.clampToEdge;
			page.vWrap = spine.Atlas.TextureWrap.clampToEdge;
			if (direction == "x")
				page.uWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "y")
				page.vWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "xy")
				page.uWrap = page.vWrap = spine.Atlas.TextureWrap.repeat;

			textureLoader.load(page, line, this);

			this.pages.push(page);

		} else {
			var region = new spine.AtlasRegion();
			region.name = line;
			region.page = page;

			region.rotate = reader.readValue() == "true";

			reader.readTuple(tuple);
			var x = parseInt(tuple[0]);
			var y = parseInt(tuple[1]);

			reader.readTuple(tuple);
			var width = parseInt(tuple[0]);
			var height = parseInt(tuple[1]);

			region.u = x / page.width;
			region.v = y / page.height;
			if (region.rotate) {
				region.u2 = (x + height) / page.width;
				region.v2 = (y + width) / page.height;
			} else {
				region.u2 = (x + width) / page.width;
				region.v2 = (y + height) / page.height;
			}
			region.x = x;
			region.y = y;
			region.width = Math.abs(width);
			region.height = Math.abs(height);

			if (reader.readTuple(tuple) == 4) { // split is optional
				region.splits = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

				if (reader.readTuple(tuple) == 4) { // pad is optional, but only present with splits
					region.pads = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

					reader.readTuple(tuple);
				}
			}

			region.originalWidth = parseInt(tuple[0]);
			region.originalHeight = parseInt(tuple[1]);

			reader.readTuple(tuple);
			region.offsetX = parseInt(tuple[0]);
			region.offsetY = parseInt(tuple[1]);

			region.index = parseInt(reader.readValue());

			this.regions.push(region);
		}
	}
};
spine.Atlas.prototype = {
	findRegion: function (name) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++)
			if (regions[i].name == name) return regions[i];
		return null;
	},
	dispose: function () {
		var pages = this.pages;
		for (var i = 0, n = pages.length; i < n; i++)
			this.textureLoader.unload(pages[i].rendererObject);
	},
	updateUVs: function (page) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++) {
			var region = regions[i];
			if (region.page != page) continue;
			region.u = region.x / page.width;
			region.v = region.y / page.height;
			if (region.rotate) {
				region.u2 = (region.x + region.height) / page.width;
				region.v2 = (region.y + region.width) / page.height;
			} else {
				region.u2 = (region.x + region.width) / page.width;
				region.v2 = (region.y + region.height) / page.height;
			}
		}
	}
};

spine.Atlas.Format = {
	alpha: 0,
	intensity: 1,
	luminanceAlpha: 2,
	rgb565: 3,
	rgba4444: 4,
	rgb888: 5,
	rgba8888: 6
};

spine.Atlas.TextureFilter = {
	nearest: 0,
	linear: 1,
	mipMap: 2,
	mipMapNearestNearest: 3,
	mipMapLinearNearest: 4,
	mipMapNearestLinear: 5,
	mipMapLinearLinear: 6
};

spine.Atlas.TextureWrap = {
	mirroredRepeat: 0,
	clampToEdge: 1,
	repeat: 2
};

spine.AtlasPage = function () {};
spine.AtlasPage.prototype = {
	name: null,
	format: null,
	minFilter: null,
	magFilter: null,
	uWrap: null,
	vWrap: null,
	rendererObject: null,
	width: 0,
	height: 0
};

spine.AtlasRegion = function () {};
spine.AtlasRegion.prototype = {
	page: null,
	name: null,
	x: 0, y: 0,
	width: 0, height: 0,
	u: 0, v: 0, u2: 0, v2: 0,
	offsetX: 0, offsetY: 0,
	originalWidth: 0, originalHeight: 0,
	index: 0,
	rotate: false,
	splits: null,
	pads: null
};

spine.AtlasReader = function (text) {
	this.lines = text.split(/\r\n|\r|\n/);
};
spine.AtlasReader.prototype = {
	index: 0,
	trim: function (value) {
		return value.replace(/^\s+|\s+$/g, "");
	},
	readLine: function () {
		if (this.index >= this.lines.length) return null;
		return this.lines[this.index++];
	},
	readValue: function () {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		return this.trim(line.substring(colon + 1));
	},
	/** Returns the number of tuple values read (1, 2 or 4). */
	readTuple: function (tuple) {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		var i = 0, lastMatch = colon + 1;
		for (; i < 3; i++) {
			var comma = line.indexOf(",", lastMatch);
			if (comma == -1) break;
			tuple[i] = this.trim(line.substr(lastMatch, comma - lastMatch));
			lastMatch = comma + 1;
		}
		tuple[i] = this.trim(line.substring(lastMatch));
		return i + 1;
	}
};

spine.AtlasAttachmentLoader = function (atlas) {
	this.atlas = atlas;
};
spine.AtlasAttachmentLoader.prototype = {
	newRegionAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (region attachment: " + name + ")";
		var attachment = new spine.RegionAttachment(name);
		attachment.rendererObject = region;
		attachment.setUVs(region.u, region.v, region.u2, region.v2, region.rotate);
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (mesh attachment: " + name + ")";
		var attachment = new spine.MeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newSkinnedMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (skinned mesh attachment: " + name + ")";
		var attachment = new spine.SkinnedMeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newBoundingBoxAttachment: function (skin, name) {
		return new spine.BoundingBoxAttachment(name);
	}
};

spine.SkeletonBounds = function () {
	this.polygonPool = [];
	this.polygons = [];
	this.boundingBoxes = [];
};
spine.SkeletonBounds.prototype = {
	minX: 0, minY: 0, maxX: 0, maxY: 0,
	update: function (skeleton, updateAabb) {
		var slots = skeleton.slots;
		var slotCount = slots.length;
		var x = skeleton.x, y = skeleton.y;
		var boundingBoxes = this.boundingBoxes;
		var polygonPool = this.polygonPool;
		var polygons = this.polygons;

		boundingBoxes.length = 0;
		for (var i = 0, n = polygons.length; i < n; i++)
			polygonPool.push(polygons[i]);
		polygons.length = 0;

		for (var i = 0; i < slotCount; i++) {
			var slot = slots[i];
			var boundingBox = slot.attachment;
			if (boundingBox.type != spine.AttachmentType.boundingbox) continue;
			boundingBoxes.push(boundingBox);

			var poolCount = polygonPool.length, polygon;
			if (poolCount > 0) {
				polygon = polygonPool[poolCount - 1];
				polygonPool.splice(poolCount - 1, 1);
			} else
				polygon = [];
			polygons.push(polygon);

			polygon.length = boundingBox.vertices.length;
			boundingBox.computeWorldVertices(x, y, slot.bone, polygon);
		}

		if (updateAabb) this.aabbCompute();
	},
	aabbCompute: function () {
		var polygons = this.polygons;
		var minX = Number.MAX_VALUE, minY = Number.MAX_VALUE, maxX = Number.MIN_VALUE, maxY = Number.MIN_VALUE;
		for (var i = 0, n = polygons.length; i < n; i++) {
			var vertices = polygons[i];
			for (var ii = 0, nn = vertices.length; ii < nn; ii += 2) {
				var x = vertices[ii];
				var y = vertices[ii + 1];
				minX = Math.min(minX, x);
				minY = Math.min(minY, y);
				maxX = Math.max(maxX, x);
				maxY = Math.max(maxY, y);
			}
		}
		this.minX = minX;
		this.minY = minY;
		this.maxX = maxX;
		this.maxY = maxY;
	},
	/** Returns true if the axis aligned bounding box contains the point. */
	aabbContainsPoint: function (x, y) {
		return x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY;
	},
	/** Returns true if the axis aligned bounding box intersects the line segment. */
	aabbIntersectsSegment: function (x1, y1, x2, y2) {
		var minX = this.minX, minY = this.minY, maxX = this.maxX, maxY = this.maxY;
		if ((x1 <= minX && x2 <= minX) || (y1 <= minY && y2 <= minY) || (x1 >= maxX && x2 >= maxX) || (y1 >= maxY && y2 >= maxY))
			return false;
		var m = (y2 - y1) / (x2 - x1);
		var y = m * (minX - x1) + y1;
		if (y > minY && y < maxY) return true;
		y = m * (maxX - x1) + y1;
		if (y > minY && y < maxY) return true;
		var x = (minY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		x = (maxY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		return false;
	},
	/** Returns true if the axis aligned bounding box intersects the axis aligned bounding box of the specified bounds. */
	aabbIntersectsSkeleton: function (bounds) {
		return this.minX < bounds.maxX && this.maxX > bounds.minX && this.minY < bounds.maxY && this.maxY > bounds.minY;
	},
	/** Returns the first bounding box attachment that contains the point, or null. When doing many checks, it is usually more
	 * efficient to only call this method if {@link #aabbContainsPoint(float, float)} returns true. */
	containsPoint: function (x, y) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (this.polygonContainsPoint(polygons[i], x, y)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns the first bounding box attachment that contains the line segment, or null. When doing many checks, it is usually
	 * more efficient to only call this method if {@link #aabbIntersectsSegment(float, float, float, float)} returns true. */
	intersectsSegment: function (x1, y1, x2, y2) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (polygons[i].intersectsSegment(x1, y1, x2, y2)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns true if the polygon contains the point. */
	polygonContainsPoint: function (polygon, x, y) {
		var nn = polygon.length;
		var prevIndex = nn - 2;
		var inside = false;
		for (var ii = 0; ii < nn; ii += 2) {
			var vertexY = polygon[ii + 1];
			var prevY = polygon[prevIndex + 1];
			if ((vertexY < y && prevY >= y) || (prevY < y && vertexY >= y)) {
				var vertexX = polygon[ii];
				if (vertexX + (y - vertexY) / (prevY - vertexY) * (polygon[prevIndex] - vertexX) < x) inside = !inside;
			}
			prevIndex = ii;
		}
		return inside;
	},
	/** Returns true if the polygon contains the line segment. */
	polygonIntersectsSegment: function (polygon, x1, y1, x2, y2) {
		var nn = polygon.length;
		var width12 = x1 - x2, height12 = y1 - y2;
		var det1 = x1 * y2 - y1 * x2;
		var x3 = polygon[nn - 2], y3 = polygon[nn - 1];
		for (var ii = 0; ii < nn; ii += 2) {
			var x4 = polygon[ii], y4 = polygon[ii + 1];
			var det2 = x3 * y4 - y3 * x4;
			var width34 = x3 - x4, height34 = y3 - y4;
			var det3 = width12 * height34 - height12 * width34;
			var x = (det1 * width34 - width12 * det2) / det3;
			if (((x >= x3 && x <= x4) || (x >= x4 && x <= x3)) && ((x >= x1 && x <= x2) || (x >= x2 && x <= x1))) {
				var y = (det1 * height34 - height12 * det2) / det3;
				if (((y >= y3 && y <= y4) || (y >= y4 && y <= y3)) && ((y >= y1 && y <= y2) || (y >= y2 && y <= y1))) return true;
			}
			x3 = x4;
			y3 = y4;
		}
		return false;
	},
	getPolygon: function (attachment) {
		var index = this.boundingBoxes.indexOf(attachment);
		return index == -1 ? null : this.polygons[index];
	},
	getWidth: function () {
		return this.maxX - this.minX;
	},
	getHeight: function () {
		return this.maxY - this.minY;
	}
};
var a,aa=document.getElementById("canvasBackground"),ba=!1;function ca(b,c){var d=b.userAgent.match(c);return d&&1<d.length&&d[1]||""}
var f=new function(){this.userAgent=void 0;void 0===this.userAgent&&(this.userAgent=void 0!==navigator?navigator.userAgent:"");var b=ca(this,/(ipod|iphone|ipad)/i).toLowerCase(),c=!/like android/i.test(this.userAgent)&&/android/i.test(this.userAgent),d=ca(this,/version\/(\d+(\.\d+)?)/i),e=/tablet/i.test(this.userAgent),g=!e&&/[^-]mobi/i.test(this.userAgent);this.ja={};this.Ib={};this.Ba={};/opera|opr/i.test(this.userAgent)?(this.name="Opera",this.ja.opera=!0,this.ja.version=d||ca(this,/(?:opera|opr)[\s\/](\d+(\.\d+)?)/i)):
/windows phone/i.test(this.userAgent)?(this.name="Windows Phone",this.Ib.og=!0,this.ja.Tv=!0,this.ja.version=ca(this,/iemobile\/(\d+(\.\d+)?)/i)):/msie|trident/i.test(this.userAgent)?(this.name="Internet Explorer",this.ja.Tv=!0,this.ja.version=ca(this,/(?:msie |rv:)(\d+(\.\d+)?)/i)):/chrome|crios|crmo/i.test(this.userAgent)?(this.name="Chrome",this.ja.chrome=!0,this.ja.version=ca(this,/(?:chrome|crios|crmo)\/(\d+(\.\d+)?)/i)):b?(this.name="iphone"==b?"iPhone":"ipad"==b?"iPad":"iPod",d&&(this.ja.version=
d)):/sailfish/i.test(this.userAgent)?(this.name="Sailfish",this.ja.NT=!0,this.ja.version=ca(this,/sailfish\s?browser\/(\d+(\.\d+)?)/i)):/seamonkey\//i.test(this.userAgent)?(this.name="SeaMonkey",this.ja.TT=!0,this.ja.version=ca(this,/seamonkey\/(\d+(\.\d+)?)/i)):/firefox|iceweasel/i.test(this.userAgent)?(this.name="Firefox",this.ja.oA=!0,this.ja.version=ca(this,/(?:firefox|iceweasel)[ \/](\d+(\.\d+)?)/i),/\((mobile|tablet);[^\)]*rv:[\d\.]+\)/i.test(this.userAgent)&&(this.Ib.CR=!0)):/silk/i.test(this.userAgent)?
(this.name="Amazon Silk",this.ja.VC=!0,this.ja.version=ca(this,/silk\/(\d+(\.\d+)?)/i)):c?(this.name="Android",this.ja.Nx=!0,this.ja.version=d):/phantom/i.test(this.userAgent)?(this.name="PhantomJS",this.ja.jT=!0,this.ja.version=ca(this,/phantomjs\/(\d+(\.\d+)?)/i)):/blackberry|\bbb\d+/i.test(this.userAgent)||/rim\stablet/i.test(this.userAgent)?(this.name="BlackBerry",this.ja.mz=!0,this.ja.version=d||ca(this,/blackberry[\d]+\/(\d+(\.\d+)?)/i)):/(web|hpw)os/i.test(this.userAgent)?(this.name="WebOS",
this.ja.ND=!0,this.ja.version=d||ca(this,/w(?:eb)?osbrowser\/(\d+(\.\d+)?)/i),/touchpad\//i.test(this.userAgent)&&(this.Ba.kg=!0)):/bada/i.test(this.userAgent)?(this.name="Bada",this.ja.iz=!0,this.ja.version=ca(this,/dolfin\/(\d+(\.\d+)?)/i)):/tizen/i.test(this.userAgent)?(this.name="Tizen",this.ja.EP=!0,this.ja.version=ca(this,/(?:tizen\s?)?browser\/(\d+(\.\d+)?)/i)||d):/safari/i.test(this.userAgent)&&(this.name="Safari",this.ja.EC=!0,this.ja.version=d);/(apple)?webkit/i.test(this.userAgent)?(this.name=
this.name||"Webkit",this.ja.BU=!0,!this.ja.version&&d&&(this.ja.version=d)):!this.opera&&/gecko\//i.test(this.userAgent)&&(this.name=this.name||"Gecko",this.ja.NR=!0,this.ja.version=this.ja.version||ca(this,/gecko\/(\d+(\.\d+)?)/i));c||this.VC?this.Ib.RQ=!0:b&&(this.Ib.Nq=!0);d="";b?(d=ca(this,/os (\d+([_\s]\d+)*) like mac os x/i),d=d.replace(/[_\s]/g,".")):c?d=ca(this,/android[ \/-](\d+(\.\d+)*)/i):this.og?d=ca(this,/windows phone (?:os)?\s?(\d+(\.\d+)*)/i):this.ND?d=ca(this,/(?:web|hpw)os\/(\d+(\.\d+)*)/i):
this.mz?d=ca(this,/rim\stablet\sos\s(\d+(\.\d+)*)/i):this.iz?d=ca(this,/bada\/(\d+(\.\d+)*)/i):this.EP&&(d=ca(this,/tizen[\/\s](\d+(\.\d+)*)/i));d&&(this.Ib.version=d);d=d.split(".")[0];if(e||"ipad"==b||c&&(3==d||4==d&&!g)||this.VC)this.Ba.vf=!0;else if(g||"iphone"==b||"ipod"==b||c||this.mz||this.ND||this.iz)this.Ba.ve=!0;this.Zu={Km:!1,dn:!1,x:!1};this.Tv&&10<=this.ja.version||this.chrome&&20<=this.ja.version||this.oA&&20<=this.ja.version||this.EC&&6<=this.ja.version||this.opera&&10<=this.ja.version||
this.Nq&&this.Ib.version&&6<=this.Ib.version.split(".")[0]?this.Zu.Km=!0:this.Tv&&10>this.ja.version||this.chrome&&20>this.ja.version||this.oA&&20>this.ja.version||this.EC&&6>this.ja.version||this.opera&&10>this.ja.version||this.Nq&&this.Ib.version&&6>this.Ib.version.split(".")[0]?this.Zu.dn=!0:this.Zu.x=!0;try{this.ja.xp=this.ja.version?parseFloat(this.ja.version.match(/\d+(\.\d+)?/)[0],10):0}catch(h){this.ja.xp=0}try{this.Ib.xp=this.Ib.version?parseFloat(this.Ib.version.match(/\d+(\.\d+)?/)[0],
10):0}catch(l){this.Ib.xp=0}};function k(b,c){this.x=b;this.y=c}a=k.prototype;a.length=function(){return Math.sqrt(this.x*this.x+this.y*this.y)};a.bu=function(b){var c=this.x-b.x;b=this.y-b.y;return Math.sqrt(c*c+b*b)};a.direction=function(){return 180*Math.atan2(-this.y,this.x)/Math.PI};a.cl=function(){return new k(this.x,this.y)};a.add=function(b){return new k(this.x+b.x,this.y+b.y)};a.scale=function(b){return new k(b*this.x,b*this.y)};
a.rotate=function(b){var c=Math.sin(b*Math.PI/180);b=Math.cos(b*Math.PI/180);return new k(b*this.x+c*this.y,-c*this.x+b*this.y)};a.qn=function(b){return this.x*b.x+this.y*b.y};a.normalize=function(){var b=Math.sqrt(this.x*this.x+this.y*this.y);return 0===b?new k(0,0):new k(this.x/b,this.y/b)};
a.du=function(b,c,d){var e=Math.min(8,this.length()/4),g;g=this.normalize().scale(2*e);g=new k(this.x-g.x,this.y-g.y);var h=g.add((new k(this.y,-this.x)).normalize().scale(e)),e=g.add((new k(this.y,-this.x)).normalize().scale(-e)),l=p.context;l.strokeStyle=d;l.beginPath();l.moveTo(b,c);l.lineTo(b+g.x,c+g.y);l.lineTo(b+h.x,c+h.y);l.lineTo(b+this.x,c+this.y);l.lineTo(b+e.x,c+e.y);l.lineTo(b+g.x,c+g.y);l.stroke()};
function da(b){this.Wn=4294967296;this.Km=1664525;this.dn=1013904223;this.state=void 0===b?Math.floor(Math.random()*(this.Wn-1)):b}da.prototype.cl=function(){var b=new da;b.Wn=this.Wn;b.Km=this.Km;b.dn=this.dn;b.state=this.state;return b};da.prototype.random=function(b){var c=1;void 0!==b&&(c=b);this.state=(this.Km*this.state+this.dn)%this.Wn;return this.state/this.Wn*c};function ea(b,c){var d=1;void 0!==c&&(d=c);return Math.floor(b.random(d+1))}var fa=new da;
function ga(){this.lE="";this.ys=[];this.Im=[];this.Tk=[];this.vm=[];this.Cf=[];ha(this,"start");ha(this,"load");ha(this,"game")}function ha(b,c){b.Cf[c]||(b.Im[c]=0,b.Tk[c]=0,b.vm[c]=0,b.Cf[c]=[],b.ys[c]=!1)}a=ga.prototype;a.loaded=function(b){return this.Cf[b]?this.Tk[b]:0};a.complete=function(b){return this.Cf[b]?this.Tk[b]+this.vm[b]===this.Im[b]:!0};a.Pl=function(b){return this.Cf[b]?100*(this.Tk[b]+this.vm[b])/this.Im[b]:100};
a.Vf=function(b){this.Tk[b]+=1;this.complete(b)&&ia("Load Complete",{HB:b})};a.Oi=function(b){this.vm[b]+=1;ia("Load Failed",{HB:b})};function ka(b,c,d){var e=la;e.Cf[c]||ha(e,c);e.Cf[c].push(b);e.Im[c]+=d}a.Rh=function(b){var c;if(!this.ys[b])if(this.ys[b]=!0,this.Cf[b]&&0!==this.Cf[b].length)for(c=0;c<this.Cf[b].length;c+=1)this.Cf[b][c].Rh(b,this.lE);else ia("Load Complete",{HB:b})};var la=new ga;function ma(b){this.context=this.canvas=void 0;this.height=this.width=0;b&&na(this,b)}
function na(b,c){b.canvas=c;b.context=c.getContext("2d");b.width=c.width;b.height=c.height}ma.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height);this.context.beginPath();this.context.moveTo(0,0);this.context.lineTo(-1,-1);this.context.closePath();this.context.stroke()};ma.prototype.clearColor=function(b){var c=this.context.fillStyle;this.context.fillStyle=b;this.context.fillRect(0,0,this.width,this.height);this.context.fillStyle=c};
function oa(b,c,d,e,g,h,l){var m=p;m.context.save();!1===h?(m.context.fillStyle=g,m.context.fillRect(b,c,d,e)):!0===h?(m.context.strokeStyle=g,m.context.strokeRect(b,c,d,e)):(void 0!==g&&(m.context.fillStyle=g,m.context.fillRect(b,c,d,e)),void 0!==h&&(l&&(m.context.lineWidth=l),m.context.strokeStyle=h,m.context.strokeRect(b,c,d,e)));m.context.restore()}
function pa(b,c,d,e,g,h,l){b.context.save();void 0===h&&(h=8);e<2*h&&(h=Math.floor(e/2));g<2*h&&(h=Math.floor(g/2));b.context.beginPath();b.context.moveTo(c+h,d);b.context.arcTo(c+e,d,c+e,d+g,h);b.context.arcTo(c+e,d+g,c,d+g,h);b.context.arcTo(c,d+g,c,d,h);b.context.arcTo(c,d,c+e,d,h);b.context.closePath();"black"===!1?(b.context.fillStyle=l,b.context.fill()):("black"===!0?b.context.strokeStyle=l:(void 0!==l&&(b.context.fillStyle=l,b.context.fill()),b.context.strokeStyle="black"),b.context.stroke());
b.context.restore()}function qa(b,c,d,e){var g;b.context.save();b.context.beginPath();b.context.moveTo(c[0],d[0]);for(g=1;g<c.length;g+=1)b.context.lineTo(c[g],d[g]);b.context.closePath();void 0!==e&&(b.context.fillStyle=e,b.context.fill());b.context.restore()}
ma.prototype.le=function(b,c,d,e,g,h,l){this.context.save();this.context.font=g;!1===h?(this.context.fillStyle=e,this.context.fillText(b,c,d)):!0===h?(this.context.strokeStyle=e,this.context.strokeText(b,c,d)):(void 0!==e&&(this.context.fillStyle=e,this.context.fillText(b,c,d)),void 0!==h&&(l&&(this.context.lineWidth=l),this.context.strokeStyle=h,this.context.strokeText(b,c,d)));this.context.restore()};ma.prototype.Fk=function(b,c){this.context.font=c;return this.context.measureText(b).width};
var p=new ma(aa);function ra(b,c,d){this.name=b;this.Y=c;this.bL=d;this.Ze=[];this.Eu=[];ka(this,this.bL,this.Y)}ra.prototype.Rh=function(b,c){function d(){la.Oi(b)}function e(){la.Vf(b)}var g,h;for(g=0;g<this.Ze.length;g+=1)h=this.Eu[g],0!==h.toLowerCase().indexOf("http:")&&0!==h.toLowerCase().indexOf("https:")&&(h=c+h),this.Ze[g].src=h,this.Ze[g].addEventListener("load",e,!1),this.Ze[g].addEventListener("error",d,!1)};
ra.prototype.complete=function(){var b;for(b=0;b<this.Ze.length;b+=1)if(!this.Ze[b].complete||0===this.Ze[b].width)return!1;return!0};function sa(b,c,d){0<=c&&c<b.Y&&(b.Ze[c]=new Image,b.Eu[c]=d)}ra.prototype.e=function(b,c){0<=b&&b<this.Y&&(this.Ze[b]=c,this.Eu[b]="")};ra.prototype.yb=function(b,c,d,e,g,h,l,m,n){this.Ze[b]&&this.Ze[b].complete&&(void 0===m&&(m=e),void 0===n&&(n=g),0>=e||0>=g||0!==Math.round(m)&&0!==Math.round(n)&&p.context.drawImage(this.Ze[b],c,d,e,g,h,l,m,n))};
function q(b,c,d,e,g,h,l,m,n,s){this.name=b;this.Xh=c;this.Y=d;this.width=e;this.height=g;this.Qa=h;this.Sa=l;this.ni=m;this.mi=n;this.lC=s;this.Sh=[];this.Th=[];this.Vh=[];this.Wg=[];this.Vg=[];this.Uh=[];this.Wh=[]}a=q.prototype;a.e=function(b,c,d,e,g,h,l,m){0<=b&&b<this.Y&&(this.Sh[b]=c,this.Th[b]=d,this.Vh[b]=e,this.Wg[b]=g,this.Vg[b]=h,this.Uh[b]=l,this.Wh[b]=m)};
function ta(b,c,d,e){var g;g=new ra(b+"_Texture",1,b);sa(g,0,c);c=new q(b,g,1,d,e,0,0,d,e,1);c.e(0,0,0,0,d,e,0,0);la.Rh(b);return c}a.complete=function(){return this.Xh.complete()};a.ma=function(b,c,d){b=(Math.round(b)%this.Y+this.Y)%this.Y;this.Xh.yb(this.Sh[b],this.Th[b],this.Vh[b],this.Wg[b],this.Vg[b],c-this.Qa+this.Uh[b],d-this.Sa+this.Wh[b])};
a.ui=function(b,c,d,e){var g=p.context,h=g.globalAlpha;g.globalAlpha=e;b=(Math.round(b)%this.Y+this.Y)%this.Y;this.Xh.yb(this.Sh[b],this.Th[b],this.Vh[b],this.Wg[b],this.Vg[b],c-this.Qa+this.Uh[b],d-this.Sa+this.Wh[b]);g.globalAlpha=h};
a.Ha=function(b,c,d,e,g,h,l){var m=p.context;1E-4>Math.abs(e)||1E-4>Math.abs(g)||(b=(Math.round(b)%this.Y+this.Y)%this.Y,m.save(),m.translate(c,d),m.rotate(-h*Math.PI/180),m.scale(e,g),m.globalAlpha=l,this.Xh.yb(this.Sh[b],this.Th[b],this.Vh[b],this.Wg[b],this.Vg[b],this.Uh[b]-this.Qa,this.Wh[b]-this.Sa),m.restore())};
a.Of=function(b,c,d,e,g,h){var l=p.context,m=l.globalAlpha;0!==this.width&&0!==this.height&&(b=(Math.round(b)%this.Y+this.Y)%this.Y,l.globalAlpha=h,e/=this.width,g/=this.height,this.Xh.yb(this.Sh[b],this.Th[b],this.Vh[b],this.Wg[b],this.Vg[b],c+e*this.Uh[b],d+g*this.Wh[b],e*this.Wg[b],g*this.Vg[b]),l.globalAlpha=m)};
a.Jc=function(b,c,d,e,g,h,l,m,n,s){var w,y,D,t,z,A,B,Y,ja,Fa,Zb,Jb,$b,ac,Kb,Ud;0!==this.width&&0!==this.height&&(void 0===l&&(l=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.width/3)),void 0===n&&(n=Math.floor(this.height/3)),void 0===s&&(s=Math.floor(this.height/3)),e<l+m&&(l=Math.round(l*e/(l+m)),m=e-l),g<n+s&&(n=Math.round(n*g/(n+s)),s=g-n),ja=this.width,w=l,y=this.width-l-m,D=m,t=w+y,Fa=this.height,z=n,A=this.height-n-s,B=s,Y=z+A,Zb=l,l=e-l-m,Jb=c+Zb,$b=c+Zb+l,ac=n,n=g-n-s,Kb=d+ac,
Ud=d+ac+n,e===this.width&&g===this.height?this.ui(b,c+this.Qa,d+this.Sa,h):g===this.height?(this.Jd(b,w,0,y,Fa,Jb,d,l,g,h),this.yb(b,0,0,w,Fa,c,d,h),this.yb(b,t,0,D,Fa,$b,d,h)):e===this.width?(this.Jd(b,0,z,ja,A,c,Kb,e,n,h),this.yb(b,0,0,ja,z,c,d,h),this.yb(b,0,Y,ja,B,c,Ud,h)):(this.Jd(b,w,z,y,A,Jb,Kb,l,n,h),this.Jd(b,w,0,y,z,Jb,d,l,ac,h),this.Jd(b,0,z,w,A,c,Kb,Zb,n,h),this.Jd(b,t,z,D,A,$b,Kb,m,n,h),this.Jd(b,w,Y,y,B,Jb,Ud,l,s,h),this.yb(b,0,0,w,z,c,d,h),this.yb(b,0,Y,w,B,c,Ud,h),this.yb(b,t,0,D,
z,$b,d,h),this.yb(b,t,Y,D,B,$b,Ud,h)))};
a.Lj=function(b,c,d,e,g,h,l,m){var n=p.context,s=n.globalAlpha,w,y,D,t,z,A,B,Y,ja;if(0!==this.width&&0!==this.height){b=(Math.round(b)%this.Y+this.Y)%this.Y;n.globalAlpha=m;c=Math.round(c-this.Qa)%this.width;0<c&&(c-=this.width);d=Math.round(d-this.Sa)%this.height;0<d&&(d-=this.height);m=Math.ceil((h-c)/this.width);w=Math.ceil((l-d)/this.height);c+=e+this.Uh[b];d+=g+this.Wh[b];for(Y=0;Y<m;Y+=1)for(ja=0;ja<w;ja+=1)t=this.Th[b],z=this.Vh[b],A=this.Wg[b],B=this.Vg[b],y=c+Y*this.width,D=d+ja*this.height,
y<e&&(t+=e-y,A-=e-y,y=e),y+A>=e+h&&(A=e+h-y),D<g&&(z+=g-D,B-=g-D,D=g),D+B>=g+l&&(B=g+l-D),0<A&&0<B&&this.Xh.yb(this.Sh[b],t,z,A,B,y,D);n.globalAlpha=s}};a.hu=function(b,c,d,e,g,h){this.Lj(b,0,0,c,d,e,g,h)};
a.yb=function(b,c,d,e,g,h,l,m){var n=p.context,s=n.globalAlpha,w,y,D,t;b=(Math.round(b)%this.Y+this.Y)%this.Y;w=this.Uh[b];y=this.Wh[b];D=this.Wg[b];t=this.Vg[b];c-=w;d-=y;0>=c+e||0>=d+g||c>=D||d>=t||(0>c&&(e+=c,h-=c,c=0),0>d&&(g+=d,l-=d,d=0),c+e>D&&(e=D-c),d+g>t&&(g=t-d),n.globalAlpha=m,this.Xh.yb(this.Sh[b],this.Th[b]+c,this.Vh[b]+d,e,g,h,l),n.globalAlpha=s)};
a.Jd=function(b,c,d,e,g,h,l,m,n,s){var w=p.context,y=w.globalAlpha,D,t,z,A,B,Y;b=(Math.round(b)%this.Y+this.Y)%this.Y;D=m/e;t=n/g;z=this.Uh[b];A=this.Wh[b];B=this.Wg[b];Y=this.Vg[b];c-=z;d-=A;0>=c+e||0>=d+g||c>=B||d>=Y||(0>c&&(e+=c,m+=D*c,h-=D*c,c=0),0>d&&(g+=d,n+=t*d,l-=t*d,d=0),c+e>B&&(m-=D*(e-B+c),e=B-c),d+g>Y&&(n-=t*(g-Y+d),g=Y-d),w.globalAlpha=s,this.Xh.yb(this.Sh[b],this.Th[b]+c,this.Vh[b]+d,e,g,h,l,m,n),w.globalAlpha=y)};
function ua(b,c,d){var e,g,h;for(e=0;e<b.Y;e+=1)g=c+e%b.lC*b.width,h=d+b.height*Math.floor(e/b.lC),b.Xh.yb(b.Sh[e],b.Th[e],b.Vh[e],b.Wg[e],b.Vg[e],g-b.Qa+b.Uh[e],h-b.Sa+b.Wh[e])}function va(b,c,d,e,g,h){var l=p.context;1E-4>Math.abs(e)||1E-4>Math.abs(g)||(l.save(),l.translate(c,d),l.rotate(-0*Math.PI/180),l.scale(e,g),l.globalAlpha=h,ua(b,0,0),l.restore())}
function wa(b,c){this.canvas=document.createElement("canvas");this.context=this.canvas.getContext("2d");this.width=b;this.height=c;this.Sa=this.Qa=0;this.canvas.width=b;this.canvas.height=c;this.clear();this.qr=void 0}a=wa.prototype;a.cl=function(){var b=new wa(this.width,this.height);b.Qa=this.Qa;b.Sa=this.Sa;xa(b);this.ma(0,0);ya(b);return b};function xa(b){b.qr=p.canvas;na(p,b.canvas)}function ya(b){p.canvas===b.canvas&&void 0!==b.qr&&(na(p,b.qr),b.qr=void 0)}
a.clear=function(){this.context.clearRect(0,0,this.canvas.width,this.canvas.height)};a.clearColor=function(b){this.context.fillStyle=b;this.context.fillRect(0,0,this.canvas.width,this.canvas.height)};a.ma=function(b,c){p.context.drawImage(this.canvas,b-this.Qa,c-this.Sa)};a.ui=function(b,c,d){var e=p.context,g=e.globalAlpha;e.globalAlpha=d;p.context.drawImage(this.canvas,b-this.Qa,c-this.Sa);e.globalAlpha=g};
a.Ha=function(b,c,d,e,g,h){var l=p.context;1E-4>Math.abs(d)||1E-4>Math.abs(e)||(l.save(),l.translate(b,c),l.rotate(-g*Math.PI/180),l.scale(d,e),l.globalAlpha=h,p.context.drawImage(this.canvas,-this.Qa,-this.Sa),l.restore())};a.Of=function(b,c,d,e,g){var h=p.context,l=h.globalAlpha;0!==this.width&&0!==this.height&&0!==Math.round(d)&&0!==Math.round(e)&&(h.globalAlpha=g,p.context.drawImage(this.canvas,b,c,d,e),h.globalAlpha=l)};
a.Jc=function(b,c,d,e,g,h,l,m,n){var s,w,y,D,t,z,A,B,Y,ja,Fa,Zb,Jb,$b,ac,Kb;0!==this.width&&0!==this.height&&(void 0===h&&(h=Math.floor(this.width/3)),void 0===l&&(l=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.height/3)),void 0===n&&(n=Math.floor(this.height/3)),d<h+l&&(h=Math.round(h*d/(h+l)),l=d-h),e<m+n&&(m=Math.round(m*e/(m+n)),n=e-m),Y=this.width,s=h,w=this.width-h-l,y=l,D=s+w,ja=this.height,t=m,z=this.height-m-n,A=n,B=t+z,Fa=h,h=d-h-l,Zb=b+Fa,Jb=b+Fa+h,$b=m,m=e-m-n,ac=c+$b,Kb=c+
$b+m,d===this.width&&e===this.height?this.ui(b+this.Qa,c+this.Sa,g):e===this.height?(this.Jd(s,0,w,ja,Zb,c,h,e,g),this.yb(0,0,s,ja,b,c,g),this.yb(D,0,y,ja,Jb,c,g)):d===this.width?(this.Jd(0,t,Y,z,b,ac,d,m,g),this.yb(0,0,Y,t,b,c,g),this.yb(0,B,Y,A,b,Kb,g)):(this.Jd(s,t,w,z,Zb,ac,h,m,g),this.Jd(s,0,w,t,Zb,c,h,$b,g),this.Jd(0,t,s,z,b,ac,Fa,m,g),this.Jd(D,t,y,z,Jb,ac,l,m,g),this.Jd(s,B,w,A,Zb,Kb,h,n,g),this.yb(0,0,s,t,b,c,g),this.yb(0,B,s,A,b,Kb,g),this.yb(D,0,y,t,Jb,c,g),this.yb(D,B,y,A,Jb,Kb,g)))};
a.Lj=function(b,c,d,e,g,h,l){var m=p.context,n=m.globalAlpha,s,w,y,D,t,z,A,B,Y;if(0!==this.width&&0!==this.height){m.globalAlpha=l;b=Math.round(b-this.Qa)%this.width;0<b&&(b-=this.width);c=Math.round(c-this.Sa)%this.height;0<c&&(c-=this.height);l=Math.ceil((g-b)/this.width);s=Math.ceil((h-c)/this.height);b+=d;c+=e;for(B=0;B<l;B+=1)for(Y=0;Y<s;Y+=1)t=D=0,z=this.width,A=this.height,w=b+B*this.width,y=c+Y*this.height,w<d&&(D+=d-w,z-=d-w,w=d),w+z>=d+g&&(z=d+g-w),y<e&&(t+=e-y,A-=e-y,y=e),y+A>=e+h&&(A=
e+h-y),0<z&&0<A&&p.context.drawImage(this.canvas,D,t,z,A,w,y,z,A);m.globalAlpha=n}};a.hu=function(b,c,d,e,g){this.Lj(0,0,b,c,d,e,g)};a.yb=function(b,c,d,e,g,h,l){var m=p.context,n=m.globalAlpha;0>=d||0>=e||(b+d>this.width&&(d=this.width-b),c+e>this.height&&(e=this.height-c),m.globalAlpha=l,p.context.drawImage(this.canvas,b,c,d,e,g,h,d,e),m.globalAlpha=n)};
a.Jd=function(b,c,d,e,g,h,l,m,n){var s=p.context,w=s.globalAlpha;0>=d||0>=e||(b+d>this.width&&(d=this.width-b),c+e>this.height&&(e=this.height-c),0!==Math.round(l)&&0!==Math.round(m)&&(s.globalAlpha=n,p.context.drawImage(this.canvas,b,c,d,e,g,h,l,m),s.globalAlpha=w))};
function za(b,c,d,e){this.o=b;this.nQ=c;this.JP=d;this.Cp=[{text:"MiHhX!@v&Qq",width:-1,font:"sans-serif"},{text:"MiHhX!@v&Qq",width:-1,font:"serif"},{text:"AaMm#@!Xx67",width:-1,font:"sans-serif"},{text:"AaMm#@!Xx67",width:-1,font:"serif"}];this.mD=!1;ka(this,e,1)}function Aa(b,c,d){p.context.save();p.context.font="250pt "+b+", "+c;b=p.context.measureText(d).width;p.context.restore();return b}
function Ba(b){var c,d,e;for(c=0;c<b.Cp.length;c+=1)if(d=b.Cp[c],e=Aa(b.o,d.font,d.text),d.width!==e){la.Vf(b.ZK);document.body.removeChild(b.ci);b.mD=!0;return}window.setTimeout(function(){Ba(b)},33)}
za.prototype.Rh=function(b,c){var d="@font-face {font-family: "+this.o+";src: url('"+c+this.nQ+"') format('woff'), url('"+c+this.JP+"') format('truetype');}",e=document.createElement("style");e.id=this.o+"_fontface";e.type="text/css";e.styleSheet?e.styleSheet.cssText=d:e.appendChild(document.createTextNode(d));document.getElementsByTagName("head")[0].appendChild(e);this.ci=document.createElement("span");this.ci.style.position="absolute";this.ci.style.left="-9999px";this.ci.style.top="-9999px";this.ci.style.visibility=
"hidden";this.ci.style.fontSize="250pt";this.ci.id=this.o+"_loader";document.body.appendChild(this.ci);for(d=0;d<this.Cp.length;d+=1)e=this.Cp[d],e.width=Aa(e.font,e.font,e.text);this.ZK=b;Ba(this)};za.prototype.complete=function(){return this.mD};
function Ca(b,c){this.o=b;this.An=c;this.fontWeight=this.fontStyle="";this.ml="normal";this.fontSize=12;this.fill=!0;this.mc=1;this.Je=0;this.fillColor="black";this.Qf={c:void 0,Da:0,Nw:!0,Ow:!0};this.sd={ns:!0,Y:3,Ot:["red","white","blue"],size:.6,offset:0};this.fillStyle=void 0;this.stroke=!1;this.qc=1;this.gm=0;this.strokeColor="black";this.strokeStyle=void 0;this.ig=1;this.dj=!1;this.Dk="miter";this.Ac={ba:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1};this.align="left";this.xb=
"top";this.Zb=this.Lg=0}a=Ca.prototype;
a.cl=function(){var b=new Ca(this.o,this.An);b.fontStyle=this.fontStyle;b.fontWeight=this.fontWeight;b.ml=this.ml;b.fontSize=this.fontSize;b.fill=this.fill;b.mc=this.mc;b.Je=this.Je;b.fillColor=this.fillColor;b.Qf={c:this.Qf.c,Nw:this.Qf.Nw,Ow:this.Qf.Ow};b.sd={ns:this.sd.ns,Y:this.sd.Y,Ot:this.sd.Ot.slice(0),size:this.sd.size,offset:this.sd.offset};b.fillStyle=this.fillStyle;b.stroke=this.stroke;b.qc=this.qc;b.gm=this.gm;b.strokeColor=this.strokeColor;b.strokeStyle=this.strokeStyle;b.ig=this.ig;
b.dj=this.dj;b.Dk=this.Dk;b.Ac={ba:this.Ac.ba,color:this.Ac.color,offsetX:this.Ac.offsetX,offsetY:this.Ac.offsetY,blur:this.Ac.blur};b.align=this.align;b.xb=this.xb;b.Lg=this.Lg;b.Zb=this.Zb;return b};
a.i=function(b){void 0!==b.o&&(this.o=b.o);void 0!==b.An&&(this.An=b.An);void 0!==b.fontStyle&&(this.fontStyle=b.fontStyle);void 0!==b.fontWeight&&(this.fontWeight=b.fontWeight);void 0!==b.ml&&(this.ml=b.ml);void 0!==b.fontSize&&(this.fontSize=b.fontSize);void 0!==b.fill&&(this.fill=b.fill);void 0!==b.mc&&(this.mc=b.mc);void 0!==b.fillColor&&(this.Je=0,this.fillColor=b.fillColor);void 0!==b.Qf&&(this.Je=1,this.Qf=b.Qf);void 0!==b.sd&&(this.Je=2,this.sd=b.sd);void 0!==b.fillStyle&&(this.Je=3,this.fillStyle=
b.fillStyle);void 0!==b.stroke&&(this.stroke=b.stroke);void 0!==b.qc&&(this.qc=b.qc);void 0!==b.strokeColor&&(this.gm=0,this.strokeColor=b.strokeColor);void 0!==b.strokeStyle&&(this.gm=3,this.strokeStyle=b.strokeStyle);void 0!==b.ig&&(this.ig=b.ig);void 0!==b.dj&&(this.dj=b.dj);void 0!==b.Dk&&(this.Dk=b.Dk);void 0!==b.Ac&&(this.Ac=b.Ac);void 0!==b.align&&(this.align=b.align);void 0!==b.xb&&(this.xb=b.xb);void 0!==b.Lg&&(this.Lg=b.Lg);void 0!==b.Zb&&(this.Zb=b.Zb)};
function Da(b,c){b.fontSize=void 0===c?12:c}a.setFillColor=function(b){this.Je=0;this.fillColor=void 0===b?"black":b};function Ea(b,c){b.stroke=void 0===c?!1:c}a.setStrokeColor=function(b){this.gm=0;this.strokeColor=void 0===b?"black":b};function Ga(b,c){b.ig=void 0===c?1:c}function Ha(b,c){b.dj=void 0===c?!1:c}function Ia(b,c){b.Dk=void 0===c?"miter":c}function Ja(b,c){b.align=void 0===c?"left":c}function Ka(b,c){b.xb=void 0===c?"top":c}function La(b,c){b.Lg=void 0===c?0:c}
function Ma(b){return b.fontStyle+" "+b.fontWeight+" "+b.fontSize+"px "+b.o+", "+b.An}function Na(b){var c=0,d;for(d=0;d<b.length;d+=1)c=Math.max(c,b[d].width);return c}function Oa(b,c){return b.fontSize*c.length+b.Zb*(c.length-1)}
function Pa(b,c,d){var e,g,h,l,m,n,s=[],w=p.context;w.font=Ma(b);switch(b.ml){case "upper":c=c.toUpperCase();break;case "lower":c=c.toLowerCase()}if(void 0===d){n=c.split("\n");for(b=0;b<n.length;b+=1)s.push({text:n[b],width:w.measureText(n[b]).width});return s}n=c.split("\n");h=w.measureText(" ").width;for(b=0;b<n.length;b+=1){g=n[b].split(" ");e=g[0];m=w.measureText(g[0]).width;for(c=1;c<g.length;c+=1)l=w.measureText(g[c]).width,m+h+l<d?(e+=" "+g[c],m+=h+l):(s.push({text:e,width:m}),e=g[c],m=l);
s.push({text:e,width:m})}return s}a.Fk=function(b,c){var d;p.context.save();d=Na(Pa(this,b,c));p.context.restore();return d};a.wf=function(b,c){var d;p.context.save();d=Oa(this,Pa(this,b,c));p.context.restore();return d};function Qa(b,c,d,e,g,h){var l=b.fontSize;b.fontSize=c;c=h?Pa(b,d,e):Pa(b,d);e=Na(c)<=e&&Oa(b,c)<=g;b.fontSize=l;return e}
function Ra(b,c,d,e,g){var h=0,l=32;void 0===g&&(g=!1);for(p.context.save();Qa(b,h+l,c,d,e,g);)h+=l;for(;2<=l;)l/=2,Qa(b,h+l,c,d,e,g)&&(h+=l);p.context.restore();return Math.max(4,h)}function Sa(b,c,d,e,g){var h=Math.max(.01,b.sd.size),l=b.sd.offset;b.sd.ns?(l=g/2+l*g,h=.5*h*g,c=p.context.createLinearGradient(c,d+l-h,c,d+l+h)):(l=e/2+l*e,h=.5*h*e,c=p.context.createLinearGradient(c+l-h,d,c+l+h,d));d=1/(b.sd.Y-1);for(e=0;e<b.sd.Y;e+=1)c.addColorStop(e*d,b.sd.Ot[e]);return c}
function Ta(b,c,d,e,g,h,l){var m,n;!b.fill&&b.Ac.ba?(c.shadowColor=b.Ac.color,c.shadowOffsetX=b.Ac.offsetX,c.shadowOffsetY=b.Ac.offsetY,c.shadowBlur=b.Ac.blur):(c.shadowColor=void 0,c.shadowOffsetX=0,c.shadowOffsetY=0,c.shadowBlur=0);c.globalAlpha=l*b.qc;switch(b.gm){case 0:c.strokeStyle=b.strokeColor;break;case 3:c.strokeStyle=b.strokeStyle}c.lineWidth=b.ig;c.lineJoin=b.Dk;for(l=0;l<d.length;l+=1){m=0;switch(b.align){case "right":m=h-d[l].width;break;case "center":m=(h-d[l].width)/2}n=b.fontSize*
(l+1)+b.Zb*l;c.strokeText(d[l].text,e+m,g+n)}}
function Ua(b,c,d,e,g,h,l){d=Pa(b,d,l);l=Na(d);var m=Oa(b,d);c.textAlign="left";c.textBaseline="bottom";switch(b.align){case "right":e+=-l;break;case "center":e+=-l/2}switch(b.xb){case "base":case "bottom":g+=-m+Math.round(b.Lg*b.fontSize);break;case "middle":g+=-m/2+Math.round(b.Lg*b.fontSize/2)}c.font=Ma(b);b.stroke&&b.dj&&Ta(b,c,d,e,g,l,h);if(b.fill){var n=e,s=g,w,y;b.Ac.ba?(c.shadowColor=b.Ac.color,c.shadowOffsetX=b.Ac.offsetX,c.shadowOffsetY=b.Ac.offsetY,c.shadowBlur=b.Ac.blur):(c.shadowColor=
void 0,c.shadowOffsetX=0,c.shadowOffsetY=0,c.shadowBlur=0);c.globalAlpha=h*b.mc;switch(b.Je){case 0:c.fillStyle=b.fillColor;break;case 1:m=b.Qf.c;y=new wa(m.width,m.height);var D=b.Qf.Nw,t=b.Qf.Ow;D&&t?w="repeat":D&&!t?w="repeat-x":!D&&t?w="repeat-y":D||t||(w="no-repeat");xa(y);m.ma(b.Qf.Da,0,0);ya(y);w=p.context.createPattern(y.canvas,w);c.fillStyle=w;break;case 2:c.fillStyle=Sa(b,n,s,l,m);break;case 3:c.fillStyle=b.fillStyle;break;default:c.fillStyle=b.fillColor}for(w=0;w<d.length;w+=1){m=0;switch(b.align){case "right":m=
l-d[w].width;break;case "center":m=(l-d[w].width)/2}y=b.fontSize*(w+1)+b.Zb*w;2===b.Je&&b.sd.ns&&(c.fillStyle=Sa(b,n,s+y-b.fontSize,l,b.fontSize));c.fillText(d[w].text,n+m,s+y)}}b.stroke&&!b.dj&&Ta(b,c,d,e,g,l,h)}a.ma=function(b,c,d,e){var g=p.context;this.fill&&1===this.Je?this.Ha(b,c,d,1,1,0,1,e):(g.save(),Ua(this,g,b,c,d,1,e),g.restore())};a.ui=function(b,c,d,e,g){var h=p.context;this.fill&&1===this.Je?this.Ha(b,c,d,1,1,0,e,g):(h.save(),Ua(this,h,b,c,d,e,g),h.restore())};
a.Ha=function(b,c,d,e,g,h,l,m){var n=p.context;n.save();n.translate(c,d);n.rotate(-h*Math.PI/180);n.scale(e,g);try{Ua(this,n,b,0,0,l,m)}catch(s){}n.restore()};
function Va(){this.rL=10;this.zs=-1;this.mE="stop_lowest_prio";this.cz=this.$c=this.ad=!1;var b,c=this,d="undefined"!==typeof AudioContext?AudioContext:"undefined"!==typeof webkitAudioContext?webkitAudioContext:void 0;if(d)this.ad=!0;else if("undefined"!==typeof Audio)try{"undefined"!==typeof(new Audio).canPlayType&&(this.$c=!0)}catch(e){}this.cz=this.ad||this.$c;this.$c&&f.ja.Nx&&(this.zs=1);if(this.cz)try{b=new Audio,this.xy={ogg:!!b.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,""),
mp3:!!b.canPlayType("audio/mpeg;").replace(/^no$/,""),opus:!!b.canPlayType('audio/ogg; codecs="opus"').replace(/^no$/,""),wav:!!b.canPlayType('audio/wav; codecs="1"').replace(/^no$/,""),m4a:!!(b.canPlayType("audio/x-m4a;")||b.canPlayType("audio/aac;")).replace(/^no$/,""),mp4:!!(b.canPlayType("audio/x-mp4;")||b.canPlayType("audio/aac;")).replace(/^no$/,""),weba:!!b.canPlayType('audio/webm; codecs="vorbis"').replace(/^no$/,"")}}catch(g){this.xy={ogg:!1,mp3:!0,opus:!1,wav:!1,m4a:!1,mp4:!1,weba:!1},ba&&
console.log("Cannot create Audio object to determine codec support. Only supporting MP3.")}this.nd=[];this.rj={};this.Gc={};this.Gf={};this.bh=[];this.xe=0;this.ad?(this.ah=new d,this.yy="function"===typeof this.ah.createGain?function(){return c.ah.createGain()}:"function"===typeof this.ah.createGainNode?function(){return c.ah.createGainNode()}:function(){},this.pj={},this.Ep=this.yy(),void 0===this.Ep?(this.$c=!0,this.wm=Va.prototype.xs):(this.Ep.connect(this.ah.destination),this.pj.master=this.Ep,
this.wm=Va.prototype.kE)):this.wm=this.$c?Va.prototype.xs:function(){}}
function Wa(b){var c=r,d,e,g,h,l;for(d=0;d<c.nd.length;d+=1)if((e=c.nd[d])&&0===e.yu)if(e.paused)e.Ey&&(e.As+=b,e.As>=e.Ey&&c.Xi(e.id));else if(e.Bs+=b,e.Rk&&e.Bs>=e.iD)e.Rk=!1,Xa(c,e,e.eh);else if(e.Qg&&c.$c&&Ya(c,e.id)>=e.duration)if(e.Pi)try{e.la.pause(),e.la.currentTime=e.eh/1E3,4===e.la.readyState?e.la.play():(g=function(){var b=e;return{ready:function(){b.la.play();b.la.removeEventListener("canplaythrough",g.ready,!1)}}}(),e.la.addEventListener("canplaythrough",g.ready,!1))}catch(m){ba&&console.log("error in step when position > duration: "+
m.name+", "+m.message)}else e.la.pause(),Za(e);for(d=c.bh.length-1;0<=d;d-=1)h=c.bh[d],c.Rn(h.id)||0!==h.yu||(h.jb+=b,h.jb>=h.duration?($a(r,h.id,h.qp),void 0!==c.Gf[h.id]&&(c.Gf[h.id]=h.qp),h.al&&h.al(),c.bh.splice(d,1)):(l=h.D(h.jb,h.start,h.qp-h.start,h.duration),$a(r,h.id,l),void 0!==c.Gf[h.id]&&(c.Gf[h.id]=l)))}function ab(b,c){b.rj[c.$d.Ug.name]?b.rj[c.$d.Ug.name].length<b.rL&&b.rj[c.$d.Ug.name].push(c.la):b.rj[c.$d.Ug.name]=[c.la]}
function bb(b,c){var d,e,g;g=[];for(d=0;d<b.nd.length;d+=1)(e=b.nd[d])&&0<=e.ib.indexOf(c)&&g.push(e);return g}function cb(b,c){if(0<b.zs&&b.xe>=b.zs)switch(b.mE){case "cancel_new":return!1;case "stop_lowest_prio":var d,e,g;for(d=0;d<b.nd.length;d+=1)(e=b.nd[d])&&e.Qg&&!e.paused&&(void 0===g||g.Fr<e.Fr)&&(g=e);if(g.Fr>c.Fm){b.stop(g.id);break}return!1}return!0}
function db(b,c){var d,e=1;for(d=0;d<c.ib.length;d+=1)void 0!==r.Gc[c.ib[d]]&&(e*=r.Gc[c.ib[d]]);d=b.yy();d.gain.value=e;d.connect(b.Ep);b.pj[c.id]=d;c.la.connect(d)}function eb(b,c){c.la.disconnect(0);b.pj[c.id]&&(b.pj[c.id].disconnect(0),delete b.pj[c.id])}function fb(b,c){var d;if(c.Ug&&c.Ug.Oc){if(b.ad)return d=b.ah.createBufferSource(),d.buffer=c.Ug.Oc,d.loopStart=c.startOffset/1E3,d.loopEnd=(c.startOffset+c.duration)/1E3,d;if(b.$c)return d=c.Ug.Oc.cloneNode(!0),d.volume=0,d}}
function gb(b,c){var d,e;if(b.ad)(d=fb(b,c))&&(e=new hb(c,d));else if(b.$c){d=b.rj[c.Ug.name];if(!d)return;0<d.length?e=new hb(c,d.pop()):(d=fb(b,c))&&(e=new hb(c,d))}if(e){b.ad&&db(b,e);for(d=0;d<b.nd.length;d+=1)if(void 0===b.nd[d])return b.nd[d]=e;b.nd.push(e)}return e}function ib(b){var c=r,d,e;for(d=0;d<b.length;d+=1)if(e=b[d].split(".").pop(),c.xy[e])return b[d];return!1}a=Va.prototype;
a.xs=function(b,c,d){function e(){var c;b.loaded=!0;la.Vf(d);b.duration=Math.ceil(1E3*b.Oc.duration);b.Oc.removeEventListener("canplaythrough",e,!1);b.Oc.removeEventListener("error",g,!1);c=b.Oc.cloneNode(!0);r.rj[b.name].push(c)}function g(){la.Oi(d)}(c=ib(c))?(b.Oc=new Audio,b.Oc.src=c,b.Oc.autoplay=!1,b.Oc.pT="auto",b.Oc.addEventListener("canplaythrough",e,!1),b.Oc.addEventListener("error",g,!1),b.Oc.load()):g()};
a.kE=function(b,c,d){var e=ib(c),g=new XMLHttpRequest;g.open("GET",e,!0);g.responseType="arraybuffer";g.onload=function(){r.ah.decodeAudioData(g.response,function(c){c&&(b.Oc=c,b.duration=1E3*c.duration,b.loaded=!0,la.Vf(d))},function(){la.Oi(d)})};g.onerror=function(){"undefined"!==typeof Audio&&(r.ad=!1,r.$c=!0,r.wm=Va.prototype.xs,r.wm(b,c,d))};try{g.send()}catch(h){}};
a.play=function(b,c,d,e){if(b instanceof jb){if(cb(this,b)){b=gb(this,b);if(!b)return-1;b.iD=c||0;b.Rk=0<c;b.ff=d||0;b.rh=e||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c};b.Rk||Xa(this,b,b.eh);return b.id}return-1}};
function Xa(b,c,d){var e;"number"!==typeof d&&(d=0);kb(b,c.id);0<c.ff&&(e=lb(b,c.id),$a(b,c.id,0),b.zi(c.id,e,c.ff,c.rh),c.ff=0,c.rh=void 0);if(b.ad){e=d-c.eh;c.uE=1E3*b.ah.currentTime-e;c.la.onended=function(){Za(c)};try{c.la.start?c.la.start(0,d/1E3,(c.duration-e)/1E3):c.la.noteGrainOn&&c.la.noteGrainOn(0,d/1E3,(c.duration-e)/1E3),c.pg=!0,c.Qg=!0,b.xe+=1,c.la.loop=c.Pi}catch(g){ba&&console.log("error in starting sound: "+g.name+", "+g.message)}}else if(b.$c){if(4!==c.la.readyState){var h=function(){return{ready:function(){c.la.currentTime=
d/1E3;c.la.play();c.pg=!0;c.la.removeEventListener("canplaythrough",h.ready,!1)}}}();c.la.addEventListener("canplaythrough",h.ready,!1)}else c.la.currentTime=d/1E3,c.la.play(),c.pg=!0;c.Qg=!0;b.xe+=1}}
a.Xi=function(b,c,d,e){var g,h,l,m,n=bb(this,b);for(g=0;g<n.length;g+=1)if(h=n[g],(h.paused||!h.Qg)&&!e||!h.paused&&e){if(!e){for(g=this.bh.length-1;0<=g;g-=1)if(b=this.bh[g],b.id===h.id){m=b;c=0;d=void 0;break}h.paused=!1;h.ff=c||0;h.rh=d||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c};h.um&&(void 0===c&&(h.ff=h.um.duration),void 0===d&&(h.rh=h.um.D),l=h.um.gain,h.um=void 0)}this.ad&&(b=fb(this,h.$d))&&(h.la=b,db(this,h));void 0!==l&&$a(r,h.id,l);Xa(this,h,h.eh+(h.Fp||0));void 0!==m&&
($a(r,h.id,m.D(m.jb,m.start,m.qp-m.start,m.duration)),r.zi(h.id,m.qp,m.duration-m.jb,m.D,m.al))}};
a.pause=function(b,c,d,e,g){var h,l,m=bb(this,b);for(b=0;b<m.length;b+=1)if(h=m[b],!h.paused)if(h.ff=d||0,0<h.ff)h.rh=e||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c},h.um={gain:mb(h.id),duration:h.ff,D:h.rh},r.zi(h.id,0,h.ff,h.rh,function(){r.pause(h.id,c)});else if(l=Ya(this,h.id),h.Fp=l,g||(h.paused=!0,h.As=0,h.Ey=c,this.xe-=1),this.ad){h.la.onended=function(){};if(h.Qg&&h.pg){try{h.la.stop?h.la.stop(0):h.la.noteOff&&h.la.noteOff(0)}catch(n){ba&&console.log("error in stopping sound for pause: "+
n.name+", "+n.message)}h.pg=!1}eb(this,h)}else this.$c&&h.la.pause()};function Za(b){var c=r;c.Gc[b.id]&&delete c.Gc[b.id];b.paused||(c.xe-=1);c.ad?(b.pg=!1,b.Qg=!1,eb(c,b)):c.$c&&ab(c,b);c.nd[c.nd.indexOf(b)]=void 0}
a.stop=function(b,c,d){var e,g=bb(this,b);for(b=0;b<g.length;b+=1)if(e=g[b],e.ff=c||0,0<e.ff)e.rh=d||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c},r.zi(e.id,0,e.ff,e.rh,function(){r.stop(e.id)});else{this.Gc[e.id]&&delete this.Gc[e.id];e.Qg&&!e.paused&&(this.xe-=1);if(this.ad){if(e.Qg&&!e.paused&&!e.Rk){if(e.pg){try{e.la.stop?e.la.stop(0):e.la.noteOff&&e.la.noteOff(0)}catch(h){ba&&console.log("error in stopping sound: "+h.name+", "+h.message)}e.pg=!1}eb(this,e)}}else this.$c&&(e.Rk||
e.la.pause(),ab(this,e));this.nd[this.nd.indexOf(e)]=void 0;e.Qg=!1}};a.zi=function(b,c,d,e,g){var h;for(h=0;h<this.bh.length;h+=1)if(this.bh[h].id===b){this.bh.splice(h,1);break}this.bh.push({id:b,qp:c,D:e||function(b,c,d,e){return b==e?c+d:d*(-Math.pow(2,-10*b/e)+1)+c},duration:d,jb:0,start:lb(this,b),al:g,yu:0})};function nb(b){var c=r,d;void 0===c.Gf[b]&&(d=void 0!==c.Gc[b]?c.Gc[b]:1,$a(c,b,0),c.Gf[b]=d)}function ob(b){var c=r;void 0!==c.Gf[b]&&($a(c,b,c.Gf[b]),delete c.Gf[b])}
a.position=function(b,c){var d,e,g,h,l=bb(this,b);if(!isNaN(c)&&0<=c)for(d=0;d<l.length;d++)if(e=l[d],c%=e.duration,this.ad)if(e.paused)e.Fp=c;else{e.la.onended=function(){};if(e.pg){try{e.la.stop?e.la.stop(0):e.la.noteOff&&e.la.noteOff(0)}catch(m){ba&&console.log("error in stopping sound for position: "+m.name+", "+m.message)}e.pg=!1}eb(this,e);this.xe-=1;if(g=fb(this,e.$d))e.la=g,db(this,e),Xa(this,e,e.eh+c)}else this.$c&&(4===e.la.readyState?e.la.currentTime=(e.eh+c)/1E3:(h=function(){var b=e,
d=c;return{HA:function(){b.la.currentTime=(b.eh+d)/1E3;b.la.removeEventListener("canplaythrough",h.HA,!1)}}}(),e.la.addEventListener("canplaythrough",h.HA,!1)))};a.em=function(b,c){var d,e=bb(this,b);for(d=0;d<e.length;d+=1)e[d].Pi=c,this.ad&&(e[d].la.loop=c)};function pb(b){var c=r,d,e,g=[];for(d=0;d<c.nd.length;d+=1)(e=c.nd[d])&&0<=e.ib.indexOf(b)&&g.push(e.id);return g}function lb(b,c){return void 0!==b.Gc[c]?b.Gc[c]:1}
function mb(b){var c=r,d=1,e=bb(c,b)[0];if(e)for(b=0;b<e.ib.length;b+=1)void 0!==c.Gc[e.ib[b]]&&(d*=c.Gc[e.ib[b]]);return Math.round(100*d)/100}function $a(b,c,d){var e,g,h=1,l=bb(b,c);b.Gc[c]=d;b.Gf[c]&&delete b.Gf[c];for(d=0;d<l.length;d+=1)if(e=l[d],0<=e.ib.indexOf(c)){for(g=0;g<e.ib.length;g+=1)void 0!==b.Gc[e.ib[g]]&&(h*=b.Gc[e.ib[g]]);h=Math.round(100*h)/100;b.ad?b.pj[e.id].gain.value=h:b.$c&&(e.la.volume=h)}}
function kb(b,c){var d,e,g,h=1,l=bb(b,c);for(d=0;d<l.length;d+=1){e=l[d];for(g=0;g<e.ib.length;g+=1)void 0!==b.Gc[e.ib[g]]&&(h*=b.Gc[e.ib[g]]);h=Math.round(100*h)/100;b.ad?b.pj[e.id].gain.value=h:b.$c&&(e.la.volume=h)}}a.Dq=function(b){var c,d,e,g=bb(this,b),h=[];for(b=0;b<g.length;b+=1)for(c=g[b],d=0;d<c.ib.length;d+=1)e=c.ib[d],0>h.indexOf(e)&&h.push(e);return h};a.Rn=function(b){if(b=bb(this,b)[0])return b.paused};a.F=function(b){return bb(this,b)[0]?!0:!1};a.Aq=function(b){if(b=bb(this,b)[0])return b.$d.duration};
function Ya(b,c){var d=bb(b,c)[0];if(d){if(b.ad)return d.paused?d.Fp:(1E3*r.ah.currentTime-d.uE)%d.duration;if(r.$c)return Math.ceil(1E3*d.la.currentTime-d.eh)}}var r=new Va;function qb(b,c,d,e){this.name=b;this.SL=c;this.cM=d;this.Me=e;this.loaded=!1;this.Oc=null;ka(this,this.Me,1)}
qb.prototype.Rh=function(b,c){var d,e;d=this.SL;0!==d.toLowerCase().indexOf("http:")&&0!==d.toLowerCase().indexOf("https:")&&(d=c+d);e=this.cM;0!==e.toLowerCase().indexOf("http:")&&0!==e.toLowerCase().indexOf("https:")&&(e=c+e);r.rj[this.name]=[];r.wm(this,[e,d],b)};qb.prototype.complete=function(){return this.loaded};
function jb(b,c,d,e,g,h,l){this.name=b;this.Ug=c;this.startOffset=d;this.duration=e;$a(r,this.name,void 0!==g?g:1);this.Fm=void 0!==h?h:10;this.ib=[];l&&(this.ib=this.ib.concat(l));0>this.ib.indexOf(this.name)&&this.ib.push(this.name)}jb.prototype.complete=function(){return this.Ug.complete()};jb.prototype.Fr=function(b){void 0!==b&&(this.Fm=b);return this.Fm};jb.prototype.Dq=function(){return this.ib.slice(0)};
function hb(b,c){this.$d=b;this.eh=this.$d.startOffset;this.la=c;this.duration=this.$d.duration;this.id=Math.round(Date.now()*Math.random())+"";this.ib=["master",this.id].concat(this.$d.ib);this.Fr=void 0!==this.$d.Fm?this.$d.Fm:10;this.paused=this.Qg=this.Pi=!1;this.Bs=this.yu=0;this.pg=this.Rk=!1;this.iD=this.Fp=0;var d,e=1;for(d=0;d<this.ib.length;d+=1)void 0!==r.Gc[this.ib[d]]&&(e*=r.Gc[this.ib[d]]);!r.ad&&r.$c&&(this.la.volume=e)}
function rb(b,c){this.name=b;this.fileName=c;this.info=void 0}function sb(b){b&&(this.A=b);this.clear();this.Cm=this.Uk=this.Ef=this.Bm=this.Am=this.Em=this.xm=this.Dm=this.dh=this.zm=this.ym=0;tb(this,this);ub(this,this);vb(this,this);this.wy=[];this.sm=[];this.Gm=[];this.Aa=0;this.Fy=!1;this.Hg=this.startTime=Date.now();this.Ck=this.hf=0;this.sL=200;this.up=0;this.Me="";window.Bp(window.ry)}a=sb.prototype;a.clear=function(){this.ka=[];this.Hm=!1;this.Dd=[];this.us=!1};
function tb(b,c){window.addEventListener("click",function(b){var e,g,h;if(void 0!==c.A&&!(0<c.Aa)&&(e=c.A,g=e.getBoundingClientRect(),h=e.width/g.width*(b.clientX-g.left),e=e.height/g.height*(b.clientY-g.top),b.preventDefault(),c.Qk.x=h,c.Qk.y=e,c.tm.push({x:c.Qk.x,y:c.Qk.y}),0<c.Bm))for(b=c.ka.length-1;0<=b&&!((h=c.ka[b])&&h.ba&&0>=h.Aa&&h.av&&(h=h.av(c.Qk.x,c.Qk.y),!0===h));b-=1);},!1);wb(b)}function wb(b){b.Qk={x:0,y:0};b.tm=[]}
function ub(b,c){window.addEventListener("mousedown",function(b){0<c.Aa||(b.preventDefault(),window.focus(),c.Dy>=Date.now()-1E3||(xb(c,b.button,b.clientX,b.clientY),yb(c,b.button)))},!1);window.addEventListener("mouseup",function(b){0<c.Aa||(b.preventDefault(),c.Dp>=Date.now()-1E3||(xb(c,b.button,b.clientX,b.clientY),zb(c,b.button)))},!1);window.addEventListener("mousemove",function(b){0<c.Aa||(b.preventDefault(),xb(c,b.button,b.clientX,b.clientY))},!1);window.addEventListener("touchstart",function(b){var e=
b.changedTouches;c.Dy=Date.now();if(!(0<c.Aa))for(b.preventDefault(),window.focus(),b=0;b<e.length;b+=1)xb(c,e[b].identifier,e[b].clientX,e[b].clientY),yb(c,e[b].identifier)},!1);window.addEventListener("touchend",function(b){var e=b.changedTouches;c.Dp=Date.now();if(!(0<c.Aa))for(b.preventDefault(),b=0;b<e.length;b+=1)xb(c,e[b].identifier,e[b].clientX,e[b].clientY),zb(c,e[b].identifier)},!1);window.addEventListener("touchmove",function(b){var e=b.changedTouches;if(!(0<c.Aa))for(b.preventDefault(),
b=0;b<e.length;b+=1)xb(c,e[b].identifier,e[b].clientX,e[b].clientY)},!1);window.addEventListener("touchleave",function(b){var e=b.changedTouches;c.Dp=Date.now();if(!(0<c.Aa))for(b.preventDefault(),b=0;b<e.length;b+=1)xb(c,e[b].identifier,e[b].clientX,e[b].clientY),zb(c,e[b].identifier)},!1);window.addEventListener("touchcancel",function(b){var e=b.changedTouches;c.Dp=Date.now();if(!(0<c.Aa))for(b.preventDefault(),b=0;b<e.length;b+=1)xb(c,e[b].identifier,e[b].clientX,e[b].clientY),zb(c,e[b].identifier)},
!1);window.addEventListener("mousewheel",function(b){Ab(c,b)},!1);window.addEventListener("DOMMouseScroll",function(b){Ab(c,b)},!1);Bb(b);b.Dy=0;b.Dp=0}function Bb(b){var c;b.Ob=[];for(c=0;16>c;c+=1)b.Ob[c]={id:-1,ke:!1,x:0,y:0};b.tj=[]}function Cb(b,c){var d=-1,e;for(e=0;16>e;e+=1)if(b.Ob[e].id===c){d=e;break}if(-1===d)for(e=0;16>e;e+=1)if(!b.Ob[e].ke){d=e;b.Ob[e].id=c;break}return d}
function xb(b,c,d,e){var g,h;void 0!==b.A&&(c=Cb(b,c),-1!==c&&(g=b.A,h=g.getBoundingClientRect(),b.Ob[c].x=g.width/h.width*(d-h.left),b.Ob[c].y=g.height/h.height*(e-h.top)))}function yb(b,c){var d=Cb(b,c),e,g;if(-1!==d&&!b.Ob[d].ke&&(b.tj.push({ua:d,x:b.Ob[d].x,y:b.Ob[d].y,ke:!0}),b.Ob[d].ke=!0,0<b.Ef))for(e=b.ka.length-1;0<=e&&!((g=b.ka[e])&&g.ba&&0>=g.Aa&&g.Uj&&(g=g.Uj(d,b.Ob[d].x,b.Ob[d].y),!0===g));e-=1);}
function zb(b,c){var d=Cb(b,c),e,g;if(-1!==d&&b.Ob[d].ke&&(b.tj.push({ua:d,x:b.Ob[d].x,y:b.Ob[d].y,ke:!1}),b.Ob[d].ke=!1,0<b.Ef))for(e=b.ka.length-1;0<=e&&!((g=b.ka[e])&&g.ba&&0>=g.Aa&&g.Cg&&(g=g.Cg(d,b.Ob[d].x,b.Ob[d].y),!0===g));e-=1);}
function Ab(b,c){var d;if(!(0<b.Aa)){c.preventDefault();window.focus();d=Math.max(-1,Math.min(1,c.wheelDelta||-c.detail));var e,g;b.tj.push({ua:0,x:b.Ob[0].x,y:b.Ob[0].y,wheelDelta:d});if(0<b.Ef)for(e=b.ka.length-1;0<=e&&!((g=b.ka[e])&&g.ba&&0>=g.Aa&&g.dv&&(g=g.dv(d,b.Ob[0].x,b.Ob[0].y),!0===g));e-=1);}}a.Ec=function(b){return this.Ob[b].x};a.sc=function(b){return this.Ob[b].y};
function vb(b,c){window.addEventListener("keydown",function(b){if(!(0<c.Aa)){-1<[32,37,38,39,40].indexOf(b.keyCode)&&b.preventDefault();b=b.keyCode;var e,g;if(!c.Df[b]&&(c.Sk.push({key:b,ke:!0}),c.Df[b]=!0,0<c.Uk))for(e=0;e<c.ka.length&&!((g=c.ka[e])&&g.ba&&0>=g.Aa&&g.bv&&(g=g.bv(b),!0===g));e+=1);}},!1);window.addEventListener("keyup",function(b){if(!(0<c.Aa)){-1<[32,37,38,39,40].indexOf(b.keyCode)&&b.preventDefault();b=b.keyCode;var e,g;if(c.Df[b]&&(c.Sk.push({key:b,ke:!1}),c.Df[b]=!1,0<c.Uk))for(e=
0;e<c.ka.length&&!((g=c.ka[e])&&g.ba&&0>=g.Aa&&g.cv&&(g=g.cv(b),!0===g));e+=1);}},!1);Db(b)}function Db(b){var c;b.Df=[];for(c=0;256>c;c+=1)b.Df[c]=!1;b.Sk=[]}function ia(b,c){var d,e=u,g,h;void 0===d&&(d=null);e.Gm.push({id:b,sF:c,lm:d});if(0<e.Cm)for(g=0;g<e.ka.length&&(!((h=e.ka[g])&&h.ba&&0>=h.Aa&&h.ev)||null!==d&&d!==h||(h=h.ev(b,c),!0!==h));g+=1);}
function Eb(b,c){var d=b.Dd[c];d.visible&&(void 0!==d.canvas&&d.canvas!==p.canvas&&na(p,d.canvas),!1!==p.canvas.dA||!0===d.HI)&&(0===d.Cy&&(0>=d.Aa&&(d.Da+=d.qF*b.Ck/1E3),1===d.os&&1===d.qs&&0===d.qb?1===d.alpha?d.c.ma(d.Da,d.x,d.y):d.c.ui(d.Da,d.x,d.y,d.alpha):d.c.Ha(d.Da,d.x,d.y,d.os,d.qs,d.qb,d.alpha)),1===d.Cy&&(1===d.os&&1===d.qs&&0===d.qb?1===d.alpha?d.font.ma(d.text,d.x,d.y):d.font.ui(d.text,d.x,d.y,d.alpha):d.font.Ha(d.text,d.x,d.y,d.os,d.qs,d.qb,d.alpha)))}
function Fb(b,c){var d=b.ka[c];if(d.visible&&(void 0!==d.canvas&&d.canvas!==p.canvas&&na(p,d.canvas),(!1!==p.canvas.dA||!0===d.HI)&&d.Uc))return d.Uc()}function Gb(b){for(var c=0,d=0;c<b.ka.length||d<b.Dd.length;)if(d===b.Dd.length){if(!0===Fb(b,c))break;c+=1}else if(c===b.ka.length)Eb(b,d),d+=1;else if(b.Dd[d].d>b.ka[c].d||b.Dd[d].d===b.ka[c].d&&b.Dd[d].depth>b.ka[c].depth)Eb(b,d),d+=1;else{if(!0===Fb(b,c))break;c+=1}}a.pause=function(b){this.Aa+=1;void 0===b&&(b=!1);this.Fy=b};
a.Xi=function(){0!==this.Aa&&(this.Hg=Date.now(),this.Aa-=1)};a.Rn=function(){return 0<this.Aa};window.ss=0;window.rs=0;window.sy=0;window.bE=0;window.ty=0;window.dE=60;window.eE=0;window.cE=!1;
window.ry=function(){window.ss=Date.now();window.bE=window.ss-window.rs;var b=u,c;if(0<b.Aa)b.Fy&&(Hb(b),Gb(b));else{c=Date.now();"number"!==typeof c&&(c=b.Hg);b.Ck=Math.min(b.sL,c-b.Hg);b.hf+=b.Ck;b.up+=1;""===b.Me&&(b.Me="start",la.Rh(b.Me));"start"===b.Me&&la.complete(b.Me)&&(b.Me="load",la.Rh(b.Me));"load"===b.Me&&la.complete(b.Me)&&(b.Me="game",la.Rh(b.Me));"undefined"!==typeof r&&Wa(b.Ck);var d,e;if(0<b.ym)for(d=0;d<b.ka.length&&!((e=b.ka[d])&&e.ne&&e.ba&&0>=e.Aa&&!0===e.ne(b.Ck));d+=1);var g,
h;if(0!==b.tm.length){if(0<b.zm)for(e=b.ka.length-1;0<=e;e-=1)if((g=b.ka[e])&&g.ba&&0>=g.Aa&&g.$u)for(d=0;d<b.tm.length;d+=1)h=b.tm[d],!0!==h.lf&&(h.lf=g.$u(h.x,h.y));b.tm=[]}if(0!==b.tj.length){if(0<b.dh)for(e=b.ka.length-1;0<=e;e-=1)if((g=b.ka[e])&&g.ba&&0>=g.Aa&&(g.Ld||g.Tf||g.Sf))for(d=0;d<b.tj.length;d+=1)h=b.tj[d],!0!==h.lf&&(void 0!==h.wheelDelta&&g.Sf?h.lf=g.Sf(h.wheelDelta,h.x,h.y):h.ke&&g.Ld?h.lf=g.Ld(h.ua,h.x,h.y):void 0!==h.ke&&!h.ke&&g.Tf&&(h.lf=g.Tf(h.ua,h.x,h.y)));b.tj=[]}if(0!==b.Sk.length){if(0<
b.Dm)for(e=0;e<b.ka.length;e+=1)if((g=b.ka[e])&&g.ba&&0>=g.Aa&&(g.oe||g.xh))for(d=0;d<b.Sk.length;d+=1)h=b.Sk[d],!0!==h.lf&&(h.ke&&g.oe?h.lf=g.oe(h.key):!h.ke&&g.xh&&(h.lf=g.xh(h.key)));b.Sk=[]}d=b.Ck;for(e=b.sm.length=0;e<b.wy.length;e+=1)g=b.wy[e],void 0!==g.id&&0===g.paused&&(0<g.km||0<g.Pw)&&(g.km-=d,0>=g.km&&(b.sm.push({id:g.id,lm:g.lm}),0<g.Pw?(g.Pw-=1,g.km+=g.time):g.km=0));if(0<b.xm&&0<b.sm.length)for(d=0;d<b.ka.length;d+=1)if((e=b.ka[d])&&e.Tj&&e.ba)for(g=0;g<b.sm.length;g+=1)h=b.sm[g],!0===
h.lf||null!==h.lm&&h.lm!==e||(h.lf=e.Tj(h.id));if(0<b.Em&&0<b.Gm.length)for(d=0;d<b.ka.length;d+=1)if((g=b.ka[d])&&g.Dg&&g.ba&&0>=g.Aa)for(e=0;e<b.Gm.length;e+=1)h=b.Gm[e],!0===h.lf||null!==h.lm&&h.lm!==g||(h.lf=g.Dg(h.id,h.sF));b.Gm.length=0;if(0<b.Am)for(d=0;d<b.ka.length&&!((e=b.ka[d])&&e.Ab&&e.ba&&0>=e.Aa&&!0===e.Ab(b.Ck));d+=1);Hb(b);Gb(b);b.Hg=c}window.rs=Date.now();window.sy=window.rs-window.ss;window.ty=Math.max(window.eE,1E3/window.dE-window.sy);window.Bp(window.ry)};
window.Bp=function(b){window.setTimeout(b,window.ty)};window.cE||(window.Bp=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||window.Bp);
function Hb(b){function c(b,c){return b.d===c.d?c.depth-b.depth:b.d>c.d?-1:1}var d,e;for(d=e=0;d<b.ka.length;d+=1)b.ka[d]&&(b.ka[d].uy&&(b.ka[d].uy=!1,b.ka[d].ba=!0),b.ka[e]=b.ka[d],e+=1);b.ka.length=e;b.Hm&&b.ka.sort(c);b.Hm=!1;for(d=e=0;d<b.Dd.length;d+=1)b.Dd[d]&&(b.Dd[e]=b.Dd[d],e+=1);b.Dd.length=e;b.us&&b.Dd.sort(c);b.us=!1}
function Ib(b){var c=u;void 0===b.group&&(b.group=0);void 0===b.visible&&(b.visible=!0);void 0===b.ba&&(b.ba=!0);void 0===b.depth&&(b.depth=0);void 0===b.d&&(b.d=0);void 0===b.Aa&&(b.Aa=0);void 0===b.sj&&(b.sj=[]);b.uy=!1;c.ka.push(b);c.Hm=!0;b.ne&&(c.ym+=1);b.$u&&(c.zm+=1);if(b.Ld||b.Tf)c.dh+=1;b.Sf&&(c.dh+=1);if(b.oe||b.xh)c.Dm+=1;b.Tj&&(c.xm+=1);b.Dg&&(c.Em+=1);b.Ab&&(c.Am+=1);b.av&&(c.Bm+=1);if(b.Uj||b.Cg)c.Ef+=1;b.dv&&(c.Ef+=1);if(b.bv||b.cv)c.Uk+=1;b.ev&&(c.Cm+=1);b.me&&b.me()}
function Lb(b,c){var d=u;b.depth!==c&&(d.Hm=!0);b.depth=c}function Mb(b,c){var d=u;b.d!==c&&(d.Hm=!0);b.d=c}function Nb(b){var c=u,d=[],e,g;if(void 0===b||"all"===b||"master"===b)for(e=0;e<c.ka.length;e+=1)g=c.ka[e],void 0!==g&&d.push(g);else if("function"===typeof b)for(e=0;e<c.ka.length;e+=1)g=c.ka[e],void 0!==g&&b(g)&&d.push(g);else for(e=0;e<c.ka.length;e+=1)g=c.ka[e],void 0!==g&&0<=g.sj.indexOf(b)&&d.push(g);return d}function Ob(b){b.Aa+=1}
function Pb(b){var c=Nb(b);for(b=0;b<c.length;b+=1)Ob(c[b])}function Qb(b){b.Aa=Math.max(0,b.Aa-1)}function Rb(b){var c=Nb(b);for(b=0;b<c.length;b+=1)Qb(c[b])}function Sb(b){var c=u;b=c.ka.indexOf(b);if(!(0>b)){c.ka[b].kf&&c.ka[b].kf();var d=c.ka[b];d.ne&&(c.ym-=1);d.$u&&(c.zm-=1);if(d.Ld||d.Tf)c.dh-=1;d.Sf&&(c.dh-=1);if(d.oe||d.xh)c.Dm-=1;d.Tj&&(c.xm-=1);d.Dg&&(c.Em-=1);d.Ab&&(c.Am-=1);d.av&&(c.Bm-=1);if(d.Uj||d.Cg)c.Ef-=1;d.dv&&(c.Ef-=1);if(d.bv||d.cv)c.Uk-=1;d.ev&&(c.Cm-=1);c.ka[b]=void 0}}
sb.prototype.e=function(b,c,d,e,g,h,l){void 0===l&&(l=0);this.Dd.push({Cy:0,c:b,Da:c,qF:d,visible:!0,x:e,y:g,os:1,qs:1,qb:0,alpha:1,depth:h,d:l,Aa:0,sj:[]});this.us=!0;return this.Dd[this.Dd.length-1]};var u=new sb(aa);new da;function Tb(b,c){return c}function Ub(b,c,d,e){return c+b/e*d}function Vb(b,c,d,e,g){void 0===g&&(g=3);return c+d*Math.pow(b/e,g)}function Wb(b,c,d,e){return c+d*Vb(e-b,1,-1,e,3)}function Xb(b,c,d,e){return Vb(b,c,d,e,3)}
function Yb(b,c,d,e){return c+d*(b<e/2?Vb(b,0,.5,e/2,3):Vb(e-b,1,-.5,e/2,3))}function bc(b,c,d,e,g,h){b=e-b;var l=h;void 0===g&&(g=3);void 0===l&&(l=8);h=Math.sin(2*(1-b/e)*Math.PI*g+Math.PI/2);g=l;void 0===g&&(g=8);l=Math.pow(2,-g);h*=0+(Math.pow(2,g*b/e-g)-l)/(1-l)*1;return c+d*(1+-1*h)}function cc(b,c,d,e,g){void 0===g&&(g=1.70158);return c+d*((1+g)*Math.pow(b/e,3)-g*Math.pow(b/e,2))}function dc(b,c,d,e,g){return c+d*cc(e-b,1,-1,e,g)}
function ec(b,c,d){var e,g=0,h=1,l=[0],m=[0];for(void 0===c&&(c=[]);c.length<b.length;)c.push(!1);for(void 0===d&&(d=[]);d.length<b.length;)d.push(1/b.length);for(e=0;e<b.length;e+=1)g+=d[e];for(e=0;e<b.length;e+=1)d[e]/=g;for(e=0;e<b.length;e+=1)m.push(m[e]+d[e]),g=b[e]===Tb?0:c[e]?-1:1,l.push(l[e]+g),h=Math.max(h,l[e+1]);return function(e,g,w,y,D,t,z){var A,B;A=b.length-1;for(B=0;B<b.length;B+=1)if(e/y<=m[B+1]){A=B;break}e=b[A](e/y-m[A],0,1,d[A],D,t,z);c[A]&&(e=-e);return g+(l[A]+e)*w/h}}
function fc(b,c,d){this.currentTime=this.paused=0;this.speed=1;this.Pi=!1;this.target=b;this.duration=0;this.Ve=[];this.sa=[];if(void 0!==c&&(b=c,void 0!==b))for(b=[].concat(b),c=0;c<b.length;c+=1)gc(this,b[c].kind,b[c].target,b[c].Gn,b[c].hi,b[c].keys);void 0!==d&&this.OQ(d)}function gc(b,c,d,e,g,h){b.Ve.push({kind:c,target:d,Gn:e,hi:g,keys:[],Pi:!1,bO:"none",zM:!0,CK:void 0});c=b.Ve[b.Ve.length-1];void 0!==h&&hc(b,c,h);return c}
function ic(b){var c;c=b.keys.length;return 0===c?0:b.keys[c-1].time}function jc(b){var c;for(c=b.duration=0;c<b.Ve.length;c+=1)b.duration=Math.max(b.duration,ic(b.Ve[c]));c=b.sa.length;b.duration=Math.max(b.duration,0===c?0:b.sa[c-1].time)}function hc(b,c,d){var e;if(void 0!==d)for(d=[].concat(d),e=0;e<d.length;e+=1){var g=b,h=c,l=d[e].D;void 0===l&&(l=Ub);h.keys.push({time:d[e].time,value:d[e].value,D:l,hi:d[e].hi});kc(h);jc(g)}}function kc(b){b.keys.sort(function(b,d){return b.time-d.time})}
function lc(b,c,d,e,g){b.sa.push({target:c,time:d,al:e,hi:g});c=b.sa[b.sa.length-1];mc(b);jc(b);return c}function mc(b){b.sa.sort(function(b,d){return b.time-d.time})}a=fc.prototype;a.pause=function(){this.paused+=1};a.Xi=function(){this.paused-=1};a.Rn=function(){return 0<this.paused};a.em=function(b){this.Pi=b};a.Aq=function(){return this.duration};function nc(b,c){b.Pi?(c%=b.duration,0>c&&(c+=b.duration)):c=Math.max(0,Math.min(b.duration,c));return c}
a.setTime=function(b,c){var d;this.currentTime=nc(this,b);if(!c)for(d=0;d<this.Ve.length;d+=1){var e=this.Ve[d],g=void 0,h=void 0;if(0!==e.keys.length){var g=e,h=this.currentTime,l=void 0,m=l=void 0,m=l=void 0,l=g.keys.length;if(0===l)g=0;else{g.Pi&&(h%=g.keys[l-1].time,0>h&&(h+=g.keys[l-1].time));if(h<=g.keys[0].time)l=g.keys[0].value;else if(h>=g.keys[l-1].time)l=g.keys[l-1].value;else{for(m=0;g.keys[m].time<h;)m+=1;l=g.keys[m-1];m=g.keys[m];l=l.D(h-l.time,l.value,m.value-l.value,m.time-l.time)}switch(g.bO){case "round":l=
Math.round(l);break;case "floor":l=Math.floor(l);break;case "ceil":l=Math.ceil(l)}g=l}if(g!==e.CK||!e.zM)if(h=void 0===e.target?this.target:e.target,void 0!==h||"function"===e.kind)switch(e.kind){case "image":h.c=g;break;case "subImage":h.Da=g;break;case "alpha":h.alpha=g;break;case "xScale":h.pb=g;break;case "yScale":h.Cb=g;break;case "scale":h.scale=g;break;case "angle":h.qb=g;break;case "x":h.x=g;break;case "y":h.y=g;break;case "speed":h.speed=g;break;case "function":void 0===h?e.Gn(g,e.hi):e.Gn.call(h,
g,e.hi)}}}};
a.lg=function(b){var c;if(!(0<this.paused)){b=nc(this,this.currentTime+this.speed*b);c=this.currentTime;var d,e=[];if(0<this.speed)if(b>=c)for(d=0;d<this.sa.length;d+=1)this.sa[d].time>c&&this.sa[d].time<=b&&e.push(this.sa[d]);else{for(d=0;d<this.sa.length;d+=1)this.sa[d].time>c&&e.push(this.sa[d]);for(d=0;d<this.sa.length;d+=1)this.sa[d].time<=b&&e.push(this.sa[d])}else if(b<=c)for(d=this.sa.length-1;0<=d;d-=1)this.sa[d].time<c&&this.sa[d].time>=b&&e.push(this.sa[d]);else{for(d=this.sa.length-1;0<=
d;d-=1)this.sa[d].time<c&&e.push(this.sa[d]);for(d=this.sa.length-1;0<=d;d-=1)this.sa[d].time>=b&&e.push(this.sa[d])}for(c=0;c<e.length;c+=1){this.setTime(e[c].time);d=e[c];var g=void 0,g=void 0===d.target?this.target:d.target;if(void 0===g?d.al(d.hi):d.al.call(g,d.hi)){this.currentTime=e[c].time-1E-7*Math.fU(this.speed);return}}this.setTime(b)}};
var oc=function(){function b(b,d,e,g,h,l){this.orientation=d;this.HM=e;this.YP=g;this.PO=h;this.Ft=l;this.YE=b.adChannel;this.dJ=b.gameCode;this.eJ=b.gameName;this.In=b.gameVersion;this.cJ=b.gameCategory;this.QH=b.developerId;this.bJ=b.gameAnalyticsId;this.oP=b.tabIcon;var m=setInterval(function(){this.ready()&&(this.oO(),clearInterval(m))}.bind(this),100)}b.prototype.ready=function(){return window.Booster.ready&&window.Booster.Ad};b.prototype.oO=function(){new Booster.Init({orientation:this.orientation,
splash:!0,minimalUI:!0,rotationOnHide:function(){window.setTimeout(function(){v.Se()},400)},rotationOnShow:function(){v.Ti()}});adSense=new Booster.Ad({type:"adsense",size:"300x250",channelID:this.YE});community=new Booster.Community({position:1,gameCode:this.dJ,tabIcon:this.oP});analytics=new Booster.Analytics({gameName:this.eJ,gameId:this.In,gameCategory:this.cJ,developer:this.QH,gameAnalyticsId:this.bJ});moregames=new Booster.Moregames;try{freemium=new Booster.Freemium}catch(b){}var d=this;Booster.onSplashFinishedEvent=
function(){d.PO.call(d.Ft)};Booster.onOpenTab=function(){d.HM.call(d.Ft)};Booster.onCloseTab=function(){d.YP.call(d.Ft)}};return b}(),pc={};window.placementSounds=pc;var qc={};window.removeSounds=qc;window.AppIcon60x60=new rb("AppIcon60x60","AppIcon60x60.png");window.AppIcon76x76=new rb("AppIcon76x76","AppIcon76x76.png");var x=new ra("FrameworkTexture",1,"frameworkImages");window.FrameworkTexture=x;sa(x,0,"media/FrameworkTexture0.png");var rc=new ra("FlowStartTexture",1,"startImages");
window.FlowStartTexture=rc;sa(rc,0,"media/FlowStartTexture0.png");var sc=new ra("FlowTexture",1,"images");window.FlowTexture=sc;sa(sc,0,"media/FlowTexture0.png");var tc=new ra("UITexture",1,"images");window.UITexture=tc;sa(tc,0,"media/UITexture0.png");var C=new ra("LevelMap",1,"load");window.LevelMap=C;sa(C,0,"media/LevelMap0.png");var E=new ra("texture",3,"load");window.texture=E;sa(E,0,"media/texture0.png");sa(E,1,"media/texture1.png");sa(E,2,"media/texture2.png");
var uc=new q("s_tgf_transparent",x,1,64,64,0,0,64,64,1);window.s_tgf_transparent=uc;uc.e(0,0,597,105,1,1,0,0);var vc=new q("s_tgf_throbber",x,12,78,78,0,0,936,78,12);window.s_tgf_throbber=vc;vc.e(0,0,689,93,74,75,2,1);vc.e(1,0,153,121,74,75,2,1);vc.e(2,0,77,121,74,75,2,1);vc.e(3,0,1,121,74,75,2,1);vc.e(4,0,521,105,74,75,2,1);vc.e(5,0,765,93,74,75,2,1);vc.e(6,0,765,173,74,75,2,1);vc.e(7,0,305,121,74,75,2,1);vc.e(8,0,381,125,74,75,2,1);vc.e(9,0,841,177,74,75,2,1);vc.e(10,0,229,121,74,75,2,1);
vc.e(11,0,689,173,74,75,2,1);var wc=new q("s_tgf_frame",x,1,120,120,0,0,120,120,1);window.s_tgf_frame=wc;wc.e(0,0,397,1,120,119,0,1);var F=new q("s_tgf_button",x,2,90,90,0,0,180,90,2);window.s_tgf_button=F;F.e(0,0,701,1,90,89,0,1);F.e(1,0,793,1,90,89,0,1);var xc=new q("s_tgf_tutorial_close",x,1,66,65,0,0,66,65,1);window.s_tgf_tutorial_close=xc;xc.e(0,0,457,185,65,65,0,0);var yc=new q("s_tgf_tutorial_next",x,1,66,65,0,0,66,65,1);window.s_tgf_tutorial_next=yc;yc.e(0,0,917,177,66,65,0,0);
var zc=new q("s_tgf_tutorial_previous",x,1,66,65,0,0,66,65,1);window.s_tgf_tutorial_previous=zc;zc.e(0,0,597,181,66,65,0,0);var Ac=new q("s_tgf_progressbar_back",x,1,42,30,0,0,42,30,1);window.s_tgf_progressbar_back=Ac;Ac.e(0,0,841,93,42,29,0,1);var Bc=new q("s_tgf_progressbar_fill",x,1,42,30,0,0,42,30,1);window.s_tgf_progressbar_fill=Bc;Bc.e(0,0,309,241,32,18,5,6);var Cc=new q("s_tgf_slider_back",x,2,64,16,0,0,64,32,1);window.s_tgf_slider_back=Cc;Cc.e(0,0,525,197,55,10,4,3);
Cc.e(1,0,525,185,55,10,4,3);var Dc=new q("s_tgf_slider_slider",x,1,16,48,0,0,16,48,1);window.s_tgf_slider_slider=Dc;Dc.e(0,0,665,181,13,41,1,3);var Ec=new q("s_tgf_icon_difficulty_easy",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_difficulty_easy=Ec;Ec.e(0,0,885,89,86,86,1,2);var Fc=new q("s_tgf_icon_difficulty_hard",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_difficulty_hard=Fc;Fc.e(0,0,601,93,86,86,1,2);var Gc=new q("s_tgf_icon_difficulty_medium",x,1,88,88,0,0,88,88,1);
window.s_tgf_icon_difficulty_medium=Gc;Gc.e(0,0,885,1,86,86,1,2);var Hc=new q("s_tgf_icon_music_off",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_music_off=Hc;Hc.e(0,0,57,201,51,40,17,24);var Ic=new q("s_tgf_icon_music_on",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_music_on=Ic;Ic.e(0,0,269,241,37,40,23,24);var Jc=new q("s_tgf_icon_sound_off",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_sound_off=Jc;Jc.e(0,0,1,201,53,31,20,28);var Kc=new q("s_tgf_icon_sound_on",x,1,88,88,0,0,88,88,1);
window.s_tgf_icon_sound_on=Kc;Kc.e(0,0,973,37,49,31,20,28);var Lc=new q("s_tgf_icon_options",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_options=Lc;Lc.e(0,0,457,125,55,56,17,17);var Mc=new q("s_tgf_icon_play",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_play=Mc;Mc.e(0,0,985,197,30,42,33,24);var Nc=new q("s_tgf_icon_pause",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_pause=Nc;Nc.e(0,0,985,153,36,42,26,24);var Oc=new q("s_tgf_icon_retry",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_retry=Oc;
Oc.e(0,0,217,241,47,44,23,23);var Pc=new q("s_tgf_icon_undo",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_undo=Pc;Pc.e(0,0,973,1,49,31,19,29);var Qc=new q("s_tgf_icon_exit",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_exit=Qc;Qc.e(0,0,1,237,48,46,15,22);var Rc=new q("s_tgf_icon_quit",x,1,88,88,0,0,88,88,1);window.s_tgf_icon_quit=Rc;Rc.e(0,0,841,125,40,42,24,24);var Sc=new q("s_tgf_icon_play_large",x,1,108,108,0,0,108,108,1);window.s_tgf_icon_play_large=Sc;Sc.e(0,0,521,1,76,99,20,4);
var Tc=new q("s_tgf_icon_retry_large",x,1,108,108,0,0,108,108,1);window.s_tgf_icon_retry_large=Tc;Tc.e(0,0,601,1,98,89,9,10);var Uc=new q("s_tgf_notification_warning",x,1,128,128,0,0,128,128,1);window.s_tgf_notification_warning=Uc;Uc.e(0,0,1,1,128,116,0,8);var Vc=new q("s_tgf_notification_message",x,1,128,128,0,0,128,128,1);window.s_tgf_notification_message=Vc;Vc.e(0,0,133,1,128,116,0,8);var Wc=new q("s_tgf_notification_error",x,1,128,128,0,0,128,128,1);window.s_tgf_notification_error=Wc;
Wc.e(0,0,265,1,128,116,0,8);var Xc=new q("s_tgf_console_play",x,1,48,48,24,24,48,48,1);window.s_tgf_console_play=Xc;Xc.e(0,0,577,209,17,24,18,13);var Yc=new q("s_tgf_console_pause",x,1,48,48,24,24,48,48,1);window.s_tgf_console_pause=Yc;Yc.e(0,0,665,225,21,24,14,13);var Zc=new q("s_tgf_console_restart",x,1,48,48,24,24,48,48,1);window.s_tgf_console_restart=Zc;Zc.e(0,0,985,241,27,25,12,12);var $c=new q("s_tgf_console_step",x,1,48,48,24,24,48,48,1);window.s_tgf_console_step=$c;
$c.e(0,0,425,241,28,18,10,16);var ad=new q("s_tgf_console_position",x,1,48,48,24,24,48,48,1);window.s_tgf_console_position=ad;ad.e(0,0,425,205,25,34,12,7);var bd=new q("s_tgf_console_close",x,1,48,48,24,24,48,48,1);window.s_tgf_console_close=bd;bd.e(0,0,345,241,23,24,13,13);var cd=new q("s_tgf_flag_us",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_us=cd;cd.e(0,0,525,209,48,36,0,6);var dd=new q("s_tgf_flag_gb",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_gb=dd;dd.e(0,0,217,201,48,36,0,6);
var ed=new q("s_tgf_flag_nl",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_nl=ed;ed.e(0,0,973,73,48,36,0,6);var fd=new q("s_tgf_flag_tr",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_tr=fd;fd.e(0,0,113,201,48,36,0,6);var gd=new q("s_tgf_flag_de",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_de=gd;gd.e(0,0,973,113,48,36,0,6);var hd=new q("s_tgf_flag_fr",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_fr=hd;hd.e(0,0,165,201,48,36,0,6);var id=new q("s_tgf_flag_br",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_br=id;
id.e(0,0,321,201,48,36,0,6);var jd=new q("s_tgf_flag_es",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_es=jd;jd.e(0,0,113,241,48,36,0,6);var kd=new q("s_tgf_flag_ru",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_ru=kd;kd.e(0,0,373,205,48,36,0,6);var ld=new q("s_tgf_flag_ar",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_ar=ld;ld.e(0,0,165,241,48,36,0,6);var md=new q("s_tgf_flag_kr",x,1,48,48,0,0,48,48,1);window.s_tgf_flag_kr=md;md.e(0,0,269,201,48,36,0,6);var nd=new q("s_tgf_flag_unknown",x,1,48,48,0,0,48,48,1);
window.s_tgf_flag_unknown=nd;nd.e(0,0,597,109,1,1,0,0);var od=new q("s_sfx_star",E,8,300,300,1,1,2400,300,8);window.s_sfx_star=od;od.e(0,1,1913,881,134,131,85,89);od.e(1,1,1745,1,250,244,19,27);od.e(2,0,1741,1753,257,253,17,20);od.e(3,0,1741,1485,266,263,12,15);od.e(4,0,1741,937,262,273,13,10);od.e(5,0,1741,1213,251,270,19,12);od.e(6,0,1829,1,213,260,38,16);od.e(7,0,1741,609,243,299,23,1);var pd=new q("s_star01_empty",E,1,170,170,0,0,170,170,1);window.s_star01_empty=pd;
pd.e(0,1,1745,881,163,168,2,2);var qd=new q("s_star01_fill",E,1,170,170,0,0,170,170,1);window.s_star01_fill=qd;qd.e(0,2,1901,381,142,147,14,17);var rd=new q("s_star02_empty",E,1,170,170,0,0,170,170,1);window.s_star02_empty=rd;rd.e(0,1,1745,1053,168,162,1,1);var sd=new q("s_star02_fill",E,1,170,170,0,0,170,170,1);window.s_star02_fill=sd;sd.e(0,2,685,385,146,141,12,16);var td=new q("s_star03_empty",E,1,170,170,0,0,170,170,1);window.s_star03_empty=td;td.e(0,1,1745,1217,164,168,4,2);
var ud=new q("s_star03_fill",E,1,170,170,0,0,170,170,1);window.s_star03_fill=ud;ud.e(0,1,1905,1525,142,148,14,16);var vd=new q("s_tgf_buttonSelect",E,2,90,90,0,0,180,90,2);window.s_tgf_buttonSelect=vd;vd.e(0,1,189,1957,90,89,0,1);vd.e(1,1,97,1957,90,89,0,1);var wd=new q("s_logo_tinglygames",E,1,240,240,0,0,240,240,1);window.s_logo_tinglygames=wd;wd.e(0,1,1745,249,240,167,0,36);var xd=new q("s_level2_0",E,1,84,87,0,0,84,87,1);window.s_level2_0=xd;xd.e(0,2,89,669,84,87,0,0);
var yd=new q("s_level2_1",E,1,84,87,0,0,84,87,1);window.s_level2_1=yd;yd.e(0,2,1489,669,84,87,0,0);var zd=new q("s_level2_2",E,1,84,87,0,0,84,87,1);window.s_level2_2=zd;zd.e(0,2,377,661,84,87,0,0);var Ad=new q("s_level2_3",E,1,84,87,0,0,84,87,1);window.s_level2_3=Ad;Ad.e(0,2,1,661,84,87,0,0);var Bd=new q("s_level2_lock",E,1,84,87,0,0,84,87,1);window.s_level2_lock=Bd;Bd.e(0,2,205,661,84,87,0,0);var Cd=new q("blackAdFrame",E,1,128,128,0,0,128,128,1);window.blackAdFrame=Cd;
Cd.e(0,1,1917,1149,128,128,0,0);var Dd=new q("s_logo_tinglygames_small",rc,1,156,54,78,27,156,54,1);window.s_logo_tinglygames_small=Dd;Dd.e(0,0,657,1,78,54,39,0);var Ed=new q("s_logo_tinglygames_large",sc,1,240,240,0,0,240,240,1);window.s_logo_tinglygames_large=Ed;Ed.e(0,0,1,1,240,167,0,36);var Fd=new q("s_logo_tinglygames_background",rc,1,200,200,0,0,200,200,1);window.s_logo_tinglygames_background=Fd;Fd.e(0,0,1,1,200,200,0,0);var Gd=new q("s_dialog_load_frame",rc,1,120,120,0,0,120,120,1);
window.s_dialog_load_frame=Gd;Gd.e(0,0,529,1,120,120,0,0);var Hd=new q("s_dialog_load_bar_back",rc,1,38,20,0,0,38,20,1);window.s_dialog_load_bar_back=Hd;Hd.e(0,0,737,1,38,20,0,0);var Id=new q("s_dialog_load_bar_fill",rc,1,30,12,0,0,30,12,1);window.s_dialog_load_bar_fill=Id;Id.e(0,0,777,1,30,12,0,0);var Jd=new q("s_dialog_load_btn_load",rc,2,154,152,0,0,154,304,1);window.s_dialog_load_btn_load=Jd;Jd.e(0,0,369,1,154,152,0,0);Jd.e(1,0,209,1,154,152,0,0);
var Kd=new q("s_btn_big_start",E,2,154,152,77,76,308,152,2);window.s_btn_big_start=Kd;Kd.e(0,1,509,1877,154,152,0,0);Kd.e(1,1,1001,645,154,152,0,0);var Ld=new q("s_btn_bigtext",E,2,153,152,76,76,306,152,2);window.s_btn_bigtext=Ld;Ld.e(0,2,529,385,153,152,0,0);Ld.e(1,1,821,1877,153,152,0,0);var Md=new q("s_btn_small_exit",E,2,100,92,50,46,200,92,2);window.s_btn_small_exit=Md;Md.e(0,2,1,565,100,92,0,0);Md.e(1,2,205,565,100,92,0,0);var Nd=new q("s_btn_small_options",E,2,100,92,50,46,200,92,2);
window.s_btn_small_options=Nd;Nd.e(0,2,1533,573,100,92,0,0);Nd.e(1,2,1385,589,100,92,0,0);var Od=new q("s_btn_small_pause",E,2,100,92,50,46,200,92,2);window.s_btn_small_pause=Od;Od.e(0,2,1281,577,100,92,0,0);Od.e(1,2,1741,573,100,92,0,0);var Pd=new q("s_btn_small_undo",E,2,100,92,50,46,200,92,2);window.s_btn_small_undo=Pd;Pd.e(0,2,309,565,100,92,0,0);Pd.e(1,2,413,565,100,92,0,0);var Qd=new q("s_btn_standard",E,2,96,92,0,0,192,92,2);window.s_btn_standard=Qd;Qd.e(0,2,1845,629,96,92,0,0);
Qd.e(1,2,637,625,96,92,0,0);var Rd=new q("s_btn_toggle",E,2,162,92,81,46,324,92,2);window.s_btn_toggle=Rd;Rd.e(0,1,1741,1525,162,92,0,0);Rd.e(1,1,1741,1621,162,92,0,0);var Sd=new q("s_buttons_bigtext",E,2,137,104,0,52,274,104,2);window.s_buttons_bigtext=Sd;Sd.e(0,1,353,1921,137,104,0,0);Sd.e(1,1,1905,1677,137,104,0,0);var Td=new q("s_icon_toggle_fxoff",E,2,227,92,113,46,454,92,2);window.s_icon_toggle_fxoff=Td;Td.e(0,0,457,1929,227,92,0,0);Td.e(1,0,1153,1929,227,92,0,0);
var Vd=new q("s_icon_toggle_fxon",E,2,227,92,113,46,454,92,2);window.s_icon_toggle_fxon=Vd;Vd.e(0,0,1385,1929,227,92,0,0);Vd.e(1,1,1745,421,227,92,0,0);var Wd=new q("s_icon_toggle_music_off",E,1,67,67,33,33,67,67,1);window.s_icon_toggle_music_off=Wd;Wd.e(0,1,509,1833,51,41,8,13);var Xd=new q("s_icon_toggle_music_on",E,1,67,67,33,33,67,67,1);window.s_icon_toggle_music_on=Xd;Xd.e(0,0,2005,1133,38,41,13,13);var Yd=new q("s_icon_toggle_musicoff",E,2,227,92,113,46,454,92,2);
window.s_icon_toggle_musicoff=Yd;Yd.e(0,1,1745,517,227,92,0,0);Yd.e(1,0,921,1929,227,92,0,0);var Zd=new q("s_icon_toggle_musicon",E,2,227,92,0,0,454,92,2);window.s_icon_toggle_musicon=Zd;Zd.e(0,0,689,1929,227,92,0,0);Zd.e(1,1,1745,613,227,92,0,0);var $d=new q("s_icon_toggle_sfx_off",E,1,67,67,33,33,67,67,1);window.s_icon_toggle_sfx_off=$d;$d.e(0,0,1737,2009,53,31,7,17);var ae=new q("s_icon_toggle_sfx_on",E,1,67,67,33,33,67,67,1);window.s_icon_toggle_sfx_on=ae;ae.e(0,0,1997,1445,49,31,7,17);
var be=new q("s_buttons_bigtext_play",E,1,66,66,33,33,66,66,1);window.s_buttons_bigtext_play=be;be.e(0,0,1989,721,51,66,8,0);var ce=new q("s_btn_small_retry",E,2,100,92,50,46,200,92,2);window.s_btn_small_retry=ce;ce.e(0,2,1637,573,100,92,0,0);ce.e(1,2,1177,577,100,92,0,0);var de=new q("s_btn_big_restart",E,2,154,152,0,0,308,152,2);window.s_btn_big_restart=de;de.e(0,1,353,1765,154,152,0,0);de.e(1,1,665,1877,154,152,0,0);var ee=new q("s_profilepicture_default",E,1,128,128,0,0,128,128,1);
window.s_profilepicture_default=ee;ee.e(0,1,1913,1281,128,128,0,0);var fe=new q("s_tutorialButton_previous",E,1,66,65,0,0,66,65,1);window.s_tutorialButton_previous=fe;fe.e(0,1,1045,1981,66,65,0,0);var ge=new q("s_tutorialButton_next",E,1,66,65,0,0,66,65,1);window.s_tutorialButton_next=ge;ge.e(0,1,933,829,66,65,0,0);var ie=new q("s_tutorialButton_exit",E,1,66,65,0,0,66,65,1);window.s_tutorialButton_exit=ie;ie.e(0,1,1181,1981,65,65,0,0);var je=new q("s_button_drop_icon_coin",E,1,28,33,0,0,28,33,1);
window.s_button_drop_icon_coin=je;je.e(0,0,2009,1717,28,33,0,0);var ke=new q("s_about",E,1,524,562,0,0,524,562,1);window.s_about=ke;ke.e(0,2,1,1,524,562,0,0);var le=new q("s_ui_background",tc,1,140,580,0,0,140,580,1);window.s_ui_background=le;le.e(0,0,1,1,140,580,0,0);var me=new q("s_ui_progress_round_background",tc,1,120,190,60,60,120,190,1);window.s_ui_progress_round_background=me;me.e(0,0,145,1,120,190,0,0);var ne=new q("s_ui_star_empty",tc,1,24,24,12,12,24,24,1);window.s_ui_star_empty=ne;
ne.e(0,0,305,1,24,23,0,0);var oe=new q("s_ui_star_filled",tc,1,24,24,12,12,24,24,1);window.s_ui_star_filled=oe;oe.e(0,0,273,1,24,23,0,0);var pe=new q("s_tutorial",E,1,578,522,0,0,578,522,1);window.s_tutorial=pe;pe.e(0,1,1,917,578,522,0,0);var qe=new q("s_tutorialButton_exit_pink",E,1,66,65,33,32,66,65,1);window.s_tutorialButton_exit_pink=qe;qe.e(0,1,1249,1981,65,65,0,0);var re=new q("s_tutorialButton_next_pink",E,1,66,65,33,32,66,65,1);window.s_tutorialButton_next_pink=re;
re.e(0,1,509,1765,66,65,0,0);var se=new q("s_tutorialButton_previous_pink",E,1,66,65,33,32,66,65,1);window.s_tutorialButton_previous_pink=se;se.e(0,1,977,1981,66,65,0,0);var te=new q("s_profilepicture_penguin",E,1,94,108,0,0,94,108,1);window.s_profilepicture_penguin=te;te.e(0,1,1913,1413,94,108,0,0);var ue=new q("s_overlay_worldmap_levelselect",E,1,1152,640,576,320,1152,640,1);window.s_overlay_worldmap_levelselect=ue;ue.e(0,0,1,1,750,607,111,5);
var ve=new q("s_overlay_assignment",E,1,602,273,301,136,602,273,1);window.s_overlay_assignment=ve;ve.e(0,1,1,645,598,267,0,2);var we=new q("s_ui_progress_round_foreground",E,1,120,120,60,60,120,120,1);window.s_ui_progress_round_foreground=we;we.e(0,2,1085,385,120,120,0,0);var xe=new q("s_tutorial_01",E,1,350,190,0,0,350,190,1);window.s_tutorial_01=xe;xe.e(0,2,529,193,350,190,0,0);var ye=new q("s_tutorial_02",E,1,350,190,0,0,350,190,1);window.s_tutorial_02=ye;ye.e(0,2,1233,193,350,190,0,0);
var ze=new q("s_tutorial_03",E,1,350,190,0,0,350,190,1);window.s_tutorial_03=ze;ze.e(0,2,1585,1,350,190,0,0);var Ae=new q("s_tutorial_04",E,1,350,190,0,0,350,190,1);window.s_tutorial_04=Ae;Ae.e(0,1,993,1789,350,190,0,0);var Be=new q("s_tutorial_05",E,1,350,190,0,0,350,190,1);window.s_tutorial_05=Be;Be.e(0,1,1697,1797,350,190,0,0);var Ce=new q("s_tutorial_06",E,1,350,190,0,0,350,190,1);window.s_tutorial_06=Ce;Ce.e(0,2,881,1,350,190,0,0);var De=new q("s_tutorial_07",E,1,350,190,0,0,350,190,1);
window.s_tutorial_07=De;De.e(0,1,1389,1605,350,190,0,0);var Ee=new q("s_tutorial_08",E,1,350,190,0,0,350,190,1);window.s_tutorial_08=Ee;Ee.e(0,2,881,193,350,190,0,0);var Fe=new q("s_tutorial_09",E,1,350,190,0,0,350,190,1);window.s_tutorial_09=Fe;Fe.e(0,1,1345,1797,350,190,0,0);var Ge=new q("s_tutorial_010",E,1,350,190,0,0,350,190,1);window.s_tutorial_010=Ge;Ge.e(0,2,529,1,350,190,0,0);var He=new q("s_tutorial_011",E,1,350,190,0,0,350,190,1);window.s_tutorial_011=He;He.e(0,2,1233,1,350,190,0,0);
var Ie=new q("s_tutorial_012",E,1,350,190,0,0,350,190,1);window.s_tutorial_012=Ie;Ie.e(0,1,1,1765,350,190,0,0);var Je=new q("s_road_1",C,1,742,640,371,320,742,640,1);window.s_road_1=Je;Je.e(0,0,765,1,742,640,0,0);var Ke=new q("s_road_2",C,1,759,640,379,320,759,640,1);window.s_road_2=Ke;Ke.e(0,0,1,1,759,640,0,0);var Le=new q("s_roadblock",C,1,62,54,31,27,62,54,1);window.s_roadblock=Le;Le.e(0,0,1777,1917,62,54,0,0);var Me=new q("s_speedbump_1",C,1,29,65,14,32,29,65,1);window.s_speedbump_1=Me;
Me.e(0,0,1989,237,29,65,0,0);var Ne=new q("s_speedbump_2",C,1,58,45,29,22,58,45,1);window.s_speedbump_2=Ne;Ne.e(0,0,1989,405,58,45,0,0);var Oe=new q("s_speedbump_3",C,1,61,39,30,19,61,39,1);window.s_speedbump_3=Oe;Oe.e(0,0,457,1921,61,39,0,0);var Pe=new q("s_speedbump_4",C,1,64,31,32,15,64,31,1);window.s_speedbump_4=Pe;Pe.e(0,0,1513,1897,64,31,0,0);var Qe=new q("s_topplayer",C,1,112,142,56,71,112,142,1);window.s_topplayer=Qe;Qe.e(0,0,993,1685,112,142,0,0);
var Re=new q("s_background_pattern_grass",C,1,180,180,90,90,180,180,1);window.s_background_pattern_grass=Re;Re.e(0,0,825,1517,166,167,2,8);var Se=new q("s_bush_1",C,1,52,32,26,16,52,32,1);window.s_bush_1=Se;Se.e(0,0,1989,1521,52,32,0,0);var Te=new q("s_bush_2",C,1,56,31,28,15,56,31,1);window.s_bush_2=Te;Te.e(0,0,1989,549,56,31,0,0);var Ue=new q("s_firehydrant",C,1,24,26,12,13,24,26,1);window.s_firehydrant=Ue;Ue.e(0,0,2021,237,24,26,0,0);var Ve=new q("s_house_grass_1",C,1,81,121,40,60,81,121,1);
window.s_house_grass_1=Ve;Ve.e(0,0,1341,1241,81,121,0,0);var We=new q("s_house_grass_2",C,1,103,82,51,41,103,82,1);window.s_house_grass_2=We;We.e(0,0,137,1869,103,82,0,0);var Xe=new q("s_house_grass_3",C,1,133,115,66,57,133,115,1);window.s_house_grass_3=Xe;Xe.e(0,0,1357,1757,133,115,0,0);var Ye=new q("s_house_grass_4",C,1,133,115,66,57,133,115,1);window.s_house_grass_4=Ye;Ye.e(0,0,437,1801,132,115,1,0);var Ze=new q("s_house_grass_5",C,1,131,121,65,60,131,121,1);window.s_house_grass_5=Ze;
Ze.e(0,0,709,1805,131,121,0,0);var $e=new q("s_house_grass_6",C,1,133,115,66,57,133,115,1);window.s_house_grass_6=$e;$e.e(0,0,301,1777,132,115,1,0);var af=new q("s_house_grass_7",C,1,133,115,66,57,133,115,1);window.s_house_grass_7=af;af.e(0,0,1,1765,133,115,0,0);var bf=new q("s_house_grass_8",C,1,258,145,129,72,258,145,1);window.s_house_grass_8=bf;bf.e(0,0,1593,1265,258,145,0,0);var cf=new q("s_house_grass_9",C,1,139,124,69,62,139,124,1);window.s_house_grass_9=cf;cf.e(0,0,1621,1733,139,124,0,0);
var df=new q("s_lamp",C,1,21,78,10,39,21,78,1);window.s_lamp=df;df.e(0,0,2017,1,21,78,0,0);var ef=new q("s_rock_1",C,1,43,47,21,23,43,47,1);window.s_rock_1=ef;ef.e(0,0,993,1517,43,47,0,0);var ff=new q("s_rock_2",C,1,31,19,15,9,31,19,1);window.s_rock_2=ff;ff.e(0,0,865,1441,31,19,0,0);var gf=new q("s_rock_3",C,1,36,39,18,19,36,39,1);window.s_rock_3=gf;gf.e(0,0,629,1529,36,39,0,0);var G=new q("s_tree_1",C,1,105,135,52,67,105,135,1);window.s_tree_1=G;G.e(0,0,1249,1757,105,135,0,0);
var H=new q("s_tree_2",C,1,88,105,44,52,88,105,1);window.s_tree_2=H;H.e(0,0,1877,1829,88,105,0,0);var I=new q("s_tree_3",C,1,72,85,36,42,72,85,1);window.s_tree_3=I;I.e(0,0,1157,1865,72,85,0,0);var hf=new q("s_tree_4",C,1,68,89,34,44,68,89,1);window.s_tree_4=hf;hf.e(0,0,1621,1621,68,89,0,0);var jf=new q("s_tree_5",C,1,96,114,48,57,96,114,1);window.s_tree_5=jf;jf.e(0,0,965,1829,96,114,0,0);var kf=new q("s_water_1",C,1,209,70,104,35,209,70,1);window.s_water_1=kf;kf.e(0,0,689,1369,209,70,0,0);
var lf=new q("s_water_2",C,1,173,46,86,23,173,46,1);window.s_water_2=lf;lf.e(0,0,689,1441,173,46,0,0);var mf=new q("s_water_3",C,1,173,46,86,23,173,46,1);window.s_water_3=mf;mf.e(0,0,865,1469,172,46,0,0);var nf=new q("s_watertower",C,1,114,204,57,102,114,204,1);window.s_watertower=nf;nf.e(0,0,1593,1413,114,204,0,0);var of=new q("s_background_pattern_desert",C,1,180,180,90,90,180,180,1);window.s_background_pattern_desert=of;of.e(0,0,1825,1521,161,162,10,18);
var pf=new q("s_bush_4",C,1,61,43,30,21,61,43,1);window.s_bush_4=pf;pf.e(0,0,521,1921,61,43,0,0);var qf=new q("s_bush_5",C,1,63,49,31,24,63,49,1);window.s_bush_5=qf;qf.e(0,0,1709,1917,63,49,0,0);var rf=new q("s_cactus_1",C,1,50,77,25,38,50,77,1);window.s_cactus_1=rf;rf.e(0,0,1989,85,50,77,0,0);var sf=new q("s_cactus_2",C,1,38,52,19,26,38,52,1);window.s_cactus_2=sf;sf.e(0,0,1109,1369,38,52,0,0);var tf=new q("s_campfire",C,1,122,58,61,29,122,58,1);window.s_campfire=tf;tf.e(0,0,1205,1513,122,58,0,0);
var uf=new q("s_house_desert_1",C,1,152,129,76,64,152,129,1);window.s_house_desert_1=uf;uf.e(0,0,157,1621,152,129,0,0);var vf=new q("s_house_desert_2",C,1,98,139,49,69,98,139,1);window.s_house_desert_2=vf;vf.e(0,0,1937,1685,98,139,0,0);var wf=new q("s_house_desert_3",C,1,109,140,54,70,109,140,1);window.s_house_desert_3=wf;wf.e(0,0,1825,1685,109,140,0,0);var xf=new q("s_house_desert_4",C,1,134,170,67,85,134,170,1);window.s_house_desert_4=xf;xf.e(0,0,689,1489,134,170,0,0);
var yf=new q("s_house_desert_5",C,1,91,139,45,69,91,139,1);window.s_house_desert_5=yf;yf.e(0,0,1953,1089,91,139,0,0);var zf=new q("s_house_desert_6",C,1,91,139,45,69,91,139,1);window.s_house_desert_6=zf;zf.e(0,0,1953,945,91,139,0,0);var Af=new q("s_house_desert_7",C,1,142,153,71,76,142,153,1);window.s_house_desert_7=Af;Af.e(0,0,1205,1601,142,153,0,0);var Bf=new q("s_rock_4",C,1,48,41,24,20,48,41,1);window.s_rock_4=Bf;Bf.e(0,0,1109,1425,48,41,0,0);var Cf=new q("s_rock_5",C,1,29,32,14,16,29,32,1);
window.s_rock_5=Cf;Cf.e(0,0,1989,1557,29,32,0,0);var Df=new q("s_rock_6",C,1,31,22,15,11,31,22,1);window.s_rock_6=Df;Df.e(0,0,1989,585,31,22,0,0);var Ef=new q("s_shiprock_1",C,1,236,248,118,124,236,248,1);window.s_shiprock_1=Ef;Ef.e(0,0,1,1369,236,248,0,0);var Ff=new q("s_shiprock_2",C,1,300,329,150,164,300,329,1);window.s_shiprock_2=Ff;Ff.e(0,0,1741,613,300,329,0,0);var Gf=new q("s_shiprock_3",C,1,113,170,56,85,113,170,1);window.s_shiprock_3=Gf;Gf.e(0,0,1709,1413,113,170,0,0);
var Hf=new q("s_skull",C,1,58,48,29,24,58,48,1);window.s_skull=Hf;Hf.e(0,0,1989,305,58,48,0,0);var If=new q("s_tree_6",C,1,109,123,54,61,109,123,1);window.s_tree_6=If;If.e(0,0,1493,1769,109,123,0,0);var Jf=new q("s_tree_7",C,1,121,146,60,73,121,146,1);window.s_tree_7=Jf;Jf.e(0,0,1497,1621,121,146,0,0);var Kf=new q("s_tree_8",C,1,107,86,53,43,107,86,1);window.s_tree_8=Kf;Kf.e(0,0,1765,1829,107,86,0,0);var Lf=new q("s_tree_9",C,1,157,123,78,61,157,123,1);window.s_tree_9=Lf;
Lf.e(0,0,469,1529,157,123,0,0);var Mf=new q("s_water_6",C,1,271,88,135,44,271,88,1);window.s_water_6=Mf;Mf.e(0,0,1161,1149,271,88,0,0);var Nf=new q("s_well",C,1,57,69,28,34,57,69,1);window.s_well=Nf;Nf.e(0,0,1989,165,57,69,0,0);var Of=new q("s_bed",C,1,61,50,30,25,61,50,1);window.s_bed=Of;Of.e(0,0,393,1921,61,50,0,0);var Pf=new q("s_boat_1",C,1,111,39,55,19,111,39,1);window.s_boat_1=Pf;Pf.e(0,0,1041,1469,111,39,0,0);var Qf=new q("s_boat_2",C,1,152,140,76,70,152,140,1);window.s_boat_2=Qf;
Qf.e(0,0,1,1621,152,140,0,0);var Rf=new q("s_bush_8",C,1,72,50,36,25,72,50,1);window.s_bush_8=Rf;Rf.e(0,0,1341,1365,72,50,0,0);var Sf=new q("s_bush_9",C,1,72,50,36,25,72,50,1);window.s_bush_9=Sf;Sf.e(0,0,317,1897,72,50,0,0);var Tf=new q("s_bush_10",C,1,64,44,32,22,64,44,1);window.s_bush_10=Tf;Tf.e(0,0,1445,1897,64,44,0,0);var Uf=new q("s_house_beach_1",C,1,145,151,72,75,145,151,1);window.s_house_beach_1=Uf;Uf.e(0,0,313,1621,145,151,0,0);var Vf=new q("s_house_beach_2",C,1,144,153,72,76,144,153,1);
window.s_house_beach_2=Vf;Vf.e(0,0,1349,1601,144,153,0,0);var Wf=new q("s_house_beach_3",C,1,159,169,79,84,159,169,1);window.s_house_beach_3=Wf;Wf.e(0,0,1041,1513,159,169,0,0);var Xf=new q("s_house_beach_4",C,1,143,141,71,70,143,141,1);window.s_house_beach_4=Xf;Xf.e(0,0,461,1657,143,141,0,0);var Yf=new q("s_house_beach_5",C,1,123,142,61,71,123,142,1);window.s_house_beach_5=Yf;Yf.e(0,0,609,1661,123,142,0,0);var Zf=new q("s_ocean_1_a",C,1,196,609,98,304,196,609,1);window.s_ocean_1_a=Zf;
Zf.e(0,0,1605,1,196,609,0,0);var $f=new q("s_ocean_1_b",C,1,196,609,98,304,196,609,1);window.s_ocean_1_b=$f;$f.e(0,0,1805,1,182,609,0,0);var ag=new q("s_ocean_2_a",C,1,176,268,88,134,176,268,1);window.s_ocean_2_a=ag;ag.e(0,0,1161,1241,176,268,0,0);var bg=new q("s_ocean_2_b",C,1,176,268,88,134,176,268,1);window.s_ocean_2_b=bg;bg.e(0,0,1437,1149,152,268,24,0);var cg=new q("s_parasol",C,1,83,78,41,39,83,78,1);window.s_parasol=cg;cg.e(0,0,1357,1877,83,78,0,0);
var dg=new q("s_pool",C,1,205,96,102,48,205,96,1);window.s_pool=dg;dg.e(0,0,901,1369,205,96,0,0);var eg=new q("s_rock_9",C,1,80,90,40,45,80,90,1);window.s_rock_9=eg;eg.e(0,0,1509,1517,80,90,0,0);var fg=new q("s_rock_10",C,1,115,111,57,55,115,111,1);window.s_rock_10=fg;fg.e(0,0,845,1829,115,111,0,0);var gg=new q("s_rock_water",C,1,32,28,16,14,32,28,1);window.s_rock_water=gg;gg.e(0,0,1993,1233,32,28,0,0);var hg=new q("s_rock_water_2",C,1,67,73,33,36,67,73,1);window.s_rock_water_2=hg;
hg.e(0,0,245,1897,67,73,0,0);var ig=new q("s_sandcastle",C,1,62,68,31,34,62,68,1);window.s_sandcastle=ig;ig.e(0,0,1233,1897,62,68,0,0);var jg=new q("s_starfish",C,1,26,24,13,12,26,24,1);window.s_starfish=jg;jg.e(0,0,2021,265,26,24,0,0);var kg=new q("s_bush_6",C,1,56,33,28,16,56,33,1);window.s_bush_6=kg;kg.e(0,0,1989,513,56,33,0,0);var lg=new q("s_bush_7",C,1,54,34,27,17,54,34,1);window.s_bush_7=lg;lg.e(0,0,1681,613,54,34,0,0);var mg=new q("s_house_snow_1",C,1,139,111,69,55,139,111,1);
window.s_house_snow_1=mg;mg.e(0,0,157,1753,139,111,0,0);var ng=new q("s_house_snow_2",C,1,137,104,68,52,137,104,1);window.s_house_snow_2=ng;ng.e(0,0,1109,1757,137,104,0,0);var og=new q("s_house_snow_3",C,1,139,111,69,55,139,111,1);window.s_house_snow_3=og;og.e(0,0,737,1689,139,111,0,0);var pg=new q("s_house_snow_4",C,1,132,111,66,55,132,111,1);window.s_house_snow_4=pg;pg.e(0,0,573,1805,132,111,0,0);var qg=new q("s_icerock_1",C,1,164,254,82,127,164,254,1);window.s_icerock_1=qg;
qg.e(0,0,1853,1265,164,254,0,0);var rg=new q("s_icerock_2",C,1,338,306,169,153,338,306,1);window.s_icerock_2=rg;rg.e(0,0,1613,957,338,306,0,0);var sg=new q("s_jacuzzi",C,1,58,46,29,23,58,46,1);window.s_jacuzzi=sg;sg.e(0,0,1989,357,58,46,0,0);var tg=new q("s_lamp_snow",C,1,23,82,11,41,23,82,1);window.s_lamp_snow=tg;tg.e(0,0,1989,1,23,82,0,0);var ug=new q("s_rock_7",C,1,37,27,18,13,37,27,1);window.s_rock_7=ug;ug.e(0,0,1953,1233,37,27,0,0);var vg=new q("s_rock_8",C,1,74,66,37,33,74,66,1);
window.s_rock_8=vg;vg.e(0,0,1,1885,74,66,0,0);var wg=new q("s_snowman",C,1,35,57,17,28,35,57,1);window.s_snowman=wg;wg.e(0,0,1989,453,35,57,0,0);var xg=new q("s_swing",C,1,63,93,31,46,63,93,1);window.s_swing=xg;xg.e(0,0,1509,1421,63,93,0,0);var yg=new q("s_topplayer_snow",C,1,112,146,56,73,112,146,1);window.s_topplayer_snow=yg;yg.e(0,0,1709,1585,112,146,0,0);var Ag=new q("s_tree_10",C,1,89,105,44,52,89,105,1);window.s_tree_10=Ag;Ag.e(0,0,1065,1865,89,105,0,0);
var J=new q("s_tree_11",C,1,73,88,36,44,73,88,1);window.s_tree_11=J;J.e(0,0,1969,1829,73,88,0,0);var Bg=new q("s_tree_12",C,1,99,105,49,52,99,105,1);window.s_tree_12=Bg;Bg.e(0,0,1605,1861,99,105,0,0);var Cg=new q("s_tree_13",C,1,106,135,53,67,106,135,1);window.s_tree_13=Cg;Cg.e(0,0,881,1689,106,135,0,0);var Dg=new q("s_water_4",C,1,216,158,108,79,216,158,1);window.s_water_4=Dg;Dg.e(0,0,469,1369,216,158,0,0);var Eg=new q("s_water_5",C,1,224,247,112,123,224,247,1);window.s_water_5=Eg;
Eg.e(0,0,241,1369,224,247,0,0);var Fg=new q("s_woodpile",C,1,86,60,43,30,86,60,1);window.s_woodpile=Fg;Fg.e(0,0,1109,1685,86,60,0,0);var Gg=new q("s_background_gradient_beach_1",C,1,10,650,5,325,10,650,1);window.s_background_gradient_beach_1=Gg;Gg.e(0,0,1593,1,10,650,0,0);var Hg=new q("s_background_gradient_beach_2",C,1,10,650,5,325,10,650,1);window.s_background_gradient_beach_2=Hg;Hg.e(0,0,1569,1,10,650,0,0);var Ig=new q("s_background_gradient_desert_1",C,1,10,650,5,325,10,650,1);
window.s_background_gradient_desert_1=Ig;Ig.e(0,0,1521,1,10,650,0,0);var Jg=new q("s_background_gradient_desert_2",C,1,10,650,5,325,10,650,1);window.s_background_gradient_desert_2=Jg;Jg.e(0,0,1533,1,10,650,0,0);var Kg=new q("s_background_gradient_grass_1",C,1,10,650,5,325,10,650,1);window.s_background_gradient_grass_1=Kg;Kg.e(0,0,1545,1,10,650,0,0);var Lg=new q("s_background_gradient_grass_2",C,1,10,650,5,325,10,650,1);window.s_background_gradient_grass_2=Lg;Lg.e(0,0,1557,1,10,650,0,0);
var Mg=new q("s_background_gradient_snow_1",C,1,10,650,5,325,10,650,1);window.s_background_gradient_snow_1=Mg;Mg.e(0,0,1509,1,10,650,0,0);var Ng=new q("s_background_gradient_snow_2",C,1,10,650,5,325,10,650,1);window.s_background_gradient_snow_2=Ng;Ng.e(0,0,1581,1,10,650,0,0);var Og=new q("s_background_transition_snow_1",C,1,576,196,288,98,576,196,1);window.s_background_transition_snow_1=Og;Og.e(0,0,1161,653,576,101,0,95);var Pg=new q("s_background_transition_snow_2",C,1,576,196,288,98,576,196,1);
window.s_background_transition_snow_2=Pg;Pg.e(0,0,1161,757,576,196,0,0);var Qg=new q("s_crack",C,1,72,27,36,13,72,27,1);window.s_crack=Qg;Qg.e(0,0,1605,613,72,27,0,0);var Rg=new q("s_background_snow",C,1,180,180,90,90,180,180,1);window.s_background_snow=Rg;Rg.e(0,0,1341,1421,166,176,8,2);var Sg=new q("s_fogofwar_cloud_transparent",C,1,447,189,223,94,447,189,1);window.s_fogofwar_cloud_transparent=Sg;Sg.e(0,0,1161,957,447,189,0,0);var Tg=new q("s_fogofwar_gradient",C,2,576,766,0,0,1152,766,2);
window.s_fogofwar_gradient=Tg;Tg.e(0,0,581,645,576,720,0,0);Tg.e(1,0,1,645,576,720,0,0);var Ug=new q("s_level_locked",E,1,103,94,51,47,103,94,1);window.s_level_locked=Ug;Ug.e(0,0,1913,529,64,73,18,0);var Vg=new q("s_level_color_0",E,1,103,94,51,47,103,94,1);window.s_level_color_0=Vg;Vg.e(0,2,1209,481,103,94,0,0);var Wg=new q("s_level_color_1",E,1,103,94,51,47,103,94,1);window.s_level_color_1=Wg;Wg.e(0,2,1317,385,103,94,0,0);var Xg=new q("s_level_color_2",E,1,103,94,51,47,103,94,1);
window.s_level_color_2=Xg;Xg.e(0,2,1209,385,103,94,0,0);var Yg=new q("s_level_color_3",E,1,103,94,51,47,103,94,1);window.s_level_color_3=Yg;Yg.e(0,2,1317,481,103,94,0,0);var Zg=new q("s_level_counterblock_0",E,1,103,94,51,47,103,94,1);window.s_level_counterblock_0=Zg;Zg.e(0,2,1425,493,103,94,0,0);var $g=new q("s_level_counterblock_1",E,1,103,94,51,47,103,94,1);window.s_level_counterblock_1=$g;$g.e(0,2,1933,209,103,94,0,0);var ah=new q("s_level_counterblock_2",E,1,103,94,51,47,103,94,1);
window.s_level_counterblock_2=ah;ah.e(0,2,529,541,103,94,0,0);var bh=new q("s_level_counterblock_3",E,1,103,94,51,47,103,94,1);window.s_level_counterblock_3=bh;bh.e(0,2,961,509,103,94,0,0);var ch=new q("s_level_score_0",E,1,103,94,51,47,103,94,1);window.s_level_score_0=ch;ch.e(0,2,833,513,103,94,0,0);var dh=new q("s_level_score_1",E,1,103,94,51,47,103,94,1);window.s_level_score_1=dh;dh.e(0,2,685,529,103,94,0,0);var eh=new q("s_level_score_2",E,1,103,94,51,47,103,94,1);window.s_level_score_2=eh;
eh.e(0,2,1901,533,103,94,0,0);var fh=new q("s_level_score_3",E,1,103,94,51,47,103,94,1);window.s_level_score_3=fh;fh.e(0,2,1069,509,103,94,0,0);var gh=new q("s_gate_closed",E,1,145,103,72,0,145,103,1);window.s_gate_closed=gh;gh.e(0,0,117,1957,105,86,19,3);var hh=new q("s_gate_lock",E,1,145,103,72,0,145,103,1);window.s_gate_lock=hh;hh.e(0,0,2009,1681,24,34,61,35);var ih=new q("s_gate_open",E,1,145,103,72,0,145,103,1);window.s_gate_open=ih;ih.e(0,1,1001,801,145,103,0,0);
var jh=new q("s_glitter",E,6,82,82,41,0,492,82,6);window.s_glitter=jh;jh.e(0,1,1989,317,51,63,12,3);jh.e(1,0,1989,789,49,63,14,8);jh.e(2,2,737,625,52,59,14,13);jh.e(3,1,1977,477,60,68,12,10);jh.e(4,2,1641,669,59,59,7,13);jh.e(5,2,1529,385,51,59,12,8);var kh=new q("s_background",E,2,576,640,0,0,1152,640,2);window.s_background=kh;kh.e(0,0,1,613,576,640,0,0);kh.e(1,0,1161,1285,576,640,0,0);var lh=new q("s_shape_base",E,1,50,50,25,25,50,50,1);window.s_shape_base=lh;lh.e(0,2,1705,725,46,46,2,2);
var mh=new q("s_shape_bigcorner",E,1,50,50,25,25,50,50,1);window.s_shape_bigcorner=mh;mh.e(0,2,1033,701,46,48,2,2);var nh=new q("s_shape_bigsquare",E,1,50,50,25,25,50,50,1);window.s_shape_bigsquare=nh;nh.e(0,1,1997,1,50,48,0,1);var oh=new q("s_shape_dash",E,1,50,50,25,25,50,50,1);window.s_shape_dash=oh;oh.e(0,0,2001,1961,46,48,2,2);var ph=new q("s_shape_dot",E,1,50,50,25,25,50,50,1);window.s_shape_dot=ph;ph.e(0,2,1329,725,46,46,2,2);var qh=new q("s_shape_frikandel",E,1,50,50,25,25,50,50,1);
window.s_shape_frikandel=qh;qh.e(0,0,2001,1805,46,48,2,2);var rh=new q("s_shape_kroket",E,1,50,50,25,25,50,50,1);window.s_shape_kroket=rh;rh.e(0,2,1533,449,47,48,2,2);var sh=new q("s_shape_line",E,1,50,50,25,25,50,50,1);window.s_shape_line=sh;sh.e(0,2,1533,501,48,47,1,1);var th=new q("s_shape_minicorner",E,1,50,50,25,25,50,50,1);window.s_shape_minicorner=th;th.e(0,0,2001,1753,46,48,2,2);var vh=new q("s_shape_square",E,1,50,50,25,25,50,50,1);window.s_shape_square=vh;vh.e(0,0,2001,1909,46,48,2,2);
var wh=new q("s_powerup_counterblock",E,4,50,50,25,25,200,50,4);window.s_powerup_counterblock=wh;wh.e(0,2,1225,725,47,47,1,2);wh.e(1,2,1429,685,48,47,1,2);wh.e(2,2,1377,685,48,48,1,1);wh.e(3,1,1997,157,49,48,1,1);var xh=new q("s_shape_bigcorner_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_bigcorner_silhouette=xh;xh.e(0,2,2001,725,46,46,2,2);var yh=new q("s_shape_bigsquare_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_bigsquare_silhouette=yh;yh.e(0,2,1577,733,46,46,2,2);
var zh=new q("s_shape_dash_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_dash_silhouette=zh;zh.e(0,2,561,733,46,46,2,2);var Ah=new q("s_shape_dot_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_dot_silhouette=Ah;Ah.e(0,2,1625,733,46,46,2,2);var Bh=new q("s_shape_frikandel_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_frikandel_silhouette=Bh;Bh.e(0,2,1377,737,46,46,2,2);var Ch=new q("s_shape_kroket_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_kroket_silhouette=Ch;
Ch.e(0,2,1,753,46,46,2,2);var Dh=new q("s_shape_line_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_line_silhouette=Dh;Dh.e(0,2,1425,737,46,46,2,2);var Eh=new q("s_shape_minicorner_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_minicorner_silhouette=Eh;Eh.e(0,2,513,733,46,46,2,2);var Fh=new q("s_shape_square_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_square_silhouette=Fh;Fh.e(0,2,1953,725,46,46,2,2);var Gh=new q("s_shape_glimmericon",E,1,50,50,25,25,50,50,1);
window.s_shape_glimmericon=Gh;Gh.e(0,0,2009,1565,36,35,7,7);var Hh=new q("s_powerup_counterblock_silhouette",E,1,50,50,25,25,50,50,1);window.s_powerup_counterblock_silhouette=Hh;Hh.e(0,2,225,753,45,44,3,3);var Ih=new q("s_shape_powerup_bomb_silhouette",E,1,50,50,25,25,50,50,1);window.s_shape_powerup_bomb_silhouette=Ih;Ih.e(0,2,177,753,45,44,3,3);var Jh=new q("s_shape_whiteflash",E,1,50,50,25,25,50,50,1);window.s_shape_whiteflash=Jh;Jh.e(0,2,1277,725,47,46,2,2);
var Kh=new q("s_animation_glitter",E,8,70,69,35,34,560,69,8);window.s_animation_glitter=Kh;Kh.e(0,0,2005,937,24,55,44,0);Kh.e(1,2,1473,761,44,39,26,10);Kh.e(2,0,1565,609,49,30,0,27);Kh.e(3,0,2005,997,31,46,34,22);Kh.e(4,0,1989,857,58,48,12,21);Kh.e(5,1,1977,421,70,54,0,15);Kh.e(6,0,1997,1213,48,60,0,9);Kh.e(7,1,1509,1989,60,58,1,5);var Lh=new q("s_shape_colorbomb",E,11,50,50,25,25,550,50,11);window.s_shape_colorbomb=Lh;Lh.e(0,2,893,609,46,48,2,2);Lh.e(1,2,637,541,46,48,2,2);
Lh.e(2,2,2001,305,46,48,2,2);Lh.e(3,2,1185,673,46,48,2,2);Lh.e(4,2,881,713,46,48,2,2);Lh.e(5,2,1233,673,46,48,2,2);Lh.e(6,2,1281,673,46,48,2,2);Lh.e(7,2,737,689,46,48,2,2);Lh.e(8,2,1329,673,46,48,2,2);Lh.e(9,1,2001,821,46,48,2,2);Lh.e(10,0,2001,1857,46,48,2,2);var Mh=new q("s_animation_powerup_alldirections",E,9,130,130,65,65,1170,130,9);window.s_animation_powerup_alldirections=Mh;Mh.e(0,0,701,613,10,12,64,62);Mh.e(1,0,633,613,24,24,57,55);Mh.e(2,1,1637,1989,57,55,40,39);
Mh.e(3,1,773,829,75,73,30,30);Mh.e(4,1,1,1957,92,88,20,23);Mh.e(5,0,1617,1929,115,109,10,11);Mh.e(6,2,961,385,121,119,6,7);Mh.e(7,2,833,385,124,123,4,4);Mh.e(8,1,1917,1017,130,130,0,0);var Nh=new q("s_animation_pulse",E,7,75,75,37,37,525,75,7);window.s_animation_pulse=Nh;Nh.e(0,0,713,613,8,8,33,31);Nh.e(1,0,605,613,24,24,25,23);Nh.e(2,0,2009,1645,34,34,20,18);Nh.e(3,1,1989,1989,54,54,10,9);Nh.e(4,2,1577,669,61,61,7,6);Nh.e(5,1,1977,549,67,67,4,3);Nh.e(6,1,853,829,75,75,0,0);
var Oh=new q("s_animation_discodip",E,9,150,150,75,75,1350,150,9);window.s_animation_discodip=Oh;Oh.e(0,0,685,613,13,13,69,67);Oh.e(1,0,1649,609,28,30,61,58);Oh.e(2,0,2005,1177,35,33,58,57);Oh.e(3,0,2005,1045,41,39,55,54);Oh.e(4,2,1845,573,54,50,49,48);Oh.e(5,1,1381,1989,60,58,46,43);Oh.e(6,1,1817,1717,67,64,42,41);Oh.e(7,1,693,829,78,71,37,37);Oh.e(8,0,2045,33,1,1,0,0);var Ph=new q("s_animation_rainbowblock",E,11,50,50,25,25,550,50,11);window.s_animation_rainbowblock=Ph;
Ph.e(0,2,1037,753,44,44,3,3);Ph.e(1,2,97,761,44,44,3,3);Ph.e(2,2,273,753,44,44,3,3);Ph.e(3,2,761,757,44,44,3,3);Ph.e(4,2,989,753,44,44,3,3);Ph.e(5,2,369,753,44,44,3,3);Ph.e(6,2,321,753,44,44,3,3);Ph.e(7,2,417,753,44,44,3,3);Ph.e(8,2,809,757,44,44,3,3);Ph.e(9,2,49,761,44,44,3,3);Ph.e(10,2,929,761,44,44,3,3);var Qh=new q("s_powerup_colorbomb",E,11,50,50,25,25,550,50,11);window.s_powerup_colorbomb=Qh;Qh.e(0,2,1081,701,46,48,2,2);Qh.e(1,2,833,705,46,48,2,2);Qh.e(2,2,617,721,46,48,2,2);
Qh.e(3,2,1761,721,46,48,2,2);Qh.e(4,2,1177,725,46,48,2,2);Qh.e(5,2,665,721,46,48,2,2);Qh.e(6,2,465,713,46,48,2,2);Qh.e(7,2,941,709,46,48,2,2);Qh.e(8,2,785,705,46,48,2,2);Qh.e(9,2,1129,725,46,48,2,2);Qh.e(10,2,893,661,46,48,2,2);var Rh=new q("s_animation_discodip_BIGGER",E,9,120,120,60,60,1080,120,9);window.s_animation_discodip_BIGGER=Rh;Rh.e(0,0,2029,481,18,18,53,52);Rh.e(1,0,2009,1481,37,41,43,40);Rh.e(2,2,713,741,46,44,39,39);Rh.e(3,1,1933,1989,54,52,35,35);Rh.e(4,1,1741,1717,72,67,27,27);
Rh.e(5,0,1829,529,80,78,23,20);Rh.e(6,1,601,829,89,86,18,17);Rh.e(7,2,1937,109,104,95,11,12);Rh.e(8,0,2045,29,1,1,0,0);var Sh=new q("s_counterblock_1",E,5,70,70,35,35,350,70,5);window.s_counterblock_1=Sh;Sh.e(0,2,1761,669,48,47,11,12);Sh.e(1,0,1997,1389,50,51,10,10);Sh.e(2,1,1817,1989,56,56,7,6);Sh.e(3,1,1573,1989,60,58,5,4);Sh.e(4,0,2045,21,1,1,0,0);var Th=new q("s_counterblock_2",E,5,70,70,35,35,350,70,5);window.s_counterblock_2=Th;Th.e(0,2,1133,673,48,47,11,12);Th.e(1,0,1997,1333,50,51,10,10);
Th.e(2,1,1697,1989,57,56,6,5);Th.e(3,1,1445,1989,60,58,5,4);Th.e(4,0,2045,1,1,1,0,0);var Uh=new q("s_counterblock_3",E,5,70,70,35,35,350,70,5);window.s_counterblock_3=Uh;Uh.e(0,2,465,661,48,48,11,11);Uh.e(1,0,1997,1277,50,52,10,9);Uh.e(2,1,1757,1989,57,56,6,5);Uh.e(3,1,1937,821,60,58,5,4);Uh.e(4,0,2045,25,1,1,0,0);var Vh=new q("s_counterblock_4",E,5,70,70,35,35,350,70,5);window.s_counterblock_4=Vh;Vh.e(0,1,1997,53,49,48,11,11);Vh.e(1,2,1705,669,52,52,10,9);Vh.e(2,1,1989,249,58,63,6,4);
Vh.e(3,1,1317,1989,60,58,5,4);Vh.e(4,0,2045,17,1,1,0,0);var Wh=new q("s_animation_rowclear",E,7,492,56,0,28,3444,56,7);window.s_animation_rowclear=Wh;Wh.e(0,0,1829,481,197,20,2,17);Wh.e(1,0,1,1901,451,53,15,3);Wh.e(2,0,1741,913,283,20,183,18);Wh.e(3,0,1829,505,180,20,286,18);Wh.e(4,0,1485,609,76,20,393,18);Wh.e(5,0,2013,505,26,19,439,19);Wh.e(6,0,2045,13,1,1,0,0);var Xh=new q("s_block_glimmer",E,10,50,50,25,25,500,50,10);window.s_block_glimmer=Xh;Xh.e(0,0,2045,9,1,1,0,0);Xh.e(1,0,2045,5,1,1,0,0);
Xh.e(2,0,1713,609,22,26,2,2);Xh.e(3,0,1617,609,30,30,2,2);Xh.e(4,2,1809,725,46,44,2,2);Xh.e(5,2,1857,725,46,46,2,2);Xh.e(6,0,2005,1089,41,41,7,9);Xh.e(7,0,661,613,22,24,26,25);Xh.e(8,0,581,613,21,25,27,25);Xh.e(9,0,2045,37,1,1,0,0);var Yh=new q("s_effect_countdowntofloater",E,10,314,314,157,157,3140,314,10);window.s_effect_countdowntofloater=Yh;Yh.e(0,1,1977,621,67,56,31,185);Yh.e(1,0,1,1957,114,90,12,167);Yh.e(2,1,1741,1389,167,133,0,138);Yh.e(3,1,1745,709,187,170,15,114);
Yh.e(4,2,293,661,81,87,155,79);Yh.e(5,2,941,605,89,99,153,71);Yh.e(6,2,105,565,96,100,151,71);Yh.e(7,2,1425,385,99,103,149,68);Yh.e(8,2,1937,1,102,105,148,68);Yh.e(9,1,1937,709,105,109,147,66);var Zh=new q("s_title_background",E,4,576,320,0,0,1152,640,2);window.s_title_background=Zh;Zh.e(0,1,1161,1281,576,320,0,0);Zh.e(1,1,581,1241,576,320,0,0);Zh.e(2,1,1,1441,576,320,0,0);Zh.e(3,1,581,917,576,320,0,0);var $h=new q("s_title_gamelogo",E,1,410,310,0,0,410,310,1);window.s_title_gamelogo=$h;
$h.e(0,1,581,1565,410,310,0,0);var ai=new q("s_score_star",E,1,33,32,0,0,33,32,1);window.s_score_star=ai;ai.e(0,0,1793,2009,33,32,0,0);var bi=new q("s_overlay_options",E,1,592,640,0,0,592,640,1);window.s_overlay_options=bi;bi.e(0,1,1161,1,579,637,6,3);var ci=new q("s_overlay_win",E,1,1152,640,0,0,1152,640,1);window.s_overlay_win=ci;ci.e(0,0,753,1,728,637,133,3);var di=new q("s_overlay_fail",E,1,1152,640,0,0,1152,640,1);window.s_overlay_fail=di;di.e(0,1,1161,641,579,637,282,3);
var ei=new q("s_background_overlay_world_1",E,2,576,640,0,0,1152,640,2);window.s_background_overlay_world_1=ei;ei.e(0,0,1829,265,215,212,0,428);ei.e(1,0,1485,1,340,604,236,36);var fi=new q("s_background_overlay_world_2",E,2,576,640,0,0,1152,640,2);window.s_background_overlay_world_2=fi;fi.e(0,0,1161,641,576,640,0,0);fi.e(1,0,581,641,576,640,0,0);var gi=new q("s_background_overlay_world_3",E,2,576,640,0,0,1152,640,2);window.s_background_overlay_world_3=gi;gi.e(0,1,581,1,576,640,0,0);
gi.e(1,0,581,1285,576,640,0,0);var hi=new q("s_background_overlay_world_4",E,2,576,640,0,0,1152,640,2);window.s_background_overlay_world_4=hi;hi.e(0,1,1,1,576,640,0,0);hi.e(1,0,1,1257,576,640,0,0);var ii=new q("s_colorbomb_cover",E,1,50,50,25,25,50,50,1);window.s_colorbomb_cover=ii;ii.e(0,2,1905,725,46,46,2,2);var ji=new q("s_typebomb_fx",E,6,66,66,33,33,396,66,6);window.s_typebomb_fx=ji;ji.e(0,0,1681,609,28,26,20,20);ji.e(1,0,2009,1525,37,38,14,13);ji.e(2,1,1877,1989,54,53,5,7);
ji.e(3,2,1933,305,64,62,2,1);ji.e(4,1,281,1957,66,63,0,3);ji.e(5,1,1113,1981,66,63,0,3);var ki=new q("s_gate_beach",E,1,346,183,0,0,346,183,1);window.s_gate_beach=ki;ki.e(0,2,1585,193,346,183,0,0);var li=new q("s_gate_desert",E,1,398,186,0,0,398,186,1);window.s_gate_desert=li;li.e(0,1,601,645,398,180,0,4);var mi=new q("s_gate_grass",E,1,316,195,0,0,316,195,1);window.s_gate_grass=mi;mi.e(0,2,1585,381,313,189,3,3);var ni=new q("s_gate_snow",E,1,392,179,0,0,392,179,1);window.s_gate_snow=ni;
ni.e(0,1,993,1605,392,179,0,0);var oi=new q("s_ui_highscore",E,1,26,36,0,0,26,36,1);window.s_ui_highscore=oi;oi.e(0,0,2009,1605,26,36,0,0);var pi=new q("s_shape_blockerblock",E,1,50,50,0,0,50,50,1);window.s_shape_blockerblock=pi;pi.e(0,1,1997,105,49,48,1,1);var qi=new q("s_animation_icecreamtruck",E,8,100,100,50,50,800,100,8);window.s_animation_icecreamtruck=qi;qi.e(0,0,1989,529,55,94,22,1);qi.e(1,2,1945,629,95,92,2,5);qi.e(2,0,329,1957,99,79,0,9);qi.e(3,2,1033,605,98,91,1,2);
qi.e(4,0,1989,625,58,93,23,2);qi.e(5,2,793,609,98,91,1,2);qi.e(6,0,225,1957,99,79,1,9);qi.e(7,2,517,637,95,92,3,5);var ri=new za("ff_tgf_normal","fonts/ff_tgf_normal.woff","fonts/ff_tgf_normal.ttf","frameworkFonts");window.ff_tgf_normalLoader=ri;var si=new za("ff_tgf_bold","fonts/ff_tgf_bold.woff","fonts/ff_tgf_bold.ttf","frameworkFonts");window.ff_tgf_boldLoader=si;var K=new Ca("ff_tgf_bold","Arial");window.f_tgf_title=K;Da(K,48);K.fill=!0;K.setFillColor("Black");K.mc=1;Ea(K,!1);K.setStrokeColor("Black");
Ga(K,1);Ia(K,"miter");K.qc=1;Ha(K,!1);Ja(K,"center");Ka(K,"middle");La(K,0);K.Zb=0;var L=new Ca("ff_tgf_normal","Arial");window.f_tgf_text=L;Da(L,32);L.fill=!0;L.setFillColor("Black");L.mc=1;Ea(L,!1);L.setStrokeColor("Black");Ga(L,1);Ia(L,"miter");L.qc=1;Ha(L,!1);Ja(L,"center");Ka(L,"middle");La(L,0);L.Zb=0;var M=new Ca("ff_tgf_normal","Arial");window.f_tgf_button=M;Da(M,40);M.fill=!0;M.setFillColor("#01198A");M.mc=1;Ea(M,!1);M.setStrokeColor("Black");Ga(M,1);Ia(M,"miter");M.qc=1;Ha(M,!1);
M.Ac={ba:!0,color:"rgba(120,253,255,1.00)",offsetX:0,offsetY:2,blur:0};Ja(M,"center");Ka(M,"middle");La(M,.14);M.Zb=0;var ti=new za("f_default","fonts/f_default.woff","fonts/f_default.ttf","fonts");window.f_defaultLoader=ti;var ui=new Ca("f_default","Arial");window.f_default=ui;Da(ui,24);ui.fill=!0;ui.setFillColor("Black");ui.mc=1;Ea(ui,!1);ui.setStrokeColor("Black");Ga(ui,1);Ia(ui,"miter");ui.qc=1;Ha(ui,!1);Ja(ui,"left");Ka(ui,"top");La(ui,0);ui.Zb=0;var vi=new Ca("Lobster","");
window.f_lobster=vi;Da(vi,12);vi.fill=!0;vi.setFillColor("Black");vi.mc=1;Ea(vi,!1);vi.setStrokeColor("Black");Ga(vi,1);Ia(vi,"miter");vi.qc=1;Ha(vi,!1);Ja(vi,"left");Ka(vi,"top");La(vi,0);vi.Zb=0;var wi=new Ca("Lobster","Arial");window.f_lobster_floater1=wi;Da(wi,36);wi.fill=!0;wi.setFillColor("white");wi.mc=1;Ea(wi,!0);wi.setStrokeColor("#fc3a6c");Ga(wi,7);Ia(wi,"round");wi.qc=1;Ha(wi,!0);Ja(wi,"left");Ka(wi,"top");La(wi,0);wi.Zb=0;var xi=new Ca("Lobster","Arial");window.f_lobster_floater2=xi;
Da(xi,36);xi.fill=!0;xi.setFillColor("white");xi.mc=1;Ea(xi,!0);xi.setStrokeColor("#ec6f00");Ga(xi,7);Ia(xi,"round");xi.qc=1;Ha(xi,!0);Ja(xi,"left");Ka(xi,"top");La(xi,0);xi.Zb=0;var yi=new Ca("Lobster","Arial");window.f_lobster_floater3=yi;Da(yi,36);yi.fill=!0;yi.setFillColor("white");yi.mc=1;Ea(yi,!0);yi.setStrokeColor("#98512a");Ga(yi,7);Ia(yi,"round");yi.qc=1;Ha(yi,!0);Ja(yi,"left");Ka(yi,"top");La(yi,0);yi.Zb=0;var zi=new Ca("Lobster","Arial");window.f_lobster_floater4=zi;Da(zi,36);zi.fill=!0;
zi.setFillColor("white");zi.mc=1;Ea(zi,!0);zi.setStrokeColor("#007bee");Ga(zi,7);Ia(zi,"round");zi.qc=1;Ha(zi,!0);Ja(zi,"left");Ka(zi,"top");La(zi,0);zi.Zb=0;var N=new Ca("OpenSansBold","");window.f_open_sans_bold=N;Da(N,12);N.fill=!0;N.setFillColor("Black");N.mc=1;Ea(N,!1);N.setStrokeColor("Black");Ga(N,1);Ia(N,"miter");N.qc=1;Ha(N,!1);Ja(N,"left");Ka(N,"top");La(N,0);N.Zb=0;var Ai=new za("OpenSansExtraBold","fonts/OpenSansExtraBold.woff","fonts/OpenSansExtraBold.ttf","fonts");
window.OpenSansExtraBoldLoader=Ai;var Bi=new Ca("OpenSansExtraBold","Arial");window.OpenSansExtraBold=Bi;Da(Bi,25);Bi.fill=!0;Bi.setFillColor("White");Bi.mc=1;Ea(Bi,!0);Bi.setStrokeColor("#7A000D");Ga(Bi,5);Ia(Bi,"round");Bi.qc=1;Ha(Bi,!0);Ja(Bi,"center");Ka(Bi,"middle");La(Bi,-.21);Bi.Zb=0;var Ci=new za("OpenSansExtraBoldLocked","fonts/OpenSansExtraBoldLocked.woff","fonts/OpenSansExtraBoldLocked.ttf","fonts");window.OpenSansExtraBoldLockedLoader=Ci;var Di=new Ca("OpenSansExtraBoldLocked","Arial");
window.OpenSansExtraBoldLocked=Di;Da(Di,25);Di.fill=!0;Di.setFillColor("White");Di.mc=1;Ea(Di,!0);Di.setStrokeColor("#6B6B6B");Ga(Di,5);Ia(Di,"round");Di.qc=1;Ha(Di,!0);Ja(Di,"center");Ka(Di,"middle");La(Di,-.21);Di.Zb=0;var Ei=new za("OpenSansBold","fonts/OpenSansBold.woff","fonts/OpenSansBold.ttf","fonts");window.OpenSansBoldLoader=Ei;var Fi=new Ca("OpenSansBold","Arial");window.OpenSansBold=Fi;Da(Fi,16);Fi.fill=!0;Fi.setFillColor("Black");Fi.mc=1;Ea(Fi,!1);Fi.setStrokeColor("Black");Ga(Fi,1);
Ia(Fi,"miter");Fi.qc=1;Ha(Fi,!1);Ja(Fi,"left");Ka(Fi,"top");La(Fi,0);Fi.Zb=0;var Gi=new za("Lobster","fonts/Lobster.woff","fonts/Lobster.ttf","fonts");window.LobsterLoader=Gi;var Hi=new Ca("Lobster","Arial");window.Lobster=Hi;Da(Hi,50);Hi.fill=!0;Hi.setFillColor("#E9DEDA");Hi.mc=1;Ea(Hi,!1);Hi.setStrokeColor("Black");Ga(Hi,1);Ia(Hi,"miter");Hi.qc=1;Ha(Hi,!1);Ja(Hi,"center");Ka(Hi,"middle");La(Hi,0);Hi.Zb=0;
var Ii=new za("LobsterComingsoon","fonts/LobsterComingsoon.woff","fonts/LobsterComingsoon.ttf","fonts");window.LobsterComingsoonLoader=Ii;var Ji=new Ca("LobsterComingsoon","Arial");window.LobsterComingsoon=Ji;Da(Ji,80);Ji.fill=!0;Ji.setFillColor("#E2F1FE");Ji.mc=1;Ea(Ji,!0);Ji.setStrokeColor("#89BEEC");Ga(Ji,7);Ia(Ji,"round");Ji.qc=1;Ha(Ji,!0);Ja(Ji,"center");Ka(Ji,"middle");La(Ji,0);Ji.Zb=0;var Ki=new qb("FrameworkAudio","audio/FrameworkAudio.mp3","audio/FrameworkAudio.ogg","frameworkAudio");
window.FrameworkAudio=Ki;var Li=new qb("audioSprite","audio/audioSprite.mp3","audio/audioSprite.ogg","audio");window.audioSprite=Li;var Mi=new qb("GameMusic","audio/GameMusic.mp3","audio/GameMusic.ogg","audio");window.GameMusic=Mi;var Ni=new jb("a_tgf_silence",Ki,0,471,0,10,["sfx"]);window.a_tgf_silence=Ni;var Oi=new jb("a_tgf_button_down",Ki,2E3,471,1,10,["sfx"]);window.a_tgf_button_down=Oi;var Pi=new jb("a_levelend_star_01",Li,0,1161,1,10,["game"]);window.a_levelend_star_01=Pi;
var Qi=new jb("a_levelend_star_02",Li,3E3,1070,1,10,["game"]);window.a_levelend_star_02=Qi;var Ri=new jb("a_levelend_star_03",Li,6E3,1039,1,10,["game"]);window.a_levelend_star_03=Ri;var Si=new jb("a_unwrap",Li,9E3,2E3,.25,10,["game"]);window.a_unwrap=Si;var Ti=new jb("a_notplaced",Li,13E3,448,.25,10,["game"]);window.a_notplaced=Ti;var Ui=new jb("a_clouds",Li,15E3,5333,.25,10,["game"]);window.a_clouds=Ui;var Vi=new jb("a_powerup",Li,22E3,598,.25,10,["game"]);window.a_powerup=Vi;
var Wi=new jb("a_win",Li,24E3,2315,.25,10,["game"]);window.a_win=Wi;var Xi=new jb("a_lose",Li,28E3,1572,.26,10,["game"]);window.a_lose=Xi;pc.xE=new jb("a_place",Li,31E3,1013,.26,10,["game"]);pc.a_place=pc.xE;qc.QD=new jb("Game_bubbleshooter_04_Pop_02",Li,34E3,140,1,10,["game"]);qc.Game_bubbleshooter_04_Pop_02=qc.QD;qc.RD=new jb("Game_bubbleshooter_05_Pop_03",Li,36E3,164,1,10,["game"]);qc.Game_bubbleshooter_05_Pop_03=qc.RD;qc.SD=new jb("Game_bubbleshooter_06_Pop_04",Li,38E3,163,1,10,["game"]);
qc.Game_bubbleshooter_06_Pop_04=qc.SD;qc.TD=new jb("Game_bubbleshooter_07_Pop_05",Li,4E4,149,1,10,["game"]);qc.Game_bubbleshooter_07_Pop_05=qc.TD;qc.UD=new jb("Game_bubbleshooter_08_Pop_06",Li,42E3,103,1,10,["game"]);qc.Game_bubbleshooter_08_Pop_06=qc.UD;var Yi=new jb("a_start",Li,44E3,1302,.25,10,["game"]);window.a_start=Yi;var Zi=new jb("a_goal",Li,47E3,1002,.25,10,["game"]);window.a_goal=Zi;var $i=new jb("a_area",Li,5E4,1E3,.25,10,["game"]);window.a_area=$i;
var aj=new jb("a_type",Li,53E3,342,.25,10,["game"]);window.a_type=aj;var bj=new jb("a_bonusPoint",Li,55E3,220,.25,10,["game"]);window.a_bonusPoint=bj;var cj=new jb("a_collected",Li,57E3,562,.25,10,["game"]);window.a_collected=cj;var dj=new jb("a_ingame",Mi,0,36571,.4,10,["music","ingame"]);window.a_ingame=dj;var ej=new jb("a_music",Mi,38E3,26726,.4,1,["music","map"]);window.a_music=ej;var ba=!1,fj="37d007a56d816107ce5b52c10342db37 63584f3a94bbad2d1f63d3ce77ff6171 654876fa2c2a615f1a5410bdb6109cbe b6856a1f17d5a6ec76dc8b837841e476 ec0af3752142da7f2c1bc7947864ead0 03a60a509d53952c91fc9865fbd492ef 8784d238b5a81ab432d0bf303850ed8a 9f5ffc7a10e0bad054458b089947ce2f 0c73b027c77dd2c1ee6cd996c2c83efc 0e26dbc8d26a0880786e55e3e950a320 7e77fcbd9a8ec327db79b6c753a5eef1 5ff97ceeea117a01f512adc7ece5ade7 54f5ededff723ca5c52bc75764ceb738 526ceb1f05b2418711e1eb59058e0b09 ae11a4449bebb3561a078bac793dc74b f51482fb5ecee35fd139f89728a7a616 feecd1420633723d96c9739d50653239".split(" ");
"use strict";
var gj=new (function(){function b(){window.addEventListener("message",function(b){this.RN(b)}.bind(this),!1)}b.prototype.gE=function(){return f.Ba.ve||f.Ba.vf||f.Ba.kg?{sA:"adFrameMobile",Oy:"adtechMobile",width:320,height:250,PD:publisher.mobileRewardId}:{sA:"adFrame",Oy:"adtech",width:640,height:480,PD:publisher.desktopRewardId}};b.prototype.OM=function(b,d){this.vE=b;this.wE=d;var e=this.gE(),g=Math.floor(1E9*Math.random());this.Ff=document.createElement("div");this.Ff.className="adOverlay";var h=
document.createElement("div");h.className="adBg";var l=document.createElement("div");l.className=e.sA;this.qj=document.createElement("iframe");this.qj.src="http://media.oadts.com/www/delivery/afv.php?zoneid="+e.PD+"&cb="+g;this.qj.JR="0";this.qj.scrolling="no";this.qj.width=e.width;this.qj.height=e.height;this.qj.className=e.Oy;this.Ff.appendChild(h);this.Ff.appendChild(l);this.Ff.appendChild(this.qj);document.body.appendChild(this.Ff)};b.prototype.Iz=function(){this.Ff&&(document.body.removeChild(this.Ff),
this.Ff=null);this.vE.call(this.wE,!0)};b.prototype.RN=function(b){if("http://media.oadts.com"===b.origin&&this.Ff)switch(console.log(b),b.data){case "noVideo":case "NoVideo":document.body.removeChild(this.Ff);this.Ff=null;this.Iz();break;case "videoEnds":case "videoComplete":this.Iz()}};return b}()),hj=null;function ij(){this.depth=0;this.d=1E7;this.visible=!1;this.ba=!0;this.fi=-1;this.paused=0;this.v=this.EE;Ib(this)}a=ij.prototype;a.yr=function(){this.paused+=1};a.Lh=function(){this.paused-=1};
a.Lh=function(){this.paused=0};a.Bk=function(b,c,d){var e;Pb("play");e=v.mb("playStart");void 0!==e&&(b=e);e=function(){var b="Level"+O.xa.Fe;Rb("play");jj.Bk(O.xa.Wt,O.xa.Fe);kj.Wi(b,void 0,"Start");lj("durationWon",b,"WonDuration");lj("durationLost",b,"LostDuration");lj("stageCompleted","Stage1","StageDuration");d&&d.call(mj)};"dialog"!==b?e():(b=O.r.jD?new O.r.jD(c):new nj(c),b.ub=e,b.show())};
function oj(b,c,d,e,g,h,l,m,n){var s,w;Pb("play");w=c?v.mb("playWon",d,e,g,h):v.mb("playLost");void 0!==w&&(l=w);c?jj.jl(d,e,g,h):jj.Pj();c?(kj.Wi("Level"+O.xa.Fe,void 0,"Won"),kj.Wi("Level"+O.xa.Fe,void 0,"Score",d),pj("durationWon"),qj("durationLost")):(kj.Wi("Level"+O.xa.Fe,void 0,"Lost"),pj("durationLost"),qj("durationWon"));s=function(){Rb("play");if(n)n.call(mj,b.Qm);else{"continue"!==b.Qm&&Sb(mj);switch(b.Qm){case "title":b.v=b.qg;break;case "level":b.v=b.Lm;break;case "restart":b.v=b.Xk;break;
case "next":O.xa.Fe<O.xa.GK?(O.xa.Fe+=1,b.v=b.Xk):b.v=b.PE;break;case "continue":break;default:b.v=b.qg}Sb(mj);v.mb("playEnd",!1)}};"dialog"!==l?(b.Qm=l,s()):(c=c?O.r.iA?new O.r.iA(m):new rj(m):O.r.hA?new O.r.hA(m):new sj(m),c.m=function(c,d){c.na();b.Qm=d},c.ub=0>b.fi&&O.r.PC?function(){Sb(mj);b.v=tj(b,s)}:s,c.show())}a.jl=function(b,c,d,e,g,h,l){oj(this,!0,b,c,d,e,g,h,l)};a.Pj=function(b,c,d){oj(this,!1,void 0,void 0,void 0,void 0,b,c,d)};
a.EE=function(){var b;uj(O,{Vr:{c:void 0,color:"white",duration:2},aL:{Qj:Fd,backgroundImage:Gd,sh:$h,mh:Dd},tD:{backgroundImage:Zh,sh:$h,mh:[Dd],hn:[{x:P(-100),y:P(598)}],Pt:["http://www.coolgames.com"],GB:!1,zv:!1,Og:P(190),Pg:P(138),zg:P(190),Vl:be,Ng:Qd,fo:void 0,ck:P(65),dk:P(580),ak:Nd,bk:P(100),$j:P(92),MB:P(80)},xP:{width:P(600),height:P(600),Wp:P(600),Vp:P(590),buttons:[[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,vd]}],[{c:[F,
vd]}],[{c:[F,vd]}]]},sD:{backgroundImage:bi,Ub:!0,bg:["tutorial","oldSound","oldLanguage","moregames","about"],marginTop:P(16),Mb:Hi,Dc:"optionsTitle",marginLeft:P(170),marginRight:P(175)},Cv:{ck:65,dk:580,ak:Nd,bk:100,$j:92,kB:Bi,lB:Di,iJ:[{o:N.o,fontSize:22,fillColor:"#8f7c64"},{o:N.o,fontSize:22,fillColor:"#d0853e"},{o:N.o,fontSize:22,fillColor:"#592902"},{o:N.o,fontSize:22,fillColor:"#d0853e"}],UA:te,Dz:Ji},rB:{uC:ue,lc:P(400),Ub:!0,Vc:0,Mb:Hi,aB:{o:vi.o,fontSize:36,fillColor:"#ea8c9d"},Qq:{o:N.o,
fontSize:18,fillColor:"#452f5a"},vD:"LevelHeader",marginTop:P(16),Sn:"",Rq:P(55)},CM:{width:P(600),height:P(600),Wk:pe,Ub:!0},hC:{width:P(578),height:P(600),rc:18,QA:30,Hb:40,Fd:10,backgroundImage:pe,wC:se,ro:re,Bz:qe,ld:[{c:xe,xf:"TutorialHeader_01",pf:"TutorialText_01",rb:0},{c:ye,xf:"Tutorial_Header_02",pf:"TutorialText_02",rb:0},{c:Ae,xf:"Tutorial_Header_03",pf:"TutorialText_03",rb:0},{c:Be,xf:"Tutorial_Header_04",pf:"TutorialText_04",rb:0},{c:Ce,xf:"Tutorial_Header_05",pf:"TutorialText_05",rb:0},
{c:De,xf:"Tutorial_Header_06",pf:"TutorialText_06",rb:0},{c:Ee,xf:"Tutorial_Header_07",pf:"TutorialText_07",rb:0},{c:Fe,xf:"Tutorial_Header_08",pf:"TutorialText_08",rb:0},{c:Ge,xf:"Tutorial_Header_09",pf:"TutorialText_09",rb:0},{c:He,xf:"Tutorial_Header_10",pf:"TutorialText_10",rb:0},{c:Ie,xf:"Tutorial_Header_11",pf:"TutorialText_11",rb:0}]},aH:{backgroundImage:"undefined"!==typeof s_completion_background?s_completion_background:null,Qt:"undefined"!==typeof s_completion_congratulation?s_completion_congratulation:
null,Mz:"undefined"!==typeof f_completion_congratulation?f_completion_congratulation:K,Pz:"undefined"!==typeof s_completion_continue?s_completion_continue:F,Oz:"undefined"!==typeof f_completion_continue?f_completion_continue:M},hp:{width:P(780),height:P(300)},hI:{backgroundImage:void 0!==typeof ci?ci:void 0,vk:["stars","score","highscore"],marginTop:P(16),marginLeft:P(450),marginRight:P(460),Mb:Hi,Er:{o:N.o,fontSize:24,fillColor:"#ea8c9d"},Cr:{o:N.o,fontSize:24,fillColor:"#120825"},Nr:{o:N.o,fontSize:24,
fillColor:"#ea8c9d"},Lr:{o:N.o,fontSize:24,fillColor:"#120825"},Ub:!0,lc:P(400),Dr:"EndScore",Mr:"HighScore",Kt:"level",Wv:"level",$r:"LevelHeader",Nd:!0,Od:!0},gI:{backgroundImage:void 0!==typeof di?di:void 0,vk:["score","highscore"],marginTop:P(16),marginLeft:P(450),marginRight:P(460),Mb:Hi,Ub:!0,lc:P(400),Kt:"level",$r:"LevelHeader",Dc:"LevelFailedHeader",Nd:!1,Od:!1,Hq:!0,sq:P(-145),rq:{o:N.o,fontSize:24,fillColor:"#ffffff"},kl:""},jU:{width:P(500),height:P(300)},BA:{backgroundImage:bi,Ub:!0,
bg:["exit","oldSound","oldLanguage","moregames","about"],tz:"optionsStartScreen",marginTop:P(16),marginLeft:P(170),marginRight:P(175),Mb:Hi,Dc:"optionsTitle"},SA:{backgroundImage:bi,Ub:!0,bg:["resume","tutorial","oldSound","moregames","quit"],marginTop:P(16),marginLeft:P(170),marginRight:P(175),Mb:Hi,Dc:"optionsTitle",Mw:"level",yC:{o:N.o,fontSize:32,fillColor:"#452f5a",xb:"middle",align:"center"}},rP:{ok:"none",fi:1},sP:{},Py:{Xa:"none",Qj:Fd,pl:!0},Ry:{Xa:"none",pl:!0},r:{zk:vj,zh:void 0,Ol:wj,
gT:xj,fd:yj,Mi:zj,jD:Aj,pU:Aj,BB:Bj,iA:rj,hA:sj,iU:void 0,Kd:Cj,nf:Cj,kA:Dj.$D,RC:!1,DO:!1,BO:!0,CO:!0,vO:!1,fh:Ej,DB:Fj,de:Gj,rU:Cj,hj:Hj,rO:!1,PC:!1,FO:!0,AO:!0,SC:!0,qO:!0,mx:!0,uD:ej,wO:!0,zO:!0,Ej:void 0,sO:!0,$G:"title",dr:["load","images","audio","fonts"],er:["load","images"],YK:.5,XK:2},ol:{IR:!1},jA:{},sg:{},FA:{},Oc:{},kq:{$z:[Q]},xa:{}});hj=new Ij;new Jj;v.q();void 0!==O.wa.Yy&&(O.ol.VA=O.wa.Yy);void 0!==O.wa.sl&&(O.kq.sl=O.wa.sl);void 0!==O.wa.Pb&&(O.kq.wl=O.wa.Pb);void 0!==O.wa.$C&&(O.Vr.c=
O.wa.$C);void 0!==O.wa.YC&&(O.Vr.color=O.wa.YC);void 0!==O.wa.ZC&&(O.Vr.duration=O.wa.ZC,O.r.RC=!0);b=v.mb("getSiteLocks");if(void 0===b)if(ba)console.log("Warning: Check this out!!!");else{this.v=void 0;return}else if(!Kj(b)){this.v=void 0;return}b=v.mb("getTimeLock");void 0===b&&(void 0===b||(new Date).getTime()<=b)?(O.xa.aA&&(document.title=O.xa.aA),v.mb("beforeInitializing"),this.v=this.ME):this.v=void 0};a.ME=function(){Lj.q(O.ol);Mj.q(O.rP);Nj.q(O.sP);this.v=this.WE};
a.WE=function(){Lj.se&&(this.canvas=R.A,this.visible=!0,v.mb("afterInitializing"),this.v=this.TE)};a.TE=function(){var b=this;O.r.RC?(this.zk=O.r.zk?new O.r.zk:new vj,this.zk.ub=function(){b.v=b.JE},this.zk.show(),this.v=void 0):this.v=this.Ny};a.JE=function(){this.zk.gf();this.zk=void 0;this.v=this.Ny};
a.Ny=function(){var b=this;Oj({Eh:O.r.dr,required:O.r.er,Yf:O.r.YK,Oe:O.r.XK});O.r.DO?(this.zh=O.r.zh?new O.r.zh:new Pj,this.zh.Zl=Qj,this.zh.ub=function(){b.zh=void 0},this.zh.show()):this.zh=void 0;this.v=this.XE};a.XE=function(){v.mb("loadingProgress",Qj());Rj()&&!this.zh&&(v.mb("afterLoading"),this.v=this.DE)};a.DE=function(){var b;Sj(R);O.r.uD&&(b=S.play(O.r.uD),S.em(b,!0));this.v=this.VE};
a.VE=function(){var b=this;O.r.rO?(this.fh=O.r.fh?new O.r.fh(O.Py):new Ej(O.Py),this.fh.ub=function(){b.v=b.FE},this.fh.show(),this.v=void 0):this.v=this.QE};a.FE=function(){this.fh.gf();this.fh=void 0;this.v=this.qg};function tj(b,c){O.r.PC&&(b.CB=O.r.DB?new O.r.DB(O.Ry):new Fj(O.Ry),b.CB.ub=c,b.CB.show(),b.v=void 0)}a.QE=function(){var b=this;O.r.vO?(this.fr=O.r.kA?new O.r.kA:new Dj.$D,this.fr.ub=function(){b.v=b.HE},this.fr.show(),this.v=void 0):this.v=this.qg};
a.HE=function(){this.fr.gf();this.fr=void 0;this.v=this.qg};a.qg=function(){var b=this;O.r.FO?(v.mb("beforeTitleScreen"),this.de=O.r.de?new O.r.de:new Tj,this.de.ub=function(){b.v=b.My},this.de.cw=function(){b.v=b.RE},this.de.gw=function(){b.tE=!0;b.v=b.NE},this.de.Kl=function(){b.v=b.UE},this.de.show(),this.v=void 0):this.v=this.Lm};a.My=function(){this.de.gf();this.de=void 0;this.v=this.tE?void 0:this.Lm};
a.NE=function(){var b=this;this.Yj=O.r.BB?new O.r.BB(O.qL):new Bj(O.qL);this.Yj.ew=function(c){hj.oU(c);b.v=b.My;b.Yj.oa();b.Yj.XP};this.Yj.ub=function(c){c.Az?(b.de.Db(),b.Yj.oa(),b.Yj.XP):hj.dS()};this.Yj.show();this.v=void 0};a.RE=function(){var b=this;O.r.AO&&(this.hj=O.r.hj?new O.r.hj:new tgfDialog.BQ,this.hj.m=function(c,d){b.hj.Dj(d)},this.hj.ub=function(){b.de.Db();b.hj=void 0;b.v=void 0;b.v=void 0},this.de.Ca(),this.hj.show(),this.v=void 0)};
a.UE=function(){var b=this;O.r.SC&&(this.Cd=O.r.Cd?new O.r.Cd(O.sD):new Cj(O.sD),this.Cd.Si=function(){b.v=b.Zs},this.Cd.ub=function(){b.v=b.KE},this.Cd.Hl=function(){b.v=b.OE},this.de.Ca(),this.Cd.show(),this.v=void 0)};a.KE=function(){this.Cd.gf();this.Cd=void 0;void 0!==this.Ol&&(this.v=this.Jy);this.de.Db();this.v=void 0};
function Uj(b,c){var d;O.r.wO&&(d=v.mb("getMoreGamesFunction"),b.Kd=O.r.Kd?new O.r.Kd(O.BA):new Cj(O.BA),d&&(b.Kd.Ll=d),b.Kd.Si=function(){b.v=b.Zs},b.Kd.ub=function(){b.v=b.Ky},b.Kd.$v=function(c){c.ii.w();b.Ky();b.v=b.qg},b.Kd.ii=c,void 0!==b.fd&&b.fd.Ca(),b.Kd.show(),b.v=void 0)}a.Ky=function(){this.Kd.gf();this.Kd=void 0;void 0!==this.fd&&this.fd.Db();this.v=void 0};
a.Zs=function(){var b=this;O.r.mx&&(this.gs=O.r.hJ?new O.r.hJ(O.hC):new xj(O.hC),this.gs.ub=function(){b.v=b.LE},this.Cd&&this.Cd.Ca(),this.gs.show(),this.v=void 0)};a.LE=function(){this.gs.gf();this.gs=void 0;this.Cd?this.Cd.Db():this.nf&&(this.nf.Db(),this.nf.Rg.w());this.v=void 0};a.OE=function(){var b=this;O.r.qO&&(this.Ol=O.r.Ol?new O.r.Ol:new wj,this.Ol.ub=function(){b.v=b.Jy},void 0!==this.Cd?this.Cd.Ca():void 0!==this.Kd&&this.Kd.Ca(),this.Ol.show(),this.v=void 0)};
a.Jy=function(){void 0!==this.Cd?this.Cd.Db():void 0!==this.Kd&&this.Kd.Db();this.v=void 0};a.Lm=function(){var b=this;O.r.BO?(v.mb("beforeLevelScreen"),this.fd=O.r.fd?new O.r.fd:new Dj.DQ,this.fd.ub=function(){b.v=b.Ly},this.fd.m=function(c,d){O.rB.Vc=d;b.v=b.SE},this.fd.hw=function(){b.v=Uj(b,b.fd)},this.fd.show(),this.v=void 0):(O.xa.Fe=1,this.v=this.Xk)};a.Ly=function(){this.fd=void 0};
a.SE=function(b){var c=this;O.r.CO?(this.Mi=O.r.Mi?new O.r.Mi:new tgfDialog.CQ,this.Mi.ub=function(){c.v=c.IE},this.Mi.Ud=function(b,e){O.xa.Fe=e;c.v=c.Xk},this.Mi.show(),this.fd.Ca(),this.v=void 0):(O.xa.Fe=b,this.v=this.Xk)};a.IE=function(){this.fd.Db();this.Mi.gf();this.v=this.Mi=void 0};
function Vj(){var b=Wj,c="";O.r.zO&&(b.nf=O.r.nf?new O.r.nf(O.SA):new Cj(O.SA),b.nf.ub=function(){switch(c){case "title":b.v=b.qg;break;case "level":b.v=b.Lm;break;default:Qb(mj.Fa),Rb("play")}this.nf=void 0},b.nf.vr=function(){Ob(mj.Fa);Pb("play")},b.nf.Si=function(c){c.Ca();b.v=b.Zs},b.nf.Ao=function(b,e){c=e;Sb(mj)},b.nf.show(),b.v=void 0)}a.Xk=function(){hj.Bk();void 0!==this.fd&&(this.fd.w(),this.v=this.Ly);this.v=void 0};
a.PE=function(){var b=this;O.r.sO?(this.Ej=O.r.Ej?new O.r.Ej:new Xj,this.Ej.ub=function(){b.v=b.GE},this.Ej.show(),this.v=void 0):this.v=this.qg};a.GE=function(){this.Ej.gf();this.Ej=void 0;switch(O.r.$G){case "title":this.v=this.qg;break;case "level":this.v=this.Lm;break;case "restart":O.xa.Fe=1;this.v=this.Xk;break;default:this.v=this.qg}};a.Ab=function(b){0<this.paused||(this.v&&this.v(b),-1<this.fi&&(this.fi-=b))};
a.Uc=function(){var b=R,c;for(c=0;c<b.Hc.length;c+=1)if(!b.Hc[c].en){var d=b.Hc[c],e=d.getContext("2d");e.clearRect(0,0,d.width,d.height);e.beginPath();e.moveTo(0,0);e.lineTo(-1,-1);e.closePath();e.stroke()}};var Wj=new ij;
function P(b,c){var d;if("number"===typeof b)return d=100*b/100,"round"===c&&(d=Math.round(d)),"floor"===c&&(d=Math.floor(d)),"ceil"===c&&(d=Math.ceil(d)),d;if("[object Array]"===Object.prototype.toString.call(b)){for(d=0;d<b.length;d+=1)b[d]=P(b[d],c);return b}if("object"===typeof b)for(d in b)b.hasOwnProperty(d)&&(b[d]=P(b[d],c));return b}
function uj(b,c){var d;if("object"===typeof c)for(d in c)if(c.hasOwnProperty(d))if(void 0===c[d]||null===c[d])b[d]=c[d];else if("[object Array]"===Object.prototype.toString.call(c[d]))b[d]=c[d];else if("object"===typeof c[d]&&c[d].constructor===Object){"object"!==typeof b[d]&&(b[d]={});var e=b[d],g=c[d],h=void 0;if("object"===typeof g)for(h in g)if(g.hasOwnProperty(h))if(void 0===g[h]||null===g[h])e[h]=g[h];else if("[object Array]"===Object.prototype.toString.call(g[h]))e[h]=g[h];else if("object"===
typeof g[h]&&g[h].constructor===Object){"object"!==typeof e[h]&&(e[h]={});var l=e[h],m=g[h],n=void 0;if("object"===typeof m)for(n in m)m.hasOwnProperty(n)&&(l[n]=m[n])}else e[h]=g[h]}else b[d]=c[d]}var O=new function(){this.ol={};this.jA={};this.console={};this.sg={};this.FA={};this.Oc={};this.kq={};this.profile={};this.gP={};this.status={};this.r={};this.xa={};this.be={};this.wa={};this.play={}},Yj,Zj;function Oj(b){Yj=b;Zj=u.hf;for(b=0;b<Yj.Eh.length;b+=1)la.Rh(Yj.Eh[b])}
function Rj(){var b,c=!0;if(u.hf<Zj+1E3*Yj.Yf)return!1;for(b=0;b<Yj.required.length;b+=1)if(!la.complete(Yj.required[b]))return!1;for(b=0;b<Yj.Eh.length;b+=1)la.complete(Yj.Eh[b])||(c=!1);return c||u.hf>=Zj+1E3*Yj.Oe}function Qj(){var b,c=1,d=0;if(Rj())return 100;for(b=0;b<Yj.Eh.length;b+=1)d+=la.Pl(Yj.Eh[b]),c+=1;d/=c;b=1E3*Math.max(Yj.Oe,Yj.Yf);return d*Math.min(1,(u.hf-Zj)/b)}function ak(){r.Xi("master");wb(u);Bb(u);Db(u);u.Xi()}
function Kj(b){var c,d,e,g,h,l;if(!b)return!1;b=[].concat(b);if(0===b.length)return!1;l=void 0!==window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname;for(c=0;c<b.length;c+=1){e=b[c];if(0===l.indexOf("file://")&&e===bk("file://"))return!0;g=l.split(".");d=g.shift().split("://");d[0]+="://";g=d.concat(g);h=g[g.length-1];for(d=g.length-2;0<=d;d-=1)if(h=g[d]+(0<d?".":"")+h,e===bk(h))return!0}return!1}
function ck(b,c){var d;if(void 0===b)return void 0===c;if(null===b)return null===c;if(void 0===c||null===c)return!1;if("[object Array]"===Object.prototype.toString.call(b)){if("[object Array]"!==Object.prototype.toString.call(c)||b.length!==c.length)return!1;for(d=0;d<b.length;d+=1)if(!ck(b[d],c[d]))return!1;return!0}if("object"===typeof b&&b.constructor===Object){if("object"!==typeof c||c.constructor!==Object)return!1;for(d in b)if(b.hasOwnProperty(d)&&!ck(b[d],c[d]))return!1;for(d in c)if(c.hasOwnProperty(d)&&
!ck(b[d],c[d]))return!1;return!0}return c===b}function dk(b){var c,d;if(void 0!==b){if(null===b)return null;if("[object Array]"===Object.prototype.toString.call(b)){d=[];for(c=0;c<b.length;c+=1)d.push(dk(b[c]));return d}if("object"===typeof b&&b.constructor===Object){d={};for(c in b)b.hasOwnProperty(c)&&(d[c]=dk(b[c]));return d}return b}}
function ek(b,c){var d,e;if(void 0===b||null===b)return dk(c);if(void 0===c||null===c)return dk(b);if("[object Array]"===Object.prototype.toString.call(b)){if("[object Array]"!==Object.prototype.toString.call(c))return dk(c);e=dk(b);for(d=0;d<c.length;d+=1)e[d]=dk(c[d]);return e}if("object"===typeof b&&b.constructor===Object){if("object"!==typeof c||c.constructor!==Object)return dk(c);e=dk(b);for(d in c)c.hasOwnProperty(d)&&(e[d]=dk(c[d]));return e}return dk(c)}
function fk(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(b){var c=0+ea(fa,15);if("x"===b)return c.toString(16);if("y"===b)return(c%4+8).toString(16)})}
function gk(b){if(null===b||"undefined"===typeof b)return"";b+="";var c="",d,e,g=0;d=e=0;for(var g=b.length,h=0;h<g;h++){var l=b.charCodeAt(h),m=null;if(128>l)e++;else if(127<l&&2048>l)m=String.fromCharCode(l>>6|192,l&63|128);else if(55296!==(l&63488))m=String.fromCharCode(l>>12|224,l>>6&63|128,l&63|128);else{if(55296!==(l&64512))throw new RangeError("Unmatched trail surrogate at "+h);m=b.charCodeAt(++h);if(56320!==(m&64512))throw new RangeError("Unmatched lead surrogate at "+(h-1));l=((l&1023)<<
10)+(m&1023)+65536;m=String.fromCharCode(l>>18|240,l>>12&63|128,l>>6&63|128,l&63|128)}null!==m&&(e>d&&(c+=b.slice(d,e)),c+=m,d=e=h+1)}e>d&&(c+=b.slice(d,g));return c}
function bk(b){function c(b){var c="",d="",e;for(e=0;3>=e;e++)d=b>>>8*e&255,d="0"+d.toString(16),c+=d.substr(d.length-2,2);return c}function d(b,c,d,e,g,h,m){b=l(b,l(l(d^(c|~e),g),m));return l(b<<h|b>>>32-h,c)}function e(b,c,d,e,g,h,m){b=l(b,l(l(c^d^e,g),m));return l(b<<h|b>>>32-h,c)}function g(b,c,d,e,g,h,m){b=l(b,l(l(c&e|d&~e,g),m));return l(b<<h|b>>>32-h,c)}function h(b,c,d,e,g,h,m){b=l(b,l(l(c&d|~c&e,g),m));return l(b<<h|b>>>32-h,c)}function l(b,c){var d,e,g,h,l;g=b&2147483648;h=c&2147483648;
d=b&1073741824;e=c&1073741824;l=(b&1073741823)+(c&1073741823);return d&e?l^2147483648^g^h:d|e?l&1073741824?l^3221225472^g^h:l^1073741824^g^h:l^g^h}var m=[],n,s,w,y,D,t,z,A,B;b=gk(b);m=function(b){var c,d=b.length;c=d+8;for(var e=16*((c-c%64)/64+1),g=Array(e-1),h=0,l=0;l<d;)c=(l-l%4)/4,h=l%4*8,g[c]|=b.charCodeAt(l)<<h,l++;c=(l-l%4)/4;g[c]|=128<<l%4*8;g[e-2]=d<<3;g[e-1]=d>>>29;return g}(b);t=1732584193;z=4023233417;A=2562383102;B=271733878;b=m.length;for(n=0;n<b;n+=16)s=t,w=z,y=A,D=B,t=h(t,z,A,B,m[n+
0],7,3614090360),B=h(B,t,z,A,m[n+1],12,3905402710),A=h(A,B,t,z,m[n+2],17,606105819),z=h(z,A,B,t,m[n+3],22,3250441966),t=h(t,z,A,B,m[n+4],7,4118548399),B=h(B,t,z,A,m[n+5],12,1200080426),A=h(A,B,t,z,m[n+6],17,2821735955),z=h(z,A,B,t,m[n+7],22,4249261313),t=h(t,z,A,B,m[n+8],7,1770035416),B=h(B,t,z,A,m[n+9],12,2336552879),A=h(A,B,t,z,m[n+10],17,4294925233),z=h(z,A,B,t,m[n+11],22,2304563134),t=h(t,z,A,B,m[n+12],7,1804603682),B=h(B,t,z,A,m[n+13],12,4254626195),A=h(A,B,t,z,m[n+14],17,2792965006),z=h(z,A,
B,t,m[n+15],22,1236535329),t=g(t,z,A,B,m[n+1],5,4129170786),B=g(B,t,z,A,m[n+6],9,3225465664),A=g(A,B,t,z,m[n+11],14,643717713),z=g(z,A,B,t,m[n+0],20,3921069994),t=g(t,z,A,B,m[n+5],5,3593408605),B=g(B,t,z,A,m[n+10],9,38016083),A=g(A,B,t,z,m[n+15],14,3634488961),z=g(z,A,B,t,m[n+4],20,3889429448),t=g(t,z,A,B,m[n+9],5,568446438),B=g(B,t,z,A,m[n+14],9,3275163606),A=g(A,B,t,z,m[n+3],14,4107603335),z=g(z,A,B,t,m[n+8],20,1163531501),t=g(t,z,A,B,m[n+13],5,2850285829),B=g(B,t,z,A,m[n+2],9,4243563512),A=g(A,
B,t,z,m[n+7],14,1735328473),z=g(z,A,B,t,m[n+12],20,2368359562),t=e(t,z,A,B,m[n+5],4,4294588738),B=e(B,t,z,A,m[n+8],11,2272392833),A=e(A,B,t,z,m[n+11],16,1839030562),z=e(z,A,B,t,m[n+14],23,4259657740),t=e(t,z,A,B,m[n+1],4,2763975236),B=e(B,t,z,A,m[n+4],11,1272893353),A=e(A,B,t,z,m[n+7],16,4139469664),z=e(z,A,B,t,m[n+10],23,3200236656),t=e(t,z,A,B,m[n+13],4,681279174),B=e(B,t,z,A,m[n+0],11,3936430074),A=e(A,B,t,z,m[n+3],16,3572445317),z=e(z,A,B,t,m[n+6],23,76029189),t=e(t,z,A,B,m[n+9],4,3654602809),
B=e(B,t,z,A,m[n+12],11,3873151461),A=e(A,B,t,z,m[n+15],16,530742520),z=e(z,A,B,t,m[n+2],23,3299628645),t=d(t,z,A,B,m[n+0],6,4096336452),B=d(B,t,z,A,m[n+7],10,1126891415),A=d(A,B,t,z,m[n+14],15,2878612391),z=d(z,A,B,t,m[n+5],21,4237533241),t=d(t,z,A,B,m[n+12],6,1700485571),B=d(B,t,z,A,m[n+3],10,2399980690),A=d(A,B,t,z,m[n+10],15,4293915773),z=d(z,A,B,t,m[n+1],21,2240044497),t=d(t,z,A,B,m[n+8],6,1873313359),B=d(B,t,z,A,m[n+15],10,4264355552),A=d(A,B,t,z,m[n+6],15,2734768916),z=d(z,A,B,t,m[n+13],21,
1309151649),t=d(t,z,A,B,m[n+4],6,4149444226),B=d(B,t,z,A,m[n+11],10,3174756917),A=d(A,B,t,z,m[n+2],15,718787259),z=d(z,A,B,t,m[n+9],21,3951481745),t=l(t,s),z=l(z,w),A=l(A,y),B=l(B,D);return(c(t)+c(z)+c(A)+c(B)).toLowerCase()}O.AJ={eL:"canvas",Nz:"game_container",$a:P(1152),Ga:P(640),BH:!0,we:P(850),gg:P(640),Nh:P(0),Mh:P(151),dO:"center",eO:"middle",nF:!0,mF:!0,backgroundImage:void 0,backgroundColor:"white",gz:1,yF:!1};function hk(){this.By=!1;this.Hc=[]}
hk.prototype.q=function(b){var c=this;this.By=!0;this.Hc=[];this.Za(O.AJ);this.Za(b);this.j=document.getElementById(this.Nz);this.j||(this.j=document.createElement("DIV"),this.j.id=this.Nz,document.body.appendChild(this.j));this.A=document.getElementById(this.eL);this.A||(this.A=document.createElement("canvas"),this.j.appendChild(this.A));ik(this,this.A,{Cj:0,Bj:0});this.Hc.push(this.A);this.BH&&(this.tg=jk(this));window.addEventListener("resize",function(){hk.prototype.Jm.call(c,!0)},!0);0<this.gz&&
window.setInterval(function(){hk.prototype.Jm.call(c,c.yF)},1E3*this.gz);this.Jm(!0);void 0!==this.backgroundColor&&(document.body.style.backgroundColor=this.backgroundColor);void 0!==this.backgroundImage&&(document.body.style.backgroundImage="url("+this.backgroundImage+")");u.A=this.A;na(p,this.A)};hk.prototype.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
hk.prototype.Jm=function(b){var c,d,e,g;if(this.By&&(b||void 0===this.bi||this.bi!==window.innerWidth||void 0===this.ai||this.ai!==window.innerHeight)){this.bi=window.innerWidth;this.ai=window.innerHeight;e=this.bi/this.ai;c=this.$a/this.Ga;d=this.we/this.gg;b=this.bi;g=this.ai;this.Sb=Math.min(this.bi/this.we,this.ai/this.gg);e<c&&e<d&&(g=Math.floor(this.bi/(this.we/this.Ga)),this.Sb=this.bi/this.we);e>c&&e>d&&(b=Math.floor(this.$a/this.gg*this.ai),this.Sb=this.ai/this.gg);!this.nF&&1<this.Sb&&(b=
Math.min(b,this.$a),g=Math.min(g,this.Ga),this.Sb=1);!this.mF&&1>this.Sb&&(b=Math.max(b,this.$a),g=Math.max(g,this.Ga),this.Sb=1);this.nn=this.mn=0;c=this.$a-this.bi/this.Sb;d=this.$a===this.we?1:c/(this.$a-this.we);if(1<=c)switch(this.dO){case "right":this.mn=-Math.min(c,this.Mh);break;case "left":this.mn=-Math.max(0,c-this.$a+this.we+this.Mh);break;default:this.mn=-d*this.Mh}c=this.Ga-this.ai/this.Sb;d=c/(this.Ga-this.gg);if(1<=c)switch(this.eO){case "bottom":this.nn=-Math.min(c,this.Nh);break;
case "top":this.nn=-Math.max(0,c-this.Ga+this.gg+this.Nh);break;default:this.nn=-d*this.Nh}g=Math.min(this.ai,g);b=Math.min(this.bi,b);this.j.setAttribute("style","position:fixed; overflow:hidden; z-index: 0; width:"+b+"px; left:50%; margin-left:"+-b/2+"px; height: "+g+"px; top:50%; margin-top:"+-g/2+"px");kk(this);this.ij=-this.mn;this.jj=-this.nn;this.Nk=Math.ceil(b/this.Sb);this.yp=Math.ceil(g/this.Sb);Sj(this)}};
function Sj(b){var c,d,e,g,h;if(f.ja.Nx&&f.ja.xp&&4<=f.ja.xp&&!b.qy){b.qy=!0;r.pause("master");u.pause();g=[];for(d=0;d<b.Hc.length;d+=1){e=b.Hc[d];c=e.getContext("2d");try{h=c.getImageData(0,0,e.width,e.height),g.push(h)}catch(l){ba&&console.log("error in getting image data: "+l.name+", "+l.message)}c.clearRect(0,0,e.width,e.height);e.style.visibility="hidden"}setTimeout(function(){var c;for(c=0;c<b.Hc.length;c+=1)b.Hc[c].style.visibility="visible"},1);setTimeout(function(){var c,d;for(c=0;c<b.Hc.length;c+=
1){d=b.Hc[c].getContext("2d");try{d.putImageData(g[c],0,0)}catch(e){ba&&console.log("error in putting image data: "+e.name+", "+e.message)}}ak();this.qy=!1},100)}}function lk(b,c,d){var e,g;void 0!==b.Sb&&(e=b.mn+c.Bj,g=b.nn+c.Cj,c.setAttribute("style","position:absolute; left:"+Math.round(b.Sb*e)+"px; top:"+Math.round(b.Sb*g)+"px; width:"+Math.round(b.Sb*c.Zp)+"px; height:"+Math.round(b.Sb*c.Yp)+"px; z-index: "+(d+1).toString()))}function kk(b){var c;for(c=0;c<b.Hc.length;c+=1)lk(b,b.Hc[c],c)}
function ik(b,c,d){var e,g,h;d||(d={});e=void 0!==d.Cj?d.Cj:0;g=void 0!==d.Bj?d.Bj:0;h=void 0!==d.Zp?d.Zp:b.$a;b=void 0!==d.Yp?d.Yp:b.Ga;d=void 0!==d.en?d.en:!1;c.style.top=e+"px";c.style.left=g+"px";c.style.position="absolute";c.width=h;c.height=b;c.Cj=e;c.Bj=g;c.Zp=h;c.Yp=b;if(c.en=d)c.dA=!1}function mk(b,c){var d=document.createElement("canvas");ik(b,d,c);b.j?b.j.appendChild(d):document.body.appendChild(d);return d}
function nk(b,c){var d;if(!c)return-1;for(d=0;d<b.Hc.length;d+=1)if(b.Hc[d]===c)return d;return-1}function jk(b){var c,d;c=nk(b,void 0);0>c&&(c=0);d=mk(b,{en:!0});b.Hc.splice(c,0,d);kk(b);return d}function ok(b,c){var d=R.A;return d&&b?d.Cj-b.Cj+c:c}function pk(b,c,d,e){var g=R;g.Mh=void 0===b?g.Mh:b;g.Nh=void 0===c?g.Nh:c;g.we=void 0===d?g.we:d;g.gg=void 0===e?g.gg:e;g.Jm(!0)}function qk(b,c,d){b.$a=void 0===c?b.$a:c;b.Ga=void 0===d?b.Ga:d;b.Jm(!0)}var R=new hk;
O.RH={$z:[],wl:[],AC:[],TN:!0,sl:void 0,aQ:!0,ZP:"lang",$P:!0,CD:!0};function rk(){this.Bd={};this.Ee="en-us";this.Pb=["en-us"]}a=rk.prototype;
a.q=function(b){var c,d;this.Za(O.RH);this.Za(b);this.Bd={};b=this.$z;var e;b=[].concat(b);for(e=0;e<b.length;e+=1){var g=b[e],h=void 0,l=void 0;if("object"===typeof g)for(h in g)if(g.hasOwnProperty(h))for(l in this.Bd[h]||(this.Bd[h]={}),g[h])g[h].hasOwnProperty(l)&&(this.Bd[h][l]=g[h][l])}this.Pb=[];for(c in this.Bd)this.Bd.hasOwnProperty(c)&&this.Pb.push(c);0===this.Pb.length&&this.Pb.push("en-us");0<this.wl.length&&sk(this,this.wl);this.wl.hz&&0<this.wl.hz.length&&sk(this,this.wl.hz);if(this.aQ){c=
this.ZP;b=[];g=window.location.search.substring(1);e={};if(g)for(g=g.split("&"),l=0;l<g.length;l+=1)h=g[l].split("="),e[h[0]]=h[1];"string"===typeof e[c]&&(b=e[c].toLowerCase().split("+"));c=b;0<c.length&&sk(this,c)}0<this.AC.length&&tk(this,this.AC);if(this.TN){var m;c=[];for(m in this.Bd)if(this.Bd.hasOwnProperty(m)){a:if(b=m,h=g=e=void 0,void 0===b&&(b=this.Ee),b=b.toLowerCase(),e=this.Bd[b],void 0===e)b=!1;else{for(g in this.Bd)if(this.Bd.hasOwnProperty(g))for(h in this.Bd[g])if(this.Bd[g].hasOwnProperty(h)&&
void 0===e[h]){b=!1;break a}b=!0}b||c.push(m)}tk(this,c);if(ba)for(m=0;m<c.length;m+=1)console.log("Removed incomplete language: "+c[m])}0!==this.Pb.length&&this.Oh(this.Pb[0]);this.CD&&(d=uk(jj).language,vk(this,d)||(d=void 0));void 0===d&&this.CD&&(d=wk.language,vk(this,d)||(d=void 0));void 0===d&&this.sl&&(d=this.sl,vk(this,d)||(d=void 0));if(void 0===d&&this.$P){a:{c=navigator.languages||[navigator.language||navigator.userLanguage];for(d=0;d<c.length;d+=1)if("string"===typeof c[d])for(b=c[d].toLowerCase(),
m=0;m<this.Pb.length;m+=1)if(0<=this.Pb[m].search(b)){d=this.Pb[m];break a}d=void 0}vk(this,d)||(d=void 0)}void 0!==d&&this.Oh(d)};a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};function sk(b,c){b.Pb=[];var d,e=!0,g,h;void 0===e&&(e=!0);d=[].concat(c);for(g=0;g<d.length;g+=1)h=d[g].toLowerCase(),0<=b.Pb.indexOf(h)||e&&void 0===b.Bd[h]||b.Pb.push(h);0===b.Pb.length&&b.Pb.push("en-us")}
function tk(b,c){var d,e;c=[].concat(c);for(d=0;d<c.length;d+=1)e=c[d].toLowerCase(),e=b.Pb.indexOf(e),0<=e&&b.Pb.splice(e,1);0===b.Pb.length&&b.Pb.push("en-us")}a.Ag=function(){return this.Pb.slice(0)};function vk(b,c){if(!c)return!1;c=c.toLowerCase();return 0<=b.Pb.indexOf(c)}a.Oh=function(b){b&&(b=b.toLowerCase(),this.Ee!==b&&-1!==this.Pb.indexOf(b)&&(this.Ee=b,ia("languageSet",b)))};a.vv=function(b,c){var d;void 0===c&&(c=this.Ee);c=c.toLowerCase();d=this.Bd[c];return void 0===d?!1:void 0!==d[b]};
function xk(b,c){var d,e=yk,g,h,l;void 0===d&&(d=e.Ee);d=d.toLowerCase();void 0===c&&(c="< UNDEFINED: "+b+">");d=e.Bd[d];if(void 0===d)return c;d=d[b];if(void 0===d)return c;if(e=d.match(/#touch\{.*\}\s*\{.*\}/g))for(l=f.Ba.vf||f.Ba.ve,h=0;h<e.length;h+=1)g=l?e[h].match(/\{[^}]*\}/g)[1]:e[h].match(/\{[^}]*\}/g)[0],g=g.substring(1,g.length-1),d=d.replace(e[h],g);return d}
function zk(b){switch(b){case "nl-nl":return ed;case "en-us":return cd;case "en-gb":return dd;case "de-de":return gd;case "fr-fr":return hd;case "pt-br":return id;case "es-es":return jd;case "tr-tr":return fd;case "ru-ru":return kd;case "ar-eg":return ld;case "ko-kr":return md;default:return nd}}
function Ak(b){switch(b){case "nl-nl":return"Nederlands";case "en-us":return"English (US)";case "en-gb":return"English (GB)";case "de-de":return"Deutsch";case "fr-fr":return"Fran\u00e7ais";case "pt-br":return"Portugu\u00eas do Brasil";case "es-es":return"Espa\u00f1ol";case "tr-tr":return"T\u00fcrk\u00e7e";case "ru-ru":return"\u0420\u0443\u0441\u0441\u043a\u0438\u0439";case "ar-eg":return"\u0627\u0644\u0639\u0631\u0628\u064a\u0629";case "ko-kr":return"\ud55c\uad6d\uc5b4";default:return"<UNKNOWN>"}}
var yk=new rk;O.jP={SN:"none",vu:"hex",wu:!1,version:1,mO:!0,lO:!0,Np:0,Op:5};function Bk(b){this.name=void 0===b?"storage":b;this.timeStamp=0;this.data={};this.hl=!1}a=Bk.prototype;
a.q=function(b,c,d){var e=this;this.Za(O.jP);this.Za(b);this.$l=this.Lv=this.Up=this.Tp=!1;this.Vf=this.nD=!0;this.Oi=!1;this.Xo=!0;this.te=this.se=this.Ww=!1;if(JSON&&JSON.stringify){this.Lv=void 0!==window.localStorage;switch(this.SN){case "none":this.ho=void 0}this.$l=void 0!==this.ho;wk.id&&(this.$l=!1);this.$l?(this.nD=this.ho.nD,this.ho.q(function(){c&&c();e.se=!0},function(){d&&d();e.te=!0;e.$l=!1})):this.se=!0;Ck(this,this.Np);Dk(this,this.Op)}else this.te=!0};
function Ck(b,c){void 0!==b.dz&&window.clearInterval(b.dz);b.Np=c;0<b.Np&&(b.dz=window.setInterval(function(){Bk.prototype.Kv.call(b)},1E3*b.Np))}function Dk(b,c){void 0!==b.fz&&window.clearInterval(b.fz);b.Op=c;0<b.Op&&(b.fz=window.setInterval(function(){Bk.prototype.Jr.call(b)},1E3*b.Op))}a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
function Ek(b,c){var d,e,g;g=("000"+b.toString(16)).slice(-4);for(e=0;e<c.length;e+=1)d=c.charCodeAt(e),d+=e*b,d%=65535,g+=("000"+d.toString(16)).slice(-4);return g}function Fk(b){var c;c="TG_"+(b.version+"_");c=wk.id?c+(wk.id+"_"):c+"anonymous_";O.xa&&O.xa.id&&(c+=O.xa.id+"_");b.mO&&O.be&&O.be.id&&(c+=O.be.id+"_");b.lO&&O.wa&&O.wa.id&&(c+=O.wa.id+"_");c+=b.name;if(!ba||b.wu)switch(b.vu){case "hex":c=Ek(12345,c)}return c}
function Gk(b){var c=JSON.stringify({timeStamp:b.timeStamp,data:JSON.stringify(b.data)});if(!ba||b.wu)switch(b.vu){case "hex":c=Ek(1E4+ea(fa,1E4),c)}return c}
a.Gy=function(b){var c;if(b){if(!ba||this.wu)switch(this.vu){case "hex":var d,e;c="";var g=b.match(/.{1,4}/g)||[];d=parseInt(g[0],16);for(b=1;b<g.length;b+=1)e=parseInt(g[b],16),e-=(b-1)*d,e=(e%65535+65535)%65535,c+=String.fromCharCode(e);b=c}c=JSON.parse(b);c.timeStamp>=this.timeStamp&&(this.timeStamp=c.timeStamp,this.data=JSON.parse(c.data),this.hl=!1)}};function T(b,c,d){b.data[c]!==d&&(b.timeStamp=(new Date).getTime(),b.data[c]=d,b.hl=!0)}a.vv=function(b){return void 0!==this.data[b]};
a.tk=function(b,c,d,e,g,h){ck(this.data[b],c)||(this.timeStamp=(new Date).getTime(),this.data[b]=h?c:dk(c),this.hl=!0);d&&this.hl&&this.Jr(e,g,!1)};a.Gb=function(b,c){return c?this.data[b]:dk(this.data[b])};
a.Kv=function(b,c,d){var e=this,g;if(this.Tp||this.Up)c&&c();else{d&&(this.timeStamp=0);c=Fk(this);if(this.Lv)try{g=window.localStorage.getItem(c),this.Gy(g)}catch(h){}this.$l?(this.Oi=this.Vf=!1,this.Tp=!0,this.ho.Kv(c,function(b){Bk.prototype.Gy.call(e,b)},function(){e.Tp=!1;this.Vf=!0;b&&b()})):(this.Vf=!0,b&&b())}};
a.Jr=function(b,c,d){var e=this;if(this.hl||d)if(this.Tp||this.Up)c&&c();else{d=Fk(this);c=Gk(this);if(this.Lv)try{window.localStorage.setItem(d,c)}catch(g){}this.$l?(this.Ww=this.Xo=!1,this.Up=!0,this.ho.Jr(d,c,function(){e.Up=!1;this.Xo=!0;b&&b()})):(this.Xo=!0,b&&b());this.hl=!1}};O.lN={name:"Anonymous",id:void 0,VQ:"",UQ:void 0,language:void 0};function Hk(){}Hk.prototype.q=function(b){this.Za(O.lN);this.Za(b)};
Hk.prototype.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};var wk=new Hk;O.ip={vC:{},version:{},global:{Ue:0,Nc:0,jg:0,Un:-1,Tq:-1,Sq:-1,Wf:-1,El:-1,ao:-1,Vq:-1,Wq:-1,Uq:-1,co:-1,eo:-1,bo:-1,hm:0,lp:0,kp:0,jp:0},play:{Ik:!1,Ue:0,Nc:0,jg:0,Yq:0,np:0,jo:0,Ne:0,Hg:0,pp:0,Yf:0,Oe:0,Zq:0,op:0,ko:0,Xf:0,Xq:0,mp:0,io:0,Zj:0},Ty:{}};function Ik(){}a=Ik.prototype;
a.q=function(b,c,d,e){var g=this;this.n=new Bk("tgfStatus");this.n.q(b);Jk(this,ek(O.ip.vC,c.vC));Kk(this,ek(O.ip.version,c.version));Lk(this,ek(O.ip.global,c.global));Mk(this,ek(O.ip.Ty,c.Ty));this.TM=ek(O.ip.play,c.play);this.te=this.se=!1;this.Pn=d;this.On=e;this.Le=0;this.sv=window.setInterval(function(){Ik.prototype.Ht.call(g)},50)};
a.Ht=function(){0===this.Le&&(this.n.se?(Nk(this),this.Le=1):this.n.te&&(this.te=!0,this.Le=2));1===this.Le&&(this.Vf?(this.se=!0,this.Le=2):this.Oi&&(this.te=!0,this.Le=2));2===this.Le&&(window.clearInterval(this.sv),this.se&&this.Pn&&this.Pn(),this.te&&this.On&&this.On())};function Nk(b){b.Vf=!1;b.Oi=!1;b.n.Kv(function(){b.Vf=!0},function(){b.Oi=!0},!0)}function Ok(b){b.Xo=!1;b.Ww=!1;b.n.Jr(function(){b.Xo=!0},function(){b.Ww=!0},!1)}
function uk(b){return{language:b.n.data.Pla,qh:b.n.data.Pem,Oj:b.n.data.Peg,Fh:b.n.data.Pmm,ik:b.n.data.Pmg}}function Jk(b,c){void 0!==c.language&&T(b.n,"Pla",c.language);void 0!==c.qh&&T(b.n,"Pem",c.qh);void 0!==c.Oj&&T(b.n,"Peg",c.Oj);void 0!==c.Fh&&T(b.n,"Pmm",c.Fh);void 0!==c.ik&&T(b.n,"Pmg",c.ik)}
function Kk(b,c){void 0!==c.Hn&&T(b.n,"Vgi",c.Hn);void 0!==c.Wx&&T(b.n,"Vti",c.Wx);void 0!==c.gn&&T(b.n,"Vci",c.gn);void 0!==c.In&&T(b.n,"Vgv",c.In);void 0!==c.Xx&&T(b.n,"Vtv",c.Xx);void 0!==c.Jt&&T(b.n,"Vcv",c.Jt)}
function Pk(b){return{Ue:b.n.data.Gtp,Nc:b.n.data.Gtw,jg:b.n.data.Gtl,Un:b.n.data.Gllp,Tq:b.n.data.Gllw,Sq:b.n.data.Glll,Wf:b.n.data.Gmlp,El:b.n.data.Gmlw,ao:b.n.data.Gmll,Vq:b.n.data.Glmp,Wq:b.n.data.Glmw,Uq:b.n.data.Glml,co:b.n.data.Gmmp,eo:b.n.data.Gmmw,bo:b.n.data.Gmml,hm:b.n.data.Gsms,lp:b.n.data.Gsmt,kp:b.n.data.Gsmr,jp:b.n.data.Gsmm}}
function Lk(b,c){void 0!==c.Ue&&T(b.n,"Gtp",c.Ue);void 0!==c.Nc&&T(b.n,"Gtw",c.Nc);void 0!==c.jg&&T(b.n,"Gtl",c.jg);void 0!==c.Un&&T(b.n,"Gllp",c.Un);void 0!==c.Tq&&T(b.n,"Gllw",c.Tq);void 0!==c.Sq&&T(b.n,"Glll",c.Sq);void 0!==c.Wf&&T(b.n,"Gmlp",c.Wf);void 0!==c.El&&T(b.n,"Gmlw",c.El);void 0!==c.ao&&T(b.n,"Gmll",c.ao);void 0!==c.Vq&&T(b.n,"Glmp",c.Vq);void 0!==c.Wq&&T(b.n,"Glmw",c.Wq);void 0!==c.Uq&&T(b.n,"Glml",c.Uq);void 0!==c.co&&T(b.n,"Gmmp",c.co);void 0!==c.eo&&T(b.n,"Gmmw",c.eo);void 0!==c.bo&&
T(b.n,"Gmml",c.bo);void 0!==c.hm&&T(b.n,"Gsms",c.hm);void 0!==c.lp&&T(b.n,"Gsmt",c.lp);void 0!==c.kp&&T(b.n,"Gsmr",c.kp);void 0!==c.jp&&T(b.n,"Gsmm",c.jp)}
function Qk(b,c,d){void 0===c&&(c=0);void 0===d&&(d=0);c="M"+c+"L"+d;return b.n.vv(c+"ex")?{Ik:b.n.data[c+"un"],Ue:b.n.data[c+"tp"],Nc:b.n.data[c+"tw"],jg:b.n.data[c+"tl"],Yq:b.n.data[c+"las"],np:b.n.data[c+"sus"],jo:b.n.data[c+"mis"],Ne:b.n.data[c+"mas"],Hg:b.n.data[c+"lat"],pp:b.n.data[c+"sut"],Yf:b.n.data[c+"mit"],Oe:b.n.data[c+"mat"],Zq:b.n.data[c+"lar"],op:b.n.data[c+"sur"],ko:b.n.data[c+"mir"],Xf:b.n.data[c+"mar"],Xq:b.n.data[c+"lam"],mp:b.n.data[c+"sum"],io:b.n.data[c+"mim"],Zj:b.n.data[c+
"mam"]}:dk(b.TM)}
function Rk(b,c,d,e){void 0===c&&(c=0);void 0===d&&(d=0);c="M"+c+"L"+d;T(b.n,c+"ex",!0);void 0!==e.Ik&&T(b.n,c+"un",e.Ik);void 0!==e.Ue&&T(b.n,c+"tp",e.Ue);void 0!==e.Nc&&T(b.n,c+"tw",e.Nc);void 0!==e.jg&&T(b.n,c+"tl",e.jg);void 0!==e.Yq&&T(b.n,c+"las",e.Yq);void 0!==e.np&&T(b.n,c+"sus",e.np);void 0!==e.jo&&T(b.n,c+"mis",e.jo);void 0!==e.Ne&&T(b.n,c+"mas",e.Ne);void 0!==e.Hg&&T(b.n,c+"lat",e.Hg);void 0!==e.pp&&T(b.n,c+"sut",e.pp);void 0!==e.Yf&&T(b.n,c+"mit",e.Yf);void 0!==e.Oe&&T(b.n,c+"mat",e.Oe);
void 0!==e.Zq&&T(b.n,c+"lar",e.Zq);void 0!==e.op&&T(b.n,c+"sur",e.op);void 0!==e.ko&&T(b.n,c+"mir",e.ko);void 0!==e.Xf&&T(b.n,c+"mar",e.Xf);void 0!==e.Xq&&T(b.n,c+"lam",e.Xq);void 0!==e.mp&&T(b.n,c+"sum",e.mp);void 0!==e.io&&T(b.n,c+"mim",e.io);void 0!==e.Zj&&T(b.n,c+"mam",e.Zj)}function Mk(b,c){b.n.tk("Additional",c)}a.Oh=function(b){var c=uk(this);void 0!==b&&(c.language=b);Jk(this,c);Ok(this)};function Sk(b,c){var d=jj,e=uk(d);void 0!==b&&(e.qh=b);void 0!==c&&(e.Fh=c);Jk(d,e);Ok(d)}
a.Bk=function(b,c){var d={Hn:this.n.data.Vgi,Wx:this.n.data.Vti,gn:this.n.data.Vci,In:this.n.data.Vgv,Xx:this.n.data.Vtv,Jt:this.n.data.Vcv},e=Pk(this),g=Qk(this,b,c);this.Xg=void 0===c?0:c;this.Yg=void 0===b?0:b;O.xa&&O.xa.id&&(d.Hn=O.xa.id);O.be&&O.be.id&&(d.Wx=O.be.id);O.wa&&O.wa.id&&(d.gn=O.wa.id);O.xa&&O.xa.version&&(d.In=O.xa.version);O.be&&O.be.version&&(d.Xx=O.be.version);O.wa&&O.wa.version&&(d.Jt=O.wa.version);e.Ue+=1;e.Un=this.Xg;e.Wf=Math.max(e.Wf,this.Xg);e.Vq=this.Yg;e.co=Math.max(e.co,
this.Yg);g.Ue+=1;Kk(this,d);Lk(this,e);Rk(this,b,c,g);Ok(this)};
a.jl=function(b,c,d,e){var g=Pk(this),h=Qk(this,this.Yg,this.Xg);void 0===b&&(b=0);void 0===c&&(c=0);void 0===d&&(d=0);void 0===e&&(e=0);g.Nc+=1;g.Tq=this.Xg;g.El=Math.max(g.El,this.Xg);g.Wq=this.Yg;g.eo=Math.max(g.eo,this.Yg);b>h.Ne&&(g.hm+=b-h.Ne);c>h.Oe&&(g.lp+=c-h.Oe);d>h.Xf&&(g.kp+=d-h.Xf);e>h.Zj&&(g.jp+=e-h.Zj);h.Nc+=1;h.Yq=b;h.np+=b;h.jo=1===h.Nc?b:Math.min(h.jo,b);h.Ne=1===h.Nc?b:Math.max(h.Ne,b);h.Hg=c;h.pp+=c;h.Yf=1===h.Nc?c:Math.min(h.Yf,c);h.Oe=1===h.Nc?c:Math.max(h.Oe,c);h.Zq=d;h.op+=
d;h.ko=1===h.Nc?d:Math.min(h.ko,d);h.Xf=1===h.Nc?d:Math.max(h.Xf,d);h.Xq=e;h.mp+=e;h.io=1===h.Nc?e:Math.min(h.io,e);h.Zj=1===h.Nc?e:Math.max(h.Zj,e);Lk(this,g);Rk(this,this.Yg,this.Xg,h);Ok(this)};a.Pj=function(){var b=Pk(this),c=Qk(this,this.Yg,this.Xg);b.jg+=1;b.Sq=this.Xg;b.ao=Math.max(b.ao,this.Xg);b.Uq=this.Yg;b.bo=Math.max(b.bo,this.Yg);c.jg+=1;Lk(this,b);Rk(this,this.Yg,this.Xg,c);Ok(this)};var jj=new Ik;
O.pF={ok:"gameAnalytics",version:"1",vB:"analyticsUserId",jx:!0,aJ:"https://api.gameanalytics.com/1/",vA:void 0,wA:void 0};function Tk(){this.ta=this.ba=!1}
Tk.prototype.q=function(b){var c;this.Za(O.pF);this.Za(b);this.ee=[];this.Af=wk.Af;if(void 0===this.Af&&void 0!==window.localStorage)try{this.Af=window.localStorage.getItem(this.vB)}catch(d){this.Af=fk()}if(null===this.Af||void 0===this.Af)this.Af=fk();if(void 0!==window.localStorage)try{window.localStorage.setItem(this.vB,this.Af)}catch(e){}c=[].concat(this.ok);this.Dh=[];for(b=0;b<c.length;b+=1)switch(c[b]){case "gameAnalytics":this.Dh.push(new Uk(this))}for(b=0;b<this.Dh.length;b+=1)this.Dh[b].q();
this.ba=!1;this.ta=!0};Tk.prototype.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};Tk.prototype.Mx=function(){var b;if(!this.ba&&this.ta){this.ba=!0;for(b=0;b<this.Dh.length;b+=1)this.Dh[b].Mx(O.xa.id,O.be.id,O.wa.id,this.Af,this.version);for(b=0;b<this.Dh.length;b+=1)this.Dh[b].Wi("session",void 0,"start")}};Tk.prototype.Wi=function(b,c,d,e){var g;if(this.ba&&this.ta)for(g=0;g<this.Dh.length;g+=1)this.Dh[g].Wi(b,c,d,e)};
function lj(b,c,d){var e=kj,g,h;for(g=0;g<e.ee.length;g+=1)if(!e.ee[g].ba){h=e.ee[g];break}void 0===h&&(e.ee.push({}),h=e.ee[e.ee.length-1]);h.paused=0;h.ba=!0;h.tag=b;h.name=d;h.IG=c;h.mP=void 0;h.startTime=u.hf;h.KM=0}function pj(b){var c=kj,d,e;for(d=0;d<c.ee.length;d+=1)!c.ee[d].ba||void 0!==b&&c.ee[d].tag!==b||(e=c.ee[d],0<e.paused&&(e.startTime+=u.hf-e.KM),c.Wi(e.IG,e.mP,e.name,u.hf-e.startTime),e.ba=!1)}
function qj(b){var c=kj,d,e;for(d=0;d<c.ee.length;d+=1)!c.ee[d].ba||void 0!==b&&c.ee[d].tag!==b||(e=c.ee[d],e.ba=!1)}function Uk(b){this.sg=b;this.ba=this.ta=!1}
Uk.prototype.q=function(){this.yA=this.sg.vA;this.JC=this.sg.wA;this.GF=this.sg.aJ+this.yA;void 0===this.yA||void 0===this.JC?this.sg.jx&&ba&&(console.log("Error in gameAnalytics: no gameKey or secretKey provided."),Vk("Error in gameAnalytics: no gameKey or secretKey provided.")):JSON&&JSON.stringify?this.ta=!0:this.sg.jx&&ba&&(console.log("Error in gameAnalytics: JSON stringify not supported."),Vk("Error in gameAnalytics: JSON stringify not supported."))};
Uk.prototype.Mx=function(b,c,d,e,g){!this.ba&&this.ta&&(this.ba=!0,this.KC=fk(),this.Af=e,this.version=g,this.ba=!0,b={user_id:this.Af,session_id:this.KC,build:this.version,install_publisher:d,install_site:window.location!==window.parent.location?document.referrer:document.location.href},Wk(this,"user",b))};
Uk.prototype.Wi=function(b,c,d,e){var g="";this.ba&&this.ta&&(void 0!==b&&(g+=b+":"),void 0!==c&&(g+=c+":"),void 0!==d&&(g+=d),0!==g.length&&(":"===g.slice(-1)&&(g=g.slice(0,-1)),b={user_id:this.Af,session_id:this.KC,build:this.version,event_id:g,value:e},Wk(this,"design",b)))};
function Wk(b,c,d){var e;d=JSON.stringify(d);var g=bk(d+b.JC),h=b.GF+"/"+c;try{e=new XMLHttpRequest,e.open("POST",h,!0),b.sg.jx&&ba&&(e.onreadystatechange=function(){4===e.readyState&&200!==e.status&&console.log("ERROR ajax call error: "+e.statusText+", url: "+h)}),e.setRequestHeader("Content-Type","text/plain"),e.setRequestHeader("Authorization",g),e.send(d)}catch(l){}}var kj=new Tk;
O.mH={EO:!1,QC:!0,GP:120,Yr:"ABBCCDDA",nP:5,fy:.2,lx:!0,LI:1,width:P(320),height:void 0,left:void 0,top:P(0),OD:void 0,PA:P(320),iB:P(0),xD:void 0,jQ:!1,kQ:!1,mQ:!1,lQ:!1,MO:!0,II:!0,XN:!0,hh:P(48),bn:"#CCE6FF",rz:"#EEEEEE",margin:P(6),jv:P(48),kv:"#CCCCCC",LJ:"#999999",lv:"#000000",NA:"Arial",OA:P(16,"round"),Tx:"Courier New",Ux:P(16,"round"),Sx:"#000000",pD:"#CCE6FF",wf:P(24),textIndent:P(24),Vx:"#2E8AE6",Bx:P(32),LO:"#DDDDDD",KO:"#AAAAAA"};
function Xk(){this.depth=0;this.d=-99999999;this.visible=!1;this.ba=!0;this.ta=!1;this.ej="";this.im=0;Ib(this)}a=Xk.prototype;a.q=function(b){this.ta||(this.Za(O.mH),this.Za(b),this.QC&&!ba)||(this.ta=!0,this.info=[],this.Fl=[],this.Fc=[],this.mode=0,this.clear(),this.zr=this.vh=!1,this.tb=null,this.EO&&this.show(),this.lx&&(this.eB=u.hf,this.hB=u.up,this.vq="",this.wq=0),0<this.fy&&(this.lg=0))};
a.clear=function(){this.ta&&(this.ta&&this.F(!1)&&(this.Fl=[],Yk(this)),this.ta&&this.F(!1)&&(this.info=[],Zk(this)),this.ta&&this.F(!1)&&(this.Fc=[],$k(this)))};a.F=function(b){return!this.ta||this.QC&&!ba||!this.tb&&!1!==b?!1:!0};a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
a.show=function(b){var c,d,e;if(this.ta&&this.F(!1)&&!this.tb){void 0===b&&(b=!1);this.oE=R.$a;this.nE=R.Ga;this.sE=R.we;this.pE=R.gg;this.rE=R.Nh;this.qE=R.Mh;(this.fE=b)?(b=void 0===this.iB?R.$a:this.iB,c=void 0===this.xD?R.Ga:this.xD,d=void 0===this.OD?R.$a:this.OD,e=void 0===this.PA?R.Ga:this.PA):(b=void 0===this.left?R.$a:this.left,c=void 0===this.top?R.Ga:this.top,d=void 0===this.width?R.$a:this.width,e=void 0===this.height?R.Ga:this.height);0>b&&(b=0);0>c&&(c=0);var g=R,h;h=mk(g,{Bj:b,Cj:c,
Zp:d,Yp:e,en:!0});g.Hc.push(h);lk(g,h,g.Hc.length-1);this.tb=h;qk(R,Math.max(R.$a,b+d),Math.max(R.Ga,c+e));pk(0,0,R.$a,R.Ga);this.mode=-1;al(this)}};a.w=function(){if(this.ta&&this.F()){qk(R,this.oE,this.nE);pk(this.qE,this.rE,this.sE,this.pE);var b=this.tb,c=R,d;b!==c.A&&(d=nk(c,b),0>d||(c.Hc.splice(d,1),b===c.tg&&(c.tg=void 0),c.j?c.j.removeChild(b):document.body.removeChild(b),kk(c)));this.tb=null;this.vh&&this.XN&&(Ob(this),Rb(),this.vh=!1)}};
a.toggle=function(){this.ta&&this.F(!1)&&(this.tb?this.w():this.show())};function al(b){var c;b.ta&&b.F()&&2!==b.mode&&(b.mode=2,bl(b),c=Math.floor(b.Ga/b.wf),b.aj=Math.min(1,c/b.Fl.length),b.tf=1-b.aj,cl(b),Yk(b))}function Yk(b){var c=[],d,e,g=b.Ux+"px "+b.Tx;if(b.ta&&b.F()&&2===b.mode){for(e=0;e<b.Fl.length;e+=1)d=b.Fl[e],void 0!==d?c.push({text:d.text,color:d.color,of:0,icon:e===b.Fl.length-1?"disk":"",font:g}):c.push({text:"",color:"black",of:0,icon:"",font:g});dl(b,c)}}
function Vk(b){var c=el,d="red";c.ta&&c.F(!1)&&(void 0===d&&(d=c.Sx),c.Fl.push({text:b,color:d}),Yk(c))}function Zk(b){var c=[],d,e,g,h=b.Ux+"px "+b.Tx;if(b.ta&&b.F()&&0===b.mode){for(g=0;g<b.info.length;g+=1)d=b.info[g],void 0!==d?(e=d.text,void 0!==d.Gn&&(e+=d.Gn()),c.push({text:e,color:d.color,of:0,icon:"",font:h})):c.push({text:"",color:"black",of:0,icon:"",font:h});dl(b,c)}}
function $k(b){var c=[],d,e,g,h,l,m=b.Ux+"px "+b.Tx;if(b.ta&&b.F()&&1===b.mode){for(d=0;d<b.Fc.length;d+=1)e=b.Fc[d],g=e.RB,void 0!==e.Gr&&(g=g[e.Gr]),h=e.name+": ",l="",void 0===g?h+="undefined":null===g?h+="null":"[object Array]"===Object.prototype.toString.call(g)?(h+="Array["+g.length+"]",l=e.yi?"arrowD":"arrowR"):"object"===typeof g?(h+="Object",l=e.yi?"arrowD":"arrowR"):h="function"===typeof g?h+"Function":"string"===typeof g?h+('"'+g+'"'):h+g.toString(),c.push({text:h,color:e.color,of:e.of,
icon:l,font:m});dl(b,c)}}function fl(b,c,d,e,g,h,l){var m=e,n=!0;void 0!==m&&void 0!==g&&(m=m[g]);void 0!==m||b.mQ||(n=!1);null!==m||b.kQ||(n=!1);"function"!==typeof m||b.jQ||(n=!1);n&&b.Fc.splice(c,0,{name:d,RB:e,Gr:g,color:h,yi:!1,of:l});return n}function gl(b,c){if(b.ta&&b.F()&&(bl(b),b.vx))switch(b.tf=(c-b.Ce)/b.Ga-b.aj/2,0>b.tf&&(b.tf=0),1<b.tf+b.aj&&(b.tf=1-b.aj),b.mode){case 0:Zk(b);break;case 1:$k(b);break;case 2:Yk(b)}}
function bl(b){b.ta&&b.F()&&(b.Yk=b.margin+1,b.Ce=b.margin+b.hh+b.jv+1,b.$a=b.tb.width-2*b.margin-2,b.Ga=b.tb.height-b.Ce-b.margin-2)}
function cl(b){var c,d,e,g,h,l,m,n;if(b.ta&&b.F()){c=b.margin;d=c+b.hh;e=b.tb.width;g=b.tb.height;h=Math.min(100,Math.round((e-4*c)/3));l=b.jv-c;m=b.OA+"px "+b.NA;na(p,b.tb);p.clearColor(b.rz);bl(b);for(n=0;3>n;n+=1)pa(p,c+n*(h+c),d,h,l+P(6),P(6),n===b.mode?b.kv:b.LJ);p.le("Info",c+P(8),d+Math.round(.65*l),b.lv,m);p.le("Watch",c+(h+c)+P(8),d+Math.round(.65*l),b.lv,m);p.le("Messages",c+2*(h+c)+P(8),d+Math.round(.65*l),b.lv,m);oa(0,d+l,e,g-d-l,b.kv,"black");e=c+b.mode*(h+c)+1;g=d+l;c=c+b.mode*(h+c)+
h-2;d+=l;l=b.kv;h=p;h.context.save();h.context.beginPath();h.context.moveTo(e,g);h.context.lineTo(c,d);h.context.lineWidth=2;h.context.strokeStyle=l;h.context.stroke();h.context.restore();oa(b.Yk-1,b.Ce-1,b.$a+2,b.Ga+2,b.pD,"black");hl(b);il(b)}}
function hl(b){var c,d,e,g;b.ta&&b.F()&&(d=c=b.margin,e=b.hh-b.margin,na(p,b.tb),pa(p,c,d,e,e,P(6),b.bn),g=b.vh?Xc:Yc,g.ma(0,c+e/2,d+e/2),c+=e+b.margin,pa(p,c,d,e,e,P(6),b.bn),$c.ma(0,c+e/2,d+e/2),c+=e+b.margin,pa(p,c,d,e,e,P(6),b.bn),Zc.ma(0,c+e/2,d+e/2),c+=e+b.margin,pa(p,c,d,e,e,P(6),b.bn),ad.ma(0,c+e/2,d+e/2),c+=e+b.margin,pa(p,c,d,e,e,P(6),b.bn),bd.ma(0,c+e/2,d+e/2))}
function il(b){var c,d,e,g,h;b.ta&&b.F()&&b.lx&&(c=b.tb.width,h=b.OA+"px "+b.NA,d=c-p.Fk(b.vq,h)-P(10),e=Math.round(1.2*b.hh/3),g=Math.round(2.8*b.hh/3),na(p,b.tb),oa(d,0,c-d,b.hh,b.rz),p.le(b.vq,d,e,b.Sx,h),p.le(yk.Ee,d,g,b.Sx,h))}
function dl(b,c){var d,e;if(b.ta&&b.F()){na(p,b.tb);bl(b);d=Math.floor(b.Ga/b.wf);b.aj=0===c.length?1:Math.min(1,d/c.length);1<b.tf+b.aj&&(b.tf=1-b.aj);var g,h;b.ta&&b.F()&&(d=b.Bx,g=b.Yk+b.$a-d,e=b.Ce+Math.round(b.tf*b.Ga),h=Math.round(b.aj*b.Ga),na(p,b.tb),oa(g,b.Ce,d,b.Ga,b.LO),oa(g+2,e+2,d-4,h-4,b.KO,"black"));p.context.save();p.context.beginPath();p.context.rect(b.Yk,b.Ce,b.$a-b.Bx,b.Ga);p.context.clip();oa(b.Yk,b.Ce,b.$a,b.Ga,b.pD);for(d=0;d<c.length;d+=1)if(e=b.Ce+d*b.wf-b.tf*c.length*b.wf,
!(e<=b.Ce-b.wf||e>=b.Ce+b.Ga)){g=b;var l=b.Yk,m=e;e=c[d];var n=h=void 0;if(void 0!==e){p.le(e.text,l+(e.of+1)*g.textIndent,m+Math.round(.75*g.wf),e.color,e.font);h=l+(e.of+.5)*g.textIndent;n=m+g.wf/2;if("disk"===e.icon){var l=p,m=h,s=n,w=P(4),y=g.Vx;l.context.save();l.context.beginPath();l.context.arc(m,s,w,0,2*Math.PI,!1);l.context.closePath();void 0!==y&&(l.context.fillStyle=y,l.context.fill());l.context.restore()}"arrowR"===e.icon&&qa(p,[h-P(4),h-P(4),h+P(4)],[n-P(4),n+P(4),n],g.Vx);"arrowD"===
e.icon&&qa(p,[h-P(4),h+P(4),h],[n-P(4),n-P(4),n+P(4)],g.Vx)}}p.context.restore()}}a.kf=function(){this.ta&&this.F()&&this.w()};a.ne=function(){this.ta&&this.F()&&this.zr&&(Pb(),Qb(this),this.vh=!0,this.zr=!1,hl(this))};
a.Ld=function(b,c,d){var e="X";if(this.ta&&(""===this.Yr||void 0!==this.tb&&null!==this.tb||(c<p.width/3&&d<p.height/3&&(e="A"),c>2*p.width/3&&d<p.height/3&&(e="B"),c<p.width/3&&d>2*p.height/3&&(e="C"),c>2*p.width/3&&d>2*p.height/3&&(e="D"),this.ej+=e,0!==this.Yr.indexOf(this.ej)&&(this.ej="",this.im=0),this.ej===this.Yr&&(this.show(),this.ej="",this.im=0)),this.F())){var e=this.tb,g=R.A;c=g&&e?g.Bj-e.Bj+c:c;d=ok(this.tb,d);if(0<=c&&c<this.tb.width&&0<=d&&d<this.tb.height){this.Qv=!0;this.IB=b;b=
Math.min(100,Math.round((this.tb.width-4*this.margin)/3));var h;if(this.ta&&this.F())if(bl(this),d<this.hh){if(h=Math.floor((c-this.margin/2)/this.hh),this.ta&&this.F())switch(h){case 0:this.vh=!this.vh;this.zr=!1;this.vh?(Pb(),Qb(this)):(Ob(this),Rb());hl(this);break;case 1:this.vh&&(Ob(this),Rb(),this.vh=!1);this.zr=!0;break;case 2:location.reload(this.II);break;case 3:this.w();this.show(!this.fE);break;case 4:this.w()}}else if(d<this.hh+this.jv)switch(h=Math.floor((c-this.margin/2)/(b+this.margin)),
h){case 0:this.ta&&this.F()&&0!==this.mode&&(this.tf=this.mode=0,cl(this),Zk(this));break;case 1:this.ta&&this.F()&&1!==this.mode&&(this.mode=1,this.tf=0,cl(this),$k(this));break;case 2:al(this)}else if(d<=this.Ce+this.Ga&&c>=this.Yk+this.$a-this.Bx)this.vx=!0;else if(1===this.mode&&d<=this.Ce+this.Ga&&(b=Math.floor(this.tf*this.Fc.length+(d-this.Ce)/this.wf),0<=b&&b<this.Fc.length))if(this.Fc[b].yi){if(this.ta&&this.F()&&!(0>b||b>=this.Fc.length)&&(h=this.Fc[b],void 0!==h&&h.yi)){h.yi=!1;for(c=0;b+
c+1<this.Fc.length&&this.Fc[b+c+1].of>h.of;)c+=1;this.Fc.splice(b+1,c);$k(this)}}else if(g=0,this.ta&&this.F()&&!(0>b||b>=this.Fc.length)&&(e=this.Fc[b],void 0!==e&&!e.yi)){c=e.RB;void 0!==c&&void 0!==e.Gr&&(c=c[e.Gr]);if("[object Array]"===Object.prototype.toString.call(c))for(e.yi=!0,h=c.length-1;0<=h;h-=1)fl(this,b+1,h.toString(),c,h.toString(),e.color,e.of+1)&&(g+=1);else if("object"===typeof c)for(h in e.yi=!0,c)(c.hasOwnProperty(h)||!this.lQ)&&fl(this,b+1,h,c,h,e.color,e.of+1)&&(g+=1);if(this.MO)for(h=
b+g,b+=1;b<h;b+=1)for(c=b+1;c<=h;c+=1)this.Fc[c].name<this.Fc[b].name&&(e=this.Fc[b],this.Fc[b]=this.Fc[c],this.Fc[c]=e);$k(this)}gl(this,d);return!0}}};a.Tf=function(b){if(this.ta&&this.F()&&this.Qv&&this.IB===b)return this.Qv=!1,this.ta&&this.F()&&this.vx&&(this.vx=!1),!0};a.oe=function(b){this.ta&&this.F(!1)&&b===this.GP&&this.toggle()};
a.Ab=function(b){if(this.ta&&(""===this.Yr||void 0!==this.tb&&null!==this.tb||(""!==this.ej&&(this.im+=b/1E3),this.im>this.nP&&(this.im=0,this.ej="")),this.F())){if(this.lx&&(this.wq+=b/1E3,this.wq>=this.LI)){a:{var c=Math.round((u.up-this.hB)/((u.hf-this.eB)/1E3));if(this.ta){this.eB=u.hf;this.hB=u.up;c="fps: "+c;if(c!==this.vq&&(this.vq=c,!this.tb))break a;il(this)}}this.wq=0}0<this.fy&&(this.lg+=b/1E3,this.lg>=this.fy&&(this.ta&&this.F()&&0===this.mode&&Zk(this),this.ta&&this.F()&&1===this.mode&&
$k(this),this.lg=0));this.Qv&&(b=ok(this.tb,u.sc(this.IB)),gl(this,b))}};var el=new Xk;O.kI={aU:!0,eU:!0,YT:!0,yO:!1,GO:!1,GT:!1,JT:!1,ET:!0,FT:!0,IT:!0,HT:"console",Gj:{width:P(640),height:P(400),Pc:P(200),KD:-280,LD:150,JD:{o:"ff_tgf_normal",fontSize:14,align:"left",xb:"top"}}};function jl(){}
jl.prototype.q=function(b){this.Za(O.kI);this.Za(b);this.Mk="F: "+Lj.id+"_"+Lj.version;O.xa&&(this.Mk+=", G: "+O.xa.id+"_"+O.xa.version);O.be&&(this.Mk+=", T: "+O.be.id+"_"+O.be.version);O.wa&&(this.Mk+=", C: "+O.wa.id+"_"+O.wa.version)};jl.prototype.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
jl.prototype.show=function(b,c,d,e){var g="",h=new kl(this.Gj);h.i({Zc:b,Qd:c,buttons:[{text:"Close"}]});d&&this.yO&&"error"===e&&(g+="Error Id: "+d+"\n");this.GO&&"error"===e&&(""===g&&(g="\n"),g+="Version: "+this.Mk);""!==g&&h.h.push(new U({x:void 0!==this.Gj.KD?this.Gj.KD:-h.width/2+h.marginLeft,y:void 0!==this.Gj.LD?this.Gj.LD:h.height/2-h.marginBottom-P(12),font:void 0!==this.Gj.JD?this.Gj.JD:{o:"ff_tgf_normal",fontSize:14,align:"left",xb:"top"},text:g}));switch(e){case "message":h.Ia=Vc;break;
case "warning":h.Ia=Uc;break;default:h.Ia=Wc}h.ub=function(b){b.w();Rb()};Pb();h.show()};var ll=new jl;O.tF={TC:Ni,oq:["sfx","effect","game"],or:"music",nq:!0,mr:!0,mq:!0,lr:!0,Fh:!1,qh:!1,ik:1,Oj:1};function ml(){}a=ml.prototype;a.q=function(b){var c=uk(jj);this.Za(O.tF);this.Za(b);nl(this);void 0!==c.Oj&&(this.Oj=c.Oj);void 0!==c.ik&&(this.ik=c.ik);void 0!==c.qh&&(this.qh=c.qh);void 0!==c.Fh&&(this.Fh=c.Fh);ol(this,this.Oj);pl(this,this.ik);this.qh?ql(this):rl(this);this.Fh?sl(this):tl(this)};
a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};function nl(b){void 0!==b.TC&&(b.UC=!1,b.Xl=function(){b.UC||(b.UC=!0,r.play(b.TC),window.removeEventListener("click",b.Xl,!1),window.removeEventListener("mousedown",b.Xl,!1),window.removeEventListener("touchstart",b.Xl,!1))},window.addEventListener("click",b.Xl,!1),window.addEventListener("mousedown",b.Xl,!1),window.addEventListener("touchstart",b.Xl,!1))}
function ql(b){var c=[].concat(b.oq);if(b.nq&&b.mq)for(b=0;b<c.length;b+=1)nb(c[b])}function sl(b){var c=[].concat(b.or);if(b.mr&&b.lr)for(b=0;b<c.length;b+=1)nb(c[b])}function rl(b){var c=[].concat(b.oq);if(b.nq&&b.mq)for(b=0;b<c.length;b+=1)ob(c[b])}function tl(b){var c=[].concat(b.or);if(b.mr&&b.lr)for(b=0;b<c.length;b+=1)ob(c[b])}function ol(b,c){var d,e=[].concat(b.oq);if(b.nq&&b.mq)for(d=0;d<e.length;d+=1)$a(r,e[d],c)}
function pl(b,c){var d,e=[].concat(b.or);if(b.mr&&b.lr)for(d=0;d<e.length;d+=1)$a(r,e[d],c)}a.play=function(b,c,d,e){var g;a:{g=b.Dq();var h=[].concat(this.oq),l;for(l=0;l<h.length;l+=1)if(0<=g.indexOf(h[l])){g=!0;break a}g=!1}if(!(g=g&&this.nq&&this.mq)){a:{g=b.Dq();h=[].concat(this.or);for(l=0;l<h.length;l+=1)if(0<=g.indexOf(h[l])){g=!0;break a}g=!1}g=g&&this.mr&&this.lr}return g?r.play(b,c,d,e):void 0};a.stop=function(b,c,d){void 0!==b&&r.stop(b,c,d)};a.F=function(b){return void 0!==b?r.F(b):!1};
a.pause=function(b,c,d,e){void 0!==b&&r.pause(b,c,d,e)};a.Xi=function(b,c,d){void 0!==b&&r.Xi(b,c,d)};a.Rn=function(b){return void 0!==b?r.Rn(b):!1};a.zi=function(b,c,d,e,g){void 0!==b&&r.zi(b,c,d,e,g)};a.em=function(b,c){void 0!==b&&r.em(b,c)};var S=new ml;
O.SI={name:"Tingly Games Framework",id:"tgf",version:"3.0.0",load:{Eh:"start startImages startAudio startFonts frameworkImages frameworkAudio frameworkFonts".split(" "),required:["start","startImages","frameworkImages"],Yf:0,Oe:1},hK:!0,iK:!0,fK:!0,jK:!0,Lq:!0,gK:!0,VA:!0,Kq:!0,IM:!0,JM:!0,nI:[],oI:[]};function ul(){}a=ul.prototype;
a.q=function(b,c,d){var e=this;this.Za(O.SI);this.Za(b);this.hK&&ll.q(O.jA);this.iK&&R.q(O.FA);this.fK&&el.q(O.console);this.jK&&wk.q(O.profile);this.Lq&&jj.q(O.gP,O.status);vl(this,this.nI,this.oI);this.te=this.se=!1;this.Pn=c;this.On=d;this.Le=0;this.sv=window.setInterval(function(){ul.prototype.Ht.call(e)},50)};
a.Ht=function(){0!==this.Le||this.Lq&&!jj.se&&!jj.te||(this.Le=1,this.gK&&yk.q(O.kq),this.VA&&(kj.q(O.sg),kj.Mx()));1===this.Le&&Rj()&&(this.Le=2,this.Kq&&S.q(O.Oc),Sj(R));2===this.Le&&(this.se=!0,this.te=!1,this.Lq&&(this.se=this.se&&jj.se),this.Lq&&(this.te=this.te||jj.te),window.clearInterval(this.sv),this.se&&this.Pn&&this.Pn(),this.te&&this.On&&this.On(),this.IM&&document.addEventListener("visibilitychange",this.jE,!1),this.JM&&(R.j.onfocus=this.iE,R.j.onblur=this.hE))};
a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};function vl(b,c,d){var e=[],g=[];void 0===c&&(c=[]);void 0===d&&(d=[]);e=e.concat(b.load.Eh);e=e.concat(c);g=g.concat(b.load.required);g=g.concat(d);Oj({Eh:e,required:g,Yf:b.load.Yf,Oe:b.load.Oe})}a.jE=function(){document.hidden?(r.pause("master"),u.pause()):ak()};a.iE=function(){};a.hE=function(){};var Lj=new ul,v={};window.tgfHooks=v;
v.q=function(){v.getClientName||(v.getClientName=v.oJ);v.getClientId||(v.getClientId=v.mJ);v.getClientVersion||(v.getClientVersion=v.rJ);v.getAnalyticsTracking||(v.getAnalyticsTracking=v.kJ);v.getSiteLocks||(v.getSiteLocks=v.DA);v.getTimeLock||(v.getTimeLock=v.xJ);v.getInitialLanguage||(v.getInitialLanguage=v.sJ);v.getAvailableLanguages||(v.getAvailableLanguages=v.Ag);v.getMoreGamesUrl||(v.getMoreGamesUrl=v.Cq);v.getMoreGamesFunction||(v.getMoreGamesFunction=v.Vu);v.getSplashScreenImage||(v.getSplashScreenImage=
v.wJ);v.getSplashScreenColor||(v.getSplashScreenColor=v.uJ);v.getSplashScreenDuration||(v.getSplashScreenDuration=v.vJ);v.getClientLogo||(v.getClientLogo=v.nJ);v.getClientUrl||(v.getClientUrl=v.qJ);v.getClientFunction||(v.getClientFunction=v.lJ);v.getClientReplace||(v.getClientReplace=v.pJ);v.beforeInitializing||(v.beforeInitializing=v.jz);v.afterInitializing||(v.afterInitializing=v.Uy);v.loadingProgress||(v.loadingProgress=v.cL);v.afterLoading||(v.afterLoading=v.kF);v.beforeTitleScreen||(v.beforeTitleScreen=
v.kz);v.beforeLevelScreen||(v.beforeLevelScreen=v.HF);v.beforePlay||(v.beforePlay=v.IF);v.playStart||(v.playStart=v.sC);v.playWon||(v.playWon=v.tC);v.playLost||(v.playLost=v.pC);v.playStage||(v.playStage=v.$M);v.playEnd||(v.playEnd=v.nC);v.playRestart||(v.playRestart=v.rC);v.stepGame||(v.stepGame=v.hP);v.stepPlay||(v.stepPlay=v.iP);v.gameCompleted||(v.gameCompleted=v.xA);v.ZN()};
v.ZN=function(){O.wa=O.wa||{};v.getClientName&&(O.wa.name=v.mb("getClientName"));v.getClientId&&(O.wa.id=v.mb("getClientId"));v.getClientVersion&&(O.wa.version=v.mb("getClientVersion"));v.getAnalyticsTracking&&(O.wa.Yy=v.mb("getAnalyticsTracking"));v.getInitialLanguage&&(O.wa.sl=v.mb("getInitialLanguage"));v.getAvailableLanguages&&(O.wa.Pb=v.mb("getAvailableLanguages"));v.getMoreGamesUrl&&(O.wa.IS=v.mb("getMoreGamesUrl"));v.getMoreGamesFunction&&(O.wa.JS=v.mb("getMoreGamesFunction"));v.getSplashScreenImage&&
(O.wa.$C=v.mb("getSplashScreenImage"));v.getSplashScreenColor&&(O.wa.YC=v.mb("getSplashScreenColor"));v.getSplashScreenDuration&&(O.wa.ZC=v.mb("getSplashScreenDuration"));v.getClientLogo&&(O.wa.vS=v.mb("getClientLogo"));v.getClientUrl&&(O.wa.yS=v.mb("getClientUrl"));v.getClientFunction&&(O.wa.wS=v.mb("getClientFunction"));v.getClientReplace&&(O.wa.xS=v.mb("getClientReplace"))};v.mb=function(b,c,d,e,g){if(v[b])return v[b](c,d,e,g,void 0)};v.iC=function(){r.pause("master")};v.CC=function(){r.Xi("master")};
v.yr=function(){Wj.yr()};v.Lh=function(){wb(u);Bb(u);Db(u);Wj.Lh(!1)};v.kC=function(){Pb("play")};v.DC=function(){wb(u);Bb(u);Db(u);Rb("play")};v.Ti=function(){v.yr();v.kC();v.iC()};v.Se=function(){v.Lh();v.DC();v.CC()};v.pauseFlow||(v.pauseFlow=v.yr);v.resumeFlow||(v.resumeFlow=v.Lh);v.pauseGame||(v.pauseGame=v.kC);v.resumeGame||(v.resumeGame=v.DC);v.pauseAudio||(v.pauseAudio=v.iC);v.resumeAudio||(v.resumeAudio=v.CC);v.pauseAll||(v.pauseAll=v.Ti);v.resumeAll||(v.resumeAll=v.Se);
v.wH=function(b,c){var d=c.width,e=c.height,g;g=new ra(b+"_Texture",1,b);g.e(0,c);g=new q(b,g,1,d,e,0,0,d,e,1);g.e(0,0,0,0,d,e,0,0);return g};v.xH=function(b,c,d,e){return ta(b,c,d,e)};v.convertImage||(v.convertImage=v.wH);v.convertImageFile||(v.convertImageFile=v.xH);v.Hn=function(){return O.xa.id};v.gameId||(v.gameId=v.Hn);v.oJ=function(){return"Unknown"};v.mJ=function(){return"unknown"};v.rJ=function(){return"1.0"};v.kJ=function(){return!0};v.DA=function(){};v.xJ=function(){};v.sJ=function(){};
v.Ag=function(){};v.Cq=function(){};v.Vu=function(){};v.wJ=function(){};v.uJ=function(){};v.vJ=function(){};v.nJ=function(){};v.qJ=function(){};v.lJ=function(){};v.pJ=function(){};v.jz=function(){};v.Uy=function(){};v.cL=function(){};v.kF=function(){};v.kz=function(){};v.HF=function(){};v.IF=function(){};v.sC=function(){};v.tC=function(){};v.pC=function(){};v.$M=function(){};v.nC=function(){};v.rC=function(){};v.hP=function(){};v.iP=function(){};v.xA=function(){};var wl={};O.W={};
function V(b,c){function d(){}d.prototype=c.prototype;b.prototype=new d;b.Bb=c.prototype;b.prototype.constructor=b}function xl(){this.d=this.depth=-1E5;this.visible=!1;this.ba=!0;this.eu=this.gu=this.fu=!1;this.Va=null;this.Sv=!1;this.oo=this.no=this.fk=0;Ib(this)}function yl(){return u.Df[17]&&u.Df[18]&&u.Df[16]?!0:!1}
xl.prototype.oe=function(b){var c,d,e=0;if(yl())switch(b){case 76:b=yk.Ag();c=yk.Ee;for(d=0;d<b.length;d+=1)b[d]===c&&(e=(d+1)%b.length);yk.Oh(b[e]);break;case 79:this.fu=!this.fu;break;case 80:this.gu=!this.gu;break;case 78:this.eu=!this.eu;break;case 67:this.Va&&console.log("x: tgfScale("+Math.round(this.Va.La.Rd+this.Va.x)+"),\ny: tgfScale("+Math.round(this.Va.La.Sd+this.Va.y)+"),\n");break;case 37:this.Va&&(this.Va.La.Rd-=1,this.fk=.5,this.no=-1);break;case 39:this.Va&&(this.Va.La.Rd+=1,this.fk=
.5,this.no=1);break;case 38:this.Va&&(this.Va.La.Sd-=1,this.fk=.5,this.oo=-1);break;case 40:this.Va&&(this.Va.La.Sd+=1,this.fk=.5,this.oo=1)}};xl.prototype.xh=function(b){switch(b){case 37:this.no=0;break;case 39:this.no=0;break;case 38:this.oo=0;break;case 40:this.oo=0}};
xl.prototype.Ab=function(b){var c,d;yl()&&(this.Sv&&this.Va&&(c=u.Ec(0),d=u.sc(0),this.Va.La.Rd+=c-this.Va.La.pc,this.Va.La.Sd+=d-this.Va.La.Ma,this.Va.La.pc=c,this.Va.La.Ma=d),this.Va&&(this.fk-=b/1E3,0>=this.fk&&(this.Va.La.Rd+=this.no*b/100,this.Va.La.Sd+=this.oo*b/100)))};var zl=ba?new xl:void 0;
function Al(b){switch(b){case "nothing":return Bl;case "show":return Cl;case "hide":return Dl;case "fadeIn":return El;case "fadeOut":return Fl;case "move":return Gl;case "scale":return Hl;case "rotate":return Il;case "alpha":return Jl;case "transform":return Kl;case "blink":return Ll;default:return Bl}}function Bl(){}function Cl(b){b.alpha=1}function Dl(b){b.alpha=0}function El(b,c,d){b.alpha=(void 0===c.D?Ub:c.D)(d,0,1,c.duration,c.da)}
function Fl(b,c,d){b.alpha=(void 0===c.D?Ub:c.D)(d,1,-1,c.duration,c.da)}function Gl(b,c,d){var e=void 0===c.D?Ub:c.D,g=void 0===c.da?void 0:c.da,h=void 0===c.pc?0:c.pc,l=void 0===c.rd?0:c.rd,m=void 0===c.Ma?0:c.Ma,n=void 0===c.bb?0:c.bb;if(void 0!==c.pc||void 0!==c.rd)b.x=e(d,h,l-h,c.duration,g);if(void 0!==c.Ma||void 0!==c.bb)b.y=e(d,m,n-m,c.duration,g)}function Il(b,c,d){var e=void 0===c.Kx?0:c.Kx;b.qb=(void 0===c.D?Ub:c.D)(d,e,(void 0===c.xu?0:c.xu)-e,c.duration,void 0===c.da?void 0:c.da)}
function Hl(b,c,d){var e=void 0===c.jc?1:c.jc;b.pb=(void 0===c.D?Ub:c.D)(d,e,(void 0===c.cc?1:c.cc)-e,c.duration,void 0===c.da?void 0:c.da);b.Cb=b.pb}function Jl(b,c,d){var e=void 0===c.Te?1:c.Te;b.alpha=(void 0===c.D?Ub:c.D)(d,e,(void 0===c.vi?1:c.vi)-e,c.duration,void 0===c.da?void 0:c.da)}
function Kl(b,c,d){var e=void 0===c.D?Ub:c.D,g=void 0===c.da?void 0:c.da,h=void 0===c.pc?0:c.pc,l=void 0===c.Ma?0:c.Ma,m=void 0===c.bb?0:c.bb,n=void 0===c.ZH?e:c.ZH,s=void 0===c.$H?g:c.$H,w=void 0===c.jc?1:c.jc,y=void 0===c.cc?1:c.cc,D=void 0===c.Nj?e:c.Nj,t=void 0===c.un?g:c.un,z=void 0===c.Kx?0:c.Kx,A=void 0===c.xu?0:c.xu,B=void 0===c.aI?e:c.aI,Y=void 0===c.bI?g:c.bI,ja=void 0===c.Te?1:c.Te,Fa=void 0===c.vi?1:c.vi,e=void 0===c.ju?e:c.ju,g=void 0===c.XH?g:c.XH;b.x=n(d,h,(void 0===c.rd?0:c.rd)-h,
c.duration,s);b.y=n(d,l,m-l,c.duration,s);b.pb=D(d,w,y-w,c.duration,t);b.Cb=b.pb;b.qb=B(d,z,A-z,c.duration,Y);b.alpha=e(d,ja,Fa-ja,c.duration,g)}function Ll(b,c,d){var e=void 0===c.zi?0:c.zi;c=1/(2*(void 0===c.frequency?1:c.frequency));var g=d%c;b.alpha=0===Math.floor(d/c)%2?Math.min(1,g/e):1-Math.min(1,g/e)}O.W.ii={ib:[],x:0,y:0,width:0,height:0,pb:1,Cb:1,qb:0,alpha:1,ra:null,jC:!1,UN:99999999,eI:2,VB:null,Td:null,Mg:null,ag:null};function W(b){this.q();void 0!==b&&this.i(b)}a=W.prototype;
a.q=function(b){this.i(O.W.ii);this.i(b);this.parent=null;this.kind="component";this.F=this.nb=this.Uf=!1;this.t=[];zl&&(this.La={Rd:0,Sd:0,pc:0,Ma:0})};a.i=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
a.Xd=function(b,c){var d,e,g=this.qb*Math.PI/180;null!==this.parent?(d=this.parent.Xd(b,c),e=this.parent.Yd(b,c)):(d=b,e=c);zl&&(d-=this.La.Rd,e-=this.La.Sd);d-=this.x;0!==this.qb&&(d=d*Math.cos(g)-e*Math.sin(g));0!==this.pb&&1!==this.pb&&(d/=this.pb);return d};
a.Yd=function(b,c){var d,e,g=this.qb*Math.PI/180;null!==this.parent?(d=this.parent.Xd(b,c),e=this.parent.Yd(b,c)):(d=b,e=c);zl&&(d-=this.La.Rd,e-=this.La.Sd);e-=this.y;0!==this.qb&&(e=d*Math.sin(g)+e*Math.cos(g));0!==this.Cb&&1!==this.Cb&&(e/=this.Cb);return e};
a.ug=function(b,c){var d,e,g=this.qb*Math.PI/180;d=b*(0===this.pb?1:this.pb);e=c*(0===this.Cb?1:this.Cb);0!==this.qb&&(d=d*Math.cos(g)-e*Math.sin(g),e=d*Math.sin(g)+e*Math.cos(g));zl&&(d-=this.La.Rd,e-=this.La.Sd);return null!==this.parent?this.parent.ug(d+this.x,e+this.y):d+this.x};
a.vg=function(b,c){var d,e,g=this.qb*Math.PI/180;d=b*(0===this.pb?1:this.pb);e=c*(0===this.Cb?1:this.Cb);0!==this.qb&&(d=d*Math.cos(g)-e*Math.sin(g),e=d*Math.sin(g)+e*Math.cos(g));zl&&(d-=this.La.Rd,e-=this.La.Sd);return null!==this.parent?this.parent.vg(d+this.x,e+this.y):e+this.y};a.bq=function(b,c){return new k(this.ug(b,c),this.vg(b,c))};a.Ec=function(b){return this.Xd(u.Ec(b),u.sc(b))};a.sc=function(b){return this.Yd(u.Ec(b),u.sc(b))};a.ec=function(){return void 0===this.width?0:this.width};
a.dc=function(){return void 0===this.height?0:this.height};a.Bq=function(){return-this.ec()/2};a.Eq=function(){return-this.dc()/2};a.Dq=function(){return this.ib.slice(0)};a.g=function(b){b.parent=this;this.t.push(b)};a.ic=function(){this.t=[]};function X(b,c){var d;b.xg=0;if("[object Array]"===Object.prototype.toString.call(b.ra))for(void 0===c&&(c=0),0>c&&(c=0),c>=b.ra.length&&(c=b.ra.length-1),d=0;d<c;d+=1)b.xg+=Ml(b,b.ra[d],!1)}
function Ml(b,c,d){var e,g,h=0;void 0===d&&(d=!0);if(null===c||"[object Array]"===Object.prototype.toString.call(c)&&0===c.length)return 0;if("[object Array]"!==Object.prototype.toString.call(c))return c.duration;for(e=0;e<c.length;e+=1)g=Ml(b,c[e],!d),h=d?h+g:Math.max(h,g);return h}function Nl(b,c){null===b.ra||"[object Array]"===Object.prototype.toString.call(b.ra)&&0===b.ra.length||0>=b.wn||(0<b.lu?b.lu-=1:b.xg+=c/1E3,b.xg>=b.fA&&(b.Td&&b.Td(b),b.wn-=1,0>=b.wn||(b.xg-=b.fA,b.VB&&b.VB(b))))}
function Ol(b,c,d,e,g){var h,l,m;if(null!==c&&("[object Array]"!==Object.prototype.toString.call(c)||0!==c.length))if("[object Array]"!==Object.prototype.toString.call(c))d<c.duration&&g.push({k:c,time:d});else if(e)for(h=l=0;h<c.length;h+=1){m=Ml(b,c[h],!e);if(l+m>d){Ol(b,c[h],d-l,!e,g);break}l+=m}else for(h=0;h<c.length;h+=1)Ol(b,c[h],d,!e,g)}a.Po=function(b){void 0===b&&(b=!0);if(!(this.Uf||this.iw&&this.iw(this))&&(this.Uf=!0,this.K&&this.K(),b))for(b=0;b<this.t.length;b+=1)this.t[b].Po()};
a.gf=function(b){void 0===b&&(b=!0);if(this.Uf&&(!this.aw||!this.aw(this))){this.nb&&this.w();this.Uf=!1;if(b)for(b=0;b<this.t.length;b+=1)this.t[b].gf();this.oa&&this.oa()}};
a.show=function(b){void 0===b&&(b=!0);if(!this.nb&&(this.Uf||this.Po(),!this.vr||!this.vr())&&(this.nb=!0,null===this.ra||"[object Array]"===Object.prototype.toString.call(this.ra)&&0===this.ra.length||(this.fA=Ml(this,this.ra,!0),this.xg=0,this.lu=this.eI,this.wn=this.UN,this.vn=[]),this.Wa&&this.Wa(),b))for(b=0;b<this.t.length;b+=1)this.t[b].show()};a.w=function(b){void 0===b&&(b=!0);if(this.nb&&(this.F&&this.Ca(),!this.ub||!this.ub(this))&&(this.nb=!1,b))for(b=0;b<this.t.length;b+=1)this.t[b].w()};
a.Db=function(b){void 0===b&&(b=!0);if(!(this.F||this.wo&&this.wo(this))&&(this.nb||this.show(),this.F=!0,b))for(this.Mf&&this.Mf(),b=0;b<this.t.length;b+=1)this.t[b].Db()};a.Ca=function(b){void 0===b&&(b=!0);if(this.F&&(!this.Yv||!this.Yv(this))&&(this.F=!1,b))for(b=0;b<this.t.length;b+=1)this.t[b].Ca()};a.ne=function(b){var c;if(this.F&&this.nb){this.jC&&Nl(this,b);this.oM&&this.oM(this,b);if(this.Hd&&this.Hd(b))return!0;for(c=0;c<this.t.length;c+=1)if(this.t[c].ne(b))return!0}};
a.Ld=function(b,c,d){var e;if(this.F&&this.nb){for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Ld(b,c,d))return!0;if(e=zl){var g,h,l,m,n;yl()?(e=this.Xd(c,d),g=this.Yd(c,d),m=this.ec(),n=this.dc(),h=this.Bq(),l=this.Eq(),m&&n&&e>h&&e<h+m&&g>l&&g<l+n?(this.La.pc=c,this.La.Ma=d,zl.Va=this,e=zl.Sv=!0):e=!1):e=void 0}if(e)return!0;e=this.Xd(c,d);c=this.Yd(c,d);this.Ri&&this.Ri(this,b,e,c);if(this.Id&&this.Id(b,e,c))return!0}};
a.Tf=function(b,c,d){var e;if(this.F&&this.nb){for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Tf(b,c,d))return!0;zl&&(zl.Sv=!1);e=this.Xd(c,d);c=this.Yd(c,d);this.xM&&this.xM(this,b,e,c);if(this.He&&this.He(b,e,c))return!0}};a.Sf=function(b,c,d){var e;if(this.F&&this.nb){for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Sf(b,c,d))return!0;e=this.Xd(c,d);c=this.Yd(c,d);this.vM&&this.vM(this,b,e,c);if(this.Hj&&this.Hj(b,e,c))return!0}};
a.Uj=function(b,c,d){var e;if(this.F&&this.nb){for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Uj(b,c,d))return!0;e=this.Xd(c,d);c=this.Yd(c,d);this.rM&&this.rM(this,b,e,c);if(this.qi&&this.qi(b,e,c))return!0}};a.Cg=function(b,c,d){var e;if(this.F&&this.nb){for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Cg(b,c,d))return!0;e=this.Xd(c,d);c=this.Yd(c,d);this.sM&&this.sM(this,b,e,c);if(this.ri&&this.ri(b,e,c))return!0}};
a.oe=function(b){var c;if(this.F&&this.nb){this.tM&&this.tM(this,b);if(this.si&&this.si(b))return!0;for(c=0;c<this.t.length;c+=1)if(this.t[c].oe(b))return!0}};a.xh=function(b){var c;if(this.F&&this.nb){this.uM&&this.uM(this,b);if(this.ph&&this.ph(b))return!0;for(c=0;c<this.t.length;c+=1)if(this.t[c].xh(b))return!0}};a.Tj=function(b){var c;if(this.F&&this.nb)for(this.nM&&this.nM(this,b),c=0;c<this.t.length;c+=1)if(this.t[c].Tj(b))return!0};
a.Dg=function(b,c){var d;if(this.F&&this.nb){this.wM&&this.wM(this,b,c);if(this.wg&&this.wg(b,c))return!0;for(d=0;d<this.t.length;d+=1)if(this.t[d].Dg(b,c))return!0}};a.Ab=function(b){var c;if(this.F&&this.nb){this.qM&&this.qM(this,b);if(this.qd&&this.qd(b))return!0;for(c=0;c<this.t.length;c+=1)if(this.t[c].Ab(b))return!0}};
function Pl(b,c){var d;if(b.nb){b.jC||Nl(b,c);d=[];var e,g,h,l;if(null!==b.ra&&!("[object Array]"===Object.prototype.toString.call(b.ra)&&0===b.ra.length||0>=b.wn)){Ol(b,b.ra,b.xg,!0,d);for(h=0;h<b.vn.length;h+=1){e=b.vn[h];l=!1;for(g=0;g<d.length;g+=1)if(d[g].k===e.k){l=!0;break}l||("function"===typeof e.k.k?e.k.k(b,e.k,e.k.duration):Al(e.k.k)(b,e.k,e.k.duration),b.ag&&b.ag(b,e.k))}for(h=0;h<d.length;h+=1){e=d[h];l=!1;for(g=0;g<b.vn.length;g+=1)if(b.vn[g].k===e.k){l=!0;break}l||(b.Mg&&b.Mg(b,e.k),
"function"===typeof e.k.k?e.k.k(b,e.k,0):Al(e.k.k)(b,e.k,0))}for(g=0;g<d.length;g+=1)e=d[g],"function"===typeof e.k.k?e.k.k(b,e.k,e.time):Al(e.k.k)(b,e.k,e.time);b.vn=d}b.yM&&b.yM(b,c);if(b.cf&&b.cf(c))return!0;for(d=0;d<b.t.length;d+=1)if(Pl(b.t[d],c))return!0}}
a.Uc=function(){var b;if(this.nb&&!(1E-6>Math.abs(this.pb)||1E-6>Math.abs(this.Cb))){p.context.save();zl&&p.context.translate(this.La.Rd,this.La.Sd);p.context.translate(this.x,this.y);1===this.pb&&1===this.Cb||p.context.scale(this.pb,this.Cb);0!==this.qb&&p.context.rotate(-this.qb*Math.PI/180);p.context.globalAlpha*=this.alpha;this.Zv&&this.Zv(this);if(this.Ic&&this.Ic())return p.context.restore(),!0;for(b=0;b<this.t.length;b+=1)if(this.t[b].Uc())return p.context.restore(),!0;this.pM&&this.pM(this);
if(this.Nf&&this.Nf())return p.context.restore(),!0;if(zl){var c,d,e,g,h,l;zl.fu&&(e=this.ec(),g=this.dc(),c=this.Bq(),d=this.Eq(),b=zl.Va===this?"red":"blue",e&&g&&(oa(c,d,e,g,void 0,"white",3),oa(c,d,e,g,void 0,b,1)));zl.eu&&(c=void 0===this.name?"undefined":this.name,l="bold 12px Arial",b=zl.Va===this?"red":"blue",g=p.Fk(c,l)+4,h=16,d=this.Bq(),e=this.Eq(),oa(d,e,g,h,"rgba(255, 255, 255, 0.8)"),p.le(c,d+2,e+h-4,b,l));zl.gu&&(c="X: "+Math.round(this.La.Rd+this.x)+" Y: "+Math.round(this.La.Sd+this.y),
l="bold 12px Arial",g=p.Fk(c,l)+4,h=16,d=-Math.round(g/2),e=-Math.round(h/2),oa(d,e,g,h,"rgba(255, 255, 255, 0.8)"),p.le(c,d+2,e+h-4,"black",l))}p.context.restore()}};O.W.Qx={h:[]};function Ql(b){this.name="Template";this.q(O.W.Qx);void 0!==b&&this.i(b)}V(Ql,W);a=Ql.prototype;a.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};a.Hd=function(){};a.Id=function(){};a.He=function(){};a.Hj=function(){};a.qi=function(){};
a.ri=function(){};a.si=function(){};a.ph=function(){};a.wg=function(){};a.qd=function(){};a.cf=function(){};a.Ic=function(){};a.Nf=function(){};O.W.hO={cm:!0,Kr:!0,$a:0,Ga:0,az:0,bz:0,clip:!0,xO:!1,HO:!1,tc:!0,FC:null,UJ:null,iQ:null,Yi:600,h:[]};function Rl(b){this.name="ScrollBox";this.q(O.W.hO);void 0!==b&&this.i(b);this.Xc=new k(0,0);this.Zi=new k(0,0);this.bm=new k(0,0);this.zy=[];this.scroll=new k(0,0);this.fs=new k(0,0);this.$p=new k(0,0)}V(Rl,W);a=Rl.prototype;
a.K=function(){var b;Math.round(this.width/2);Math.round(this.height/2);this.scroll.x=0;this.scroll.y=0;this.Zh=new k(0,0);this.es=new k(0,0);this.speed=new k(0,0);this.HO&&this.Kr&&(this.kc=new Sl,this.kc.i(this.FC),this.kc.i(this.iQ),this.kc.x=(this.width-this.kc.ec())/2,this.kc.y=0,this.kc.height=this.height,this.g(this.kc),this.kc.ec());this.xO&&this.cm&&(this.fc=new Sl({direction:Tl}),this.fc.i(this.FC),this.fc.i(this.UJ),this.fc.x=0,this.fc.y=(this.height-this.fc.dc())/2,this.fc.width=this.width,
this.g(this.fc),this.fc.dc());this.kc&&this.fc&&(this.kc.height-=this.fc.dc(),this.kc.y-=this.fc.dc()/2,this.fc.width-=this.kc.ec(),this.fc.x-=this.kc.ec()/2);this.ua=-1;this.J=new wa(this.width-(this.kc?this.kc.ec():0),this.height-(this.fc?this.fc.dc():0));this.j=new W({x:this.scroll.x,y:this.scroll.y});this.J.context.translate(Math.round(this.width/2),Math.round(this.height/2));this.g(this.j);this.$p.x=-Math.round(this.width-this.J.width)/2;this.$p.y=-Math.round(this.height-this.J.height)/2;if(this.h)for(b=
0;b<this.h.length;b+=1)this.j.g(this.h[b]);this.kD&&(this.Kr?(b=-(Math.max(this.Ga,this.J.height)-this.J.height),this.scroll.y=this.kD*b):this.cm&&(b=-(Math.max(this.$a,this.J.width)-this.J.width),this.scroll.x=this.kD*b))};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};function Ul(b){return b.JI?b.JI:-(Math.max(b.$a,b.J.width)-b.J.width)}function Vl(b){return b.KI?b.KI:-(Math.max(b.Ga,b.J.height)-b.J.height)}a.Hd=function(){};
a.Id=function(b,c,d){var e=Math.round(this.width),g=Math.round(this.height);if(c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&(this.ua=b,c=this.Ec(this.ua),d=this.sc(this.ua),this.Xc.x=0,this.Xc.y=0,this.Zh.x=c,this.Zh.y=d,this.fs.x=this.scroll.x,this.fs.y=this.scroll.y,this.tc))return!0};
a.Hj=function(b,c,d){var e=Math.round(this.width),g=Math.round(this.height);c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&(this.Kr?(this.scroll.y+=100*b,b=this.En?this.En:0,c=Vl(this),this.scroll.y>b&&(this.scroll.y=0),this.scroll.y<c&&(this.scroll.y=c)):this.cm&&(this.scroll.x+=100*b,b=this.Dn?this.Dn:0,c=Ul(this),this.scroll.x>b&&(this.scroll.x=0),this.scroll.x<c&&(this.scroll.x=c)))};a.He=function(b){this.ua===b&&(this.ua=-1,Wl(this),Xl(this))};
function Wl(b){var c=b.Dn?b.Dn:0,d=Ul(b);b.scroll.x>c&&(b.Xc.x=b.Yi,b.Zi.x=b.scroll.x,b.bm.x=c);b.scroll.x<d&&(b.Xc.x=b.Yi,b.Zi.x=b.scroll.x,b.bm.x=d)}function Xl(b){var c=b.En?b.En:0,d=Vl(b);b.scroll.y>c&&(b.Xc.y=b.Yi,b.Zi.y=b.scroll.y,b.bm.y=c);b.scroll.y<d&&(b.Xc.y=b.Yi,b.Zi.y=b.scroll.y,b.bm.y=d)}a.si=function(){};a.ph=function(){};a.wg=function(){};
a.qd=function(b){var c,d,e,g,h,l=Math.max(this.Ga,this.J.height),m=Math.max(this.$a,this.J.width);g=Ul(this);e=Vl(this);d=this.Dn?this.Dn:0;h=this.En?this.En:0;if(-1!==this.ua)this.cm&&(c=this.Ec(this.ua),this.es.x=c,c=this.fs.x+this.es.x-this.Zh.x,this.speed.x=(this.speed.x+(c-this.scroll.x)/(b/1E3))/2,this.scroll.x=c,this.scroll.x>d&&(this.scroll.x=d+Math.min(this.J.width/2,Wb(c-d,0,this.J.width/2,this.J.width))/2),this.scroll.x<g&&(this.scroll.x=g+Math.max(-this.J.width/2,Wb(c-g,0,-this.J.width/
2,-this.J.width))/2)),this.Kr&&(d=this.sc(this.ua),this.es.y=d,d=this.fs.y+this.es.y-this.Zh.y,this.speed.y=(this.speed.y+(d-this.scroll.y)/(b/1E3))/2,this.scroll.y=d,this.scroll.y>h&&(this.scroll.y=h+Math.min(this.J.height/2,Wb(d-h,0,this.J.height/2,this.J.height))/2),this.scroll.y<e&&(this.scroll.y=e+Math.max(-this.J.height/2,Wb(d-e,0,-this.J.height/2,-this.J.height))/2));else{if(0<this.Xc.x)this.Xc.x-=b,this.Xc.x=Math.max(0,this.Xc.x),this.scroll.x=dc(this.Yi-this.Xc.x,this.Zi.x,this.bm.x-this.Zi.x,
this.Yi),this.speed.x=0;else if(0<Math.abs(this.speed.x))if(this.speed.x*=Math.pow(.99,b),1<Math.abs(this.speed.x)){if(this.scroll.x+=b/1E3*this.speed.x,0<this.scroll.x||this.scroll.x<g)this.speed.x=0,Wl(this)}else this.speed.x=0;if(0<this.Xc.y)this.Xc.y-=b,this.Xc.y=Math.max(0,this.Xc.y),this.scroll.y=dc(this.Yi-this.Xc.y,this.Zi.y,this.bm.y-this.Zi.y,this.Yi),this.speed.y=0;else if(0<Math.abs(this.speed.y))if(this.speed.y*=Math.pow(.99,b),1<Math.abs(this.speed.y)){if(this.scroll.y+=b/1E3*this.speed.y,
0<this.scroll.y||this.scroll.y<e)this.speed.y=0,Xl(this)}else this.speed.y=0}this.kc&&(this.kc.rk=l-this.J.height,this.kc.qk=Math.min(-e,Math.max(0,-this.scroll.y)),void 0!==this.kc.nm&&(this.scroll.y=-this.kc.nm));this.fc&&(this.fc.rk=m-this.J.width,this.fc.qk=Math.min(-g,Math.max(0,-this.scroll.x)),void 0!==this.fc.nm&&(this.scroll.x=-this.fc.nm));this.j.x=this.scroll.x+this.$p.x;this.j.y=this.scroll.y+this.$p.y};a.g=function(b){Rl.Bb.g.call(this,b);b!==this.j&&this.zy.push(b)};a.cf=function(){};
a.Ic=function(){var b=Math.round(this.width/2),c=Math.round(this.height/2);xa(this.J);this.J.context.clearRect(-b,-c,this.J.width,this.J.height);this.j.Uc();ya(this.J);this.J.ma(-this.width/2,-this.height/2);this.Iy=this.t;this.t=this.zy};a.Nf=function(){this.t=this.Iy};O.W.EK={width:P(400),height:P(400),Ip:"top",Kz:P(90),dl:P(8),Om:!0,Pm:!0,h:[]};function Yl(b){this.name="LayoutVertical";this.q(O.W.EK);void 0!==b&&this.i(b)}V(Yl,W);
Yl.prototype.Bv=function(){var b,c,d,e,g,h;c=[].concat(this.Pm);d=[].concat(this.Om);e=[].concat(this.Kz);for(b=g=0;b<this.h.length;b+=1)h=e[b%e.length],c[b%c.length]&&(this.h[b].width=this.width),d[b%d.length]&&(this.h[b].height=h),g+=h;g+=(this.h.length-1)*this.dl;c=this.dl;switch(this.Ip){case "top":d=-this.height/2;break;case "middle":d=-g/2;break;case "bottom":d=this.height/2-g;break;case "spread":d=-this.height/2;c+=(this.height-g)/(this.h.length-1);break;default:d=-this.height/2}for(b=0;b<
this.h.length;b+=1)h=e[b%e.length],this.h[b].y=Math.round(d+h/2),d+=h+c};Yl.prototype.K=function(){var b;this.Bv();for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};O.W.DK={width:P(400),height:P(400),Ip:"center",dH:P(90),dl:P(8),Om:!0,Pm:!0,h:[]};function Zl(b){this.name="LayoutHorizontal";this.q(O.W.DK);void 0!==b&&this.i(b)}V(Zl,W);
Zl.prototype.Bv=function(){var b,c,d,e,g,h;c=[].concat(this.Pm);d=[].concat(this.Om);e=[].concat(this.dH);for(b=g=0;b<this.h.length;b+=1)h=e[b%e.length],c[b%c.length]&&(this.h[b].width=h),d[b%d.length]&&(this.h[b].height=this.height),g+=h;g+=(this.h.length-1)*this.dl;c=this.dl;switch(this.Ip){case "left":d=-this.width/2;break;case "center":d=-g/2;break;case "right":d=this.width/2-g;break;case "spread":d=-this.width/2;c+=(this.width-g)/(this.h.length-1);break;default:d=-this.width/2}for(b=0;b<this.h.length;b+=
1)h=e[b%e.length],this.h[b].x=Math.round(d+h/2),d+=h+c};Zl.prototype.K=function(){var b;this.Bv();for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};O.W.jb={pq:!0,interval:1,repeat:99999999,h:[],Qi:null};function $l(b){this.name="Timer";this.q(O.W.jb);void 0!==b&&this.i(b)}V($l,W);a=$l.prototype;a.ec=function(){return P(32)};a.dc=function(){return P(32)};a.reset=function(){this.oc=0};a.K=function(){var b;this.reset();for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};
a.Hd=function(b){var c;this.pq&&(c=Math.floor(this.oc/this.interval),this.oc+=b/1E3,b=Math.floor(this.oc/this.interval),c!==b&&b<=this.repeat&&this.Qi&&this.Qi(this))};O.W.j={h:[]};function am(b){this.name="Container";this.q(O.W.j);void 0!==b&&this.i(b)}V(am,W);am.prototype.ec=function(){return P(32)};am.prototype.dc=function(){return P(32)};am.prototype.K=function(){var b;for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};
O.W.label={text:"",s:"",font:L,align:void 0,xb:void 0,dd:!0,Bc:!1,Ea:P(20),Wb:!0,h:[],m:null};function U(b){this.name="Label";this.q(O.W.label);void 0!==b&&this.i(b)}V(U,W);a=U.prototype;a.ec=function(){return this.Cc.width-2*this.Ea};a.dc=function(){return this.Cc.height-2*this.Ea};a.Bq=function(){var b;switch(this.font.align){case "left":return 0;case "right":return-this.Cc.width+2*this.Ea;default:return b=-this.Cc.width/2+this.Ea,this.Wb?Math.floor(b):b}};
a.Eq=function(){var b;switch(this.font.xb){case "top":return 0;case "bottom":return-this.Cc.height+2*this.Ea+Math.round(this.font.Lg*this.font.fontSize);default:return b=-this.Cc.height/2+this.Ea+Math.round(this.font.Lg*this.font.fontSize)/2,this.Wb?Math.floor(b):b}};a.Wd=function(){this.ln()};a.findText=function(){return""!==this.s?xk(this.s,"<"+this.s+">"):void 0===this.text?"<UNDEFINED>":this.text};
a.ln=function(){var b,c,d,e,g,h,l,m,n=this.findText();this.font instanceof Ca?g=this.font:(g=new Ca,g.i(this.font));d=0<this.width?this.width:g.Fk(n);e=0<this.height?this.height:g.wf(n);h=g.align;void 0!==this.align&&Ja(g,this.align);l=g.xb;void 0!==this.xb&&Ka(g,this.xb);switch(g.align){case "left":b=this.Ea;break;case "center":b=this.Ea+d/2;break;case "right":b=this.Ea+d}switch(g.xb){case "top":c=this.Ea;break;case "middle":c=this.Ea+e/2;break;case "bottom":c=this.Ea+e}this.Wb&&(b=Math.floor(b),
c=Math.floor(c));this.Cc=new wa(d+2*this.Ea,e+2*this.Ea);xa(this.Cc);d=g.fontSize;this.dd&&0<this.width&&(m=this.height,0>=m&&(m=e),e=Ra(g,n,this.width,m,this.Bc),e<d&&Da(g,e));this.Bc&&0<this.width?g.ma(n,b,c,this.width):g.ma(n,b,c);Da(g,d);void 0!==this.align&&Ja(g,h);void 0!==this.xb&&Ka(g,l);ya(this.Cc)};a.K=function(){var b;this.ln();for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.Cc=void 0};
a.Id=function(b,c,d){var e,g,h;if(null!==this.m){b=-this.Cc.width/2;e=-this.Cc.height/2;this.Wb&&(b=Math.floor(b),e=Math.floor(e));switch(this.font.align){case "left":b=-this.Ea;break;case "right":b=-this.Cc.width+this.Ea}switch(this.font.xb){case "top":e=-this.Ea;break;case "bottom":e=-this.Cc.height+this.Ea}g=this.Cc.width-2*this.Ea;h=this.Cc.height-2*this.Ea;c>=b&&c<=b+g&&d>=e&&d<=e+h&&this.m(this)}};a.wg=function(b){"languageSet"===b&&this.ln()};
a.Ic=function(){var b=-this.Cc.width/2,c=-this.Cc.height/2;this.Wb&&(b=Math.floor(b),c=Math.floor(c));switch(this.font.align){case "left":b=-this.Ea;break;case "right":b=-this.Cc.width+this.Ea}switch(this.font.xb){case "top":c=-this.Ea;break;case "bottom":c=-this.Cc.height+this.Ea}this.Cc.ma(b,c)};O.W.MM={c:wc,rb:0,fm:0,Ig:!0,Wo:!0,lh:!1,Tb:!1,xd:null,Wb:!0,gr:!0,h:[],m:null};function Z(b){this.name="Picture";this.q(O.W.MM);void 0!==b&&this.i(b)}V(Z,W);a=Z.prototype;
a.ec=function(){return 0<this.width?this.width:this.c?this.lh?this.c.ni:this.c.width:0};a.dc=function(){return 0<this.height?this.height:this.c?this.lh?this.c.mi:this.c.height:0};a.K=function(){var b;for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.Wa=function(){this.Da=this.fm;this.Ed=!0};
a.Id=function(b,c,d){var e;this.m&&null!==this.c&&(this.lh&&this.c instanceof q?(b=0<this.width?this.width:this.c.ni,e=0<this.height?this.height:this.c.mi):(b=0<this.width?this.width:this.c.width,e=0<this.height?this.height:this.c.height),c>=-b/2&&c<=b&&d>=-e/2&&d<=e/2&&this.m(this))};
a.cf=function(b){null!==this.c&&this.c instanceof q&&this.Ed&&(this.Da+=this.rb*b/1E3,0<this.rb&&this.Da>=this.c.Y?(this.Ig?this.Da-=this.c.Y:(this.Da=this.c.Y-1,this.Ed=!1),this.xd&&this.xd(this)):0>this.rb&&0>this.Da&&(this.Ig?this.Da+=this.c.Y:(this.Da=0,this.Ed=!1),this.xd&&this.xd(this)))};
a.Ic=function(){var b,c,d,e,g,h;null!==this.c&&(this.c instanceof wa?(c=0<this.width?this.width:this.c.width,d=0<this.height?this.height:this.c.height,e=-c/2,g=-d/2,this.Wb&&(e=Math.floor(e),g=Math.floor(g)),this.Tb?this.c.Jc(e,g,c,d,p.context.alpha,Math.floor(this.c.width/2)-2,Math.floor(this.c.width/2)-2,Math.floor(this.c.height/2)-2,Math.floor(this.c.height/2)-2):c===this.c.width&&d===this.c.height?this.c.ma(e+this.c.Qa,g+this.c.Sa):(this.gr&&(h=this.c.width/this.c.height,c/d<h?(g+=(d-c/h)/2,d=
c/h):(e+=(c-d*h)/2,c=d*h)),this.c.Of(e,g,c,d,p.context.alpha))):this.c instanceof q&&(c=0<this.width?this.width:this.c.width,d=0<this.height?this.height:this.c.height,e=-c/2,g=-d/2,this.Wb&&(e=Math.floor(e),g=Math.floor(g)),b=this.Wo?this.Da:Math.min(this.c.Y-1,Math.floor(this.Da)),this.Tb?this.c.Jc(b,e,g,c,d,p.context.alpha,Math.floor(this.c.width/2)-2,Math.floor(this.c.width/2)-2,Math.floor(this.c.height/2)-2,Math.floor(this.c.height/2)-2):this.lh?(c=0<this.width?this.width:this.c.ni,d=0<this.height?
this.height:this.c.mi,e=-c/2,g=-d/2,this.Wb&&(e=Math.floor(e),g=Math.floor(g)),c===this.c.ni&&d===this.c.mi?ua(this.c,e+this.c.Qa,g+this.c.Sa):(this.gr&&(h=this.c.ni/this.c.mi,c/d<h?(g+=(d-c/h)/2,d=c/h):(e+=(c-d*h)/2,c=d*h)),b=this.c,h=p.context.alpha,0!==b.ni&&0!==b.mi&&(c/=b.ni,d/=b.mi,va(b,e+b.Qa*c,g+b.Sa*d,c,d,h)))):c===this.c.width&&d===this.c.height?this.c.ma(b,e+this.c.Qa,g+this.c.Sa):(this.gr&&(h=this.c.width/this.c.height,c/d<h?(g+=(d-c/h)/2,d=c/h):(e+=(c-d*h)/2,c=d*h)),this.c.Of(b,e,g,c,
d,p.context.alpha))))};O.W.mN={za:Ac,YJ:null,Eg:Bc,Je:"slice",qI:"right",tI:0,uI:0,sI:0,rI:0,rb:0,fm:0,Ig:!0,Wo:!0,qN:0,Zl:null,rN:100,Wb:!0,h:[],bw:null,WB:null,xd:null};function bm(b){this.name="ProgressBar";this.q(O.W.mN);void 0!==b&&this.i(b)}V(bm,W);a=bm.prototype;a.ec=function(){return this.width?this.width:this.za&&this.za.width?this.za.width:0};a.dc=function(){return this.height?this.height:this.za&&this.za.height?this.za.height:0};a.zd=function(b,c){this.Kb=b;c&&(this.Gd=this.Kb)};
a.K=function(){var b;for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.Wa=function(){this.Da=this.fm;this.zd(this.qN,!0)};
a.cf=function(b){var c,d,e;this.Zl&&(this.Kb=this.Zl());c=this.Gd;d=this.Kb-this.Gd;e=this.rN*b/1E3;this.Gd=Math.abs(d)<=e?this.Kb:0>d?this.Gd-e:this.Gd+e;this.Gd=Math.min(100,Math.max(0,this.Gd));100>c&&100<=this.Gd&&this.bw?this.bw(this):0<c&&0>=this.Gd&&this.WB&&this.WB(this);null!==this.za&&this.za instanceof q&&(b=this.Da+this.rb*b/1E3,this.Da<this.za.Y&&b>=this.za.Y?(this.Da=this.Ig?b-this.za.Y:this.za.Y,this.xd&&this.xd(this)):0<this.Da&&0>b?(this.Da=this.Ig?this.za.Y+b:0,this.xd&&this.xd(this)):
this.Da=b)};
a.drawImage=function(b,c,d,e,g,h){var l;if(null!==b)if(b instanceof wa)switch(h){case "slice":b.Jc(c,d,e,g,p.context.alpha,Math.floor(b.width/2)-2,Math.floor(b.width/2)-2,Math.floor(b.height/2)-2,Math.floor(b.height/2)-2);break;case "stretch":b.Of(c,d,e,g,p.context.alpha);break;case "tile":b.Lj(b.Qa,b.Sa,c,d,e,g,p.context.alpha)}else if(b instanceof q)switch(l=this.Wo?this.Da:Math.min(b.Y-1,Math.floor(this.Da)),h){case "slice":b.Jc(l,c,d,e,g,p.context.alpha,Math.floor(b.width/2)-2,Math.floor(b.width/2)-
2,Math.floor(b.height/2)-2,Math.floor(b.height/2)-2);break;case "stretch":b.Of(l,c,d,e,g,p.context.alpha);break;case "tile":b.Lj(l,b.Qa,b.Sa,c,d,e,g,p.context.alpha)}};
a.Ic=function(){var b=0<this.width?this.width:this.za.width,c=0<this.height?this.height:this.za.height,d=-b/2,e=-c/2,g,h,l,m;this.Wb&&(d=Math.floor(d),e=Math.floor(e));g=d+this.tI;h=e+this.uI;l=b+this.sI;m=c+this.rI;this.drawImage(this.za,d,e,b,c,"slice");switch(this.qI){case "right":l*=this.Gd/100;break;case "left":g+=l*(1-this.Gd/100);l*=this.Gd/100;break;case "down":m*=this.Gd/100;break;case "up":h+=m*(1-this.Gd/100),m*=this.Gd/100}this.drawImage(this.Eg,g,h,l,m,this.Je);this.drawImage(this.YJ,
d,e,b,c,"slice")};O.W.pi={width:void 0,height:void 0,iq:"#000000",on:.6,duration:.2,eP:!0,h:[],UB:null,dw:null};function cm(b){this.name="Darkener";this.q(O.W.pi);void 0!==b&&this.i(b)}V(cm,W);a=cm.prototype;a.ec=function(){return this.width?this.width:p.width};a.dc=function(){return this.height?this.height:p.height};function dm(b,c,d){void 0===c&&(c=b.duration);void 0===d&&(d=0);b.mode="lighting";b.Te=b.on;b.Wu=0;b.Yt=c;b.oi=c+d}a.K=function(){var b;this.mode="idle";for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};
a.Wa=function(){if(this.eP){var b,c;void 0===b&&(b=this.duration);void 0===c&&(c=0);this.mode="darkening";this.Te=0;this.Wu=this.on;this.Yt=b;this.oi=b+c}};a.cf=function(b){"idle"===this.mode||0>=this.oi||(this.oi-=b/1E3,0>=this.oi&&("darkening"===this.mode&&null!==this.UB&&this.UB(this),"lighting"===this.mode&&null!==this.dw&&this.dw(this)))};
a.Ic=function(){var b=0,c,d=this.ec(),e=this.dc();p.canvas===R.A&&"idle"!==this.mode&&(b=this.oi>=this.Yt?this.Te:0>=this.oi?this.Wu:this.Te+(1-this.oi/this.Yt)*(this.Wu-this.Te),0!==b&&(c=p.context.globalAlpha,p.context.globalAlpha*=b,oa(-d/2,-e/2,d,e,this.iq),p.context.globalAlpha=c))};
O.W.button={c:F,Tb:!0,marginLeft:P(24),marginRight:P(24),marginTop:P(24),marginBottom:P(24),icon:null,Ja:"left",pe:P(24),text:"",s:"",Sj:null,ya:M,Bc:!1,uo:0,vo:0,to:0,qf:0,dp:Oi,ep:null,kb:0,Yh:!1,cb:0,eb:0,Zd:null,Rm:!1,Vi:!1,tc:!0,mg:!1,Wb:!0,h:[],m:null,oF:1E4};function $(b){this.name="Button";this.q(O.W.button);this.Zh=new k(0,0);void 0!==b&&this.i(b)}V($,W);a=$.prototype;a.ec=function(){return this.Ka.width};a.dc=function(){return this.Ka.height};a.Wd=function(){this.De()};
a.findText=function(){var b=this.text,c=this.s;"[object Array]"===Object.prototype.toString.call(this.text)&&(b=this.text[this.kb%this.text.length]);"[object Array]"===Object.prototype.toString.call(this.s)&&(c=this.s[this.kb%this.s.length]);""!==c&&(b=xk(c,"<"+c+">"));return b};
a.rn=function(b,c){var d="up"===c?0:1,e=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(e=this.c[this.kb%this.c.length]);if(e)if(e instanceof wa)if(this.Tb){var g=this.ZL||0,h=this.$L||0;e.Jc(0,0,b.width,b.height,1,Math.floor(e.width/2)-2+g,Math.floor(e.width/2)-2-g,Math.floor(e.height/2)-2+h,Math.floor(e.height/2)-2-h)}else b.width===e.width&&b.height===e.height?e.ma(e.Qa,e.Sa):e.Of(0,0,b.width,b.height,1);else e instanceof q&&(this.Tb?(g=this.ZL||0,h=this.$L||0,e.Jc(d,
0,0,b.width,b.height,1,Math.floor(e.width/2)-2+g,Math.floor(e.width/2)-2-g,Math.floor(e.height/2)-2+h,Math.floor(e.height/2)-2-h)):b.width===e.width&&b.height===e.height?e.ma(d,e.Qa,e.Sa):e.Of(d,0,0,b.width,b.height,1))};
a.sn=function(b,c){var d="up"===c?0:1,e,g,h=this.icon;this.icon&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(h=this.icon[this.kb%this.icon.length]);if(h){switch(this.Ja){case "left":e=this.marginLeft;g=(b.height-h.height)/2;break;case "center":e=(b.width-h.width)/2;g=(b.height-h.height)/2;break;case "right":e=b.width-h.width-this.marginRight;g=(b.height-h.height)/2;break;case "top":e=(b.width-h.width)/2;g=this.marginTop;break;case "bottom":e=(b.width-h.width)/2,g=b.width-h.width-
this.marginBottom}this.Wb&&(e=Math.floor(e),g=Math.floor(g));"down"===c?(e+=this.to,g+=this.qf):(e+=this.uo,g+=this.vo);h instanceof wa?h.ma(e+h.Qa,g+h.Sa):h instanceof q&&h.ma(d,e+h.Qa,g+h.Sa)}};
a.le=function(b,c){var d,e,g,h,l,m,n=this.findText();(l=this.icon)&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(l=this.icon[this.kb%this.icon.length]);d="down"===c?null!==this.Sj?this.Sj:this.ya:null!==this.ya?this.ya:this.Sj;d instanceof Ca?m=d:(m=new Ca,m.i(d));d=this.marginLeft;e=this.marginTop;g=b.width-this.marginLeft-this.marginRight;h=b.height-this.marginTop-this.marginBottom;if(l)switch(this.Ja){case "left":d+=l.width+this.pe;g-=l.width+this.pe;break;case "right":g-=l.width+
this.pe;break;case "top":e+=l.height+this.pe;h-=l.height+this.pe;break;case "bottom":h-=l.height+this.pe}switch(m.align){case "center":d+=g/2;break;case "right":d+=g}switch(m.xb){case "middle":e+=h/2;break;case "bottom":e+=h}this.Wb&&(d=Math.floor(d),e=Math.floor(e));"down"===c?(d+=this.to,e+=this.qf):(d+=this.uo,e+=this.vo);l=m.fontSize;h=Ra(m,n,g,h,this.Bc);h<l&&Da(m,h);this.Bc?m.ma(n,d,e,g):m.ma(n,d,e);Da(m,l)};
a.De=function(){var b=this.width,c=this.height,d=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(d=this.c[this.cb%this.c.length]);d&&0===b&&(b=d.width);d&&0===c&&(c=d.height);this.Ka=new wa(b,c);xa(this.Ka);this.rn(this.Ka,"down");this.sn(this.Ka,"down");this.le(this.Ka,"down");ya(this.Ka);this.ae=new wa(b,c);xa(this.ae);this.rn(this.ae,"up");this.sn(this.ae,"up");this.le(this.ae,"up");ya(this.ae)};
a.ac=function(b,c){this.state!==b&&("down"===b?(this.state="down",c&&(this.dp&&S.play(this.dp),this.Vi&&(this.Yh&&1<this.cb&&(this.kb=(this.kb+1)%this.cb,this.De()),this.m&&this.m(this)))):(this.state="up",c&&(this.ep&&S.play(this.ep),this.Vi||(this.Yh&&1<this.cb&&(this.kb=(this.kb+1)%this.cb,this.De()),this.m&&this.m(this)))))};
a.K=function(){var b;0>=this.cb&&(this.cb=1,"[object Array]"===Object.prototype.toString.call(this.c)&&(this.cb=Math.max(this.cb,this.c.length)),"[object Array]"===Object.prototype.toString.call(this.icon)&&(this.cb=Math.max(this.cb,this.icon.length)),"[object Array]"===Object.prototype.toString.call(this.text)&&(this.cb=Math.max(this.cb,this.text.length)),"[object Array]"===Object.prototype.toString.call(this.s)&&(this.cb=Math.max(this.cb,this.s.length)));this.De();this.ac("up",!1);this.ua=-1;for(b=
0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.ae=this.Ka=void 0};a.Id=function(b,c,d){if(!this.mg)return this.Ij(b,c,d)};a.He=function(b,c,d){if(!this.mg)return this.Jj(b,c,d)};a.qi=function(b,c,d){if(this.mg)return this.Ij(b,c,d)};a.ri=function(b,c,d){if(this.mg)return this.Jj(b,c,d)};a.Ij=function(b,c,d){var e=this.Ka.width+2*this.eb,g=this.Ka.height+2*this.eb;if(c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&("up"===this.state&&(this.ac("down",!0),this.ua=b,this.Zh=this.bq(c,d)),this.tc))return!0};
a.Jj=function(b,c,d){var e=this.Ka.width+2*this.eb,g=this.Ka.height+2*this.eb;if(this.ua===b&&(this.ua=-1,c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&("down"===this.state&&this.ac("up",!0),this.tc)))return!0};a.si=function(b){if(this.Rm||this.Zd&&b===this.Zd)if(this.ac("down",!0),this.tc)return!0};a.ph=function(b){if(this.Rm||this.Zd&&b===this.Zd)if(this.ac("up",!0),this.tc)return!0};
a.qd=function(){var b,c,d=this.Ka.width+2*this.eb,e=this.Ka.height+2*this.eb;-1!==this.ua&&(b=this.Ec(this.ua),c=this.sc(this.ua),this.bq(b,c).bu(this.Zh)>=this.oF?("down"===this.state&&this.ac("up",!1),this.ua=-1):b>=-d/2&&b<=d/2&&c>=-e/2&&c<=e/2?this.ac("down",!1):this.ac("up",!1))};a.wg=function(b){"languageSet"===b&&this.De()};a.Ic=function(){var b=-this.Ka.width/2,c=-this.Ka.height/2;this.Wb&&(b=Math.floor(b),c=Math.floor(c));"down"===this.state?this.Ka.ma(b,c):this.ae.ma(b,c)};
O.W.JO={za:Cc,Pd:Dc,icon:null,mv:void 0,Ja:"left",direction:"horizontal",minValue:0,maxValue:100,kK:50,aO:!1,nx:!1,ID:"left",Lk:P(48),Jk:P(48),Bf:L,td:P(8),eb:P(8),tc:!0,Wb:!0,h:[],Il:null,Jl:null};function em(b){this.name="Slider";this.q(O.W.JO);void 0!==b&&this.i(b)}V(em,W);a=em.prototype;a.ec=function(){return this.width?this.width:this.za&&this.za.width?this.za.width:0};a.dc=function(){return this.height?this.height:this.za&&this.za.height?this.za.height:0};a.Wd=function(){this.ln()};
a.tk=function(b,c){b=Math.max(this.minValue,Math.min(this.maxValue,b));this.aO&&(b=Math.round(b));if(b!==this.value){this.value=b;!c&&this.Il&&this.Il(this,this.value);var d=0,e=0,g=0===this.width?this.za.width:this.width,h=0===this.height?this.za.height:this.height;"vertical"===this.direction?(this.icon&&("bottom"===this.Ja?(this.qe=Math.round(e+h/2-this.icon.height/2),this.mf=0,h-=this.icon.height+this.td,e-=Math.round((this.icon.height+this.td)/2)):(this.qe=Math.round(e-h/2+this.icon.height/2),
this.mf=0,h-=this.icon.height+this.td,e+=Math.round((this.icon.height+this.td)/2))),this.nx&&("bottom"===this.ID?(this.md=Math.round(e+h/2-this.Jk/2),this.We=0,h-=this.Jk+this.td,e-=Math.round((this.Jk+this.td)/2)):(this.md=Math.round(e-h/2+this.Jk/2),h-=this.Jk+this.td,e+=Math.round((this.Jk+this.td)/2))),this.Rr=Math.round(e-h/2),this.Qr=Math.round(e+h/2),this.xk=Math.round(this.Qr-(this.Qr-this.Rr)*(this.value-this.minValue)/(this.maxValue-this.minValue)),this.wk=0):(this.icon&&("right"===this.Ja?
(this.mf=Math.round(d+g/2-this.icon.width/2),this.qe=0,g-=this.icon.width+this.td,d-=Math.round((this.icon.width+this.td)/2)):(this.mf=Math.round(d-g/2+this.icon.width/2),this.qe=0,g-=this.icon.width+this.td,d+=Math.round((this.icon.width+this.td)/2))),this.nx&&("right"===this.ID?(this.We=Math.round(d+g/2-this.Lk/2),this.md=0,g-=this.Lk+this.td,d-=Math.round((this.Lk+this.td)/2)):(this.We=Math.round(d-g/2+this.Lk/2),this.md=0,g-=this.Lk+this.td,d+=Math.round((this.Lk+this.td)/2))),this.cp=Math.round(d-
g/2),this.ux=Math.round(d+g/2),this.wk=Math.round(this.cp+(this.ux-this.cp)*(this.value-this.minValue)/(this.maxValue-this.minValue)),this.xk=0);a:if(e=0,g=100*(this.value-this.minValue)/(this.maxValue-this.minValue),void 0===this.mv)1===this.icon.Y?this.Wj=0:2===this.icon.Y?this.Wj=this.value===this.minValue?0:1:(this.Wj=1+Math.floor(g/100*(this.icon.Y-2)),this.value===this.minValue&&(this.Wj=0),this.value===this.maxValue&&(this.Wj=this.icon.Y-1));else{for(d=0;d<this.mv.length;d+=1)if(e+=this.mv[d],
g<=e){this.Wj=d;break a}this.Wj=this.icon.Y-1}this.Wd()}};a.Gb=function(){return this.value};
a.ln=function(){var b=0===this.width?this.za.width:this.width,c=0===this.height?this.za.height:this.height,b=Math.max(b,this.Pd.width)+4,c=Math.max(c,this.Pd.height)+4;this.J=new wa(b,c);xa(this.J);var d=this.J.context,b=Math.round(b/2),c=Math.round(c/2),e;if("vertical"===this.direction){e=this.za;var g=c+this.Rr,h=c+this.xk,l=c+this.Qr,m=b+Math.round(-this.za.width/2),n=Math.floor(e.width/2),s=Math.floor(e.height/2);e instanceof wa?e.Jc(m,g,e.width,l-g,1,n-2,n-2,s-2,s-2):1===e.Y?e.Jc(0,m,g,e.width,
l-g,1,n-2,n-2,s-2,s-2):(d.save(),e.Jc(0,m,g,e.width,l-g,1,n-2,n-2,s-2,s-2),d.rect(0,h,d.canvas.width,l-h),d.clip(),e.Jc(1,m,g,e.width,l-g,1,n-2,n-2,s-2,s-2),d.restore())}else e=this.za,g=b+this.cp,h=b+this.wk,l=b+this.ux,m=c+Math.round(-this.za.height/2),n=Math.floor(e.width/2),s=Math.floor(e.height/2),e instanceof wa?e.Jc(g,m,l-g,e.height,1,n-2,n-2,s-2,s-2):1===e.Y?e.Jc(0,g,m,l-g,e.height,1,n-2,n-2,s-2,s-2):(d.save(),e.Jc(0,g,m,l-g,e.height,1,n-2,n-2,s-2,s-2),d.rect(h,0,l-h,d.canvas.height),d.clip(),
e.Jc(1,g,m,l-g,e.height,1,n-2,n-2,s-2,s-2),d.restore());d=b+Math.round(-this.Pd.width/2)+this.Pd.Qa;e=c+Math.round(-this.Pd.height/2)+this.Pd.Sa;this.Pd instanceof wa?this.Pd.ma(this.wk+d,this.xk+e):this.Pd.ma(0,this.wk+d,this.xk+e);this.icon&&(d=b+Math.round(-this.icon.width/2)+this.icon.Qa,e=c+Math.round(-this.icon.height/2)+this.icon.Sa,this.icon instanceof wa?this.icon.ma(this.mf+d,this.qe+e):this.icon.ma(this.Wj,this.mf+d,this.qe+e));this.nx&&(d=Math.round(this.value).toString(),this.Bf instanceof
Ca?e=this.Bf.cl():(e=new Ca,e.i(this.Bf)),e.YQ="middle",e.align="center",e.size=Ra(e,d,this.Lk,this.Jk),e.ma(d,b+this.We,c+this.md));ya(this.J)};a.K=function(){var b;this.value=void 0;this.tk(this.kK,!0);this.ua=-1;for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.J=void 0};
a.Id=function(b,c,d){var e=this.Pd.width/2,g=this.Pd.height/2;this.eb&&(e+=this.eb,g+=this.eb);if(c>=this.wk-e&&c<=this.wk+e&&d>=this.xk-g&&d<=this.xk+g&&(this.ua=b,this.HP=c-this.wk,this.IP=d-this.xk,this.tc)||this.icon&&this.Jl&&(b=this.icon.width/2,e=this.icon.height/2,this.eb&&(b+=this.eb,e+=this.eb),c>=this.mf-b&&c<=this.mf+b&&d>=this.qe-e&&d<=this.qe+e&&(this.Jl(this),this.tc)))return!0};a.He=function(b){this.ua===b&&(this.ua=-1)};
a.qd=function(){var b,c;-1!==this.ua&&(b=this.Ec(this.ua)-this.HP,c=this.sc(this.ua)-this.IP,b="vertical"===this.direction?this.maxValue-(this.maxValue-this.minValue)*(c-this.Rr)/(this.Qr-this.Rr):this.minValue+(this.maxValue-this.minValue)*(b-this.cp)/(this.ux-this.cp),this.tk(b))};a.Ic=function(){this.Wb?this.J.ma(Math.round(-this.J.width/2),Math.round(-this.J.height/2)):this.J.ma(-this.J.width/2,-this.J.height/2)};var Tl=1;
O.W.gO={za:Ac,Mn:Bc,direction:0,width:void 0,height:P(200),marginLeft:0,marginRight:0,marginTop:0,marginBottom:0};function Sl(b){this.name="ScrollBar";this.q(O.W.gO);void 0!==b&&this.i(b);this.qk=0;this.rk=this.height;this.mm=-1;this.nm=void 0}V(Sl,W);a=Sl.prototype;
a.drawImage=function(b,c,d,e,g,h){if(null!==b)if(b instanceof wa)switch(h){case "slice":b.Jc(c,d,e,g,p.context.alpha,Math.floor(b.width/2)-2,Math.floor(b.width/2)-2,Math.floor(b.height/2)-2,Math.floor(b.height/2)-2);break;case "stretch":b.Of(c,d,e,g,p.context.alpha);break;case "tile":b.Lj(b.Qa,b.Sa,c,d,e,g,p.context.alpha)}else if(b instanceof q)switch(h){case "slice":b.Jc(0,c,d,e,g,p.context.alpha,Math.floor(b.width/2)-2,Math.floor(b.width/2)-2,Math.floor(b.height/2)-2,Math.floor(b.height/2)-2);
break;case "stretch":b.Of(0,c,d,e,g,p.context.alpha);break;case "tile":b.Lj(0,b.Qa,b.Sa,c,d,e,g,p.context.alpha)}};a.Ld=function(b,c,d){var e=this.Xd(c,d);c=this.Yd(c,d);d=this.ec();var g=this.dc();return e>-d/2+this.marginLeft&&e<d/2-this.marginRight&&c>-g/2+this.marginTop&&c<g/2-this.marginBottom?(this.mm=b,fm(this,e,c),!0):!1};a.Tf=function(b){return this.mm===b?(this.mm=-1,this.nm=void 0,!0):!1};
a.Ab=function(){if(-1!==this.mm){var b=u.Ec(this.mm),c=u.sc(this.mm);fm(this,this.Xd(b,c),this.Yd(b,c))}};
function fm(b,c,d){var e=b.ec()-b.marginLeft-b.marginRight,g=b.dc()-b.marginTop-b.marginBottom;c-=b.marginLeft;var h=d-b.marginTop,l;0===b.direction?(d=g,l=Math.ceil(b.Mn.height/3*2)):(d=e,l=Math.ceil(b.Mn.width/3*2));l=Math.min(d,Math.max(l,d/b.rk*d));isNaN(l)&&(l=d);e=0===b.direction?h+g/2:c+e/2;isNaN(e)&&(e=0);b.qk=Math.min(b.rk,Math.max(0,(e-l/2)/(d-l)*b.rk));isNaN(b.qk)&&(b.qk=0);b.nm=b.qk}a.ec=function(){return 0<this.width?this.width:this.za.width+this.marginLeft+this.marginRight};
a.dc=function(){return 0<this.height?this.height:this.za.height+this.marginTop+this.marginBottom};
a.Ic=function(){var b=0<this.width?this.width-this.marginLeft-this.marginRight:this.za.width,c=0<this.height?this.height-this.marginTop-this.marginBottom:this.za.height,d=-(b+this.marginLeft+this.marginRight)/2,e=-(c+this.marginTop+this.marginBottom)/2,d=d+this.marginLeft,e=e+this.marginTop;this.Wb&&(d=Math.floor(d),e=Math.floor(e));var g=d,h=e,l=b,m=c,n,s;0===this.direction?(n=c,s=Math.ceil(this.Mn.height/3*2)):(n=b,s=Math.ceil(this.Mn.width/3*2));s=Math.min(n,Math.max(s,n/this.rk*n));isNaN(s)&&
(s=n);n=this.qk/this.rk*(n-s);isNaN(n)&&(n=0);this.drawImage(this.za,d,e,b,c,"slice");switch(this.direction){case 0:h+=n;m=s;break;case Tl:g+=n,l=s}this.drawImage(this.Mn,g,h,l,m,"slice")};var Dj={};O.I={};function gm(b,c){function d(){}d.prototype=c.prototype;b.prototype=new d;b.Bb=c.prototype;b.prototype.constructor=b}O.I.ii={canvas:null,d:-1E3,depth:0,x:0,y:0,width:0,height:0,Re:!0};function hm(b){this.q();void 0!==b&&this.i(b)}a=hm.prototype;
a.q=function(b){this.i(O.I.ii);this.i(b);this.parent=null;this.kind="dialog";this.t=[];this.F=this.nb=this.Uf=!1;null===this.canvas&&(this.canvas=R.A)};a.i=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};a.Xd=function(b,c){return null!==this.parent?this.parent.Xd(b,c)-this.x:b-this.x};a.Yd=function(b,c){return null!==this.parent?this.parent.Yd(b,c)-this.y:c-this.y};a.ug=function(b,c){return null!==this.parent?this.parent.ug(b+this.x,c+this.y):b+this.x};
a.vg=function(b,c){return null!==this.parent?this.parent.vg(b+this.x,c+this.y):c+this.y};a.bq=function(b,c){return new k(this.ug(b,c),this.vg(b,c))};a.Ec=function(b){return this.Xd(u.Ec(b),u.sc(b))};a.sc=function(b){return this.Yd(u.Ec(b),u.sc(b))};a.g=function(b){b.parent=this;this.t.push(b)};a.ic=function(){this.t=[]};a.Po=function(b){void 0===b&&(b=!0);if(!(this.Uf||this.iw&&this.iw(this))&&(this.Uf=!0,this.K&&this.K(),b))for(b=0;b<this.t.length;b+=1)this.t[b].Po()};
a.gf=function(b){void 0===b&&(b=!0);if(this.Uf&&(!this.aw||!this.aw(this))){this.nb&&this.w();this.Uf=!1;if(b)for(b=0;b<this.t.length;b+=1)this.t[b].gf();this.oa&&this.oa()}};a.show=function(b){void 0===b&&(b=!0);null===this.canvas&&(this.canvas=R.A);if(!this.nb&&(this.Uf||this.Po(),!this.vr||!this.vr())){this.nb=!0;this.Db();if(b)for(b=0;b<this.t.length;b+=1)this.t[b].show();this.Wa&&this.Wa();this.ba=this.visible=!0;Ib(this)}};
a.w=function(b){void 0===b&&(b=!0);if(this.nb&&(!this.ub||!this.ub(this))){this.Ca();this.nb=!1;if(b)for(b=0;b<this.t.length;b+=1)this.t[b].w();this.ba=this.visible=!1;Sb(this)}};a.Db=function(b){void 0===b&&(b=!0);if(!(this.F||this.wo&&this.wo(this))){this.F=!0;if(b)for(b=0;b<this.t.length;b+=1)this.t[b].Db();this.Mf&&this.Mf()}};a.Ca=function(b){void 0===b&&(b=!0);if(this.F&&(!this.Yv||!this.Yv(this))&&(this.F=!1,b))for(b=0;b<this.t.length;b+=1)this.t[b].Ca()};a.me=function(){};a.kf=function(){};
a.ne=function(b){var c;if(this.F)for(c=0;c<this.t.length;c+=1)if(this.t[c].ne(b))return this.Re};a.Ld=function(b,c,d){var e;if(this.F)for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Ld(b,c,d))return this.Re};a.Tf=function(b,c,d){var e;if(this.F)for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Tf(b,c,d))return this.Re};a.Sf=function(b,c,d){var e;if(this.F)for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Sf(b,c,d))return this.Re};
a.Uj=function(b,c,d){var e;if(this.F)for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Uj(b,c,d))return this.Re};a.Cg=function(b,c,d){var e;if(this.F)for(e=this.t.length-1;0<=e;e-=1)if(this.t[e].Cg(b,c,d))return this.Re};a.oe=function(b){var c;if(this.F)for(c=0;c<this.t.length;c+=1)if(this.t[c].oe(b))return this.Re};a.xh=function(b){var c;if(this.F)for(c=0;c<this.t.length;c+=1)if(this.t[c].xh(b))return this.Re};a.Tj=function(b){var c;if(this.F)for(c=0;c<this.t.length;c+=1)if(this.t[c].Tj(b))return this.Re};
a.Dg=function(b,c){var d;if(this.F)for(d=0;d<this.t.length;d+=1)if(this.t[d].Dg(b,c))return this.Re};a.Ab=function(b){var c,d=!1;if(this.F)for(c=0;c<this.t.length;c+=1)if(this.t[c].Ab(b)){d=this.Re;break}if(this.nb)for(c=0;c<this.t.length;c+=1)if(Pl(this.t[c],b)){d=this.Re;break}return d};a.Uc=function(){var b,c=!1;if(this.nb){p.context.save();p.context.translate(this.x,this.y);for(b=0;b<this.t.length;b+=1)if(this.t[b].Uc()){c=this.Re;break}p.context.restore();return c}};O.I.Qx={h:[]};
function im(b){this.name="Template";this.q(O.I.Qx);void 0!==b&&this.i(b)}gm(im,hm);im.prototype.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};im.prototype.oa=function(){this.ic()};im.prototype.Wa=function(){};O.I.j={h:[],Tt:null};function jm(b){this.name="Container";this.q(O.I.j);void 0!==b&&this.i(b)}gm(jm,hm);jm.prototype.K=function(){var b;this.j=new am({});this.j.i(this.Tt);this.g(this.j);for(b=0;b<this.h.length;b+=1)this.j.g(this.h[b])};
jm.prototype.oa=function(){this.ic();this.j=void 0};O.I.iN={x:void 0,y:void 0,backgroundImage:null,hb:!1,sb:{k:Cl,duration:0},Ua:{k:Dl,duration:0},oc:99999,pd:!1,h:[],bc:null,wb:null};function km(b){this.name="PopUp";this.q(O.I.iN);void 0!==b&&this.i(b)}gm(km,hm);km.prototype.na=function(){this.Ca();X(this.j,2)};km.prototype.Ta=function(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.g(c);return c};
km.prototype.K=function(){var b,c=this,d;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);this.hb&&(d=this.Ta(this,cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.Ta(this,Z,{c:this.backgroundImage,Tb:!0,width:0===this.width&&this.backgroundImage?this.backgroundImage.width:this.width,height:0===this.height&&this.backgroundImage?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:this.oc},this.Ua],Mg:function(b,g){g===c.Ua&&c.hb&&dm(d,d.duration,
c.j.ra[2].duration-d.duration)},Td:function(){c.w()}},this.wb);this.pd&&(this.j.Ri=function(){lm.prototype.na.call(c)});for(b=0;b<this.h.length;b+=1)this.j.g(this.h[b])};km.prototype.oa=function(){this.ic();this.j=void 0};
O.I.an={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:10,Hb:0,Fd:90,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),Kt:"close",ji:!1,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!1,ge:F,ih:M,kh:null,buttons:[],hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};
function lm(b){this.name="ButtonBox";this.q(O.I.an);void 0!==b&&this.i(b)}gm(lm,hm);a=lm.prototype;a.na=function(){this.Ca();X(this.j,2)};a.Ta=function(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.g(c);return c};
a.Xe=function(b,c,d,e,g,h){var l=this;return this.Ta(b,$,{x:e,y:g,width:void 0===c.IO?h:0,height:0,c:void 0===c.c?this.ge:c.c,text:void 0===c.text?"":c.text,s:void 0===c.key?"":c.key,icon:c.icon,Ja:"left",font:void 0===c.font?this.ih:c.font,Qb:void 0===c.id?d:c.id,zj:void 0===c.w?this.jh:c.w,tc:!0,m:function(b){b.zj&&lm.prototype.na.call(l);l.m&&l.m(l,b.Qb)}},this.kh,c.Jw)};
a.K=function(){var b=this,c,d,e,g=[],h=[],l=[];c=[];var m,n,s,w,y,D;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);m=0===this.width?this.backgroundImage.width:this.width;n=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);h[0]=Math.round(-n/2+this.marginTop);c[0]=Math.round(this.rc*(n-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);h[1]=Math.round(h[0]+c[0]);c[1]=Math.round(this.Hb*(n-this.marginTop-this.marginBottom)/100);this.Ia&&(l[2]=this.Ia.width,g[2]=g[1]+l[1]-l[2],h[2]=h[1],c[2]=c[1],l[1]-=l[2]+P(32),"left"===this.Ja&&(g[2]=g[1],g[1]+=l[2]+P(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Pc&&(g[3]=Math.round(-this.Pc/2),l[3]=this.Pc);h[3]=Math.round(h[1]+c[1]);c[3]=Math.round(this.Fd*(n-this.marginTop-this.marginBottom)/100);this.hb&&
(D=this.Ta(this,cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.Ta(this,Z,{c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:this.oc},this.Ua],Mg:function(c,d){d===b.Ua&&b.hb&&dm(D,D.duration,b.j.ra[2].duration-D.duration)},Td:function(){b.w()}},this.wb);this.pd&&(this.j.Ri=function(){b.ab&&b.ab(b);lm.prototype.na.call(b)});this.rc&&this.Ta(this.j,U,{x:Math.round(g[0]+
l[0]/2),y:Math.round(h[0]+c[0]/2),width:l[0],height:c[0],text:this.Zc,s:this.Dc,font:this.Mb,dd:!0,Bc:!1,Ea:P(20)},this.Mc);this.Hb&&this.Ta(this.j,U,{x:Math.round(g[1]+l[1]/2),y:Math.round(h[1]+c[1]/2),width:l[1],height:c[1],text:this.Qd,s:this.vd,font:this.Wc,dd:!0,Bc:!0,Ea:P(20)},this.wd);this.Hb&&this.Ia&&this.Ta(this.j,Z,{c:this.Ia,x:Math.round(g[2]+l[2]/2),y:Math.round(h[2]+c[2]/2)},this.Lc);this.Ub&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.lc/2),n=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.Qc/2),this.Ta(this.j,$,{x:m,y:n,width:this.lc,height:this.Qc,c:uc,Qb:this.Kt,m:function(c){b.ab&&b.ab(b);b.m&&b.m(b,c.Qb);lm.prototype.na.call(b)}},this.je));if(this.Fd){m=this.ji?[this.buttons]:this.buttons;d=this.ge.height;n=d+this.od;h=Math.round(h[3]+d/2);switch(this.ki){case "top":break;case "bottom":h+=c[3]-m.length*n-this.od;break;default:h+=Math.round((c[3]-m.length*n-this.od)/2)}for(c=e=0;c<m.length;c+=1)if("[object Array]"===Object.prototype.toString.call(m[c]))for(y=
Math.round((l[3]-this.Lf*(m[c].length-1))/m[c].length),w=y+this.Lf,s=Math.round(g[3]+y/2),d=0;d<m[c].length;d+=1)this.Xe(this.j,m[c][d],e,s+d*w,h+c*n,y),e+=1;else this.Xe(this.j,m[c],e,Math.round(g[3]+l[3]/2),h+c*n,l[3]),e+=1}for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){this.ic();this.j=void 0};
O.I.yL={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:25,Hb:75,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:4,pd:!0,h:[],ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};function mm(b){this.name="MessageBox";this.q(O.I.yL);void 0!==b&&this.i(b)}gm(mm,lm);
O.I.Kw={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:15,Hb:55,Fd:30,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),ji:!0,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!0,ge:F,ih:M,kh:null,buttons:[],hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};
function kl(b){this.name="QuestionBox";this.q(O.I.Kw);void 0!==b&&this.i(b)}gm(kl,lm);O.W.OO={NO:void 0,yk:void 0,rF:"animation",Rc:-1,repeat:!1,Hh:null,play:!0,FJ:!0,h:[]};function nm(b){this.name="SpineComponent";this.q(O.W.OO);void 0!==b&&this.i(b)}V(nm,W);function om(b,c,d){om(b.yk,c,b.repeat);b.yk.nO(function(){d&&d()})}function pm(b){om(b.yk,b.rF,b.repeat);b.yk.nO(function(){b.Hh&&b.Hh()})}a=nm.prototype;
a.K=function(){var b;this.play&&0<this.Rc&&(this.Rc=-1);this.yk=this.NO.cl();pm(this);if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};a.Hd=function(b){!this.FJ||0<this.Rc?this.Rc-=b:this.play=!0};a.Id=function(){};a.He=function(){};a.Hj=function(){};a.qi=function(){};a.ri=function(){};a.si=function(){};a.ph=function(){};a.wg=function(){};a.qd=function(b){this.play&&this.yk.lg(b)};a.cf=function(){};
a.Ic=function(){this.play&&this.yk.ma(this.x,this.y)};a.Nf=function(){};
O.jF={ok:"none",$b:void 0,viewport:void 0,sw:0,pl:!0,Ln:!1,ww:!1,ky:!1,Rx:!0,LA:!1,Xt:-1,nc:!1,CL:"none",fi:P(-1),Or:-1,fv:!1,aF:!1,Qy:!0,bF:"ca-app-pub-9362790118294805/1178913377",eF:"ca-app-pub-9362790118294805/3214049773",dF:"ca-app-pub-9362790118294805/5050709772",gF:"ca-app-pub-9362790118294805/3573976572",cF:"ca-app-pub-9362790118294805/9480909379",fF:"ca-app-pub-9362790118294805/8004176173",ct:{},Xn:"",Yn:"",MG:"565eaaadf789823be08c4b1d",OG:"5f1ed7c97da30349b3797ed3b09ec383dae8d43c",NG:"565eafbaa8b63c592bcd1c50",
PG:"4e1d6b0510d750f9a2c294a240da48b3856c64db",WC:"8420994579",hF:"http://googleads.g.doubleclick.net/pagead/ads",gn:"ca-games-pub-7949653012476008",description:"http://www.tinglygames.com/html5-games",KA:!1,JJ:!0,rA:void 0,$s:void 0,zJ:"//imasdk.googleapis.com/js/sdkloader/ima3.js",ax:!1,jJ:!0,ud:void 0,Yu:void 0,PQ:void 0,Rf:-1,Ae:-1,kN:{gi:{ey:!0,ox:!0,text:!0,qA:!0,c:!0},Mv:12E4,bM:15E3},Qn:{gi:{ey:!0,ox:!0,text:!0,qA:!0,c:!0},Mv:12E4,bM:15E3},gN:0,fN:0,hN:"//game-cdn.poki.com/scripts/1.0.0/poki-ads.min.js",
bx:!1,HC:!1,oT:void 0,xw:void 0,oQ:17726,pQ:0,qQ:"http://js.tokenads.com/woobi-min.js",GU:"http://js.tokenads.com/vidget.css",gS:"//ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js",IC:!1,FU:void 0,Ml:null};function qm(){}a=qm.prototype;a.q=function(b){this.Za(O.jF);this.Za(b);if(!this.nc)if("[object Array]"===Object.prototype.toString.call(this.ok))for(b=0;b<this.ok.length;b++)rm(this,this.ok[b]);else rm(this,this.ok);sm(this)};
a.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};function sm(b){b.Or=6E4*b.fi;Wj.fi=b.Or}
function tm(b){var c;c=b.KA?b.kN:b.Qn;var d,e=[];d=""+b.hF;d+="?ad_type=";f.Ib.Nq&&f.Ba.ve||(c.gi.ox&&c.gi.ey?e.push("video"):c.gi.ox?e.push("skippablevideo"):c.gi.ey&&e.push("standardvideo"));c.gi.c&&e.push("image");c.gi.text&&e.push("text");c.gi.qA&&e.push("flash");for(var g=0;g<e.length;++g)d+=e[g],g<e.length-1&&(d+="_");d+="&client="+b.gn;b.WC&&(d+="&slotname="+b.WC);d=d+"&videoad_start_delay=0"+("&description_url="+encodeURIComponent(b.description));b.rA&&(d+="&hl="+b.rA);c.Mv&&(d+="&max_ad_duration="+
c.Mv);b.Rx&&(d+="&adtest=on");return d}
function rm(b,c){var d=document.getElementsByTagName("script")[0],e=document.createElement("script");e.type="text/javascript";e.async=!0;switch(c){case "google":e.src=b.zJ;break;case "poki":e.src=b.hN;break;case "woobi":e.src=b.qQ}void 0!==typeof e.addEventListener&&(e.addEventListener("load",function(){switch(c){case "google":b.ax=!0;break;case "poki":b.bx=!0;break;case "woobi":b.IC=!0}b.Rx&&console.log(c+" SDK LOADED")},!1),e.addEventListener("error",function(){b.fv=!0;console.log("ERRor")},!1));
d.parentNode.insertBefore(e,d)}function um(b,c,d,e,g,h){b.ks=!1;b.Ln=!1;b.ww=!1;b.ky=!1;b.sw=0;switch(c){case "google":b.ax&&vm(b,d,e,g,h);break;case "poki":b.bx&&wm(b,d,e,g,h);break;case "woobi":b.IC&&xm(b)}}function ym(){var b=Mj;!b.ks&&b.ax?(b.$s.initialize(),b.ks=!0):!b.ks&&b.bx&&b.HC&&(POKI_ADS.requestAd({position:poki.ads.position.preroll}),b.ks=!0)}
function zm(){var b=Mj;b.ct=/(android)/i.test(navigator.userAgent)?{gt:b.bF,Qn:b.eF}:/(ipod|iphone|ipad)/i.test(navigator.userAgent)?{gt:b.dF,Qn:b.gF}:{gt:b.cF,Qn:b.fF};/(ipad|iphone|ipod|android|windows phone)/i.test(navigator.userAgent)&&(document.addEventListener("deviceready",function(){AdMob?b.aF?AdMob&&AdMob.qR({HQ:b.ct.gt,eS:!0,LQ:"SMART_BANNER",position:AdMob.yQ.AQ,xF:!0}):b.Qy&&AdMob&&AdMob.sT({IQ:b.ct.Qn,xF:!1}):alert("admob plugin not ready")},!1),document.addEventListener("onAdFailLoad",
function(b){alert("error: "+b.error+", reason: "+b.reason+", adNetwork:"+b.KQ+", adType:"+b.MQ+", adEvent:"+b.GQ)}))}function Am(){var b=Mj;if(navigator.userAgent.match(/Android/i))b.Xn=b.MG,b.Yn=b.OG;else if(navigator.userAgent.match(/iPhone/i)||navigator.userAgent.match(/iPad/i))b.Xn=b.NG,b.Yn=b.PG;console.log("Made chartboost container "+b.Xn+"   "+b.Yn);document.addEventListener("deviceready",function(){Bm(b)},!1)}
function Bm(b){console.log("Init ids "+b.Xn+"   "+b.Yn);window.he.UT(b.Xn,b.Yn);window.he.RS=function(b){console.log("onInterstitialAdPreloaded: "+b)};window.he.QS=function(b){console.log("onInterstitialAdLoaded: "+b)};window.he.SS=function(b){console.log("onInterstitialAdShown: "+b)};window.he.PS=function(b){console.log("onInterstitialAdHidden: "+b)};window.he.WS=function(b){console.log("onMoreAppsAdPreloaded: "+b)};window.he.VS=function(b){console.log("onMoreAppsAdLoaded: "+b)};window.he.XS=function(b){console.log("onMoreAppsAdShown: "+
b)};window.he.US=function(b){console.log("onMoreAppsAdHidden: "+b)};window.he.cT=function(b){console.log("onRewardedVideoAdPreloaded: "+b)};window.he.bT=function(b){console.log("onRewardedVideoAdLoaded: "+b)};window.he.dT=function(b){console.log("onRewardedVideoAdShown: "+b)};window.he.aT=function(b){console.log("onRewardedVideoAdHidden: "+b)};window.he.$S=function(b){console.log("onRewardedVideoAdCompleted: "+b)};console.log("Chartboost INIT")}
function vm(b,c,d,e,g){function h(b){y.Ln=!1;console.log(b.getError());y.ud&&y.ud.vR();y.rg(b)}function l(){console.log("Completeeeed")}function m(){y.DD=!0;y.ze()}function n(){y.Rf=-1;y.Ae=-1;y.Ln=!0}function s(){y.Rf=1E3*y.ud.getRemainingTime();y.Ae=y.Rf;0>y.Rf&&(y.KA?(y.Rf=y.preroll.max_ad_duration,y.Ae=y.Rf):y.JJ&&(y.Rf=y.interstitial.max_ad_duration,y.Ae=y.Rf))}function w(){console.log("Ad Closed");y.$b.style.display="none";y.ze()}var y=b;b.$b=document.createElement("div");b.viewport=R.j;b.$b.id=
"adContainer";b.viewport.appendChild(b.$b);b.Yu=document.getElementById("adContainer");b.$s=new google.ima.AdDisplayContainer(document.getElementById("adContainer"));var D=b.viewport.clientWidth/R.Nk,t=Math.round(e*D),z=Math.round(g*D);d=Math.round((d-R.jj)*D)+"px";c=Math.round((c-R.ij)*D)+"px";b.$b.style.width=t+"px";b.$b.style.height=z+"px";b.$b.style["z-index"]=300;b.$b.style.position="absolute";b.$b.style.top=d;b.$b.style.left=c;b.$b.style.display="block";var A={currentTime:0};c=new google.ima.AdsLoader(b.$s);
c.addEventListener(google.ima.AdsManagerLoadedEvent.Type.ADS_MANAGER_LOADED,function(b){y.ud=b.getAdsManager(A);y.ud.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR,h);y.ud.addEventListener(google.ima.AdEvent.Type.CONTENT_PAUSE_REQUESTED,l);y.ud.addEventListener(google.ima.AdEvent.Type.CONTENT_RESUME_REQUESTED,m);y.ud.addEventListener(google.ima.AdEvent.Type.COMPLETE,l);y.ud.addEventListener(google.ima.AdEvent.Type.USER_CLOSE,w);y.ud.addEventListener(google.ima.AdEvent.Type.STARTED,s);y.ud.addEventListener(google.ima.AdEvent.Type.LOADED,
n);try{y.ud.init(t,z,google.ima.ViewMode.NORMAL)}catch(c){y.Ln=!1,y.rg(c)}},!1);c.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR,h,!1);D=new google.ima.AdsRequest;D.adTagUrl="http://pubads.g.doubleclick.net/gampad/ads?sz=640x360&iu=/6062/iab_vast_samples/skippable&ciu_szs=300x250,728x90&impl=s&gdfp_req=1&env=vp&output=vast&unviewed_position_start=1&url=[referrer_url]&correlator=[timestamp]";f.Ib.Nq&&f.Ba.ve&&(console.log("iOS"),D.adTagUrl="http://pubads.g.doubleclick.net/gampad/ads?sz=400x300&iu=%2F6062%2Fiab_vast_samples&ciu_szs=300x250%2C728x90&gdfp_req=1&env=vp&output=xml_vast2&unviewed_position_start=1&url=[referrer_url]&correlator=[timestamp]&cust_params=iab_vast_samples%3Dlinear");
b.jJ&&(D.adTagUrl=tm(b));250>t&&(t=250);250>z&&(z=250);D.linearAdSlotWidth=t;D.linearAdSlotHeight=z;D.nonLinearAdSlotWidth=t;D.nonLinearAdSlotHeight=z;c.requestAds(D)}
function wm(b,c,d,e,g){b.$b=document.createElement("div");b.viewport=R.j;b.$b.id="poki-sdk-container";b.viewport.appendChild(b.$b);var h=b.viewport.clientWidth/R.Nk;e=Math.round(e*h);g=Math.round(g*h);d=Math.round((d-R.jj)*h)+"px";c=Math.round((c-R.ij)*h)+"px";b.$b.style.width=e+"px";b.$b.style.height=g+"px";b.$b.style["z-index"]=300;b.$b.style.position="absolute";b.$b.style.top=d;b.$b.style.left=c;b.$b.style.display="block";b.xw=document.getElementById("poki-sdk-container");POKI_DISPATCHER.addEventListener(poki.ready,
function(){b.HC=!0});POKI_DISPATCHER.addEventListener(poki.ads.ready,function(){b.ww=!0;console.log("ads start")});POKI_DISPATCHER.addEventListener(poki.ads.completed,function(){b.ze()});POKI_DISPATCHER.addEventListener(poki.ads.limit,function(c){b.rg(c)});POKI_DISPATCHER.addEventListener(poki.ads.error,function(c){b.rg(c)});POKI_DISPATCHER.addEventListener(poki.ads.update,function(c){b.Or(c.percentageComplete)});250>e&&(e=250);250>g&&(g=250);c=b.Rx?{timeUpdateInterval:100,debug:!0,staticAd:!0,width:e,
height:g}:{partnerId:b.gN,gameId:b.fN,timeUpdateInterval:100,debug:!1,width:e,height:g};if(POKI_ADS.publisherSettings&&POKI_ADS.publisherSettings.pokiads&&POKI_ADS.publisherSettings.pokiads.initParams)for(param in h=POKI_ADS.publisherSettings.pokiads.initParams,h)h.UR(param)&&(c[param]=h[param]);POKI_ADS.init(c)}
function xm(b){tokenads.config.appId=[b.oQ];tokenads.config.clientId=[b.pQ];tokenads.settings.position.centerPlayer=!0;tokenads.settings.view.draggable=!1;tokenads.settings.offersLimit=1;tokenads.config.listener.onError=function(c){b.rg(c)};tokenads.config.listener.onClose=function(){b.ze()};tokenads.config.listener.onCredit=function(c){b.ze(c)};tokenads.checkInventory(function(c){0<c?b.ky=!0:b.rg()});tokenads.settings.view.colorTheme="#954217";tokenads.settings.view.showTitle=!1}
function Cm(b,c){window.addEventListener("resize",function(){b(c)},!0)}function Dm(b,c,d,e,g){var h=Mj;250>e&&(e=250);250>g&&(g=250);switch(b){case "google":h.ud.resize(e,g,google.ima.ViewMode.NORMAL);h.Yu.style.top=d;h.Yu.style.left=c;break;case "poki":POKI_ADS.resize(e,g),h.xw.style.top=d,h.xw.style.left=c}}function Em(b){var c=Mj;switch(b){case "google":if(c.Ln)return!0;break;case "poki":if(c.ww)return!0;break;case "woobi":if(c.ky)return!0;console.log(document.getElementById("ta-player"))}}
function Fm(b){var c=Mj;switch(b){case "google":c.ud.start();break;case "poki":POKI_ADS.startAd();break;case "woobi":tokenads.showPlayer()}if(c.nc)switch(c.CL){case "admob":c.Qy&&AdMob&&AdMob.$T();break;case "chartboost":window.he.cU("Default"),console.log("Show chartboost ad")}}
a.ze=function(b){this.LA&&void 0===b&&0>this.Xt?(b=0,ia("Ad Reward",{Gp:b}),this.Ml&&this.Ml(b)):this.LA&&void 0===b&&-1<this.Xt?(b=this.Xt,ia("Ad Reward",{Gp:b}),this.Ml&&this.Ml(b)):void 0!==b?(ia("Ad Reward",{Gp:b}),this.Ml&&this.Ml(b)):ia("Ad Completed",{});this.$b&&(this.$b.style.display="none");(b=document.getElementById("adContainer"))&&b.parentNode.removeChild(b)};a.rg=function(b){ia("Ad Failed",{error:b})};a.Or=function(b){this.sw=b};
a.Bg=function(b,c){switch(b){case "google":if(-1<this.Rf&&-1<this.Ae)return-1<this.ud.getRemainingTime()?this.Ae=1E3*this.ud.getRemainingTime():this.Ae-=c,Math.round((this.Rf-this.Ae)/this.Rf*100);break;case "poki":return this.sw}};var Mj=new qm;
O.wI={vI:"https://cdn.firebase.com/js/client/2.2.1/firebase.js",fS:"https://ajax.googleapis.com/ajax/libs/jquery/2.2.0/jquery.min.js",hS:"https://ajax.googleapis.com/ajax/libs/jqueryui/1.11.4/jquery-ui.min.js",DS:"https://incandescent-inferno-1440.firebaseio.com/",qU:"https://testten.firebaseio.com/",tR:null,GJ:!1,Fb:void 0,KH:"undefined"!==typeof s_avatar80?s_avatar80:void 0,uR:"undefined"!==typeof s_avatar140?s_avatar140:void 0,lA:void 0,mA:void 0,zu:void 0,nv:[]};function Gm(){}
Gm.prototype.q=function(b){this.Za(O.wI);this.Za(b);this.GJ&&(this.IH=firebaseLocal?testUrl:mainUrl,Hm(this))};Gm.prototype.Za=function(b){var c;if("object"===typeof b)for(c in b)b.hasOwnProperty(c)&&(this[c]=dk(b[c]))};
function Hm(b){var c=document.getElementsByTagName("script")[0],d=document.createElement("script");d.type="text/javascript";d.async=!0;d.src=b.vI;void 0!==typeof d.addEventListener&&(d.addEventListener("load",function(){console.log("Create Reference");b.Fb=new Firebase(b.IH)},!1),d.addEventListener("error",function(){console.log("Error loading")},!1));c.parentNode.insertBefore(d,c)}Gm.prototype.Jn=function(){if(this.Fb)return this.Fb};
function Im(b){var c=Nj;c.Fb.TQ("facebook",b,function(b,e){b?console.log("Login Failed!",b):(console.log("Authenticated successfully with payload:",e),Jm(c,e))})}
function Jm(b,c){Km(Lm,function(c){if(c.data||c.picture.data)b.lA=(c.data||c.picture.data).url});Km(Mm,function(c){if(c.data||c.picture.data)b.mA=(c.data||c.picture.data).url});var d=b.Fb.ie("players");d.kw("value",function(e){e.DJ(c.uid)?d.ie(c.uid).kw("value",function(c){b.zu=c.pm()}):(d.ie(c.uid).set({uid:c.uid,name:c.pI.TH,tQ:0,R:0,Mt:0}),b.zu={uid:c.uid,name:c.pI.TH,tQ:0,R:0,Mt:0})})}
function Nm(b,c){var d=Nj;if(d.nv[b])return d.nv[b];if(void 0===b||"noUrl"===b)return d.KH;var e=ta(b,b,c,c);return d.nv[b]=e}var Nj=new Gm;function Om(b){hm.call(this,b)}gm(Om,hm);Om.prototype.oa=function(){this.ic()};var Lm=80,Mm=130;function Pm(b){var c=GameSparksWrapper.lK;c.nc||b&&(c.ll?b():c.sr.push(b))}function Qm(b){!b.uv&&b.nc&&(console.log("MOBILE INIT CALLED"),facebookConnectPlugin.getLoginStatus(function(c){Rm(b,c)}))}
function Sm(b,c){var d=Tm;if(d.nc)facebookConnectPlugin.login(d.dL,function(b){console.log("FB Success Test: "+b);console.log("USERDATA: "+b.authResponse);d.uv=!1;Rm(d,b)},function(b){console.log("Mobile error: "+b)});else{var e=d.xB;"connected"===e.status?b&&b(e):d.ll.login(function(e){Rm(d,e);d.Dl?b&&b(e):c&&c(e)},{scope:"user_friends"})}}
function Km(b,c){var d=Tm;void 0===b&&(b=Lm);d.uv||(d.nc?facebookConnectPlugin.api("me/?fields=picture.type(square).width("+b+").height("+b+")",["public_profile"],function(b){c(b)}):d.Du("/me/picture","get",{type:"square",height:b,width:b},function(b){c(b)}))}
function Rm(b,c){console.log(c);b.Dl||(b.nc?"unknown"===c.status&&3>b.rD?(console.log("unknown response"),Qm(b),b.rD++):c.authResponse&&(b.Dl=!0,facebookConnectPlugin.api("me?fields=id,name,picture",["public_profile"],function(){}),Pm(function(){GameSparksWrapper.lK.zR(c.authResponse.accessToken)})):(b.xB=c,c.authResponse&&(b.Dl=!0,b.Du("/me",function(){}),Im(c.authResponse.accessToken))))}
var Tm=new function(){this.uv=this.nc=this.dK=!1;this.dL=["public_profile","user_friends"];this.rD=0;this.Du=this.ll=null;this.sr=[];this.xB=null;var b=this;this.nc||!this.dK?console.log("FB on Mobile or not in use"):(window.fbAsyncInit=function(){b.ll=window.FB;b.Du=b.ll.api;b.ll.init({appId:facebook_config.SQ,cookie:!0,xfbml:!1,version:"v2.5"});b.ll.getLoginStatus(function(c){Rm(b,c);for(c=0;c<b.sr.length;++c)b.sr[c]();b.sr=[]})},function(b,d,e){var g=b.getElementsByTagName(d)[0];b.getElementById(e)||
(b=b.createElement(d),b.id=e,b.src="//connect.facebook.net/en_US/sdk.js",g.parentNode.insertBefore(b,g))}(document,"script","facebook-jssdk"))};O.W.pz={c:F,ef:500,ye:45,Jb:1,Ge:7};function Um(b){this.q(O.W.pz);this.index=0;this.ef=500;this.elements=[];this.kd=-1;this.axis=new k(1,0);this.Ci=new k(0,0);this.speed=0;this.ye=45;this.Ge=7;this.Lp=!1;this.fO=P(470);this.Zw=P(200);this.lL=P(0);this.mL=P(0);this.AB=P(50);this.j=new W({});this.dm=this.u=0;this.GC=1E3;this.Yl=null;void 0!==b&&this.i(b)}
V(Um,W);Math.round=Math.round;a=Um.prototype;a.K=function(){this.Lp&&(this.J=new wa(this.fO,this.Zw),this.j.x=this.x,this.j.y=this.y,this.g(this.j),this.J.context.translate(Math.round(this.AB),Math.round(this.Zw/2)))};a.addElement=function(b){this.Lp?this.j.g(b):this.g(b);this.elements.push(b);this.Sg(b,this.elements.length-1)};a.Sy=function(b,c){this.g(b);this.elements[c]=b;this.Sg(b,c)};a.Sg=function(b,c){var d=this.axis.scale(this.ef*(c-this.u));b.x=d.x;b.y=d.y;this.Yl&&this.Yl(b)};
a.Cx=function(b){this.u=Math.max(Math.min(this.elements.length-1,b),0);for(b=0;b<this.elements.length;++b)this.Sg(this.elements[b],b)};
a.Hd=function(b){var c=this.u;if(0<=this.kd){var d=new k(u.Ec(this.kd)-this.Ci.x,u.sc(this.kd)-this.Ci.y),e=-1/this.ef;d.x*=e;d.y*=e;this.u=d.qn(this.axis)+this.dm;0>this.u?this.u=Math.atan(this.u*this.Jb)/this.Jb:this.u>this.elements.length-1&&(this.u=Math.atan(this.Jb*(this.u-this.elements.length+1))/this.Jb+this.elements.length-1);this.speed=Math.min(Math.max(1E3*(this.u-c)/b,-4),4)}else d=Math.round(this.u),d=Math.max(0,Math.min(this.elements.length-1,d)),this.speed+=b/1E3*((d-this.u)*this.ye-
this.speed*this.Ge),this.u+=b/1E3*this.speed;if(c!==this.u)if(this.u>this.GC-.001)this.u=this.GC;else for(b=0;b<this.elements.length;++b)this.Sg(this.elements[b],b)};a.Id=function(b){if(-1===this.kd){this.kd=b;var c=this.Ci,d=u.sc(b);c.x=u.Ec(b);c.y=d;this.dm=this.u}};a.He=function(b){b===this.kd&&(this.kd=-1)};a.Ic=function(){if(this.Lp){var b=Math.round(this.AB),c=Math.round(this.Zw/2);xa(this.J);this.J.context.clearRect(-b,-c,this.J.width,this.J.height)}};
a.Nf=function(){this.Lp&&(ya(this.J),this.J.ma(this.lL,this.mL),this.Iy=this.t,this.t=this.elements)};O.W.PF={ce:void 0,Zx:void 0};function Vm(b){this.q(O.W.pz);this.i(O.W.PF);this.index=0;this.ef=500;this.elements=[];this.kd=-1;this.axis=new k(1,0);this.Ci=new k(0,0);this.speed=0;this.ye=45;this.Ge=7;this.dm=this.u=0;this.Yl=null;void 0!==b&&this.i(b)}V(Vm,Um);Math.round=Math.round;Vm.prototype.K=function(){void 0!==this.Zx&&this.g(this.Zx);void 0!==this.ce&&this.g(this.ce)};
Vm.prototype.Hd=function(b){Vm.Bb.Hd.call(this,b);0<=this.kd&&void 0!==this.ce&&(void 0!==this.ce.oD&&(this.ce.text=this.ce.oD[Math.round(this.u)]),this.ce.Wd())};Vm.prototype.Sf=function(b,c,d){Vm.Bb.Sf.call(this,b,c,d);console.log("DELTA: "+b+" X: "+c+" Y: "+d)};O.W.xL={h:[]};function Wm(b){this.name="MenuScroll";this.q(O.W.xL);void 0!==b&&this.i(b)}V(Wm,W);a=Wm.prototype;a.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};
a.Hd=function(){};a.Id=function(){};a.He=function(){};a.Hj=function(){};a.qi=function(){};a.ri=function(){};a.si=function(){};a.ph=function(){};a.wg=function(){};a.qd=function(){};a.cf=function(){};a.Ic=function(){};a.Nf=function(){};O.W.dR={c:F,Tb:!0,marginLeft:P(24),marginRight:P(24),marginTop:P(24),marginBottom:P(24),icon:null,Ja:"left",pe:P(24),text:"",s:"",Sj:null,ya:M,Bc:!1,uo:0,vo:0,to:0,qf:0,dp:Oi,ep:null,kb:0,Yh:!1,cb:0,eb:0,Zd:null,Rm:!1,Vi:!1,tc:!0,mg:!1,Wb:!0,h:[],m:null};
function Xm(b){this.name="ButtonList";this.q(O.W.button);void 0!==b&&this.i(b)}V(Xm,W);a=Xm.prototype;a.ec=function(){return this.Ka.width};a.dc=function(){return this.Ka.height};a.Wd=function(){this.De()};a.findText=function(){var b=this.text,c=this.s;"[object Array]"===Object.prototype.toString.call(this.text)&&(b=this.text[this.kb%this.text.length]);"[object Array]"===Object.prototype.toString.call(this.s)&&(c=this.s[this.kb%this.s.length]);""!==c&&(b=xk(c,"<"+c+">"));return b};
a.rn=function(b,c){var d="up"===c?0:1,e=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(e=this.c[this.kb%this.c.length]);e&&(e instanceof wa?this.Tb?e.Jc(0,0,b.width,b.height,1,Math.floor(e.width/2)-2,Math.floor(e.width/2)-2,Math.floor(e.height/2)-2,Math.floor(e.height/2)-2):b.width===e.width&&b.height===e.height?e.ma(e.Qa,e.Sa):e.Of(0,0,b.width,b.height,1):e instanceof q&&(this.Tb?e.Jc(d,0,0,b.width,b.height,1,Math.floor(e.width/2)-2,Math.floor(e.width/2)-2,Math.floor(e.height/
2)-2,Math.floor(e.height/2)-2):b.width===e.width&&b.height===e.height?e.ma(d,e.Qa,e.Sa):e.Of(d,0,0,b.width,b.height,1)))};
a.sn=function(b,c){var d="up"===c?0:1,e,g,h=this.icon;this.icon&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(h=this.icon[this.kb%this.icon.length]);if(h){switch(this.Ja){case "left":e=this.marginLeft;g=(b.height-h.height)/2;break;case "center":e=(b.width-h.width)/2;g=(b.height-h.height)/2;break;case "right":e=b.width-h.width-this.marginRight;g=(b.height-h.height)/2;break;case "top":e=(b.width-h.width)/2;g=this.marginTop;break;case "bottom":e=(b.width-h.width)/2,g=b.width-h.width-
this.marginBottom}this.Wb&&(e=Math.floor(e),g=Math.floor(g));"down"===c?(e+=this.to,g+=this.qf):(e+=this.uo,g+=this.vo);h instanceof wa?h.ma(e+h.Qa,g+h.Sa):h instanceof q&&h.ma(d,e+h.Qa,g+h.Sa)}};
a.le=function(b,c){var d,e,g,h,l,m,n=this.findText();(l=this.icon)&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(l=this.icon[this.kb%this.icon.length]);d="down"===c?null!==this.Sj?this.Sj:this.ya:null!==this.ya?this.ya:this.Sj;d instanceof Ca?m=d:(m=new Ca,m.i(d));d=this.marginLeft;e=this.marginTop;g=b.width-this.marginLeft-this.marginRight;h=b.height-this.marginTop-this.marginBottom;if(l)switch(this.Ja){case "left":d+=l.width+this.pe;g-=l.width+this.pe;break;case "right":g-=l.width+
this.pe;break;case "top":e+=l.height+this.pe;h-=l.height+this.pe;break;case "bottom":h-=l.height+this.pe}switch(m.align){case "center":d+=g/2;break;case "right":d+=g}switch(m.xb){case "middle":e+=h/2;break;case "bottom":e+=h}this.Wb&&(d=Math.floor(d),e=Math.floor(e));"down"===c?(d+=this.to,e+=this.qf):(d+=this.uo,e+=this.vo);l=m.fontSize;h=Ra(m,n,g,h,this.Bc);h<l&&Da(m,h);this.Bc?m.ma(n,d,e,g):m.ma(n,d,e);Da(m,l)};
a.De=function(){var b=this.width,c=this.height,d=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(d=this.c[this.cb%this.c.length]);d&&0===b&&(b=d.width);d&&0===c&&(c=d.height);this.Ka=new wa(b,c);xa(this.Ka);this.rn(this.Ka,"down");this.sn(this.Ka,"down");this.le(this.Ka,"down");ya(this.Ka);this.ae=new wa(b,c);xa(this.ae);this.rn(this.ae,"up");this.sn(this.ae,"up");this.le(this.ae,"up");ya(this.ae)};
a.ac=function(b,c){this.state!==b&&("down"===b?(this.state="down",c&&(this.dp&&S.play(this.dp),this.Vi&&(this.Yh&&1<this.cb&&(this.kb=(this.kb+1)%this.cb,this.De()),this.m&&this.m(this)))):"up"===b&&(this.state="up",c&&(this.ep&&S.play(this.ep),this.Vi||(this.Yh&&1<this.cb&&(this.kb=(this.kb+1)%this.cb,this.De()),this.m&&this.m(this)))))};
a.K=function(){var b;0>=this.cb&&(this.cb=1,"[object Array]"===Object.prototype.toString.call(this.c)&&(this.cb=Math.max(this.cb,this.c.length)),"[object Array]"===Object.prototype.toString.call(this.icon)&&(this.cb=Math.max(this.cb,this.icon.length)),"[object Array]"===Object.prototype.toString.call(this.text)&&(this.cb=Math.max(this.cb,this.text.length)),"[object Array]"===Object.prototype.toString.call(this.s)&&(this.cb=Math.max(this.cb,this.s.length)));this.De();this.ac("up",!1);this.ua=-1;for(b=
0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.ae=this.Ka=void 0};a.Id=function(b,c,d){if(!this.mg)return this.Ij(b,c,d)};a.He=function(b,c,d){if(!this.mg)return this.Jj(b,c,d)};a.qi=function(b,c,d){if(this.mg)return this.Ij(b,c,d)};a.ri=function(b,c,d){if(this.mg)return this.Jj(b,c,d)};a.Ij=function(b,c,d){var e=this.Ka.width+2*this.eb,g=this.Ka.height+2*this.eb;if(c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&("up"===this.state&&(this.ac("down",!0),this.ua=b),this.tc))return!0};
a.Jj=function(b,c,d){var e=this.Ka.width+2*this.eb,g=this.Ka.height+2*this.eb;if(this.ua===b&&(this.ua=-1,c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&("down"===this.state&&this.ac("up",!0),this.tc)))return!0};a.si=function(b){if(this.Rm||this.Zd&&b===this.Zd)if(this.ac("down",!0),this.tc)return!0};a.ph=function(b){if(this.Rm||this.Zd&&b===this.Zd)if(this.ac("up",!0),this.tc)return!0};
a.qd=function(){var b,c,d=this.Ka.width+2*this.eb,e=this.Ka.height+2*this.eb;-1!==this.ua&&(b=this.Ec(this.ua),c=this.sc(this.ua),b>=-d/2&&b<=d/2&&c>=-e/2&&c<=e/2?this.ac("down",!1):this.ac("up",!1))};a.wg=function(b){"languageSet"===b&&this.De()};a.Ic=function(){var b=-this.Ka.width/2,c=-this.Ka.height/2;this.Wb&&(b=Math.floor(b),c=Math.floor(c));"down"===this.state?this.Ka.ma(b,c):this.ae.ma(b,c)};
O.I.AM={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:10,Hb:0,Fd:90,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),ji:!1,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!1,ge:F,ih:M,kh:null,buttons:[],hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,Si:null,jk:null,zo:null,kk:null,Co:null,Ll:null,Hl:null,bg:[],Fo:[{x:P(0),y:P(-200)},{x:P(0),y:P(-100)},
{x:P(0),y:P(0)},{x:P(0),y:P(100)},{x:P(0),y:P(200)}],xc:P(0),yc:P(0),Ct:F,yz:M,At:"Tutorial",Et:P(400),Bt:P(80),Dt:"",rG:null,rx:Cc,sx:Dc,tx:P(400),px:P(80),qx:Ic,yx:Cc,zx:Dc,Ax:P(400),wx:P(80),xx:Kc,wt:F,xz:M,ut:"More Games",zt:P(400),vt:P(80),xt:"",eG:null,yt:"http://www.tinglygames.com/html5-games/",rt:F,qz:M,pt:"About",tt:P(400),qt:P(80),st:"",QF:null,$m:[],Wk:bi,Us:"Developed by:",Ws:"",Vs:K,Xs:P(0),Ys:P(-250),Ls:wd,Ns:P(0),Os:P(-100),Ms:"http://www.tinglygames.com/",Ps:"Tingly Games \n www.tinglygames.com \n \u00a9 2014 - 2015",
Qs:P(0),Rs:P(100),Ss:"http://www.tinglygames.com/",Gs:F,Hs:"",Ds:"Back",Es:M,Js:P(0),Ks:P(200),Is:P(400),Fs:P(80),bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null,by:null,nr:null,Sr:null,AK:null,Pv:null,Ts:null};function Ym(b){this.name="OptionButtonBox";this.q(O.I.AM);void 0!==b&&this.i(b)}gm(Ym,hm);a=Ym.prototype;a.na=function(){this.Ca();X(this.j,2)};a.mw=function(){var b;O.r.OC&&(O.r.Tn?(b=new Zm(O.r.Tn),b.m=function(b,d){Rb();b.Dj(d)},Pb(),b.show()):console.log("No languageScreenProperties can be found"))};
a.nw=function(){var b;O.r.mx&&(O.r.ay?(b=new xj(O.r.ay),b.m=function(){Rb()},Pb(),b.show()):console.log("No tutorialMenuProperties can be found"))};
a.rv=function(b){var c=new U({text:this.Ws,s:this.Us,x:this.Xs,y:this.Ys,ya:this.Vs});this.$m.push(c);c=new Z({c:this.Ls,x:this.Ns,y:this.Os,url:this.Ms,m:function(){window.open(this.url)}});this.$m.push(c);c=new U({text:this.Ps,x:this.Qs,y:this.Rs,url:this.Ss,m:function(){window.open(this.url)}});this.$m.push(c);c=new $({c:this.Gs,x:this.Js,y:this.Ks,width:this.Is,height:this.Fs,text:this.Hs,s:this.Ds,ya:this.Es,m:function(){b.xo?b.xo():b.na()}});this.$m.push(c);return this.$m};
a.lw=function(){var b;b=new lm({backgroundImage:this.Wk,Ub:!0,xo:null});b.h=this.rv(b);b.ub=function(){Rb()};Pb();b.show()};a.wj=function(b){this.xc=this.Fo[b].x;this.yc=this.Fo[b].y};a.Ta=function(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.g(c);return c};
a.Xe=function(b,c,d,e,g,h){var l=this;return this.Ta(b,$,{x:e,y:g,width:void 0===c.IO?h:0,height:0,c:void 0===c.c?this.ge:c.c,text:void 0===c.text?"":c.text,s:void 0===c.key?"":c.key,icon:c.icon,Ja:"left",font:void 0===c.font?this.ih:c.font,Qb:void 0===c.id?d:c.id,zj:void 0===c.w?this.jh:c.w,tc:!0,m:function(b){b.zj&&lm.prototype.na.call(l);l.m&&l.m(l,b.Qb)}},this.kh,c.Jw)};
a.K=function(){var b=this,c;c=[];var d=[],e=[],g=[],h,l,m;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);h=0===this.width?this.backgroundImage.width:this.width;l=0===this.height?this.backgroundImage.height:this.height;c[0]=Math.round(-h/2+this.marginLeft);e[0]=Math.round(h-this.marginLeft-this.marginRight);d[0]=Math.round(-l/2+this.marginTop);g[0]=Math.round(this.rc*(l-this.marginTop-this.marginBottom)/100);c[1]=Math.round(-h/2+this.marginLeft);e[1]=Math.round(h-this.marginLeft-
this.marginRight);d[1]=Math.round(d[0]+g[0]);g[1]=Math.round(this.Hb*(l-this.marginTop-this.marginBottom)/100);this.Ia&&(e[2]=this.Ia.width,c[2]=c[1]+e[1]-e[2],d[2]=d[1],g[2]=g[1],e[1]-=e[2]+P(32),"left"===this.Ja&&(c[2]=c[1],c[1]+=e[2]+P(32)));c[3]=Math.round(-h/2+this.marginLeft);e[3]=Math.round(h-this.marginLeft-this.marginRight);0<this.Pc&&(c[3]=Math.round(-this.Pc/2),e[3]=this.Pc);d[3]=Math.round(d[1]+g[1]);g[3]=Math.round(this.Fd*(l-this.marginTop-this.marginBottom)/100);this.hb&&(m=this.Ta(this,
cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.Ta(this,Z,{c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:this.oc},this.Ua],Mg:function(c,d){d===b.Ua&&b.hb&&dm(m,m.duration,b.j.ra[2].duration-m.duration)},Td:function(){b.w()}},this.wb);this.pd&&(this.j.Ri=function(){b.ab&&b.ab(b);lm.prototype.na.call(b)});this.rc&&this.Ta(this.j,U,{x:Math.round(c[0]+e[0]/
2),y:Math.round(d[0]+g[0]/2),width:e[0],height:g[0],text:this.Zc,s:this.Dc,font:this.Mb,dd:!0,Bc:!1,Ea:P(20)},this.Mc);this.Hb&&this.Ta(this.j,U,{x:Math.round(c[1]+e[1]/2),y:Math.round(d[1]+g[1]/2),width:e[1],height:g[1],text:this.Qd,s:this.vd,font:this.Wc,dd:!0,Bc:!0,Ea:P(20)},this.wd);this.Hb&&this.Ia&&this.Ta(this.j,Z,{c:this.Ia,x:Math.round(c[2]+e[2]/2),y:Math.round(d[2]+g[2]/2)},this.Lc);this.Ub&&(c=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.lc/2),d=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.Qc/2),this.Ta(this.j,$,{x:c,y:d,width:this.lc,height:this.Qc,c:uc,m:function(){b.ab&&b.ab(b);lm.prototype.na.call(b)}},this.je));for(c=0;c<this.bg.length;c++)switch(this.bg[c]){case "tutorial":this.wj(c);this.Hk=new $({c:this.Ct,x:this.xc,y:this.yc,width:this.Et,height:this.Bt,text:this.Dt,s:this.At,ya:this.yz,m:function(){b.Si?b.Si(b):b.nw()}});this.Hk.i(this.by);this.j.g(this.Hk);break;case "music":this.wj(c);this.Kg=new em({icon:this.qx,
za:this.rx,Pd:this.sx,x:this.xc,y:this.yc,width:this.tx,height:this.px,Il:function(c,d){b.zo?b.zo(b):pl(S,d/100)},Jl:function(){b.jk&&b.jk(b)}});this.Kg.i(this.nr);this.j.g(this.Kg);break;case "audio":this.wj(c);this.Tg=new em({icon:this.xx,za:this.yx,Pd:this.zx,x:this.xc,y:this.yc,width:this.Ax,height:this.wx,Il:function(c,d){b.Co?b.Co(b):ol(S,d/100)},Jl:function(){b.kk&&b.kk(b)}});this.Tg.i(this.Sr);this.j.g(this.Tg);break;case "moregames":this.wj(c);this.ek=new $({c:this.wt,x:this.xc,y:this.yc,
width:this.zt,height:this.vt,text:this.xt,link:this.yt,s:this.ut,ya:this.xz,m:function(){b.Ll?b.Ll(b):window.open(this.link)}});this.ek.i(this.Pv);this.j.g(this.ek);break;case "about":this.wj(c),this.uj=new $({c:this.rt,x:this.xc,y:this.yc,width:this.tt,height:this.qt,text:this.st,s:this.pt,ya:this.qz,m:function(){b.Hl?b.Hl(b):b.lw()}}),this.uj.i(this.Ts),this.j.g(this.uj)}for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){this.ic();this.uj=this.ek=this.Tg=this.Kg=this.Hk=this.j=void 0};
O.I.tK={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:10,Hb:0,Fd:90,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),ji:!1,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!1,ge:vd,ih:M,kh:null,buttons:[],Wp:P(500),Vp:P(500),cn:[],Aj:P(0),Vm:[],Wm:[],bd:[],hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null,
$w:null};function Zm(b){this.name="LanguageBox";this.q(O.I.tK);void 0!==b&&this.i(b)}gm(Zm,hm);a=Zm.prototype;a.na=function(){this.Ca();X(this.j,2)};a.Ta=function(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.g(c);return c};a.ts=function(b,c,d,e,g){b=new c(d);void 0!==e&&b.i(e);void 0!==g&&b.i(g);this.cn.push(b)};
a.Xe=function(b,c,d,e,g,h){var l=this;return this.ts(b,$m,{x:e,y:g,width:h,height:0,c:void 0===c.c?this.ge:c.c,text:this.Wm[d],vl:this.bd[d],s:void 0===c.key?"":c.key,icon:this.Vm[d],Ja:"left",font:void 0===c.font?this.ih:c.font,Qb:void 0===c.id?d:c.id,zj:void 0===c.w?this.jh:c.w,tc:!1,qf:2,threshold:P(1.5),m:function(b){b.zj&&lm.prototype.na.call(l);l.m&&l.m(l,b.Qb)}},this.kh,c.Jw)};a.Dj=function(b){yk.Oh(yk.Ag()[b]);this.Ca();X(this.j,2)};
a.Nn=function(){this.bd=yk.Ag();for(var b=0;b<this.bd.length;b++)this.Vm.push(zk(this.bd[b])),this.Wm.push(Ak(this.bd[b]))};
a.K=function(){var b=this,c,d,e,g=[],h=[],l=[];c=[];var m,n,s,w,y,D;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);m=0===this.width?this.backgroundImage.width:this.width;n=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);h[0]=Math.round(-n/2+this.marginTop);c[0]=Math.round(this.rc*(n-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);h[1]=Math.round(h[0]+c[0]);c[1]=Math.round(this.Hb*(n-this.marginTop-this.marginBottom)/100);this.Ia&&(l[2]=this.Ia.width,g[2]=g[1]+l[1]-l[2],h[2]=h[1],c[2]=c[1],l[1]-=l[2]+P(32),"left"===this.Ja&&(g[2]=g[1],g[1]+=l[2]+P(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Pc&&(g[3]=Math.round(-this.Pc/2),l[3]=this.Pc);h[3]=Math.round(h[1]+c[1]);c[3]=Math.round(this.Fd*(n-this.marginTop-this.marginBottom)/100);this.hb&&
(D=this.Ta(this,cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.Ta(this,Z,{c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:this.oc},this.Ua],Mg:function(c,d){d===b.Ua&&b.hb&&dm(D,D.duration,b.j.ra[2].duration-D.duration)},Td:function(){b.w()}},this.wb);this.pd&&(this.j.Ri=function(){b.ab&&b.ab(b);Zm.prototype.na.call(b)});this.rc&&this.Ta(this.j,U,{x:Math.round(g[0]+
l[0]/2),y:Math.round(h[0]+c[0]/2),width:l[0],height:c[0],text:this.Zc,s:this.Dc,font:this.Mb,dd:!0,Bc:!1,Ea:P(20)},this.Mc);this.Hb&&this.Ta(this.j,U,{x:Math.round(g[1]+l[1]/2),y:Math.round(h[1]+c[1]/2),width:l[1],height:c[1],text:this.Qd,s:this.vd,font:this.Wc,dd:!0,Bc:!0,Ea:P(20)},this.wd);this.Hb&&this.Ia&&this.Ta(this.j,Z,{c:this.Ia,x:Math.round(g[2]+l[2]/2),y:Math.round(h[2]+c[2]/2)},this.Lc);this.Ub&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.lc/2),n=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.Qc/2),this.Ta(this.j,$,{x:m,y:n,width:this.lc,height:this.Qc,c:uc,m:function(){b.ab&&b.ab(b);lm.prototype.na.call(b)}},this.je));this.Nn();if(this.Fd){m=this.ji?[this.buttons]:this.buttons;d=this.ge.height;n=d+this.od;h=Math.round(h[3]+d/2);switch(this.ki){case "top":break;case "bottom":h+=c[3]-m.length*n-this.od;break;default:h+=Math.round((c[3]-m.length*n-this.od)/2)}for(c=e=0;c<m.length;c+=1)if("[object Array]"===Object.prototype.toString.call(m[c]))for(y=
Math.round((l[3]-this.Lf*(m[c].length-1))/m[c].length),w=y+this.Lf,s=Math.round(g[3]+y/2),this.Aj+=n+this.od,d=0;d<m[c].length;d+=1)this.Xe(this.j,m[c][d],e,s+d*w,h+c*n,y),e+=1;else this.Xe(this.j,m[c],e,Math.round(g[3]+l[3]/2),h+c*n,l[3]),e+=1}this.Ta(this.j,Rl,{cm:!1,az:0,bz:0,width:this.Wp,height:this.Vp,$a:this.ge.width,Ga:this.Aj,h:this.cn},this.$w);for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){this.ic();this.j=void 0};
O.I.fJ={backgroundImage:void 0,nH:P(0),cq:P(-700),nh:!1,hL:"",fL:"MAIN",iL:P(0),jL:P(-100),gL:K,NH:"",LH:"Second",OH:P(0),PH:P(0),MH:L,sb:{k:Kl,duration:1,Ma:P(-700),bb:P(0),D:dc,da:1.2,name:"appear"},Ua:{k:Kl,duration:1,Ma:P(0),bb:P(-700),D:cc,da:1.2,name:"disappear"},h:[],j:[],yo:null};function an(b){this.name="GameStart";this.q(O.I.fJ);this.i(O.hp);void 0!==b&&this.i(b)}gm(an,hm);a=an.prototype;a.na=function(){this.Ca();X(this.uc,2)};
a.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;this.uc=new am({y:this.cq,ra:[this.sb,{k:"show",duration:4},this.Ua,{k:"show",duration:9999999999}],Mg:function(b,e){"disappear"===e.name&&(c.nh=!1)},ag:function(b,e){"appear"===e.name&&(c.nh=!0);"disappear"===e.name&&c.yo&&c.yo(c)}});this.Ye=new Z({c:this.backgroundImage,x:this.WQ,y:this.XQ});this.j.push(this.Ye);this.yB=new U({text:this.hL,s:this.fL,x:this.iL,y:this.jL,GI:this.gL});this.j.push(this.yB);this.Zz=new U({text:this.NH,
s:this.LH,x:this.OH,y:this.PH,GI:this.MH});this.j.push(this.Zz);for(b=0;b<this.j.length;b++)this.uc.g(this.j[b]);this.g(this.uc);if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.ic();this.uc=this.Zz=this.yB=this.Ye=void 0};a.Wa=function(){};a.Cg=function(){this.nh&&this.na()};O.kR={};
O.I.JK={backgroundImage:kh,qB:"manual",ar:"vertical",mode:O.xa.Wt,hc:20,Ko:20,fl:P(0),hT:P(0),iv:!1,MA:!1,ds:0,Bh:2.8,bp:2,Pq:!0,Wf:0,ei:null,EJ:!0,AF:!0,pP:!1,IJ:!0,UA:F,qv:P(0),Jq:P(0),bS:{k:Hl,duration:.5,jc:P(1),cc:P(1.2),D:bc,da:1},aS:{k:Hl,duration:.5,jc:P(1.2),cc:P(1),D:bc,da:1},Ev:F,br:["Page 01","Page 02","Page 03"],tS:"",Bl:void 0,Cl:void 0,Al:P(300),zl:P(100),WG:"",VG:"ComingSoonText",Dz:L,XG:P(576),YG:P(-335),Dv:P(3),yl:P(3),uB:10,pB:void 0,LK:void 0,mB:void 0,IK:!1,kB:M,lB:M,xl:[xd,yd,
zd,Ad,Bd],$q:P(73),Vn:P(64),nB:P(75),FK:P(50),sS:P(0),oS:P(4),pS:!1,Li:[{x:P(-79),y:P(232)},{x:P(-168),y:P(92)},{x:P(-26),y:P(90)},{x:P(96),y:P(128)},{x:P(224),y:P(130)},{x:P(178),y:P(-82)},{x:P(-62),y:P(-86)},{x:P(-275),y:P(-134)},{x:P(-138),y:P(-244)}],eN:[],as:[{x:P(345),y:P(356)},{x:P(345),y:P(356)},{x:P(345),y:P(356)}],ak:F,fo:Lc,ck:P(-300),dk:P(100),bk:P(0),$j:P(0),ES:[F,F],Zn:void 0,hr:void 0,nS:[[F,F],[F]],lS:-1E3,mS:[[{x:P(500),y:P(100)},{x:P(560),y:P(100)}],[{x:P(559),y:P(100)}]],wh:[],
LR:["SPRINGFIELD","CLAY VALLEY","PALM BEACH","TUNDRA TOWN"],MR:[{x:3,y:-23},{x:17,y:-25},{x:0,y:-28},{x:10,y:-26}],iJ:[],m:null,hw:null,yf:[],h:[],cd:[],Cv:null,ZQ:null};function yj(b){this.name="LevelMap";this.q(O.I.JK);this.i(O.Cv);void 0!==b&&this.i(b)}gm(yj,hm);a=yj.prototype;a.na=function(){this.w()};a.Hy=function(b){b.sort(function(b,d){return b.d-d.d});return b};a.Ay=function(b){for(var c=0;c<b.length;c++)this.h.push(b[c])};
a.oe=function(b){if(ba&&u.Df[90]){if(49==b)for(var c=0;c<this.cd.length;c++)1===this.cd[c].id&&(this.cd[c].ap(1),bn(this.wh[c],1));if(50==b)for(c=0;c<this.cd.length;c++)2===this.cd[c].id&&(this.cd[c].ap(2),bn(this.wh[c],2));if(51==b)for(c=0;c<this.cd.length;c++)3===this.cd[c].id&&this.cd[c].ap(3)}};
function cn(b){b.cd.reverse();var c=0;if(b.ei.rm)for(var c=b.ei.rm.Ch,d=0;d<c.length;d++){var e=c[d],g=Qk(jj,b.mode,e+1);e+1<b.Wf&&0<b.Wf?b.cd[d]&&(dn(b.cd[d],d+1),b.wh[d]&&(b.wh[d].Pp=!0)):e<=b.Wf&&0<g.Ue?b.cd[d]&&0<g.Ue&&(dn(b.cd[d],d+1),b.wh[d]&&(b.wh[d].Pp=!0)):e===b.Wf&&b.cd[d]&&(b.cd[d].ap(d+1),b.wh[d]&&bn(b.wh[d],d+1))}}a.Ta=function(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.h.push(c)};
a.Xe=function(b,c,d,e,g,h,l,m,n,s){var w=this;return this.Ta(b,$m,{x:l,y:m,width:n,height:s,c:d,text:this.IK?"":h.toString(),marginTop:P(-5),icon:void 0===this.mB?null:this.mB[g],Ja:"top",ya:e?this.lB:this.kB,Qb:g,OK:e,tc:!1,threshold:P(1.5),m:function(b){!this.OK&&w.m&&w.m(w,b.Qb)}},this.Cv)};
function en(b){var c=new fn,d=0,e=0,g=c.Ni.pw;b.ei=gn();b.hc=b.ei.hc.length;var h=1,l,m,n;m=Pk(jj);h=m.Un;b.Wf=m.El;void 0===b.Bl&&(b.Bl=p.width/2);void 0===b.Cl&&(b.Cl=p.height/8);void 0==b.Zn&&(b.Zn=p.width);void 0==b.hr&&(b.hr=p.height);switch(b.qB){case "grid":b.Ko=Math.ceil(b.hc/(b.Dv*b.yl));c=b.Vn*b.yl+b.nB*(b.yl-2);for(m=0;m<b.Ko;m++){var s=new am({});if(b.iv&&!b.MA){var w=new am({}),y=new Z({c:b.Ev,x:b.Bl,y:b.Cl,width:b.Al,height:b.zl});l=new U({text:b.br[m],x:b.Bl,y:b.Cl,width:b.Al,height:b.zl});
w.h.push(y);w.h.push(l);s.h.push(w)}d=void 0===b.pB?(p.width-c)/2:b.pB;e=void 0===b.LK?200:b.EQ;for(w=0;w<b.Dv;w++)for(y=0;y<b.yl;y++){var D=w*b.yl+y+m*b.Dv*b.yl;n=Qk(jj,b.mode,D);D+1===h&&(b.fl=m);if(D===b.hc){b.yf.push(s);return}var t=d+y*(b.Vn+b.nB),z=e+w*(b.$q+b.FK),A=D+1;n.mK?l=b.xl[n.Xf]:(l=b.xl[4],A="");b.Xe(s,b.oB,l,n.mK,D,A,t,z,b.Vn,b.$q)}b.yf.push(s)}break;case "manual":var B=!1,h=p.width/2,Y=p.height/2;b.Ko=g.length;var ja=new hn;m=b.Ko/b.bp;b.eN=ja.Ni.page.yH;b.ps=ja.Ni.page.ps;if(ja)for(b.Li=
[],w=0;w<m;w++)for(y=0;y<ja.Ni.page.Qz.length;y++)b.Li.push(ja.Ni.page.Qz[y]);for(var Fa=[],w=0;w<b.Ko;w++){s=new am({});m=c.Ni[g[w]].items;for(y=0;y<m.length;y++)"background"===m[y].id&&(l=b.AF?new Z({c:m[y].c,x:h,y:Y,Tb:!0,lh:!0,width:b.Zn,height:b.hr}):new Z({c:m[y].c,x:h,y:Y,Tb:!1,lh:!0,width:b.Zn,height:b.hr}),s.h.push(l));Fa[w]=s}for(m=0;m<Fa.length;m++){s=c.Ni[g[m]].items;s=b.Hy(s);w=new jn({id:m,il:s});Fa[m].h.push(w);for(w=0;w<s.length;w++)"background"!==s[w].id&&"gate"===s[w].id&&(e++,0!==
d&&(y=new am({}),l=new kn({id:d,position:{x:577,y:540}}),b.wh.push(l),y.g(l),Fa[m].h.push(y)),d++);b.iv&&(w=new am({}),y=new Z({c:b.Ev,x:b.as[m].x,y:b.as[m].y,width:b.Al,height:b.zl}),l=new U({text:b.br[m],x:b.as[m].x,y:b.as[m].y,width:b.Al,height:b.zl}),w.h.push(y),w.h.push(l),Fa[m].h.push(w));s=new am({x:h,y:Y});for(w=0;w<b.uB;w++)D=w+m*b.uB,n=Qk(jj,b.mode,D+1),2!==D+1||n.Ik||(b.qv=b.Li[D-1].x,b.Jq=b.Li[D-1].y,B=!0),n.Ik&&1>n.Ne&&(b.fl=m,b.qv=b.Li[D].x,b.Jq=b.Li[D].y,-100>b.Jq&&(b.fl+=.2),B=!0),
t=b.Li[D].x,z=b.Li[D].y,b.ei.hc[D]&&void 0!==ja.buttons[b.ei.hc[D].C.mode].images&&(b.xl=ja.buttons[b.ei.hc[D].C.mode].images),A=D+1,b.pP?(b.Pq=!1,l=b.xl[n.Xf]):!n.Ik&&0<D?(l=b.xl[4],b.Pq=!0):(b.Pq=!1,l=b.xl[n.Xf]),b.Vn=l.width,b.$q=l.height,D+=1,b.Xe(s,b.oB,l,b.Pq,D,A,t,z,b.Vn,b.$q);b.IJ&&B&&(w=new Z({c:b.UA,x:b.qv-4,y:b.Jq-117}),s.h.push(w),B=!1);Fa[m].h.push(s);b.yf.push(Fa[m])}}}
a.K=function(){var b=this,c,d=0;en(this);switch(this.qB){case "grid":"horizontal"===this.ar?(this.iv&&this.MA&&(this.sB=new Z({c:this.Ev,x:this.Bl,y:this.Cl,width:this.Al,height:this.zl}),this.tB=new U({text:this.br[0],x:this.Bl,y:this.Cl,width:this.Al,height:this.zl,oD:this.br})),this.Zm=new Vm({y:0,Jb:2,ef:P(p.width),ye:25,Ge:4,axis:new k(1,0),Zx:this.sB,ce:this.tB})):"vertical"===this.ar&&(this.Zm=new Vm({y:0,Jb:2,ef:P(p.height),ye:25,Ge:4,axis:new k(0,1)}));for(c=0;c<this.yf.length;c++)this.Zm.addElement(this.yf[c]);
this.Zm.Cx(this.fl);this.g(this.Zm);break;case "manual":if("horizontal"===this.ar)for(this.Ah=new ln({y:0,Jb:1E4,ef:this.Zn,ye:25,Ge:4,axis:new k(1,0)}),c=this.yf.length-1;-1<c;c--)this.Ah.addElement(this.yf[c]);else if("vertical"===this.ar&&(this.Ah=new ln({y:0,Jb:1E4,ef:P(p.height),ye:25,Ge:4,axis:new k(0,-1)}),this.EJ))for(c=this.yf.length-1;-1<c;c--){var e=new mn({fw:function(c){var d=b.Bh;c*=b.bp;for(var e=0;e<c;e++)d+=1;0<b.ds&&d>b.ds&&(d=b.ds);b.Ah&&nn(b.Ah,d)}});d==this.bp&&(e.id=(c+1)/this.bp,
this.cd.push(e),this.yf[c].h.push(e),c===this.ei.rm.Ch.length+this.bp&&(d=new U({text:this.WG,s:this.VG,font:this.Dz,x:this.XG,y:this.YG}),this.yf[c].h.push(d)),d=0);d++;this.Ah.Sy(this.yf[c],c)}this.ds=this.yf.length;this.Ah.Cx(this.fl);nn(this.Ah,this.Bh);this.g(this.Ah)}c=new on({});this.wr=new $({c:this.ak,x:this.ck,y:this.dk,width:this.bk,height:this.$j,eb:P(30),m:function(){b.hw&&b.hw(b)}});this.wr.i(this.wr);c.g(this.wr);this.g(c);if(this.h)for(c=0;c<this.h.length;c+=1)this.g(this.h[c])};
a.oa=function(){this.ic();this.wr=this.tB=this.sB=this.Ah=this.Zm=this.oB=void 0};a.Wa=function(){cn(this);this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A))};a.wo=function(){cn(this)};
O.I.$E={backgroundImage:null,depth:-5,Uo:0,zq:M,Ju:Gd,Mu:P(0),Nu:P(0),Lu:P(480),Iu:P(480),tA:{k:pn,duration:.4,bj:1,wi:1.8,cj:1,xi:1.3,D:Ub,name:"frameScale"},MI:{k:Gl,duration:1,Ma:P(-1500),bb:P(0),D:Ub,da:1.2,name:"frameAppear"},xq:{k:Gl,duration:1,Ma:P(0),bb:P(-1500),D:Ub,da:1.2},jt:Cd,lt:P(0),mt:P(-61),kt:P(470),it:P(450),Ng:Jd,Og:P(0),Pg:P(138),Jh:P(96),Ih:P(96),Ul:{k:qn,duration:4,bj:1,wi:1.25,cj:1,xi:.9,da:1,name:"elastic"},Sl:{k:Hl,duration:.5,jc:P(0),cc:P(1),D:bc,da:1},Tl:{k:Jl,Te:P(1),vi:P(0),
duration:10,D:Ub,name:"hide"},Tu:"undefined"!==typeof $h?$h:void 0,zg:P(-320),uh:P(220),Uu:P(280),Su:P(160),zA:{k:Kl,duration:.4,pc:this.zg,Ma:this.uh,rd:P(-300),bb:P(230),jc:1,cc:.6},Gw:{k:Jl,duration:.2,Te:1,vi:0,name:"endBar"},m:null,Ud:null,mM:null,lM:null,Wl:null,th:null,Ku:null,LF:null,Hw:null,viewport:void 0,Mm:0,Nm:150,If:void 0,Hf:void 0,ql:!1,ti:!0,Bg:!1,Xa:"none",pl:!1,nc:!1,aC:null,h:[]};function Fj(b){this.name="AdDialogStage";this.q(O.I.$E);void 0!==b&&this.i(b)}gm(Fj,hm);a=Fj.prototype;
a.create=function(){um(Mj,this.Xa,this.Ei(),this.Fi(),this.Gi(),this.Di());Cm(this.Bo,this)};a.Bo=function(b){var c=b.viewport.clientWidth/R.Nk,d=b.Gi(),e=b.Di(),d=Math.round(d*c),e=Math.round(e*c),g=b.Ei(),h=b.Fi(),h=Math.round((h-R.jj)*c)+"px",c=Math.round((g-R.ij)*c)+"px";Dm(b.Xa,c,h,d,e)};a.Gi=function(){return this.If-P(32)-P(32)};a.Di=function(){return this.Hf-P(32)-P(156)};a.Ei=function(){return this.Nm+P(32)};a.Fi=function(){return this.Mm+P(32)};a.at=function(){this.Oa&&X(this.Oa,3)};
a.bt=function(){this.vc||(console.log("adDialogStage "+this.Xa),Fm(this.Xa))};a.ze=function(){this.Ca();this.vc?X(this.uc,2):this.w();this.Hh&&this.Hh(this.Uo)};a.Xv=function(){this.vc&&X(this.uc,2);this.Oa&&X(this.Oa,3)};a.rg=function(){this.Ca();this.vc?X(this.uc,2):this.w()};a.Sz=function(){};a.BC=function(b){void 0!==this.vb&&this.vb.zd(b,!1)};a.Jz=function(){void 0!==this.vb&&this.vb.zd(100,!0)};
a.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;if(Em(this.Xa)){void 0===this.If&&(this.If=R.we);void 0===this.Hf&&(this.Hf=R.yp);this.viewport=R.j;this.create();this.nc=Mj.nc;this.uc=new am({});if(this.nc)switch(this.Xa){case "admob":zm();break;case "chartboost":Am()}this.pl?(b=new cm({width:this.width,height:this.height}),this.g(b),this.uc=new am({y:P(0),x:P(0),ra:[this.MI,{k:"show",duration:99999999},{k:"show",duration:1},this.xq],ag:function(b,e){"frameAppear"===e.name&&Fm(c.Xa)},
Td:function(){c.w()}}),this.vc=new Z({c:this.Ju,x:this.Mu,y:this.Nu,width:this.Lu,height:this.Iu,Tb:!0,pb:1.8,Cb:1.3}),this.vc.i(this.Ku),this.uc.g(this.vc),b=new Z({c:this.jt,x:this.lt,y:this.mt,height:this.it,width:this.kt,pb:1.74,Cb:1}),this.uc.g(b),this.zb=new Z({c:this.Tu,x:this.zg,y:this.uh,width:this.Uu,height:this.Su,pb:.6,Cb:.6}),this.zb.i(this.th),this.uc.g(this.zb),b=new U({s:"is continuing in",x:P(-137),y:P(232),ya:this.zq,width:P(200),height:P(100)}),this.uc.g(b),this.vb=new bm({x:P(200),
y:P(230),width:P(400),ra:[{k:"show",duration:99999999},this.Gw],ag:function(b,e){"endBar"===e.name&&c.vb.w()}}),this.vb.i(this.Hw),this.uc.g(this.vb),this.Oa=new $({c:this.Ng,x:this.Og,y:this.Pg,width:this.Jh,height:this.Ih,ra:[this.Sl,this.Ul,{k:"show",duration:99999999},this.Tl],m:function(){c.ti=!0;c.nc||"none"!==c.Xa?c.nc&&"none"===c.Xa?(c.ze(),Fm(c.Xa)):c.Ud?c.Ud(c):c.at():c.Xv()},ag:function(b,e){"elastic"===e.name&&X(c.Oa,1);"hide"===e.name&&c.Oa.w()}}),this.g(this.uc)):(b=new cm({width:this.width,
height:this.height}),this.g(b));if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b]);sm(Mj)}else Mj.ze(),this.w()};a.oa=function(){this.ic();this.uc=this.vb=this.Zk=this.zb=this.vc=this.Oa=void 0};a.Wa=function(){this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A))};a.Dg=function(b,c){"Ad Failed"===b?(this.ti&&this.rg(),console.log(c.error)):"Ad Completed"===b?(this.ti&&this.ze(),console.log("Did Complete")):"Ad Reward"===b&&(console.log(c.Gp),this.Uo++,ba&&console.log("Did Reward"))};
a.Ab=function(b){Ej.Bb.Ab.call(this,b);!this.ql&&this.ti&&Em(this.Xa)&&(this.bt(),this.ql=this.Bg=!0);this.Bg&&void 0!==this.vb&&0<Mj.Bg(this.Xa,b)&&this.vb.zd(Mj.Bg(this.Xa,b),!1)};a.Ld=function(b,c,d){Ej.Bb.Ld.call(this,b,c,d);return!0};a.Cg=function(){ym()};
O.I.fh={backgroundImage:null,depth:-5,Uo:0,Ju:Gd,Mu:P(0),Nu:P(0),Lu:P(480),Iu:P(480),tA:{k:pn,duration:.6,bj:1,wi:1.8,cj:1,xi:1.3,D:Ub,name:"frameScale"},xq:{k:Gl,duration:1,Ma:P(-100),bb:P(-1500),D:Ub,da:1.2},jt:Cd,lt:P(0),mt:P(-50),kt:P(250),it:P(550),Ng:Jd,Og:P(0),Pg:P(80),Jh:P(154),Ih:P(152),Ul:{k:qn,duration:4,bj:1,wi:1.25,cj:1,xi:.9,da:1,name:"elastic"},Sl:{k:Hl,duration:.5,jc:P(0),cc:P(1),D:bc,da:1},Tl:{k:Jl,Te:P(1),vi:P(0),duration:10,D:Ub,name:"hide"},Tu:"undefined"!==typeof $h?$h:void 0,
zg:P(0),uh:P(-115),Uu:P(417),Su:P(219),zA:{k:Kl,duration:.6,pc:this.zg,Ma:this.uh,rd:P(-300),bb:P(230),jc:1,cc:.6},OI:"",NI:"Click To Play",QI:P(0),RI:P(195),zq:M,Gw:{k:Jl,duration:.2,Te:1,vi:0,name:"endBar"},m:null,Ud:null,mM:null,lM:null,Wl:null,th:null,Ku:null,LF:null,Hw:null,Fn:null,viewport:void 0,Qj:Fd,Bn:60,Ie:P(200),Mm:0,Nm:150,If:void 0,Hf:void 0,ql:!1,ti:!1,Bg:!1,Xa:"none",pl:!1,nc:!1,aC:null,h:[]};function Ej(b){this.name="AdDialog";this.q(O.I.fh);void 0!==b&&this.i(b)}gm(Ej,hm);a=Ej.prototype;
a.create=function(){um(Mj,this.Xa,this.Ei(),this.Fi(),this.Gi(),this.Di());Cm(this.Bo,this)};a.Bo=function(b){var c=b.viewport.clientWidth/R.Nk,d=b.Gi(),e=b.Di(),d=Math.round(d*c),e=Math.round(e*c),g=b.Ei(),h=b.Fi(),h=Math.round((h-R.jj)*c)+"px",c=Math.round((g-R.ij)*c)+"px";Dm(b.Xa,c,h,d,e)};a.Gi=function(){return this.If-P(32)-P(32)};a.Di=function(){return this.Hf-P(32)-P(156)};a.Ei=function(){return this.Nm+P(32)};a.Fi=function(){return this.Mm+P(32)};a.at=function(){this.Oa&&X(this.Oa,3)};
a.bt=function(){this.vc?(this.Zk.show(),X(this.vc,1),X(this.zb,1)):Fm(this.Xa)};a.ze=function(){this.Ca();this.vc?(X(this.vc,3),X(this.zb,3)):this.w();"none"!==this.Xa&&this.vb&&X(this.vb,1);this.Hh&&this.Hh(this.Uo);Mj.fv&&(this.Oa.w(),this.yq.w())};a.Xv=function(){this.vc&&(X(this.vc,3),X(this.zb,3));this.Oa&&X(this.Oa,3)};a.rg=function(){this.Ca();this.ql?(this.vc?(X(this.vc,3),X(this.zb,3)):this.w(),"none"!==this.Xa&&X(this.vb,1)):this.w()};
a.Sz=function(){var b=this,c=new U({s:"is loading now",x:P(-310),y:P(5),ya:this.zq,width:P(200),height:P(100)});this.vb=new bm({x:P(200),y:P(230),width:P(400),ra:[{k:"show",duration:99999999},this.Gw],ag:function(d,e){"endBar"===e.name&&(b.vb.w(),c.w())}});this.vb.i(this.Hw);this.vb.h.push(c);this.g(this.vb);"woobi"!==this.Xa&&(this.vb.Db(),this.vb.show())};a.BC=function(b){void 0!==this.vb&&this.vb.zd(b,!1)};a.Jz=function(){void 0!==this.vb&&this.vb.zd(100,!0)};
a.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;void 0===this.If&&(this.If=R.we);void 0===this.Hf&&(this.Hf=R.yp);this.viewport=R.j;this.create();this.nc=Mj.nc;this.Fn=new am({});if(this.nc)switch(this.Xa){case "admob":zm();break;case "chartboost":Am()}null!==this.Qj&&(b=function(b,e,g){b.x=c.Ie/2*Math.sin(2*Math.PI*g/c.Bn);b.y=c.Ie/2*-Math.cos(2*Math.PI*g/c.Bn)},this.Rj=new W({ra:{k:b,duration:9999999}}),this.Rj.Zv=function(){c.Qj.hu(0,-c.x-c.Ie/2,-c.y-c.Ie/2,p.width+c.Ie,p.height+
c.Ie,1)},this.g(this.Rj));this.pl?(this.vc=new Z({c:this.Ju,x:this.Mu,y:this.Nu,width:this.Lu,height:this.Iu,Tb:!0,ra:[{k:"show",duration:99999999},this.tA,{k:"show",duration:99999999},{k:"show",duration:1},this.xq],ag:function(b,e){"frameScale"===e.name&&Fm(c.Xa)},Td:function(){c.w()}}),this.vc.i(this.Ku),this.Zk=new Z({c:this.jt,x:this.lt,y:this.mt,height:this.it,width:this.kt,pb:1.74,Cb:1.37}),this.vc.h.push(this.Zk),this.Fn.g(this.vc),this.zb=new Z({c:this.Tu,x:this.zg,y:this.uh,width:this.Uu,
height:this.Su,ra:[{k:"show",duration:99999999},this.zA,{k:"show",duration:99999999},{k:"show",duration:1},this.xq]}),this.zb.i(this.th),this.Fn.g(this.zb),this.Oa=new $({c:this.Ng,x:this.Og,y:this.Pg,width:this.Jh,height:this.Ih,ra:[this.Sl,this.Ul,{k:"show",duration:99999999},this.Tl],m:function(){c.ti=!0;Mj.fv?c.ze():c.nc||"none"!==c.Xa?c.nc&&"none"===c.Xa?(c.ze(),Fm(c.Xa)):c.Ud?c.Ud(c):c.at():c.Xv()},ag:function(b,e){"elastic"===e.name&&X(c.Oa,1);"hide"===e.name&&(c.Oa.w(),c.yq.w())}}),this.Oa.i(this.Wl),
this.Fn.g(this.Oa),this.g(this.Fn),this.yq=new U({text:this.OI,x:this.QI,y:this.RI,s:this.NI,ya:this.zq}),this.g(this.yq)):(b=new cm({width:this.width,height:this.height}),this.g(b));if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.ic();this.Rj=this.vb=this.Zk=this.yq=this.zb=this.vc=this.Oa=void 0};a.Wa=function(){this.Zk&&this.Zk.w();this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A))};
a.Dg=function(b,c){"Ad Failed"===b?(this.rg(),console.log(c.error)):"Ad Completed"===b?(this.ti&&this.ze(),console.log("Did Complete")):"Ad Reward"===b&&(console.log(c.Gp),this.Uo++,ba&&console.log("Did Reward"))};a.Ab=function(b){Ej.Bb.Ab.call(this,b);!this.ql&&this.ti&&Em(this.Xa)&&(this.bt(),this.Sz(),this.ql=this.Bg=!0);this.Bg&&void 0!==this.vb&&0<Mj.Bg(this.Xa,b)&&this.vb.zd(Mj.Bg(this.Xa,b),!1)};a.Ld=function(b,c,d){Ej.Bb.Ld.call(this,b,c,d);return!0};a.Cg=function(){ym()};
O.W.cH={ZJ:"undefined"!==typeof gh?gh:null,RA:"undefined"!==typeof ih?ih:null,XJ:"undefined"!==typeof hh?hh:null,dI:"undefined"!==typeof jh?jh:null,eA:P(0),kx:!1,bA:1,wB:1,BD:0,position:[],id:0,gb:0,AD:!1,Pp:!1,jb:5E3,ii:null,xU:3E3,xg:1E3,h:[]};function kn(b){this.name="ComponentGate";this.q(O.W.cH);void 0!==b&&this.i(b);this.G=new fc(this)}V(kn,W);a=kn.prototype;a.ap=function(b){b===this.id&&(this.AD=!0);console.log("ID: "+b+"THIS ID: "+this.id)};
function bn(b,c){var d;c===b.id&&(b.G.Ve=[],b.G.sa=[],b.G.setTime(0),d=gc(b.G,"function",b,function(c){b.bA=c}),hc(b.G,d,[{time:0,value:1},{time:1E3,value:0}]),d=gc(b.G,"function",b,function(c){b.wB=c}),hc(b.G,d,[{time:1E3,value:1},{time:2E3,value:0}]),lc(b.G,b,1E3,b.LC),d=gc(b.G,"function",b,function(c){b.eA=Math.floor(c)}),hc(b.G,d,[{time:1E3,value:0},{time:2E3,value:6}]),d=gc(b.G,"function",b,function(c){b.BD=c}),hc(b.G,d,[{time:1500,value:0},{time:2200,value:1}]),lc(b.G,b,2200,b.LC))}
a.LC=function(){this.kx=this.kx?!1:!0};a.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};a.Hd=function(b){this.G.lg(b)};a.Id=function(){};a.He=function(){};a.Hj=function(){};a.qi=function(){};a.ri=function(){};a.si=function(){};a.ph=function(){};a.wg=function(){};a.qd=function(){};a.cf=function(){};
a.Ic=function(){this.Pp||(this.AD||(this.ZJ.Ha(0,this.position.x,this.position.y,1,1,0,this.wB),this.RA.Ha(0,this.position.x,this.position.y,1,1,0,this.BD),this.XJ.Ha(0,this.position.x,this.position.y,1,1,0,this.bA)),this.kx&&this.dI.Ha(this.eA,this.position.x,this.position.y,1,1,0,1));this.Pp&&this.RA.Ha(0,this.position.x,this.position.y,1,1,0,1)};a.Nf=function(){};
O.W.VO={re:null,Eg:null,lb:null,rb:0,fm:0,Ig:!1,Wo:!0,lh:!1,Tb:!1,xd:null,Wb:!0,gr:!0,h:[],id:0,ob:0,fj:.2,nh:!1,dU:!1,gp:!1,$d:void 0,yo:null};function rn(b){this.name="Star";this.q(O.W.VO);void 0!==b&&this.i(b)}V(rn,W);a=rn.prototype;a.ec=function(){return 0<this.width?this.width:this.re?this.lh?this.re.ni:this.re.width:0};a.dc=function(){return 0<this.height?this.height:this.re?this.lh?this.re.mi:this.re.height:0};a.K=function(){var b;for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};
a.Wa=function(){0===this.id&&(this.gp=!0);this.Da=this.fm;this.fj*=1E3};a.cf=function(b){0<this.fj&&this.gp?this.fj-=1E3*b/1E3:(1>this.fj&&(this.fj=0),null!==this.lb&&this.lb instanceof q&&!this.nh&&this.gp&&(b=this.Da+this.rb*b/1E3,this.Da<this.lb.Y&&b>=this.lb.Y?(this.Da=this.Ig?b-this.lb.Y:this.lb.Y,this.xd&&(this.xd(this,this.id),this.nh=!0)):0<this.Da&&0>b?(this.Da=this.Ig?this.lb.Y+b:0,this.xd&&(this.xd(this,this.id),this.nh=!0)):this.Da=b))};
a.Ic=function(){var b,c,d;null!==this.re&&(c=this.re.width,b=this.re.height,this.re.ma(0,-c/2+this.re.Qa,-b/2+this.re.Sa));this.id<this.ob&&0===this.fj&&(null===this.lb||this.nh||(c=this.lb.width,b=this.lb.height,c=-c/2,d=-b/2,b=this.Wo?this.Da:Math.min(this.c.Y-1,Math.floor(this.Da)),this.lb.ma(b,c+this.lb.Qa,d+this.lb.Sa)),null!==this.Eg&&(c=this.Eg.width,b=this.Eg.height,this.Eg.ma(0,-c/2+this.Eg.Qa,-b/2+this.Eg.Sa)))};
O.W.bH={c:"undefined"!==typeof Sg?Sg:null,backgroundImage:"undefined"!==typeof Tg?Tg:null,zc:[{x:100,y:-150},{x:50,y:-400},{x:70,y:-270},{x:200,y:-300},{x:300,y:-200},{x:300,y:-350},{x:450,y:-250},{x:530,y:-300},{x:600,y:-250},{x:700,y:-300},{x:800,y:-200},{x:950,y:-300},{x:1100,y:-150},{x:1100,y:-250}],id:0,gb:0,Rv:!1,jb:5E3,ii:null,fw:null,YA:!0,h:[]};
function mn(b){this.name="ComponentCloud";this.q(O.W.bH);void 0!==b&&this.i(b);b=new da;for(var c=0;c<this.zc.length;c++)this.zc[c].dt=0+b.random(6),this.zc[c].et=0+b.random(6)}V(mn,W);a=mn.prototype;a.ap=function(b){b===this.id&&(this.Rv=!0)};function dn(b,c){b.fw&&c===b.id&&(b.fw(b.id),b.YA=!1)}a.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};a.Wa=function(){};a.Mf=function(){};a.Hd=function(){};a.Id=function(){};a.He=function(){};a.Hj=function(){};
a.qi=function(){};a.ri=function(){};a.ph=function(){};a.wg=function(){};a.qd=function(b){this.Rv&&(this.gb+=b,this.y-=80/b,this.gb>this.jb&&(this.Rv=!1,dn(this,this.id)));if(0!==b)for(var c=0;c<this.zc.length;c++){var d=this.zc[c].dt,e=this.zc[c].et,d=d+.06/b,e=e+.0833/b;6.2831852<d&&(d%=6.2831852);6.2831852<e&&(e%=6.2831852);this.zc[c].dt=d;this.zc[c].et=e}};a.cf=function(){};
a.Ic=function(){if(this.YA){va(this.backgroundImage,0,-730,1,1,1);for(var b=0;b<this.zc.length;b++)this.c.Ha(0,this.zc[b].x+20*Math.sin(this.zc[b].dt),this.zc[b].y+5*Math.sin(this.zc[b].et),1,1,0,1)}};a.Nf=function(){};O.W.ZE={Qp:null,viewport:void 0,Mm:0,Nm:150,If:void 0,Hf:void 0,Xa:"google",m:null,aC:null,h:[]};function sn(b){this.name="Ad";this.q(O.W.ZE);void 0!==b&&this.i(b)}V(sn,W);a=sn.prototype;a.create=function(){um(Mj,this.Xa,this.Ei(),this.Fi(),this.Gi(),this.Di());Cm(this.Bo,this)};
a.Bo=function(b){var c=b.viewport.clientWidth/R.Nk,d=b.Gi(),e=b.Di(),d=Math.round(d*c),e=Math.round(e*c),g=b.Ei(),h=b.Fi(),h=Math.round((h-R.jj)*c)+"px",c=Math.round((g-R.ij)*c)+"px";Dm(b.Xa,c,h,d,e)};a.Gi=function(){return this.If-P(32)-P(32)};a.Di=function(){return this.Hf-P(32)-P(156)};a.Ei=function(){return this.Nm+P(32)};a.Fi=function(){return this.Mm+P(32)};
a.K=function(){var b;void 0===this.If&&(this.If=R.we);void 0===this.Hf&&(this.Hf=R.yp);this.viewport=R.j;this.create();if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.Hd=function(){if(this.fP&&-1<this.Ae&&!this.DD){this.Ae=1E3*this.JQ.QR();var b=Math.round((this.iF-this.Ae)/this.iF*100);null!==this.Qp&&this.Qp.BC(b);0>this.Ae&&(this.fP=!1)}else this.DD&&null!==this.Qp&&this.Qp.Jz()};O.W.kL={c:F,ef:500,ye:45,Jb:1,Ge:7,index:0};
function ln(b){this.q(O.W.kL);this.index=0;this.ef=500;this.elements=[];this.kd=-1;this.axis=new k(1,0);this.Ci=new k(0,0);this.speed=0;this.ye=45;this.Ge=7;this.Bh=-1;this.dm=this.u=0;this.Yl=null;this.OL=.1;this.isMap=!0;void 0!==b&&this.i(b)}V(ln,W);Math.round=Math.round;a=ln.prototype;a.addElement=function(b){this.g(b);this.elements.push(b);this.Sg(b,this.elements.length-1)};a.Sy=function(b,c){this.g(b);this.elements[c]=b;this.Sg(b,c)};
a.Sg=function(b,c){var d=this.axis.scale(this.ef*(c-this.u));b.x=Math.round(d.x);b.y=Math.round(d.y);this.Yl&&this.Yl(b)};a.Cx=function(b){this.u=Math.max(Math.min(this.elements.length-1,b),0);for(b=0;b<this.elements.length;++b)this.Sg(this.elements[b],b)};function nn(b,c){c&&(b.Bh=c)}
a.Hd=function(b){if(this.isMap){if(0!==Math.round(this.u)){this.elements[Math.round(this.u)].show();this.elements[Math.round(this.u)].Db();this.elements[Math.round(this.u)+1].show();this.elements[Math.round(this.u)+1].Db();this.elements[Math.round(this.u)-1].show();this.elements[Math.round(this.u)-1].Db();1<Math.round(this.u)&&this.elements[0].w();for(var c=Math.round(this.u)-2;0<c;c--)this.elements[c]&&this.elements[c].w();for(c=Math.round(this.u)+2;c<this.elements.length;c++)this.elements[c]&&this.elements[c].w()}else if(0>=
Math.round(this.u))for(this.elements[Math.round(this.u)].show(),this.elements[Math.round(this.u)].Db(),c=2;c<this.elements.length;c++)this.elements[c].w();c=this.u}if(0<=this.kd){var d=new k(u.Ec(this.kd)-this.Ci.x,u.sc(this.kd)-this.Ci.y),e=-1/this.ef;d.x*=e;d.y*=e;this.u=d.qn(this.axis)+this.dm;0>this.Bh?0>this.u?this.u=Math.atan(this.u*this.Jb)/this.Jb:this.u>this.elements.length-1&&(this.u=Math.atan(this.Jb*(this.u-this.elements.length+1))/this.Jb+this.elements.length-1):0>this.u?this.u=Math.atan(this.u*
this.Jb)/this.Jb:this.u>this.Bh-1&&(this.u=Math.atan(this.Jb*(this.u-this.Bh+1))/this.Jb+this.Bh-1);this.speed=Math.min(Math.max(1E3*(this.u-c)/b,-4),4)}else 0>this.u?(this.u=Math.atan(this.u*this.Jb)/this.Jb,d=Math.round(this.u),d=Math.max(0,Math.min(this.elements.length-1,d)),d-=this.u,d=d*this.ye-this.speed*this.Ge,this.speed+=b/1E3*d,this.u+=b/1E3*this.speed):this.u>this.elements.length-1&&(this.u=Math.atan(this.Jb*(this.u-this.elements.length+1))/this.Jb+this.elements.length-1,d=Math.round(this.u),
d=Math.max(0,Math.min(this.elements.length-1,d)),d-=this.u,d=d*this.ye-this.speed*this.Ge,this.speed+=b/1E3*d,this.u+=b/1E3*this.speed);if(c!==this.u)for(c=0;c<this.elements.length;++c)this.Sg(this.elements[c],c)};a.Id=function(b){if(-1===this.kd){this.kd=b;var c=this.Ci,d=u.sc(b);c.x=u.Ec(b);c.y=d;this.dm=this.u}};a.He=function(b){b===this.kd&&(this.kd=-1)};
a.Sf=function(b){if(!(2>this.elements.length))for(this.u+=b*this.OL,b=this.Bh,0>b&&(b=this.elements.length-1),0>this.u?(this.u=Math.atan(this.u*this.Jb)/this.Jb,b=Math.round(this.u),b=Math.max(0,Math.min(this.elements.length-1,b)),b-=this.u,b=b*this.ye-this.speed*this.Ge,this.speed+=2E-4*b,this.u+=2E-4*this.speed):this.u>b-1&&(this.u=Math.atan(this.Jb*(this.u-b+1))/this.Jb+b-1,b=Math.round(this.u),b=Math.max(0,Math.min(this.elements.length-1,b)),b-=this.u,b=b*this.ye-this.speed*this.Ge,this.speed+=
2E-4*b,this.u+=2E-4*this.speed),b=0;b<this.elements.length;++b)this.Sg(this.elements[b],b)};O.W.mI={F:!1,threshold:P(0),bs:0,cs:0,wD:P(3),vl:""};function $m(b){this.name="ExtButton";this.q(O.W.button);this.i(O.W.mI);this.Zh=new k(0,0);void 0!==b&&this.i(b)}V($m,$);a=$m.prototype;a.ac=function(b,c){"active"===b?this.m&&this.m(this):$m.Bb.ac.call(this,b,c)};
a.Id=function(b,c,d){this.bs=this.Ec(b);this.cs=this.sc(b);this.threshold=void 0===this.threshold?0:this.threshold;if(!this.mg)return this.Ij(b,c,d)};a.He=function(b,c,d){this.cs=this.bs=0;if(!this.mg)return this.Jj(b,c,d)};a.Ij=function(b,c,d){var e=this.Ka.width+2*this.eb,g=this.Ka.height+2*this.eb;if(c>=-e/2&&c<=e/2&&d>=-g/2&&d<=g/2&&("up"===this.state||"active"===this.state?(this.ac("down",!0),this.ua=b,this.Zh=this.bq(c,d)):this.ua=b,this.tc))return!0};
a.Jj=function(b){this.ua===b&&(this.ua=-1,this.ac("active"),this.F=!0,this.kb=this.wD,this.De())};a.K=function(){$m.Bb.K.call(this);""!==this.vl&&yk.Ee===this.vl&&(this.F=!0,this.ac("down",!1),this.kb=this.wD,this.De())};a.qd=function(b){var c,d;-1!==this.ua&&(c=this.Ec(this.ua),d=this.sc(this.ua),c>this.bs+this.threshold||c<this.bs-this.threshold||d<this.cs-this.threshold||d>this.cs+this.threshold?("down"===this.state&&this.ac("up",!1),this.ua=-1):$m.Bb.qd.call(this,b))};
function qn(b,c,d){var e=ec([dc,function(b,c,d,e){return bc(b,c,d,e,3,2)},Tb],[!0,!1,!1],[.02,.1,.88]),g=void 0===c.da?void 0:c.da,e=void 0===c.Nj?e:c.Nj,g=void 0===c.un?g:c.un,h=void 0===c.bj?1:c.bj,l=void 0===c.cj?1:c.cj,m=void 0===c.xi?1:c.xi;b.pb=e(d,h,(void 0===c.wi?1:c.wi)-h,c.duration,g);b.Cb=e(d,l,m-l,c.duration,g)}
function pn(b,c,d){var e=void 0===c.D?Ub:c.D,g=void 0===c.da?void 0:c.da,e=void 0===c.Nj?e:c.Nj,g=void 0===c.un?g:c.un,h=void 0===c.bj?1:c.bj,l=void 0===c.cj?1:c.cj,m=void 0===c.xi?1:c.xi;b.pb=e(d,h,(void 0===c.wi?1:c.wi)-h,c.duration,g);b.Cb=e(d,l,m-l,c.duration,g)}O.W.JH={id:0,il:[],h:[]};function jn(b){this.name="Decalls";this.q(O.W.JH);void 0!==b&&this.i(b);this.lD=!1}V(jn,W);a=jn.prototype;a.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){};
a.Wa=function(){this.lD=!0};a.Mf=function(){};a.Hd=function(){};a.qd=function(){};a.cf=function(){};a.Ic=function(){if(this.lD)for(var b=0;b<this.il.length;b++)"background"!==this.il[b].id&&this.il[b].c.Ha(0,this.il[b].x,this.il[b].y,1,1,0,1)};a.Nf=function(){};function tn(b,c,d,e,g,h){W.call(this,b);this.width=e;this.height=g;this.Ea=2;this.alpha=1;this.text="";this.font=h?h:fonts.xa.yR;this.J=new wa(e+2*this.Ea,g+2*this.Ea);un(this,"LOREM IPSUM")}V(tn,W);
function un(b,c){if(b.text!==c){b.text=c;b.J.clear();xa(b.J);var d=1,e=b.font.Fk(b.text)+(b.font.stroke?b.font.ig:0),g=b.font.wf(b.text)+(b.font.stroke?b.font.ig:0),h=b.font.fontSize;e>b.width&&(d=b.width/e);g>b.height&&(d=Math.min(d,b.height/g));Da(b.font,Math.floor(h*d));switch(b.font.align){case "left":b.font.ma(b.text,b.Ea,b.J.height/2+.085*b.J.height);break;case "center":b.font.ma(b.text,b.J.width/2,b.J.height/2+.085*b.J.height);break;case "right":b.font.ma(b.text,b.J.width-b.Ea,b.J.height/2+
.085*b.J.height)}Da(b.font,h);ya(b.J)}}tn.prototype.du=function(){wl.wR&&oa(this.x,this.y,this.width,this.height,"red",!0);1!==this.alpha&&(p.context.save(),p.context.globalAlpha*=this.alpha);this.J.ma(this.x-this.Ea,this.y-this.Ea);1!==this.alpha&&p.context.restore()};function vn(b,c,d,e,g,h,l,m,n){tn.call(this,null,0,0,d,e,g);this.canvas=n;this.depth=h?h:-900;this.d=l?l:-901;this.visible=this.ba=!0;this.ab=m;Ib(this)}V(vn,tn);vn.prototype.Uc=function(){this.du()};
function wn(b,c,d,e,g,h,l,m,n,s,w,y){void 0===e&&(e=0);void 0===g&&(g=Fi);g=g.cl();void 0!==l&&g.setFillColor(l);void 0!==m&&g.setStrokeColor(m);void 0!==h&&Da(g,g.fontSize*h);Ka(g,"middle");vn.call(this,0,0,g.Fk(b)+(g.stroke?g.ig:0),g.wf(b)+50+(g.stroke?g.ig:0),g,n,s,w,y);this.jb=0;this.duration=2200;this.cI=ec([Tb,Tb,Xb],[!1,!1,!1],[.2,0,1.3]);this.ju=ec([Tb,Tb,Yb],[!1,!1,!1],[.2,.4,.9]);this.Nj=ec([dc,Tb,Tb],[!1,!1,!1],[.2,.4,.9]);this.x=c;this.y=d;this.jb=-e;un(this,b);this.uA=d;this.FP=d-P(50);
this.ba=!0;this.scale=0;this.alpha=1}V(wn,vn);wn.prototype.ne=function(b){this.jb+=b;0<this.jb&&(this.jb>=this.duration?Sb(this):(this.y=this.cI(this.jb,this.uA,this.FP-this.uA,this.duration),this.alpha=this.ju(this.jb,1,-1,this.duration),this.scale=this.Nj(this.jb,0,1,this.duration)))};wn.prototype.du=function(){0<this.jb&&this.J.Ha(this.x-this.J.width/2*this.scale,this.y-this.J.height/2*this.scale,this.scale,this.scale,0,this.alpha)};wn.prototype.kf=function(){this.ab&&this.ab()};
O.W.GM={eT:void 0,h:[]};function xn(b,c,d){this.c=b;this.zc=c;this.ps=d;this.Fj;this.direction=.1;this.name="Pathfinding";this.q(O.W.GM);this.G=new fc(this);this.Zy=0;this.Fj=c[0];yn(this)}V(xn,W);
function yn(b){var c;b.G.Ve=[];b.G.sa=[];c=gc(b.G,"function",b,function(c){var e=Math.floor(c),g=Math.ceil(c);c-=e;var h=.5*(this.zc[e].x+this.zc[g].x),l=.5*(this.zc[e].y+this.zc[g].y),l=l+b.ps[e],e=this.zc[e],g=this.zc[g],g={x:Math.pow(1-c,2)*e.x+2*(1-c)*c*h+Math.pow(c,2)*g.x,y:Math.pow(1-c,2)*e.y+2*(1-c)*c*l+Math.pow(c,2)*g.y};c=Math.atan2(-(g.x-b.Fj.x),g.y-b.Fj.y);0>c&&(c+=2*Math.PI);b.Zy=Math.round(c/(2*Math.PI)*8);b.Fj=g});hc(b.G,c,[{time:0,value:0},{time:1500*Math.abs(19),value:19}])}
xn.prototype.ne=function(b){this.G.lg(b)};xn.prototype.Uc=function(){this.Fj&&this.c.Ha(this.Zy,this.Fj.x,this.Fj.y,1,1,0,1)};xn.prototype.K=function(){var b;if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};var Q=Q||{};Q["nl-nl"]=Q["nl-nl"]||{};Q["nl-nl"].optionsAbout_header_publisher="Published by:";Q["nl-nl"].challengeForfeitMessage_winnings="<NAME> heeft <AMOUNT> Fairplay munten gewonnen!";Q["nl-nl"].challengeEndScreenChallengeSend_submessage_stranger="Als niemand binnen 72 uur je uitdaging accepteert, worden je inzet en uitdagingskosten teruggestort.";
Q["nl-nl"].challengeEndScreenChallengeSend_submessage="<NAME> heeft 72 uur om de uitdaging aan te nemen of te weigeren. Als <NAME> je uitdaging weigert of niet accepteert binnen 72 uur worden je inzet en uitdagingskosten teruggestort.";Q["nl-nl"].levelEndScreenHighScore_number="Topscore:";Q["nl-nl"].levelEndScreenTotalScore_number="Totale score:";Q["nl-nl"].optionsExit="Stoppen";Q["nl-nl"]["optionsLang_ru-ru"]="Russisch";Q["nl-nl"]["optionsLang_pt-br"]="Braziliaans-Portugees";
Q["nl-nl"]["optionsLang_es-es"]="Spaans";Q["nl-nl"]["optionsLang_ar-eg"]="Arabisch";Q["nl-nl"]["optionsLang_ko-kr"]="Koreaans";Q["nl-nl"]["optionsLang_fr-fr"]="Frans";Q["nl-nl"].levelEndScreenTotalScore_time="Totale tijd:";Q["nl-nl"].levelEndScreenHighScore_time="Beste tijd:";Q["nl-nl"].challengeLoadingError_notStarted="Kan de server niet bereiken. Probeer het later nog een keer.";Q["nl-nl"].challengeLoadingError_notValid="Sorry, deze uitdaging kan niet meer gespeeld worden.";
Q["nl-nl"].optionsChallengeCancel="Stop";Q["nl-nl"].optionsChallengeForfeit="Geef op";Q["nl-nl"].challengeForfeitMessage_error="Er is een fout opgetreden tijdens het opgeven van de uitdaging. Probeer het later nog een keer.";Q["nl-nl"].challengeForfeitMessage_success="Je hebt de uitdaging opgegeven.";Q["nl-nl"].challengeForfeitConfirmBtn_no="Nee";Q["nl-nl"].challengeForfeitConfirmBtn_yes="Ja";Q["nl-nl"].challengeForfeitConfirmText="Je staat op het punt de uitdaging op te geven. Weet je zeker dat je dit wilt doen?";
Q["nl-nl"].challengeStartTextScore_challenger="Speel het spel en zet een score neer.";Q["nl-nl"].challengeStartTextTime_challenger="Speel het spel en zet een tijd neer.";Q["nl-nl"].challengeStartScreenTitle_challenger_stranger="Je zet een uitdaging voor:";Q["nl-nl"].challengeStartScreenTitle_challenger_friend="Jouw tegenstander:";Q["nl-nl"].challengeStartScreenTitle_challengee_stranger="Jouw tegenstander:";Q["nl-nl"].challengeEndScreenScoreSend_error="Er is een fout opgetreden tijdens de communicatie met de server. Probeer het later nog een keer.";
Q["nl-nl"].challengeCancelMessage_success="De uitdaging is geannuleerd.";Q["nl-nl"].challengeCancelMessage_error="Er is een fout opgetreden bij het annuleren van de uitdaging. Probeer het later nog een keer.";Q["nl-nl"].challengeEndScreenChallengeSend_success="Je uitdaging is verstuurd!";Q["nl-nl"].challengeEndScreenChallengeSend_error="Er is een fout opgetreden bij het versturen van de uitdaging. Probeer het later nog een keer.";Q["nl-nl"].challengeEndScreenName_you="Jij";
Q["nl-nl"].challengeEndScreenBtn_cancel="Annuleer uitdaging";Q["nl-nl"].challengeEndScreensBtn_submit="Verstuur uitdaging";Q["nl-nl"].challengeCancelConfirmBtn_no="Nee";Q["nl-nl"].challengeCancelConfirmBtn_yes="Ja";Q["nl-nl"].challengeCancelConfirmText="Je staat op het punt de uitdaging te annuleren. Je inzet wordt teruggestort minus de uitdagingskosten. Weet je zeker dat je de uitdaging wilt annuleren? ";Q["nl-nl"].challengeEndScreenOutcomeMessage_TIED="Jullie hebben gelijk gespeeld.";
Q["nl-nl"].challengeEndScreenOutcomeMessage_LOST="Je hebt de uitdaging verloren.";Q["nl-nl"].challengeEndScreenOutcomeMessage_WON="Je hebt de uitdaging gewonnen!";Q["nl-nl"].challengeEndScreenWinnings="Je hebt <AMOUNT> Fairplay munten gewonnen!";Q["nl-nl"].challengeStartScreenToWin="Te winnen aantal Fairplay munten:";Q["nl-nl"].challengeStartTextTime="Tijd van <NAME>:";Q["nl-nl"].challengeStartTextScore="Punten van <NAME>:";Q["nl-nl"].challengeStartScreenTitle_challengee_friend="Je bent uitgedaagd door:";
Q["nl-nl"].levelEndScreenSubmitHighscoreBtn="Score verzenden";Q["nl-nl"].levelEndScreenViewHighscoreBtn="Scores bekijken";Q["nl-nl"].optionsAbout_header="Ontwikkeld door:";Q["nl-nl"]["optionsLang_tr-tr"]="Turks";Q["nl-nl"]["optionsLang_de-de"]="Duits";Q["nl-nl"].startScreenByTinglyGames="door: CoolGames";Q["nl-nl"].levelMapScreenWorld_0="Kies een level";Q["nl-nl"].startScreenQuestionaire="Wat vind jij?";Q["nl-nl"].levelEndScreenMedal="VERBETERD!";Q["nl-nl"].optionsAbout="Over ons";
Q["nl-nl"].optionsAbout_version="versie:";Q["nl-nl"].optionsAbout_backBtn="Terug";Q["nl-nl"].optionsAbout_text="CoolGames\nwww.coolgames.com\nCopyright \u00a9 2016";Q["nl-nl"].optionsAbout_title="Over ons";Q["nl-nl"].optionsSFXBig_off="Geluid uit";Q["nl-nl"].optionsSFXBig_on="Geluid aan";Q["nl-nl"].optionsRestart="Herstart";Q["nl-nl"].optionsRestartConfirmationText="Pas op!\n\nAls je nu herstart verlies je alle voortgang in dit level. Weet je zeker dat je wilt herstarten?";
Q["nl-nl"].levelMapScreenTitle="Kies een level";Q["nl-nl"].optionsQuitConfirmBtn_Yes="Ja, ik weet het zeker";Q["nl-nl"].optionsQuitConfirmBtn_No="Nee";Q["nl-nl"].optionsQuitConfirmationText="Pas op!\n\nAls je nu stopt verlies je alle voortgang in dit level. Weet je zeker dat je wilt stoppen?";Q["nl-nl"].optionsTitle="Instellingen";Q["nl-nl"].gameEndScreenBtnText="Ga verder";Q["nl-nl"].gameEndScreenTitle="Gefeliciteerd!\nJe hebt gewonnen.";Q["nl-nl"]["optionsLang_nl-nl"]="Nederlands";
Q["nl-nl"]["optionsLang_en-gb"]="Engels (GB)";Q["nl-nl"]["optionsLang_en-us"]="Engels (US)";Q["nl-nl"].optionsSFX_off="Uit";Q["nl-nl"].optionsSFX_on="Aan";Q["nl-nl"].optionsMusic_off="Uit";Q["nl-nl"].optionsMusic_on="Aan";Q["nl-nl"].optionsDifficulty_hard="Moeilijk";Q["nl-nl"].optionsDifficulty_medium="Gemiddeld";Q["nl-nl"].optionsDifficulty_easy="Makkelijk";Q["nl-nl"].optionsMoreGames="Meer Spellen";Q["nl-nl"].optionsHighScore="High scores";Q["nl-nl"].optionsTutorial="Speluitleg";
Q["nl-nl"].optionsResume="Terug naar spel";Q["nl-nl"].optionsQuit="Stop";Q["nl-nl"].optionsStartScreen="Hoofdmenu";Q["nl-nl"].levelEndScreenHighScore="High score";Q["nl-nl"].levelEndScreenTimeBonus="Tijdbonus";Q["nl-nl"].levelEndScreenTimeLeft="Tijd over";Q["nl-nl"].levelEndScreenSubTitle_levelFailed="Level niet gehaald";Q["nl-nl"].levelEndScreenTotalScore="Totale score";Q["nl-nl"].levelEndScreenTitle_endless="Level <VALUE>";Q["nl-nl"].levelEndScreenTitle_difficulty="Goed Gedaan!";
Q["nl-nl"].levelEndScreenTitle_level="Level <VALUE>";Q["nl-nl"].levelMapScreenTotalScore="Totale score";Q["nl-nl"].startScreenPlay="SPELEN";Q["nl-nl"].loadingScreenLoading="Laden...";Q["nl-nl"].RewardAd_button="video";Q["nl-nl"].RewardAd_header="coins";Q["nl-nl"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["nl-nl"].RewardAd_text_2="new video is available soon";Q["en-us"]=Q["en-us"]||{};Q["en-us"].optionsAbout_header_publisher="Published by:";
Q["en-us"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["en-us"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["en-us"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["en-us"].levelEndScreenHighScore_number="High score:";Q["en-us"].levelEndScreenTotalScore_number="Total score:";Q["en-us"].optionsExit="Exit";Q["en-us"]["optionsLang_ru-ru"]="Russian";Q["en-us"]["optionsLang_pt-br"]="Brazilian-Portuguese";Q["en-us"]["optionsLang_es-es"]="Spanish";Q["en-us"]["optionsLang_ar-eg"]="Arabic";Q["en-us"]["optionsLang_ko-kr"]="Korean";Q["en-us"]["optionsLang_fr-fr"]="French";Q["en-us"].levelEndScreenTotalScore_time="Total time:";
Q["en-us"].levelEndScreenHighScore_time="Best time:";Q["en-us"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Q["en-us"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["en-us"].optionsChallengeCancel="Quit";Q["en-us"].optionsChallengeForfeit="Forfeit";Q["en-us"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Q["en-us"].challengeForfeitMessage_success="You have forfeited the challenge.";
Q["en-us"].challengeForfeitConfirmBtn_no="No";Q["en-us"].challengeForfeitConfirmBtn_yes="Yes";Q["en-us"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["en-us"].challengeStartTextScore_challenger="Play the game and set a score.";Q["en-us"].challengeStartTextTime_challenger="Play the game and set a time.";Q["en-us"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Q["en-us"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["en-us"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["en-us"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["en-us"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["en-us"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["en-us"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["en-us"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["en-us"].challengeEndScreenName_you="You";Q["en-us"].challengeEndScreenBtn_cancel="Cancel challenge";Q["en-us"].challengeEndScreensBtn_submit="Submit challenge";Q["en-us"].challengeCancelConfirmBtn_no="No";Q["en-us"].challengeCancelConfirmBtn_yes="Yes";Q["en-us"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["en-us"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["en-us"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["en-us"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["en-us"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["en-us"].challengeStartScreenToWin="Amount to win:";Q["en-us"].challengeStartTextTime="<NAME>'s time:";Q["en-us"].challengeStartTextScore="<NAME>'s score:";
Q["en-us"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["en-us"].levelEndScreenSubmitHighscoreBtn="Submit score";Q["en-us"].levelEndScreenViewHighscoreBtn="View scores";Q["en-us"].optionsAbout_header="Developed by:";Q["en-us"]["optionsLang_tr-tr"]="Turkish";Q["en-us"]["optionsLang_de-de"]="German";Q["en-us"].startScreenByTinglyGames="by: CoolGames";Q["en-us"].levelMapScreenWorld_0="Select a level";Q["en-us"].startScreenQuestionaire="What do you think?";
Q["en-us"].levelEndScreenMedal="IMPROVED!";Q["en-us"].optionsAbout="About";Q["en-us"].optionsAbout_version="version:";Q["en-us"].optionsAbout_backBtn="Back";Q["en-us"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["en-us"].optionsAbout_title="About";Q["en-us"].optionsSFXBig_off="Sound off";Q["en-us"].optionsSFXBig_on="Sound on";Q["en-us"].optionsRestart="Restart";Q["en-us"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";
Q["en-us"].levelMapScreenTitle="Select a level";Q["en-us"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Q["en-us"].optionsQuitConfirmBtn_No="No";Q["en-us"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Q["en-us"].optionsTitle="Settings";Q["en-us"].gameEndScreenBtnText="Continue";Q["en-us"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Q["en-us"]["optionsLang_nl-nl"]="Dutch";
Q["en-us"]["optionsLang_en-gb"]="English (GB)";Q["en-us"]["optionsLang_en-us"]="English (US)";Q["en-us"].optionsSFX_off="Off";Q["en-us"].optionsSFX_on="On";Q["en-us"].optionsMusic_off="Off";Q["en-us"].optionsMusic_on="On";Q["en-us"].optionsDifficulty_hard="Difficult";Q["en-us"].optionsDifficulty_medium="Medium";Q["en-us"].optionsDifficulty_easy="Easy";Q["en-us"].optionsMoreGames="More Games";Q["en-us"].optionsHighScore="High scores";Q["en-us"].optionsTutorial="How to play";
Q["en-us"].optionsResume="Resume";Q["en-us"].optionsQuit="Quit";Q["en-us"].optionsStartScreen="Main menu";Q["en-us"].levelEndScreenHighScore="High score";Q["en-us"].levelEndScreenTimeBonus="Time bonus";Q["en-us"].levelEndScreenTimeLeft="Time remaining";Q["en-us"].levelEndScreenSubTitle_levelFailed="Level failed";Q["en-us"].levelEndScreenTotalScore="Total score";Q["en-us"].levelEndScreenTitle_endless="Stage <VALUE>";Q["en-us"].levelEndScreenTitle_difficulty="Well done!";
Q["en-us"].levelEndScreenTitle_level="Level <VALUE>";Q["en-us"].levelMapScreenTotalScore="Total score";Q["en-us"].startScreenPlay="PLAY";Q["en-us"].loadingScreenLoading="Loading...";Q["en-us"].RewardAd_button="video";Q["en-us"].RewardAd_header="coins";Q["en-us"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["en-us"].RewardAd_text_2="new video is available soon";Q["en-gb"]=Q["en-gb"]||{};Q["en-gb"].optionsAbout_header_publisher="Published by:";
Q["en-gb"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["en-gb"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["en-gb"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["en-gb"].levelEndScreenHighScore_number="High score:";Q["en-gb"].levelEndScreenTotalScore_number="Total score:";Q["en-gb"].optionsExit="Exit";Q["en-gb"]["optionsLang_ru-ru"]="Russian";Q["en-gb"]["optionsLang_pt-br"]="Brazilian-Portuguese";Q["en-gb"]["optionsLang_es-es"]="Spanish";Q["en-gb"]["optionsLang_ar-eg"]="Arabic";Q["en-gb"]["optionsLang_ko-kr"]="Korean";Q["en-gb"]["optionsLang_fr-fr"]="French";Q["en-gb"].levelEndScreenTotalScore_time="Total time:";
Q["en-gb"].levelEndScreenHighScore_time="Best time:";Q["en-gb"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Q["en-gb"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["en-gb"].optionsChallengeCancel="Quit";Q["en-gb"].optionsChallengeForfeit="Forfeit";Q["en-gb"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Q["en-gb"].challengeForfeitMessage_success="You have forfeited the challenge.";
Q["en-gb"].challengeForfeitConfirmBtn_no="No";Q["en-gb"].challengeForfeitConfirmBtn_yes="Yes";Q["en-gb"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you wish to proceed?";Q["en-gb"].challengeStartTextScore_challenger="Play the game and set a score.";Q["en-gb"].challengeStartTextTime_challenger="Play the game and set a time.";Q["en-gb"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Q["en-gb"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["en-gb"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["en-gb"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["en-gb"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["en-gb"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["en-gb"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["en-gb"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["en-gb"].challengeEndScreenName_you="You";Q["en-gb"].challengeEndScreenBtn_cancel="Cancel challenge";Q["en-gb"].challengeEndScreensBtn_submit="Submit challenge";Q["en-gb"].challengeCancelConfirmBtn_no="No";Q["en-gb"].challengeCancelConfirmBtn_yes="Yes";Q["en-gb"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["en-gb"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["en-gb"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["en-gb"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["en-gb"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["en-gb"].challengeStartScreenToWin="Amount to win:";Q["en-gb"].challengeStartTextTime="<NAME>'s time:";Q["en-gb"].challengeStartTextScore="<NAME>'s score:";
Q["en-gb"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["en-gb"].levelEndScreenSubmitHighscoreBtn="Submit score";Q["en-gb"].levelEndScreenViewHighscoreBtn="View scores";Q["en-gb"].optionsAbout_header="Developed by:";Q["en-gb"]["optionsLang_tr-tr"]="Turkish";Q["en-gb"]["optionsLang_de-de"]="German";Q["en-gb"].startScreenByTinglyGames="by: CoolGames";Q["en-gb"].levelMapScreenWorld_0="Select a level";Q["en-gb"].startScreenQuestionaire="What do you think?";
Q["en-gb"].levelEndScreenMedal="IMPROVED!";Q["en-gb"].optionsAbout="About";Q["en-gb"].optionsAbout_version="version:";Q["en-gb"].optionsAbout_backBtn="Back";Q["en-gb"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["en-gb"].optionsAbout_title="About";Q["en-gb"].optionsSFXBig_off="Sound off";Q["en-gb"].optionsSFXBig_on="Sound on";Q["en-gb"].optionsRestart="Restart";Q["en-gb"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";
Q["en-gb"].levelMapScreenTitle="Select a level";Q["en-gb"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Q["en-gb"].optionsQuitConfirmBtn_No="No";Q["en-gb"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Q["en-gb"].optionsTitle="Settings";Q["en-gb"].gameEndScreenBtnText="Continue";Q["en-gb"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Q["en-gb"]["optionsLang_nl-nl"]="Dutch";
Q["en-gb"]["optionsLang_en-gb"]="English (GB)";Q["en-gb"]["optionsLang_en-us"]="English (US)";Q["en-gb"].optionsSFX_off="Off";Q["en-gb"].optionsSFX_on="On";Q["en-gb"].optionsMusic_off="Off";Q["en-gb"].optionsMusic_on="On";Q["en-gb"].optionsDifficulty_hard="Difficult";Q["en-gb"].optionsDifficulty_medium="Medium";Q["en-gb"].optionsDifficulty_easy="Easy";Q["en-gb"].optionsMoreGames="More Games";Q["en-gb"].optionsHighScore="High scores";Q["en-gb"].optionsTutorial="How to play";
Q["en-gb"].optionsResume="Resume";Q["en-gb"].optionsQuit="Quit";Q["en-gb"].optionsStartScreen="Main menu";Q["en-gb"].levelEndScreenHighScore="High score";Q["en-gb"].levelEndScreenTimeBonus="Time bonus";Q["en-gb"].levelEndScreenTimeLeft="Time remaining";Q["en-gb"].levelEndScreenSubTitle_levelFailed="Level failed";Q["en-gb"].levelEndScreenTotalScore="Total score";Q["en-gb"].levelEndScreenTitle_endless="Stage <VALUE>";Q["en-gb"].levelEndScreenTitle_difficulty="Well done!";
Q["en-gb"].levelEndScreenTitle_level="Level <VALUE>";Q["en-gb"].levelMapScreenTotalScore="Total score";Q["en-gb"].startScreenPlay="PLAY";Q["en-gb"].loadingScreenLoading="Loading...";Q["en-gb"].RewardAd_button="video";Q["en-gb"].RewardAd_header="coins";Q["en-gb"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["en-gb"].RewardAd_text_2="new video is available soon";Q["de-de"]=Q["de-de"]||{};Q["de-de"].optionsAbout_header_publisher="Published by:";
Q["de-de"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["de-de"].challengeEndScreenChallengeSend_submessage_stranger="Als niemanden Deine Herausforderung innerhalb von 72 Stunden annimmt, werden Dir Deinen Wetteinsatz Einsatzgeb\u00fchr zur\u00fcckerstattet.";Q["de-de"].challengeEndScreenChallengeSend_submessage="<NAME> hat 72 Stunden um die Wette anzunehmen oder abzulehnen. Sollte <NAME> nicht reagieren oder ablehnen werden Dir Dein Wetteinsatz und die Geb\u00fchr zur\u00fcckerstattet.";
Q["de-de"].levelEndScreenHighScore_number="Highscore:";Q["de-de"].levelEndScreenTotalScore_number="Gesamtpunktzahl:";Q["de-de"].optionsExit="Verlassen";Q["de-de"]["optionsLang_ru-ru"]="Russisch";Q["de-de"]["optionsLang_pt-br"]="Portugiesisch (Brasilien)";Q["de-de"]["optionsLang_es-es"]="Spanisch";Q["de-de"]["optionsLang_ar-eg"]="Arabisch";Q["de-de"]["optionsLang_ko-kr"]="Koreanisch";Q["de-de"]["optionsLang_fr-fr"]="Franz\u00f6sisch";Q["de-de"].levelEndScreenTotalScore_time="Gesamtzeit:";
Q["de-de"].levelEndScreenHighScore_time="Bestzeit:";Q["de-de"].challengeLoadingError_notStarted="Leider ist ein Fehler\u00a0aufgetreten. Es konnte keiner Verbindung zum Server hergestellt werden. Versuche es bitte nochmal sp\u00e4ter.";Q["de-de"].challengeLoadingError_notValid="Leider ist diese Partie nicht mehr aktuel.";Q["de-de"].optionsChallengeCancel="Zur\u00fcckziehen";Q["de-de"].optionsChallengeForfeit="Aufgeben";Q["de-de"].challengeForfeitMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Q["de-de"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["de-de"].challengeForfeitConfirmBtn_no="Nein";Q["de-de"].challengeForfeitConfirmBtn_yes="Ja";Q["de-de"].challengeForfeitConfirmText="Willst du Die Partie wirklich aufgeben?";Q["de-de"].challengeStartTextScore_challenger="Spiel um die hochste Punktzahl!";Q["de-de"].challengeStartTextTime_challenger="Spiel um die niedrigste Zeit!";Q["de-de"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Q["de-de"].challengeStartScreenTitle_challenger_friend="Du hast den folgenden Spieler herausgefordert:";Q["de-de"].challengeStartScreenTitle_challengee_stranger="Dein Gegner wird:";Q["de-de"].challengeEndScreenScoreSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Q["de-de"].challengeCancelMessage_success="Du hast die Wette erfolgreich zur\u00fcckgezogen.";Q["de-de"].challengeCancelMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Q["de-de"].challengeEndScreenChallengeSend_success="Herausforderung verschickt!";Q["de-de"].challengeEndScreenChallengeSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Q["de-de"].challengeEndScreenName_you="Du";Q["de-de"].challengeEndScreenBtn_cancel="Zur\u00fcckziehen";Q["de-de"].challengeEndScreensBtn_submit="Herausfordern";Q["de-de"].challengeCancelConfirmBtn_no="Nein";Q["de-de"].challengeCancelConfirmBtn_yes="Ja";Q["de-de"].challengeCancelConfirmText="Willst Du Deine Wette wirklich zur\u00fcckziehen? Dein Wetteinsatz wird Dir zur\u00fcckgegeben minus die Einsatzgeb\u00fchr.";
Q["de-de"].challengeEndScreenOutcomeMessage_TIED="Gleichstand!";Q["de-de"].challengeEndScreenOutcomeMessage_LOST="Leider hat Dein Gegner die Partie gewonnen.";Q["de-de"].challengeEndScreenOutcomeMessage_WON="Du hast die Partie gewonnen!";Q["de-de"].challengeEndScreenWinnings="Du hast <AMOUNT> Fairm\u00fcnzen gewonnen!";Q["de-de"].challengeStartScreenToWin="Einsatz:";Q["de-de"].challengeStartTextTime="Zeit von <NAME>:";Q["de-de"].challengeStartTextScore="Punktzahl von <NAME>:";
Q["de-de"].challengeStartScreenTitle_challengee_friend="Dein Gegner:";Q["de-de"].levelEndScreenSubmitHighscoreBtn="Punktzahl senden";Q["de-de"].levelEndScreenViewHighscoreBtn="Punktzahlen ansehen";Q["de-de"].optionsAbout_header="Entwickelt von:";Q["de-de"]["optionsLang_tr-tr"]="T\u00fcrkisch";Q["de-de"]["optionsLang_de-de"]="Deutsch";Q["de-de"].startScreenByTinglyGames="von: CoolGames";Q["de-de"].levelMapScreenWorld_0="W\u00e4hle ein Level";Q["de-de"].startScreenQuestionaire="Deine Meinung z\u00e4hlt!";
Q["de-de"].levelEndScreenMedal="VERBESSERT!";Q["de-de"].optionsAbout="\u00dcber";Q["de-de"].optionsAbout_version="Version:";Q["de-de"].optionsAbout_backBtn="Zur\u00fcck";Q["de-de"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["de-de"].optionsAbout_title="\u00dcber";Q["de-de"].optionsSFXBig_off="Sound AUS";Q["de-de"].optionsSFXBig_on="Sound EIN";Q["de-de"].optionsRestart="Neustart";Q["de-de"].optionsRestartConfirmationText="Achtung!\n\nWenn du jetzt neu startest, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich neu starten?";
Q["de-de"].levelMapScreenTitle="W\u00e4hle ein Level";Q["de-de"].optionsQuitConfirmBtn_Yes="Ja, ich bin mir sicher";Q["de-de"].optionsQuitConfirmBtn_No="NEIN";Q["de-de"].optionsQuitConfirmationText="Achtung!\n\nWenn du jetzt aufh\u00f6rst, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich aufh\u00f6ren?";Q["de-de"].optionsTitle="Einstellungen";Q["de-de"].gameEndScreenBtnText="Weiter";Q["de-de"].gameEndScreenTitle="Gl\u00fcckwunsch!\nDu hast das Spiel abgeschlossen.";
Q["de-de"]["optionsLang_nl-nl"]="Holl\u00e4ndisch";Q["de-de"]["optionsLang_en-gb"]="Englisch (GB)";Q["de-de"]["optionsLang_en-us"]="Englisch (US)";Q["de-de"].optionsSFX_off="AUS";Q["de-de"].optionsSFX_on="EIN";Q["de-de"].optionsMusic_off="AUS";Q["de-de"].optionsMusic_on="EIN";Q["de-de"].optionsDifficulty_hard="Schwer";Q["de-de"].optionsDifficulty_medium="Mittel";Q["de-de"].optionsDifficulty_easy="Einfach";Q["de-de"].optionsMoreGames="Weitere Spiele";Q["de-de"].optionsHighScore="Highscores";
Q["de-de"].optionsTutorial="So wird gespielt";Q["de-de"].optionsResume="Weiterspielen";Q["de-de"].optionsQuit="Beenden";Q["de-de"].optionsStartScreen="Hauptmen\u00fc";Q["de-de"].levelEndScreenHighScore="Highscore";Q["de-de"].levelEndScreenTimeBonus="Zeitbonus";Q["de-de"].levelEndScreenTimeLeft="Restzeit";Q["de-de"].levelEndScreenSubTitle_levelFailed="Level nicht geschafft";Q["de-de"].levelEndScreenTotalScore="Gesamtpunkte";Q["de-de"].levelEndScreenTitle_endless="Stufe <VALUE>";
Q["de-de"].levelEndScreenTitle_difficulty="Sehr gut!";Q["de-de"].levelEndScreenTitle_level="Level <VALUE>";Q["de-de"].levelMapScreenTotalScore="Gesamtpunkte";Q["de-de"].startScreenPlay="SPIELEN";Q["de-de"].loadingScreenLoading="Laden ...";Q["de-de"].RewardAd_button="video";Q["de-de"].RewardAd_header="coins";Q["de-de"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["de-de"].RewardAd_text_2="new video is available soon";Q["fr-fr"]=Q["fr-fr"]||{};Q["fr-fr"].optionsAbout_header_publisher="Published by:";
Q["fr-fr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["fr-fr"].challengeEndScreenChallengeSend_submessage_stranger="Si personne n\u2019accepte votre pari d\u2019ici 72 heures, on vous remboursera le montant du pari y compris les frais.";Q["fr-fr"].challengeEndScreenChallengeSend_submessage="<NAME> a 72 heures pour accepter votre d\u00e9fi. Si <NAME> refuse ou n\u2019accepte pas dans ce d\u00e9lai vous serez rembours\u00e9 le montant de votre pari et les frais de pari.";
Q["fr-fr"].levelEndScreenHighScore_number="Meilleur score :";Q["fr-fr"].levelEndScreenTotalScore_number="Score total :";Q["fr-fr"].optionsExit="Quitter";Q["fr-fr"]["optionsLang_ru-ru"]="Russe";Q["fr-fr"]["optionsLang_pt-br"]="Portugais - Br\u00e9silien";Q["fr-fr"]["optionsLang_es-es"]="Espagnol";Q["fr-fr"]["optionsLang_ar-eg"]="Arabe";Q["fr-fr"]["optionsLang_ko-kr"]="Cor\u00e9en";Q["fr-fr"]["optionsLang_fr-fr"]="Fran\u00e7ais";Q["fr-fr"].levelEndScreenTotalScore_time="Temps total :";
Q["fr-fr"].levelEndScreenHighScore_time="Meilleur temps :";Q["fr-fr"].challengeLoadingError_notStarted="Une erreur de connexion est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Q["fr-fr"].challengeLoadingError_notValid="D\u00e9sol\u00e9, cette partie n'existe plus.";Q["fr-fr"].optionsChallengeCancel="Annuler";Q["fr-fr"].optionsChallengeForfeit="Abandonner";Q["fr-fr"].challengeForfeitMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";
Q["fr-fr"].challengeForfeitMessage_success="Vous avez abandonn\u00e9.";Q["fr-fr"].challengeForfeitConfirmBtn_no="Non";Q["fr-fr"].challengeForfeitConfirmBtn_yes="Oui";Q["fr-fr"].challengeForfeitConfirmText="Voulez-vous vraiment abandonner la partie ?";Q["fr-fr"].challengeStartTextScore_challenger="Essayez d\u2019atteindre le plus haut score !";Q["fr-fr"].challengeStartTextTime_challenger="Finissez le plus vite possible !";Q["fr-fr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Q["fr-fr"].challengeStartScreenTitle_challenger_friend="Votre adversaire\u00a0:";Q["fr-fr"].challengeStartScreenTitle_challengee_stranger="Votre adversaire\u00a0:";Q["fr-fr"].challengeEndScreenScoreSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Q["fr-fr"].challengeCancelMessage_success="D\u00e9fi annul\u00e9.";Q["fr-fr"].challengeCancelMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";
Q["fr-fr"].challengeEndScreenChallengeSend_success="D\u00e9fi lanc\u00e9.";Q["fr-fr"].challengeEndScreenChallengeSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Q["fr-fr"].challengeEndScreenName_you="Moi";Q["fr-fr"].challengeEndScreenBtn_cancel="Annuler le d\u00e9fi";Q["fr-fr"].challengeEndScreensBtn_submit="Lancer le d\u00e9fi";Q["fr-fr"].challengeCancelConfirmBtn_no="Non";Q["fr-fr"].challengeCancelConfirmBtn_yes="Oui";Q["fr-fr"].challengeCancelConfirmText="Si vous annulez, on vous remboursera le montant du pari moins les frais de pari. Voulez-vous continuer\u00a0? ";
Q["fr-fr"].challengeEndScreenOutcomeMessage_TIED="Ex-aequo\u00a0!";Q["fr-fr"].challengeEndScreenOutcomeMessage_LOST="Zut\u00a0!";Q["fr-fr"].challengeEndScreenOutcomeMessage_WON="Vainqueur\u00a0!";Q["fr-fr"].challengeEndScreenWinnings="Vous avez gagn\u00e9 <AMOUNT> fairpoints.";Q["fr-fr"].challengeStartScreenToWin="\u00c0 gagner\u00a0:";Q["fr-fr"].challengeStartTextTime="Son temps\u00a0:";Q["fr-fr"].challengeStartTextScore="Son score :";Q["fr-fr"].challengeStartScreenTitle_challengee_friend="Votre adversaire\u00a0:";
Q["fr-fr"].levelEndScreenSubmitHighscoreBtn="Publier un score";Q["fr-fr"].levelEndScreenViewHighscoreBtn="Voir les scores";Q["fr-fr"].optionsAbout_header="D\u00e9velopp\u00e9 par :";Q["fr-fr"]["optionsLang_tr-tr"]="Turc";Q["fr-fr"]["optionsLang_de-de"]="Allemand";Q["fr-fr"].startScreenByTinglyGames="Un jeu CoolGames";Q["fr-fr"].levelMapScreenWorld_0="Choisir un niveau";Q["fr-fr"].startScreenQuestionaire="Un avis sur le jeu ?";Q["fr-fr"].levelEndScreenMedal="RECORD BATTU !";
Q["fr-fr"].optionsAbout="\u00c0 propos";Q["fr-fr"].optionsAbout_version="Version :";Q["fr-fr"].optionsAbout_backBtn="Retour";Q["fr-fr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["fr-fr"].optionsAbout_title="\u00c0 propos";Q["fr-fr"].optionsSFXBig_off="Sans son";Q["fr-fr"].optionsSFXBig_on="Avec son";Q["fr-fr"].optionsRestart="Recommencer";Q["fr-fr"].optionsRestartConfirmationText="Attention !\n\nEn recommen\u00e7ant maintenant, vous perdrez votre progression pour le niveau en cours. Recommencer quand m\u00eame ?";
Q["fr-fr"].levelMapScreenTitle="Choisir un niveau";Q["fr-fr"].optionsQuitConfirmBtn_Yes="Oui";Q["fr-fr"].optionsQuitConfirmBtn_No="Non";Q["fr-fr"].optionsQuitConfirmationText="Attention !\n\nEn quittant maintenant, vous perdrez votre progression pour le niveau en cours. Quitter quand m\u00eame ?";Q["fr-fr"].optionsTitle="Param\u00e8tres";Q["fr-fr"].gameEndScreenBtnText="Continuer";Q["fr-fr"].gameEndScreenTitle="F\u00e9licitations !\nVous avez termin\u00e9 le jeu.";
Q["fr-fr"]["optionsLang_nl-nl"]="N\u00e9erlandais";Q["fr-fr"]["optionsLang_en-gb"]="Anglais (UK)";Q["fr-fr"]["optionsLang_en-us"]="Anglais (US)";Q["fr-fr"].optionsSFX_off="Sans";Q["fr-fr"].optionsSFX_on="Avec";Q["fr-fr"].optionsMusic_off="Sans";Q["fr-fr"].optionsMusic_on="Avec";Q["fr-fr"].optionsDifficulty_hard="Difficile";Q["fr-fr"].optionsDifficulty_medium="Moyen";Q["fr-fr"].optionsDifficulty_easy="Facile";Q["fr-fr"].optionsMoreGames="Plus de jeux";Q["fr-fr"].optionsHighScore="Meilleurs scores";
Q["fr-fr"].optionsTutorial="Comment jouer";Q["fr-fr"].optionsResume="Reprendre";Q["fr-fr"].optionsQuit="Quitter";Q["fr-fr"].optionsStartScreen="Menu principal";Q["fr-fr"].levelEndScreenHighScore="Meilleur score";Q["fr-fr"].levelEndScreenTimeBonus="Bonus de temps";Q["fr-fr"].levelEndScreenTimeLeft="Temps restant";Q["fr-fr"].levelEndScreenSubTitle_levelFailed="\u00c9chec du niveau";Q["fr-fr"].levelEndScreenTotalScore="Score total";Q["fr-fr"].levelEndScreenTitle_endless="Sc\u00e8ne <VALUE>";
Q["fr-fr"].levelEndScreenTitle_difficulty="Bien jou\u00e9 !";Q["fr-fr"].levelEndScreenTitle_level="Niveau <VALUE>";Q["fr-fr"].levelMapScreenTotalScore="Score total";Q["fr-fr"].startScreenPlay="JOUER";Q["fr-fr"].loadingScreenLoading="Chargement...";Q["fr-fr"].RewardAd_button="video";Q["fr-fr"].RewardAd_header="coins";Q["fr-fr"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["fr-fr"].RewardAd_text_2="new video is available soon";Q["pt-br"]=Q["pt-br"]||{};
Q["pt-br"].optionsAbout_header_publisher="Published by:";Q["pt-br"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["pt-br"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["pt-br"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["pt-br"].levelEndScreenHighScore_number="Pontua\u00e7\u00e3o m\u00e1xima:";Q["pt-br"].levelEndScreenTotalScore_number="Pontua\u00e7\u00e3o total:";Q["pt-br"].optionsExit="Sa\u00edda";Q["pt-br"]["optionsLang_ru-ru"]="Russo";Q["pt-br"]["optionsLang_pt-br"]="Portugu\u00eas do Brasil";Q["pt-br"]["optionsLang_es-es"]="Espanhol";Q["pt-br"]["optionsLang_ar-eg"]="\u00c1rabe";Q["pt-br"]["optionsLang_ko-kr"]="Coreano";Q["pt-br"]["optionsLang_fr-fr"]="Franc\u00eas";
Q["pt-br"].levelEndScreenTotalScore_time="Tempo total:";Q["pt-br"].levelEndScreenHighScore_time="Tempo recorde:";Q["pt-br"].challengeLoadingError_notStarted="Imposs\u00edvel conectar ao servidor. Por favor, tente novamente mais tarde.";Q["pt-br"].challengeLoadingError_notValid="Desculpe, este desafio n\u00e3o \u00e9 mais v\u00e1lido.";Q["pt-br"].optionsChallengeCancel="Sair do Jogo";Q["pt-br"].optionsChallengeForfeit="Desistir";Q["pt-br"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Q["pt-br"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["pt-br"].challengeForfeitConfirmBtn_no="No";Q["pt-br"].challengeForfeitConfirmBtn_yes="Yes";Q["pt-br"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["pt-br"].challengeStartTextScore_challenger="Play the game and set a score.";Q["pt-br"].challengeStartTextTime_challenger="Play the game and set a time.";
Q["pt-br"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["pt-br"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["pt-br"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["pt-br"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["pt-br"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["pt-br"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["pt-br"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["pt-br"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["pt-br"].challengeEndScreenName_you="You";Q["pt-br"].challengeEndScreenBtn_cancel="Cancel challenge";Q["pt-br"].challengeEndScreensBtn_submit="Submit challenge";Q["pt-br"].challengeCancelConfirmBtn_no="No";Q["pt-br"].challengeCancelConfirmBtn_yes="Yes";Q["pt-br"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["pt-br"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["pt-br"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["pt-br"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["pt-br"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["pt-br"].challengeStartScreenToWin="Amount to win:";Q["pt-br"].challengeStartTextTime="<NAME>'s time:";Q["pt-br"].challengeStartTextScore="<NAME>'s score:";
Q["pt-br"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["pt-br"].levelEndScreenSubmitHighscoreBtn="Enviar recorde";Q["pt-br"].levelEndScreenViewHighscoreBtn="Ver pontua\u00e7\u00f5es";Q["pt-br"].optionsAbout_header="Desenvolvido por:";Q["pt-br"]["optionsLang_tr-tr"]="Turco";Q["pt-br"]["optionsLang_de-de"]="Alem\u00e3o";Q["pt-br"].startScreenByTinglyGames="da: CoolGames";Q["pt-br"].levelMapScreenWorld_0="Selecione um n\u00edvel";Q["pt-br"].startScreenQuestionaire="O que voc\u00ea achou?";
Q["pt-br"].levelEndScreenMedal="MELHOROU!";Q["pt-br"].optionsAbout="Sobre";Q["pt-br"].optionsAbout_version="vers\u00e3o:";Q["pt-br"].optionsAbout_backBtn="Voltar";Q["pt-br"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["pt-br"].optionsAbout_title="Sobre";Q["pt-br"].optionsSFXBig_off="Sem som";Q["pt-br"].optionsSFXBig_on="Com som";Q["pt-br"].optionsRestart="Reiniciar";Q["pt-br"].optionsRestartConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea reiniciar agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo reiniciar?";
Q["pt-br"].levelMapScreenTitle="Selecione um n\u00edvel";Q["pt-br"].optionsQuitConfirmBtn_Yes="Sim, tenho certeza.";Q["pt-br"].optionsQuitConfirmBtn_No="N\u00e3o";Q["pt-br"].optionsQuitConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea sair agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo sair?";Q["pt-br"].optionsTitle="Configura\u00e7\u00f5es";Q["pt-br"].gameEndScreenBtnText="Continuar";Q["pt-br"].gameEndScreenTitle="Parab\u00e9ns!\nVoc\u00ea concluiu o jogo.";
Q["pt-br"]["optionsLang_nl-nl"]="Holand\u00eas";Q["pt-br"]["optionsLang_en-gb"]="Ingl\u00eas (GB)";Q["pt-br"]["optionsLang_en-us"]="Ingl\u00eas (EUA)";Q["pt-br"].optionsSFX_off="N\u00e3o";Q["pt-br"].optionsSFX_on="Sim";Q["pt-br"].optionsMusic_off="N\u00e3o";Q["pt-br"].optionsMusic_on="Sim";Q["pt-br"].optionsDifficulty_hard="Dif\u00edcil";Q["pt-br"].optionsDifficulty_medium="M\u00e9dio";Q["pt-br"].optionsDifficulty_easy="F\u00e1cil";Q["pt-br"].optionsMoreGames="Mais jogos";
Q["pt-br"].optionsHighScore="Recordes";Q["pt-br"].optionsTutorial="Como jogar";Q["pt-br"].optionsResume="Continuar";Q["pt-br"].optionsQuit="Sair";Q["pt-br"].optionsStartScreen="Menu principal";Q["pt-br"].levelEndScreenHighScore="Recorde";Q["pt-br"].levelEndScreenTimeBonus="B\u00f4nus de tempo";Q["pt-br"].levelEndScreenTimeLeft="Tempo restante";Q["pt-br"].levelEndScreenSubTitle_levelFailed="Tente novamente";Q["pt-br"].levelEndScreenTotalScore="Pontua\u00e7\u00e3o";
Q["pt-br"].levelEndScreenTitle_endless="Fase <VALUE>";Q["pt-br"].levelEndScreenTitle_difficulty="Muito bem!";Q["pt-br"].levelEndScreenTitle_level="N\u00edvel <VALUE>";Q["pt-br"].levelMapScreenTotalScore="Pontua\u00e7\u00e3o";Q["pt-br"].startScreenPlay="JOGAR";Q["pt-br"].loadingScreenLoading="Carregando...";Q["pt-br"].RewardAd_button="video";Q["pt-br"].RewardAd_header="coins";Q["pt-br"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["pt-br"].RewardAd_text_2="new video is available soon";
Q["es-es"]=Q["es-es"]||{};Q["es-es"].optionsAbout_header_publisher="Published by:";Q["es-es"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["es-es"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["es-es"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["es-es"].levelEndScreenHighScore_number="Mejor puntuaci\u00f3n:";Q["es-es"].levelEndScreenTotalScore_number="Puntos totales:";Q["es-es"].optionsExit="Salir";Q["es-es"]["optionsLang_ru-ru"]="Ruso";Q["es-es"]["optionsLang_pt-br"]="Portugu\u00e9s brasile\u00f1o";Q["es-es"]["optionsLang_es-es"]="Espa\u00f1ol";Q["es-es"]["optionsLang_ar-eg"]="\u00c1rabe";Q["es-es"]["optionsLang_ko-kr"]="Coreano";Q["es-es"]["optionsLang_fr-fr"]="Franc\u00e9s";Q["es-es"].levelEndScreenTotalScore_time="Tiempo total:";
Q["es-es"].levelEndScreenHighScore_time="Mejor tiempo:";Q["es-es"].challengeLoadingError_notStarted="Imposible conectar con el servidor. Int\u00e9ntalo m\u00e1s tarde.";Q["es-es"].challengeLoadingError_notValid="Lo sentimos, este reto ya no es v\u00e1lido.";Q["es-es"].optionsChallengeCancel="Abandonar";Q["es-es"].optionsChallengeForfeit="Rendirse";Q["es-es"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Q["es-es"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["es-es"].challengeForfeitConfirmBtn_no="No";Q["es-es"].challengeForfeitConfirmBtn_yes="Yes";Q["es-es"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["es-es"].challengeStartTextScore_challenger="Play the game and set a score.";Q["es-es"].challengeStartTextTime_challenger="Play the game and set a time.";
Q["es-es"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["es-es"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["es-es"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["es-es"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["es-es"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["es-es"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["es-es"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["es-es"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["es-es"].challengeEndScreenName_you="You";Q["es-es"].challengeEndScreenBtn_cancel="Cancel challenge";Q["es-es"].challengeEndScreensBtn_submit="Submit challenge";Q["es-es"].challengeCancelConfirmBtn_no="No";Q["es-es"].challengeCancelConfirmBtn_yes="Yes";Q["es-es"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["es-es"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["es-es"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["es-es"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["es-es"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["es-es"].challengeStartScreenToWin="Amount to win:";Q["es-es"].challengeStartTextTime="<NAME>'s time:";Q["es-es"].challengeStartTextScore="<NAME>'s score:";
Q["es-es"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["es-es"].levelEndScreenSubmitHighscoreBtn="Enviar puntuaci\u00f3n";Q["es-es"].levelEndScreenViewHighscoreBtn="Ver puntuaciones";Q["es-es"].optionsAbout_header="Desarrollado por:";Q["es-es"]["optionsLang_tr-tr"]="Turco";Q["es-es"]["optionsLang_de-de"]="Alem\u00e1n";Q["es-es"].startScreenByTinglyGames="de: CoolGames";Q["es-es"].levelMapScreenWorld_0="Elige un nivel";Q["es-es"].startScreenQuestionaire="\u00bfQu\u00e9 te parece?";
Q["es-es"].levelEndScreenMedal="\u00a1SUPERADO!";Q["es-es"].optionsAbout="Acerca de";Q["es-es"].optionsAbout_version="versi\u00f3n:";Q["es-es"].optionsAbout_backBtn="Atr\u00e1s";Q["es-es"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["es-es"].optionsAbout_title="Acerca de";Q["es-es"].optionsSFXBig_off="Sonido no";Q["es-es"].optionsSFXBig_on="Sonido s\u00ed";Q["es-es"].optionsRestart="Reiniciar";Q["es-es"].optionsRestartConfirmationText="\u00a1Aviso!\n\nSi reinicias ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres reiniciar?";
Q["es-es"].levelMapScreenTitle="Elige un nivel";Q["es-es"].optionsQuitConfirmBtn_Yes="S\u00ed, seguro";Q["es-es"].optionsQuitConfirmBtn_No="No";Q["es-es"].optionsQuitConfirmationText="\u00a1Aviso!\n\nSi sales ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres salir?";Q["es-es"].optionsTitle="Ajustes";Q["es-es"].gameEndScreenBtnText="Continuar";Q["es-es"].gameEndScreenTitle="\u00a1Enhorabuena!\nHas terminado el juego.";Q["es-es"]["optionsLang_nl-nl"]="Neerland\u00e9s";
Q["es-es"]["optionsLang_en-gb"]="Ingl\u00e9s (GB)";Q["es-es"]["optionsLang_en-us"]="Ingl\u00e9s (EE.UU.)";Q["es-es"].optionsSFX_off="No";Q["es-es"].optionsSFX_on="S\u00ed";Q["es-es"].optionsMusic_off="No";Q["es-es"].optionsMusic_on="S\u00ed";Q["es-es"].optionsDifficulty_hard="Dif\u00edcil";Q["es-es"].optionsDifficulty_medium="Normal";Q["es-es"].optionsDifficulty_easy="F\u00e1cil";Q["es-es"].optionsMoreGames="M\u00e1s juegos";Q["es-es"].optionsHighScore="R\u00e9cords";Q["es-es"].optionsTutorial="C\u00f3mo jugar";
Q["es-es"].optionsResume="Seguir";Q["es-es"].optionsQuit="Salir";Q["es-es"].optionsStartScreen="Men\u00fa principal";Q["es-es"].levelEndScreenHighScore="R\u00e9cord";Q["es-es"].levelEndScreenTimeBonus="Bonif. tiempo";Q["es-es"].levelEndScreenTimeLeft="Tiempo restante";Q["es-es"].levelEndScreenSubTitle_levelFailed="Nivel fallido";Q["es-es"].levelEndScreenTotalScore="Punt. total";Q["es-es"].levelEndScreenTitle_endless="Fase <VALUE>";Q["es-es"].levelEndScreenTitle_difficulty="\u00a1Muy bien!";
Q["es-es"].levelEndScreenTitle_level="Nivel <VALUE>";Q["es-es"].levelMapScreenTotalScore="Punt. total";Q["es-es"].startScreenPlay="JUGAR";Q["es-es"].loadingScreenLoading="Cargando...";Q["es-es"].RewardAd_button="video";Q["es-es"].RewardAd_header="coins";Q["es-es"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["es-es"].RewardAd_text_2="new video is available soon";Q["tr-tr"]=Q["tr-tr"]||{};Q["tr-tr"].optionsAbout_header_publisher="Published by:";
Q["tr-tr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["tr-tr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["tr-tr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["tr-tr"].levelEndScreenHighScore_number="Y\u00fcksek Puan:";Q["tr-tr"].levelEndScreenTotalScore_number="Toplam Puan:";Q["tr-tr"].optionsExit="\u00c7\u0131k\u0131\u015f";Q["tr-tr"]["optionsLang_ru-ru"]="Rus\u00e7a";Q["tr-tr"]["optionsLang_pt-br"]="Brezilya Portekizcesi";Q["tr-tr"]["optionsLang_es-es"]="\u0130spanyolca";Q["tr-tr"]["optionsLang_ar-eg"]="Arap\u00e7a";Q["tr-tr"]["optionsLang_ko-kr"]="Korece";Q["tr-tr"]["optionsLang_fr-fr"]="Frans\u0131zca";Q["tr-tr"].levelEndScreenTotalScore_time="Toplam Zaman:";
Q["tr-tr"].levelEndScreenHighScore_time="En \u0130yi Zaman:";Q["tr-tr"].challengeLoadingError_notStarted="Sunucuya ba\u011flan\u0131lam\u0131yor. L\u00fctfen daha sonra tekrar deneyin.";Q["tr-tr"].challengeLoadingError_notValid="\u00dczg\u00fcn\u00fcz, bu zorluk art\u0131k ge\u00e7erli de\u011fil.";Q["tr-tr"].optionsChallengeCancel="\u00c7\u0131k\u0131\u015f";Q["tr-tr"].optionsChallengeForfeit="Vazge\u00e7";Q["tr-tr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Q["tr-tr"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["tr-tr"].challengeForfeitConfirmBtn_no="No";Q["tr-tr"].challengeForfeitConfirmBtn_yes="Yes";Q["tr-tr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["tr-tr"].challengeStartTextScore_challenger="Play the game and set a score.";Q["tr-tr"].challengeStartTextTime_challenger="Play the game and set a time.";
Q["tr-tr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["tr-tr"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["tr-tr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["tr-tr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["tr-tr"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["tr-tr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["tr-tr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["tr-tr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["tr-tr"].challengeEndScreenName_you="You";Q["tr-tr"].challengeEndScreenBtn_cancel="Cancel challenge";Q["tr-tr"].challengeEndScreensBtn_submit="Submit challenge";Q["tr-tr"].challengeCancelConfirmBtn_no="No";Q["tr-tr"].challengeCancelConfirmBtn_yes="Yes";Q["tr-tr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["tr-tr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["tr-tr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["tr-tr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["tr-tr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["tr-tr"].challengeStartScreenToWin="Amount to win:";Q["tr-tr"].challengeStartTextTime="<NAME>'s time:";Q["tr-tr"].challengeStartTextScore="<NAME>'s score:";
Q["tr-tr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["tr-tr"].levelEndScreenSubmitHighscoreBtn="Puan g\u00f6nder";Q["tr-tr"].levelEndScreenViewHighscoreBtn="Puanlar\u0131 g\u00f6ster:";Q["tr-tr"].optionsAbout_header="Haz\u0131rlayan:";Q["tr-tr"]["optionsLang_tr-tr"]="T\u00fcrk\u00e7e";Q["tr-tr"]["optionsLang_de-de"]="Almanca";Q["tr-tr"].startScreenByTinglyGames="taraf\u0131ndan: CoolGames";Q["tr-tr"].levelMapScreenWorld_0="Bir seviye se\u00e7";
Q["tr-tr"].startScreenQuestionaire="Ne dersin?";Q["tr-tr"].levelEndScreenMedal="\u0130Y\u0130LE\u015eT\u0130!";Q["tr-tr"].optionsAbout="Hakk\u0131nda";Q["tr-tr"].optionsAbout_version="s\u00fcr\u00fcm:";Q["tr-tr"].optionsAbout_backBtn="Geri";Q["tr-tr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["tr-tr"].optionsAbout_title="Hakk\u0131nda";Q["tr-tr"].optionsSFXBig_off="Ses kapal\u0131";Q["tr-tr"].optionsSFXBig_on="Ses a\u00e7\u0131k";Q["tr-tr"].optionsRestart="Tekrar ba\u015flat";
Q["tr-tr"].optionsRestartConfirmationText="Dikkat!\n\u015eimdi tekrar ba\u015flarsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. Ba\u015ftan ba\u015flamak istedi\u011finden emin misin?";Q["tr-tr"].levelMapScreenTitle="Bir seviye se\u00e7";Q["tr-tr"].optionsQuitConfirmBtn_Yes="Evet, eminim";Q["tr-tr"].optionsQuitConfirmBtn_No="Hay\u0131r";Q["tr-tr"].optionsQuitConfirmationText="Dikkat!\n\u015eimdi \u00e7\u0131karsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. \u00c7\u0131kmak istedi\u011finizden emin misiniz?";
Q["tr-tr"].optionsTitle="Ayarlar";Q["tr-tr"].gameEndScreenBtnText="Devam";Q["tr-tr"].gameEndScreenTitle="Tebrikler!\nOyunu tamamlad\u0131n.";Q["tr-tr"]["optionsLang_nl-nl"]="Hollandaca";Q["tr-tr"]["optionsLang_en-gb"]="\u0130ngilizce (GB)";Q["tr-tr"]["optionsLang_en-us"]="\u0130ngilizce (US)";Q["tr-tr"].optionsSFX_off="Kapal\u0131";Q["tr-tr"].optionsSFX_on="A\u00e7\u0131k";Q["tr-tr"].optionsMusic_off="Kapal\u0131";Q["tr-tr"].optionsMusic_on="A\u00e7\u0131k";Q["tr-tr"].optionsDifficulty_hard="Zorluk";
Q["tr-tr"].optionsDifficulty_medium="Orta";Q["tr-tr"].optionsDifficulty_easy="Kolay";Q["tr-tr"].optionsMoreGames="Daha Fazla Oyun";Q["tr-tr"].optionsHighScore="Y\u00fcksek skorlar";Q["tr-tr"].optionsTutorial="Nas\u0131l oynan\u0131r";Q["tr-tr"].optionsResume="Devam et";Q["tr-tr"].optionsQuit="\u00c7\u0131k";Q["tr-tr"].optionsStartScreen="Ana men\u00fc";Q["tr-tr"].levelEndScreenHighScore="Y\u00fcksek skor";Q["tr-tr"].levelEndScreenTimeBonus="S\u00fcre Bonusu";Q["tr-tr"].levelEndScreenTimeLeft="Kalan S\u00fcre";
Q["tr-tr"].levelEndScreenSubTitle_levelFailed="Seviye ba\u015far\u0131s\u0131z";Q["tr-tr"].levelEndScreenTotalScore="Toplam skor";Q["tr-tr"].levelEndScreenTitle_endless="B\u00f6l\u00fcm <VALUE>";Q["tr-tr"].levelEndScreenTitle_difficulty="Bravo!";Q["tr-tr"].levelEndScreenTitle_level="Seviye <VALUE>";Q["tr-tr"].levelMapScreenTotalScore="Toplam skor";Q["tr-tr"].startScreenPlay="OYNA";Q["tr-tr"].loadingScreenLoading="Y\u00fckleniyor...";Q["tr-tr"].RewardAd_button="video";Q["tr-tr"].RewardAd_header="coins";
Q["tr-tr"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["tr-tr"].RewardAd_text_2="new video is available soon";Q["ru-ru"]=Q["ru-ru"]||{};Q["ru-ru"].optionsAbout_header_publisher="Published by:";Q["ru-ru"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["ru-ru"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Q["ru-ru"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Q["ru-ru"].levelEndScreenHighScore_number="High score:";Q["ru-ru"].levelEndScreenTotalScore_number="Total score:";Q["ru-ru"].optionsExit="Exit";Q["ru-ru"]["optionsLang_ru-ru"]="\u0420\u0443\u0441\u0441\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_pt-br"]="\u0411\u0440\u0430\u0437\u0438\u043b\u044c\u0441\u043a\u0438\u0439 \u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439";
Q["ru-ru"]["optionsLang_es-es"]="\u0418\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_ar-eg"]="\u0410\u0440\u0430\u0431\u0441\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_ko-kr"]="\u041a\u043e\u0440\u0435\u0439\u0441\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_fr-fr"]="\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439";Q["ru-ru"].levelEndScreenTotalScore_time="Total time:";Q["ru-ru"].levelEndScreenHighScore_time="Best time:";
Q["ru-ru"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Q["ru-ru"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["ru-ru"].optionsChallengeCancel="Quit";Q["ru-ru"].optionsChallengeForfeit="Forfeit";Q["ru-ru"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Q["ru-ru"].challengeForfeitMessage_success="You have forfeited the challenge.";
Q["ru-ru"].challengeForfeitConfirmBtn_no="No";Q["ru-ru"].challengeForfeitConfirmBtn_yes="Yes";Q["ru-ru"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["ru-ru"].challengeStartTextScore_challenger="Play the game and set a score.";Q["ru-ru"].challengeStartTextTime_challenger="Play the game and set a time.";Q["ru-ru"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Q["ru-ru"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["ru-ru"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["ru-ru"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["ru-ru"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["ru-ru"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["ru-ru"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["ru-ru"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["ru-ru"].challengeEndScreenName_you="You";Q["ru-ru"].challengeEndScreenBtn_cancel="Cancel challenge";Q["ru-ru"].challengeEndScreensBtn_submit="Submit challenge";Q["ru-ru"].challengeCancelConfirmBtn_no="No";Q["ru-ru"].challengeCancelConfirmBtn_yes="Yes";Q["ru-ru"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["ru-ru"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["ru-ru"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["ru-ru"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["ru-ru"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["ru-ru"].challengeStartScreenToWin="Amount to win:";Q["ru-ru"].challengeStartTextTime="<NAME>'s time:";Q["ru-ru"].challengeStartTextScore="<NAME>'s score:";
Q["ru-ru"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["ru-ru"].levelEndScreenSubmitHighscoreBtn="Submit score";Q["ru-ru"].levelEndScreenViewHighscoreBtn="View scores";Q["ru-ru"].optionsAbout_header="Developed by:";Q["ru-ru"]["optionsLang_tr-tr"]="\u0422\u0443\u0440\u0435\u0446\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_de-de"]="\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439";Q["ru-ru"].startScreenByTinglyGames="\u0420\u0430\u0437\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0438: CoolGames";
Q["ru-ru"].levelMapScreenWorld_0="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Q["ru-ru"].startScreenQuestionaire="\u041a\u0430\u043a \u0432\u0430\u043c \u0438\u0433\u0440\u0430?";Q["ru-ru"].levelEndScreenMedal="\u041d\u041e\u0412\u042b\u0419 \u0420\u0415\u041a\u041e\u0420\u0414!";Q["ru-ru"].optionsAbout="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Q["ru-ru"].optionsAbout_version="\u0412\u0435\u0440\u0441\u0438\u044f:";
Q["ru-ru"].optionsAbout_backBtn="\u041d\u0430\u0437\u0430\u0434";Q["ru-ru"].optionsAbout_text="\u00a9 CoolGames\nwww.coolgames.com\n2016";Q["ru-ru"].optionsAbout_title="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Q["ru-ru"].optionsSFXBig_off="\u0417\u0432\u0443\u043a \u0432\u044b\u043a\u043b.";Q["ru-ru"].optionsSFXBig_on="\u0417\u0432\u0443\u043a \u0432\u043a\u043b.";Q["ru-ru"].optionsRestart="\u0417\u0430\u043d\u043e\u0432\u043e";Q["ru-ru"].optionsRestartConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0441\u0435\u0439\u0447\u0430\u0441 \u043d\u0430\u0447\u043d\u0435\u0442\u0435 \u0438\u0433\u0440\u0443 \u0437\u0430\u043d\u043e\u0432\u043e, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043d\u0430\u0447\u0430\u0442\u044c \u0437\u0430\u043d\u043e\u0432\u043e?";
Q["ru-ru"].levelMapScreenTitle="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Q["ru-ru"].optionsQuitConfirmBtn_Yes="\u0414\u0430, \u0432\u044b\u0439\u0442\u0438";Q["ru-ru"].optionsQuitConfirmBtn_No="\u041d\u0435\u0442";Q["ru-ru"].optionsQuitConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0432\u044b\u0439\u0434\u0435\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u0439\u0442\u0438?";
Q["ru-ru"].optionsTitle="\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438";Q["ru-ru"].gameEndScreenBtnText="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Q["ru-ru"].gameEndScreenTitle="\u041f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0435\u043c!\n\u0412\u044b \u043f\u0440\u043e\u0448\u043b\u0438 \u0438\u0433\u0440\u0443.";Q["ru-ru"]["optionsLang_nl-nl"]="\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438\u0439";Q["ru-ru"]["optionsLang_en-gb"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0412\u0411)";
Q["ru-ru"]["optionsLang_en-us"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0421\u0428\u0410)";Q["ru-ru"].optionsSFX_off="\u0412\u044b\u043a\u043b.";Q["ru-ru"].optionsSFX_on="\u0412\u043a\u043b.";Q["ru-ru"].optionsMusic_off="\u0412\u044b\u043a\u043b.";Q["ru-ru"].optionsMusic_on="\u0412\u043a\u043b.";Q["ru-ru"].optionsDifficulty_hard="\u0421\u043b\u043e\u0436\u043d\u044b\u0439";Q["ru-ru"].optionsDifficulty_medium="\u0421\u0440\u0435\u0434\u043d\u0438\u0439";
Q["ru-ru"].optionsDifficulty_easy="\u041b\u0435\u0433\u043a\u0438\u0439";Q["ru-ru"].optionsMoreGames="\u0411\u043e\u043b\u044c\u0448\u0435 \u0438\u0433\u0440";Q["ru-ru"].optionsHighScore="\u0420\u0435\u043a\u043e\u0440\u0434\u044b";Q["ru-ru"].optionsTutorial="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";Q["ru-ru"].optionsResume="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Q["ru-ru"].optionsQuit="\u0412\u044b\u0439\u0442\u0438";Q["ru-ru"].optionsStartScreen="\u0413\u043b\u0430\u0432\u043d\u043e\u0435 \u043c\u0435\u043d\u044e";
Q["ru-ru"].levelEndScreenHighScore="\u0420\u0435\u043a\u043e\u0440\u0434";Q["ru-ru"].levelEndScreenTimeBonus="\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f";Q["ru-ru"].levelEndScreenTimeLeft="\u041e\u0441\u0442\u0430\u0432\u0448\u0435\u0435\u0441\u044f \u0432\u0440\u0435\u043c\u044f";Q["ru-ru"].levelEndScreenSubTitle_levelFailed="\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u043f\u0440\u043e\u0439\u0434\u0435\u043d";
Q["ru-ru"].levelEndScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";Q["ru-ru"].levelEndScreenTitle_endless="\u042d\u0442\u0430\u043f <VALUE>";Q["ru-ru"].levelEndScreenTitle_difficulty="\u0425\u043e\u0440\u043e\u0448\u0438\u0439 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442!";Q["ru-ru"].levelEndScreenTitle_level="\u0423\u0440\u043e\u0432\u0435\u043d\u044c <VALUE>";Q["ru-ru"].levelMapScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";
Q["ru-ru"].startScreenPlay="\u0418\u0413\u0420\u0410\u0422\u042c";Q["ru-ru"].loadingScreenLoading="\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430...";Q["ru-ru"].RewardAd_button="video";Q["ru-ru"].RewardAd_header="coins";Q["ru-ru"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["ru-ru"].RewardAd_text_2="new video is available soon";Q["ar-eg"]=Q["ar-eg"]||{};Q["ar-eg"].optionsAbout_header_publisher="Published by:";Q["ar-eg"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";
Q["ar-eg"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["ar-eg"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Q["ar-eg"].levelEndScreenHighScore_number="High score:";
Q["ar-eg"].levelEndScreenTotalScore_number="Total score:";Q["ar-eg"].optionsExit="Exit";Q["ar-eg"]["optionsLang_ru-ru"]="\u0627\u0644\u0631\u0648\u0633\u064a\u0629";Q["ar-eg"]["optionsLang_pt-br"]="\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644\u064a\u0629 - \u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629";Q["ar-eg"]["optionsLang_es-es"]="\u0627\u0644\u0625\u0633\u0628\u0627\u0646\u064a\u0629";Q["ar-eg"]["optionsLang_ar-eg"]="\u0627\u0644\u0639\u0631\u0628\u064a\u0629";
Q["ar-eg"]["optionsLang_ko-kr"]="\u0627\u0644\u0643\u0648\u0631\u064a\u0629";Q["ar-eg"]["optionsLang_fr-fr"]="\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629";Q["ar-eg"].levelEndScreenTotalScore_time="Total time:";Q["ar-eg"].levelEndScreenHighScore_time="Best time:";Q["ar-eg"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Q["ar-eg"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["ar-eg"].optionsChallengeCancel="Quit";
Q["ar-eg"].optionsChallengeForfeit="Forfeit";Q["ar-eg"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Q["ar-eg"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["ar-eg"].challengeForfeitConfirmBtn_no="No";Q["ar-eg"].challengeForfeitConfirmBtn_yes="Yes";Q["ar-eg"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["ar-eg"].challengeStartTextScore_challenger="Play the game and set a score.";
Q["ar-eg"].challengeStartTextTime_challenger="Play the game and set a time.";Q["ar-eg"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["ar-eg"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["ar-eg"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["ar-eg"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["ar-eg"].challengeCancelMessage_success="Your challenge has been cancelled.";
Q["ar-eg"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Q["ar-eg"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["ar-eg"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["ar-eg"].challengeEndScreenName_you="You";Q["ar-eg"].challengeEndScreenBtn_cancel="Cancel challenge";Q["ar-eg"].challengeEndScreensBtn_submit="Submit challenge";
Q["ar-eg"].challengeCancelConfirmBtn_no="No";Q["ar-eg"].challengeCancelConfirmBtn_yes="Yes";Q["ar-eg"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Q["ar-eg"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["ar-eg"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["ar-eg"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";
Q["ar-eg"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["ar-eg"].challengeStartScreenToWin="Amount to win:";Q["ar-eg"].challengeStartTextTime="<NAME>'s time:";Q["ar-eg"].challengeStartTextScore="<NAME>'s score:";Q["ar-eg"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["ar-eg"].levelEndScreenSubmitHighscoreBtn="Submit score";Q["ar-eg"].levelEndScreenViewHighscoreBtn="View scores";Q["ar-eg"].optionsAbout_header="Developed by:";
Q["ar-eg"]["optionsLang_tr-tr"]="\u0627\u0644\u062a\u0631\u0643\u064a\u0629";Q["ar-eg"]["optionsLang_de-de"]="\u0627\u0644\u0623\u0644\u0645\u0627\u0646\u064a\u0629";Q["ar-eg"].startScreenByTinglyGames="\u0628\u0648\u0627\u0633\u0637\u0629: CoolGames";Q["ar-eg"].levelMapScreenWorld_0="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Q["ar-eg"].startScreenQuestionaire="\u0645\u0627 \u0631\u0623\u064a\u0643\u061f";Q["ar-eg"].levelEndScreenMedal="\u0644\u0642\u062f \u062a\u062d\u0633\u0651\u0646\u062a!";
Q["ar-eg"].optionsAbout="\u062d\u0648\u0644";Q["ar-eg"].optionsAbout_version="\u0627\u0644\u0625\u0635\u062f\u0627\u0631:";Q["ar-eg"].optionsAbout_backBtn="\u0627\u0644\u0633\u0627\u0628\u0642";Q["ar-eg"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["ar-eg"].optionsAbout_title="\u062d\u0648\u0644";Q["ar-eg"].optionsSFXBig_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0635\u0648\u062a";Q["ar-eg"].optionsSFXBig_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0635\u0648\u062a";
Q["ar-eg"].optionsRestart="\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644";Q["ar-eg"].optionsRestartConfirmationText="\u0627\u0646\u062a\u0628\u0647!\n\n\u0625\u0630\u0627 \u0642\u0645\u062a \u0628\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644\u061f";
Q["ar-eg"].levelMapScreenTitle="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Q["ar-eg"].optionsQuitConfirmBtn_Yes="\u0646\u0639\u0645\u060c \u0645\u062a\u0623\u0643\u062f";Q["ar-eg"].optionsQuitConfirmBtn_No="\u0644\u0627";Q["ar-eg"].optionsQuitConfirmationText="\u0627\u0646\u062a\u0628\u0647!n\n\u0625\u0630\u0627 \u062e\u0631\u062c\u062a \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629\u061f";
Q["ar-eg"].optionsTitle="\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a";Q["ar-eg"].gameEndScreenBtnText="\u0645\u062a\u0627\u0628\u0639\u0629";Q["ar-eg"].gameEndScreenTitle="\u062a\u0647\u0627\u0646\u064a\u0646\u0627!\n\u0644\u0642\u062f \u0623\u0643\u0645\u0644\u062a \u0627\u0644\u0644\u0639\u0628\u0629.";Q["ar-eg"]["optionsLang_nl-nl"]="\u0627\u0644\u0647\u0648\u0644\u0646\u062f\u064a\u0629";Q["ar-eg"]["optionsLang_en-gb"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";
Q["ar-eg"]["optionsLang_en-us"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";Q["ar-eg"].optionsSFX_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";Q["ar-eg"].optionsSFX_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";
Q["ar-eg"].optionsMusic_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";Q["ar-eg"].optionsMusic_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";Q["ar-eg"].optionsDifficulty_hard="\u0635\u0639\u0628";Q["ar-eg"].optionsDifficulty_medium="\u0645\u062a\u0648\u0633\u0637";Q["ar-eg"].optionsDifficulty_easy="\u0633\u0647\u0644";Q["ar-eg"].optionsMoreGames="\u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0623\u0644\u0639\u0627\u0628";
Q["ar-eg"].optionsHighScore="\u0623\u0639\u0644\u0649 \u0627\u0644\u0646\u062a\u0627\u0626\u062c";Q["ar-eg"].optionsTutorial="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";Q["ar-eg"].optionsResume="\u0627\u0633\u062a\u0626\u0646\u0627\u0641";Q["ar-eg"].optionsQuit="\u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629";Q["ar-eg"].optionsStartScreen="\u0627\u0644\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629";
Q["ar-eg"].levelEndScreenHighScore="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";Q["ar-eg"].levelEndScreenTimeBonus="\u0645\u0643\u0627\u0641\u0623\u0629 \u0627\u0644\u0648\u0642\u062a";Q["ar-eg"].levelEndScreenTimeLeft="\u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u062a\u0628\u0642\u064a";Q["ar-eg"].levelEndScreenSubTitle_levelFailed="\u0644\u0642\u062f \u0641\u0634\u0644\u062a \u0641\u064a \u0627\u062c\u062a\u064a\u0627\u0632 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649";
Q["ar-eg"].levelEndScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";Q["ar-eg"].levelEndScreenTitle_endless="\u0627\u0644\u0645\u0631\u062d\u0644\u0629 <VALUE>";Q["ar-eg"].levelEndScreenTitle_difficulty="\u0623\u062d\u0633\u0646\u062a!";Q["ar-eg"].levelEndScreenTitle_level="\u0627\u0644\u0645\u0633\u062a\u0648\u0649 <VALUE>";Q["ar-eg"].levelMapScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";
Q["ar-eg"].startScreenPlay="\u062a\u0634\u063a\u064a\u0644";Q["ar-eg"].loadingScreenLoading="\u064a\u062a\u0645 \u0627\u0644\u0622\u0646 \u0627\u0644\u062a\u062d\u0645\u064a\u0644...";Q["ar-eg"].RewardAd_button="video";Q["ar-eg"].RewardAd_header="coins";Q["ar-eg"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["ar-eg"].RewardAd_text_2="new video is available soon";Q["ko-kr"]=Q["ko-kr"]||{};Q["ko-kr"].optionsAbout_header_publisher="Published by:";
Q["ko-kr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["ko-kr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Q["ko-kr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Q["ko-kr"].levelEndScreenHighScore_number="High score:";Q["ko-kr"].levelEndScreenTotalScore_number="Total score:";Q["ko-kr"].optionsExit="Exit";Q["ko-kr"]["optionsLang_ru-ru"]="\ub7ec\uc2dc\uc544\uc5b4";Q["ko-kr"]["optionsLang_pt-br"]="\ud3ec\ub974\ud22c\uac08\uc5b4(\ube0c\ub77c\uc9c8)";Q["ko-kr"]["optionsLang_es-es"]="\uc2a4\ud398\uc778\uc5b4";Q["ko-kr"]["optionsLang_ar-eg"]="\uc544\ub77c\ube44\uc544\uc5b4";Q["ko-kr"]["optionsLang_ko-kr"]="\ud55c\uad6d\uc5b4";Q["ko-kr"]["optionsLang_fr-fr"]="\ud504\ub791\uc2a4\uc5b4";
Q["ko-kr"].levelEndScreenTotalScore_time="Total time:";Q["ko-kr"].levelEndScreenHighScore_time="Best time:";Q["ko-kr"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Q["ko-kr"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["ko-kr"].optionsChallengeCancel="Quit";Q["ko-kr"].optionsChallengeForfeit="Forfeit";Q["ko-kr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Q["ko-kr"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["ko-kr"].challengeForfeitConfirmBtn_no="No";Q["ko-kr"].challengeForfeitConfirmBtn_yes="Yes";Q["ko-kr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["ko-kr"].challengeStartTextScore_challenger="Play the game and set a score.";Q["ko-kr"].challengeStartTextTime_challenger="Play the game and set a time.";
Q["ko-kr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["ko-kr"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["ko-kr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Q["ko-kr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["ko-kr"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["ko-kr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Q["ko-kr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["ko-kr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Q["ko-kr"].challengeEndScreenName_you="You";Q["ko-kr"].challengeEndScreenBtn_cancel="Cancel challenge";Q["ko-kr"].challengeEndScreensBtn_submit="Submit challenge";Q["ko-kr"].challengeCancelConfirmBtn_no="No";Q["ko-kr"].challengeCancelConfirmBtn_yes="Yes";Q["ko-kr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Q["ko-kr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Q["ko-kr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["ko-kr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["ko-kr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["ko-kr"].challengeStartScreenToWin="Amount to win:";Q["ko-kr"].challengeStartTextTime="<NAME>'s time:";Q["ko-kr"].challengeStartTextScore="<NAME>'s score:";
Q["ko-kr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Q["ko-kr"].levelEndScreenSubmitHighscoreBtn="Submit score";Q["ko-kr"].levelEndScreenViewHighscoreBtn="View scores";Q["ko-kr"].optionsAbout_header="Developed by:";Q["ko-kr"]["optionsLang_tr-tr"]="\ud130\ud0a4\uc5b4";Q["ko-kr"]["optionsLang_de-de"]="\ub3c5\uc77c\uc5b4";Q["ko-kr"].startScreenByTinglyGames="\uc81c\uc791: CoolGames";Q["ko-kr"].levelMapScreenWorld_0="\ub808\ubca8 \uc120\ud0dd";
Q["ko-kr"].startScreenQuestionaire="\uc5b4\ub5bb\uac8c \uc0dd\uac01\ud558\uc138\uc694?";Q["ko-kr"].levelEndScreenMedal="\ud5a5\uc0c1\ud588\uad70\uc694!";Q["ko-kr"].optionsAbout="\uad00\ub828 \uc815\ubcf4";Q["ko-kr"].optionsAbout_version="\ubc84\uc804:";Q["ko-kr"].optionsAbout_backBtn="\ub4a4\ub85c";Q["ko-kr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["ko-kr"].optionsAbout_title="\uad00\ub828 \uc815\ubcf4";Q["ko-kr"].optionsSFXBig_off="\uc74c\ud5a5 \ub044\uae30";
Q["ko-kr"].optionsSFXBig_on="\uc74c\ud5a5 \ucf1c\uae30";Q["ko-kr"].optionsRestart="\ub2e4\uc2dc \uc2dc\uc791";Q["ko-kr"].optionsRestartConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \ub2e4\uc2dc \uc2dc\uc791\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \ub2e4\uc2dc \uc2dc\uc791\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Q["ko-kr"].levelMapScreenTitle="\ub808\ubca8 \uc120\ud0dd";Q["ko-kr"].optionsQuitConfirmBtn_Yes="\ub124, \ud655\uc2e4\ud569\ub2c8\ub2e4";
Q["ko-kr"].optionsQuitConfirmBtn_No="\uc544\ub2c8\uc624";Q["ko-kr"].optionsQuitConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \uc885\ub8cc\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \uc885\ub8cc\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Q["ko-kr"].optionsTitle="\uc124\uc815";Q["ko-kr"].gameEndScreenBtnText="\uacc4\uc18d";Q["ko-kr"].gameEndScreenTitle="\ucd95\ud558\ud569\ub2c8\ub2e4!\n\uac8c\uc784\uc744 \uc644\ub8cc\ud588\uc2b5\ub2c8\ub2e4.";
Q["ko-kr"]["optionsLang_nl-nl"]="\ub124\ub35c\ub780\ub4dc\uc5b4";Q["ko-kr"]["optionsLang_en-gb"]="\uc601\uc5b4(GB)";Q["ko-kr"]["optionsLang_en-us"]="\uc601\uc5b4(US)";Q["ko-kr"].optionsSFX_off="\ub044\uae30";Q["ko-kr"].optionsSFX_on="\ucf1c\uae30";Q["ko-kr"].optionsMusic_off="\ub044\uae30";Q["ko-kr"].optionsMusic_on="\ucf1c\uae30";Q["ko-kr"].optionsDifficulty_hard="\uc0c1";Q["ko-kr"].optionsDifficulty_medium="\uc911";Q["ko-kr"].optionsDifficulty_easy="\uac04\ub2e8";Q["ko-kr"].optionsMoreGames="\ub354 \ub9ce\uc740 \uac8c\uc784";
Q["ko-kr"].optionsHighScore="\ucd5c\uace0 \uc810\uc218";Q["ko-kr"].optionsTutorial="\uac8c\uc784 \ubc29\ubc95";Q["ko-kr"].optionsResume="\uacc4\uc18d";Q["ko-kr"].optionsQuit="\uc885\ub8cc";Q["ko-kr"].optionsStartScreen="\uba54\uc778 \uba54\ub274";Q["ko-kr"].levelEndScreenHighScore="\ucd5c\uace0 \uc810\uc218";Q["ko-kr"].levelEndScreenTimeBonus="\uc2dc\uac04 \ubcf4\ub108\uc2a4";Q["ko-kr"].levelEndScreenTimeLeft="\ub0a8\uc740 \uc2dc\uac04";Q["ko-kr"].levelEndScreenSubTitle_levelFailed="\ub808\ubca8 \uc2e4\ud328";
Q["ko-kr"].levelEndScreenTotalScore="\ucd1d \uc810\uc218";Q["ko-kr"].levelEndScreenTitle_endless="\uc2a4\ud14c\uc774\uc9c0 <VALUE>";Q["ko-kr"].levelEndScreenTitle_difficulty="\uc798 \ud588\uc5b4\uc694!";Q["ko-kr"].levelEndScreenTitle_level="\ub808\ubca8 <VALUE>";Q["ko-kr"].levelMapScreenTotalScore="\ucd1d \uc810\uc218";Q["ko-kr"].startScreenPlay="PLAY";Q["ko-kr"].loadingScreenLoading="\ubd88\ub7ec\uc624\uae30 \uc911...";Q["ko-kr"].RewardAd_button="video";Q["ko-kr"].RewardAd_header="coins";
Q["ko-kr"].RewardAd_text_1="watch a video and get <COINS> coins!";Q["ko-kr"].RewardAd_text_2="new video is available soon";Q["jp-jp"]=Q["jp-jp"]||{};Q["jp-jp"].optionsAbout_header_publisher="Published by:";Q["jp-jp"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Q["jp-jp"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Q["jp-jp"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Q["jp-jp"].levelEndScreenHighScore_number="\u30cf\u30a4\u30b9\u30b3\u30a2";Q["jp-jp"].levelEndScreenTotalScore_number="\u30b9\u30b3\u30a2";Q["jp-jp"].optionsExit="\u623b\u308b";Q["jp-jp"]["optionsLang_ru-ru"]="\u30ed\u30b7\u30a2\u8a9e";Q["jp-jp"]["optionsLang_pt-br"]="\u30dd\u30eb\u30c8\u30ac\u30eb\u8a9e\uff08\u30d6\u30e9\u30b8\u30eb\uff09";
Q["jp-jp"]["optionsLang_es-es"]="\u30b9\u30da\u30a4\u30f3\u8a9e";Q["jp-jp"]["optionsLang_ar-eg"]="\u30a2\u30e9\u30d3\u30a2\u8a9e";Q["jp-jp"]["optionsLang_ko-kr"]="\u97d3\u56fd\u8a9e";Q["jp-jp"]["optionsLang_fr-fr"]="\u30d5\u30e9\u30f3\u30b9\u8a9e";Q["jp-jp"].levelEndScreenTotalScore_time="\u30c8\u30fc\u30bf\u30eb\u30bf\u30a4\u30e0\uff1a";Q["jp-jp"].levelEndScreenHighScore_time="\u30d9\u30b9\u30c8\u30bf\u30a4\u30e0\uff1a";Q["jp-jp"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";
Q["jp-jp"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Q["jp-jp"].optionsChallengeCancel="\u3084\u3081\u308b";Q["jp-jp"].optionsChallengeForfeit="\u964d\u53c2";Q["jp-jp"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Q["jp-jp"].challengeForfeitMessage_success="You have forfeited the challenge.";Q["jp-jp"].challengeForfeitConfirmBtn_no="No";Q["jp-jp"].challengeForfeitConfirmBtn_yes="Yes";
Q["jp-jp"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Q["jp-jp"].challengeStartTextScore_challenger="Play the game and set a score.";Q["jp-jp"].challengeStartTextTime_challenger="Play the game and set a time.";Q["jp-jp"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Q["jp-jp"].challengeStartScreenTitle_challenger_friend="You are challenging:";Q["jp-jp"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";
Q["jp-jp"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Q["jp-jp"].challengeCancelMessage_success="Your challenge has been cancelled.";Q["jp-jp"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Q["jp-jp"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Q["jp-jp"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";
Q["jp-jp"].challengeEndScreenName_you="You";Q["jp-jp"].challengeEndScreenBtn_cancel="Cancel challenge";Q["jp-jp"].challengeEndScreensBtn_submit="Submit challenge";Q["jp-jp"].challengeCancelConfirmBtn_no="No";Q["jp-jp"].challengeCancelConfirmBtn_yes="Yes";Q["jp-jp"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Q["jp-jp"].challengeEndScreenOutcomeMessage_TIED="You tied.";
Q["jp-jp"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Q["jp-jp"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Q["jp-jp"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Q["jp-jp"].challengeStartScreenToWin="Amount to win:";Q["jp-jp"].challengeStartTextTime="<NAME>'s time:";Q["jp-jp"].challengeStartTextScore="<NAME>'s score:";Q["jp-jp"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";
Q["jp-jp"].levelEndScreenSubmitHighscoreBtn="\u30b9\u30b3\u30a2\u9001\u4fe1";Q["jp-jp"].levelEndScreenViewHighscoreBtn="\u30b9\u30b3\u30a2\u3092\u898b\u308b";Q["jp-jp"].optionsAbout_header="Developed by:";Q["jp-jp"]["optionsLang_tr-tr"]="\u30c8\u30eb\u30b3\u8a9e";Q["jp-jp"]["optionsLang_de-de"]="\u30c9\u30a4\u30c4\u8a9e";Q["jp-jp"].startScreenByTinglyGames="by: CoolGames";Q["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb\u3092\u9078\u629e";Q["jp-jp"].startScreenQuestionaire="\u3069\u3046\u3067\u3059\u304b\uff1f";
Q["jp-jp"].levelEndScreenMedal="\u8a18\u9332\u66f4\u65b0\uff01";Q["jp-jp"].optionsAbout="About";Q["jp-jp"].optionsAbout_version="version:";Q["jp-jp"].optionsAbout_backBtn="\u3082\u3069\u308b";Q["jp-jp"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Q["jp-jp"].optionsAbout_title="About";Q["jp-jp"].optionsSFXBig_off="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30d5";Q["jp-jp"].optionsSFXBig_on="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30f3";Q["jp-jp"].optionsRestart="\u518d\u30b9\u30bf\u30fc\u30c8";
Q["jp-jp"].optionsRestartConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068<br>\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c<br>\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Q["jp-jp"].levelMapScreenTitle="\u30ec\u30d9\u30eb\u9078\u629e";Q["jp-jp"].optionsQuitConfirmBtn_Yes="\u306f\u3044\u3001\u3084\u3081\u307e\u3059\u3002";Q["jp-jp"].optionsQuitConfirmBtn_No="\u3044\u3044\u3048\u3001\u7d9a\u3051\u307e\u3059\u3002";
Q["jp-jp"].optionsQuitConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u3084\u3081\u308b\u3068<br>\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c<br>\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Q["jp-jp"].optionsTitle="\u8a2d\u5b9a";Q["jp-jp"].gameEndScreenBtnText="\u7d9a\u3051\u308b";Q["jp-jp"].gameEndScreenTitle="\u304a\u3081\u3067\u3068\u3046\uff01\n\u5168\u3066\u30af\u30ea\u30a2\u306d\uff01";Q["jp-jp"]["optionsLang_nl-nl"]="\u30aa\u30e9\u30f3\u30c0\u8a9e";
Q["jp-jp"]["optionsLang_en-gb"]="\u82f1\u8a9e\uff08\u82f1\u56fd\uff09";Q["jp-jp"]["optionsLang_en-us"]="\u82f1\u8a9e\uff08\u7c73\u56fd\uff09";Q["jp-jp"].optionsSFX_off="\u30aa\u30d5";Q["jp-jp"].optionsSFX_on="\u30aa\u30f3";Q["jp-jp"].optionsMusic_off="\u30aa\u30d5";Q["jp-jp"].optionsMusic_on="\u30aa\u30f3";Q["jp-jp"].optionsDifficulty_hard="\u96e3\u3057\u3044";Q["jp-jp"].optionsDifficulty_medium="\u666e\u901a";Q["jp-jp"].optionsDifficulty_easy="\u7c21\u5358";Q["jp-jp"].optionsMoreGames="\u305d\u306e\u4ed6\u306e\u30b2\u30fc\u30e0";
Q["jp-jp"].optionsHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";Q["jp-jp"].optionsTutorial="\u3042\u305d\u3073\u65b9";Q["jp-jp"].optionsResume="\u518d\u958b";Q["jp-jp"].optionsQuit="\u3084\u3081\u308b";Q["jp-jp"].optionsStartScreen="\u30e1\u30a4\u30f3\u30e1\u30cb\u30e5\u30fc";Q["jp-jp"].levelEndScreenHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";Q["jp-jp"].levelEndScreenTimeBonus="\u30dc\u30fc\u30ca\u30b9\u30bf\u30a4\u30e0\uff01";Q["jp-jp"].levelEndScreenTimeLeft="\u6b8b\u308a\u6642\u9593";
Q["jp-jp"].levelEndScreenSubTitle_levelFailed="\u30ec\u30d9\u30eb\u5931\u6557";Q["jp-jp"].levelEndScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Q["jp-jp"].levelEndScreenTitle_endless="\u30b9\u30c6\u30fc\u30b8 <VALUE>";Q["jp-jp"].levelEndScreenTitle_difficulty="\u30af\u30ea\u30a2\uff01";Q["jp-jp"].levelEndScreenTitle_level="\u30ec\u30d9\u30eb <VALUE>";Q["jp-jp"].levelMapScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Q["jp-jp"].startScreenPlay="\u30d7\u30ec\u30a4";
Q["jp-jp"].loadingScreenLoading="\u30ed\u30fc\u30c7\u30a3\u30f3\u30b0";Q["jp-jp"].RewardAd_button="\u30d3\u30c7\u30aa";Q["jp-jp"].RewardAd_header="\u30b3\u30a4\u30f3";Q["jp-jp"].RewardAd_text_1="\u30d3\u30c7\u30aa\u3092\u89b3\u3066\n<COINS>\u30b3\u30a4\u30f3\u3092\u30b2\u30c3\u30c8\u3057\u3088\u3046\uff01";Q["jp-jp"].RewardAd_text_2="\u65b0\u3057\u3044\u30d3\u30c7\u30aa\u306f\u8fd1\u65e5\u516c\u958b\u3067\u3059";
O.I.Bk={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:25,Hb:75,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:4,pd:!0,h:[],ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};function nj(b){this.name="StartPlay";this.q(O.I.Bk);this.i(O.hp);void 0!==b&&this.i(b)}gm(nj,mm);
O.I.jl={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:10,Hb:60,Fd:30,Zc:"",Dc:"",$r:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),ji:!0,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!0,ge:F,ih:M,kh:null,buttons:[],hb:!0,sb:{k:Gl,duration:.8,Ma:P(-500),bb:P(0),D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null,KK:"",gc:void 0,yd:0,time:0,
ob:0,gk:0,Ii:0,Mt:0,cK:!1,vk:[],fp:[pd,rd,td],Fx:[qd,sd,ud],Ex:od,Ix:[P(-177),P(0),P(177)],Jx:[P(-117),P(-140),P(-117)],Hx:[P(0),P(0),P(0)],Gx:[P(0),P(0),P(0)],Ak:[],aP:[Pi,Qi,Ri],qu:"",ou:"",ru:P(0),su:P(15),pu:K,Pf:"",mu:"",tu:P(0),uu:P(50),nu:K,zw:"",Dr:"TOTAL SCORE:",Aw:P(0),Bw:P(15),Er:L,eg:"",yw:"",Cw:P(0),Dw:P(50),Cr:L,dx:"",Mr:"HIGH SCORE:",ex:P(0),fx:P(85),Nr:L,hg:"",cx:"",gx:P(0),hx:P(120),Lr:L,SG:L,TG:P(0),UG:P(0),Bu:"",kl:"Level Failed",Cu:P(0),sq:P(-15),rq:L,JA:!0,ro:Kd,NB:P(162),OB:P(184),
Wv:"next",hv:!0,Rw:ce,Sw:P(12),Tw:P(214),Qw:"restart",Md:!1,Nd:!1,Od:!1,Hq:!1,h:[],yo:null};function rj(b){this.name="EndPlayWon";this.q(O.I.Kw);this.i(O.I.jl);this.i(O.hI);void 0!==b&&this.i(b)}gm(rj,kl);a=rj.prototype;a.Vt=function(b,c,d){var e=this;c=new c({re:this.fp[d],Eg:this.Fx[d],lb:this.Ex,Ig:!1,rb:10,x:this.Ix[d],y:this.Jx[d],width:this.Hx[d],height:this.Gx[d],id:d,ob:this.ob,$d:this.aP[d],xd:function(b,c){e.Ou(c)}});this.Ak.push(c);b.g(c)};
a.Ou=function(b){void 0!==this.ob&&b<this.ob-1&&(this.Ak[b+1].gp=!0)};
a.Eb=function(b){switch(b){case "emphasized":this.Md&&(this.yn=new U({text:this.qu,s:this.ou,x:this.ru,y:this.su,font:this.pu}),this.j.g(this.yn),this.xn=new U({text:this.Pf,s:this.mu,x:this.tu,y:this.uu,font:this.nu}),this.j.g(this.xn),this.Md=!1);break;case "primary":this.Nd&&(this.So=new U({text:this.zw,s:this.Dr,x:this.Aw,y:this.Bw,font:this.Er}),this.j.g(this.So),this.Ro=new U({text:this.eg,s:this.yw,x:this.Cw,y:this.Dw,font:this.Cr}),this.j.g(this.Ro),this.Nd=!1);break;case "secondary":this.Od&&
(this.$o=new U({text:this.dx,s:this.Mr,x:this.ex,y:this.fx,font:this.Nr}),this.j.g(this.$o),this.Zo=new U({text:this.hg,s:this.cx,x:this.gx,y:this.hx,font:this.Lr}),this.j.g(this.Zo),this.Od=!1)}};
a.K=function(){this.Zc=xk(this.$r).replace("<VALUE>",O.xa.Fe.toString());rj.Bb.K.call(this);var b,c=this;this.uc=new am({y:this.cq,ra:[this.sb,{k:"show",duration:99999999},this.Ua,{k:"show",duration:9999999999}]});for(var d=0;d<this.vk.length;d++)switch(this.vk[d]){case "stars":for(b=0;3>b;b++)this.Vt(this.j,rn,b);this.Md=!1;break;case "score":this.Md?(this.Pf=this.yd.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.yd.toString(),this.Eb("primary")):this.Od&&(this.hg=this.yd.toString(),this.Eb("secondary"));
break;case "time":this.Md?(this.Pf=this.time.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.time.toString(),this.Eb("primary")):this.Od&&(this.hg=this.time.toString(),this.Eb("secondary"));break;case "moves":this.Md?(this.Pf=this.gk.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.gk.toString(),this.Eb("primary")):this.Od&&(this.hg=this.gk.toString(),this.Eb("secondary"));break;case "highscore":this.Md?(this.Pf=this.Ii.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.Ii.toString(),
this.Eb("primary")):this.Od&&(this.hg=this.Ii.toString(),this.Eb("secondary"));break;case "coins":b=new U({text:this.Mt.toString(),font:this.SG,x:this.TG,y:this.UG}),this.j.g(b)}this.JA&&(d=new $({c:this.ro,x:this.NB,y:this.OB,Qb:this.Wv,m:function(b){c.m&&c.m(c,b.Qb)}}),this.j.g(d));this.hv&&(d=new $({c:this.Rw,x:this.Sw,y:this.Tw,Qb:this.Qw,m:function(b){c.m&&c.m(c,b.Qb)}}),this.j.g(d));this.Hq&&(this.zn=new U({text:this.Bu,s:this.kl,x:this.Cu,y:this.sq,font:this.rq}),this.j.g(this.zn));if(this.h)for(b=
0;b<this.h.length;b+=1)this.j.g(this.h[b])};a.oa=function(){this.ic();this.uc=this.zn=this.Zo=this.$o=this.Ro=this.So=this.xn=this.yn=this.Ye=void 0};a.Wa=function(){if(this.Ak)for(var b=0;b<this.ob;b++){var c=this.Ak[b];b===c.id&&S.play(c.$d,730*(c.id+1))}};
O.I.Pj={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:10,Hb:60,Fd:30,Zc:"",Dc:"",$r:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),ji:!0,Pc:P(0),Lf:P(8),od:P(8),ki:"middle",jh:!0,ge:F,ih:M,kh:null,buttons:[],hb:!0,sb:{k:Gl,duration:.8,Ma:P(-500),bb:P(0),D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:9999999,pd:!1,h:[],m:null,ab:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null,nH:P(0),cq:P(-700),nh:!1,
KK:"",gc:void 0,yd:0,time:0,ob:0,gk:0,Ii:0,cK:!1,vk:[],fp:[pd,rd,td],Fx:[qd,sd,ud],Ex:od,Ix:[P(-165),P(0),P(165)],Jx:[P(-90),P(-160),P(-90)],Hx:[P(0),P(0),P(0)],Gx:[P(0),P(0),P(0)],Ak:[],qu:"",ou:"",ru:P(0),su:P(15),pu:K,Pf:"",mu:"",tu:P(0),uu:P(50),nu:K,zw:"",Dr:"TOTAL SCORE:",Aw:P(0),Bw:P(-65),Er:L,eg:"",yw:"",Cw:P(0),Dw:P(-30),Cr:L,dx:"",Mr:"HIGH SCORE:",ex:P(0),fx:P(5),Nr:L,hg:"",cx:"",gx:P(0),hx:P(40),Lr:L,Bu:"",kl:"Level Failed",Cu:P(0),sq:P(-135),rq:L,hv:!0,Rw:de,Sw:P(162),Tw:P(184),Qw:"restart",
Md:!1,Nd:!1,Od:!1,Hq:!1,h:[],m:null,yo:null};function sj(b){this.name="EndPlayLost";this.q(O.I.Kw);this.i(O.I.Pj);this.i(O.gI);void 0!==b&&this.i(b)}gm(sj,kl);a=sj.prototype;a.Vt=function(b,c,d){var e=this;c=new c({re:this.fp[d],Eg:this.Fx[d],lb:this.Ex,Ig:!1,rb:10,x:this.Ix[d],y:this.Jx[d],width:this.Hx[d],height:this.Gx[d],id:d,ob:this.ob,xd:function(b,c){e.Ou(c)}});this.Ak.push(c);b.g(c)};a.Ou=function(b){void 0!==this.ob&&b<this.ob-1&&(this.Ak[b+1].gp=!0)};
a.Eb=function(b){switch(b){case "emphasized":this.Md&&(this.yn=new U({text:this.qu,s:this.ou,x:this.ru,y:this.su,font:this.pu}),this.j.g(this.yn),this.xn=new U({text:this.Pf,s:this.mu,x:this.tu,y:this.uu,font:this.nu}),this.j.g(this.xn),this.Md=!1);break;case "primary":this.Nd&&(this.So=new U({text:this.zw,s:this.Dr,x:this.Aw,y:this.Bw,font:this.Er}),this.j.g(this.So),this.Ro=new U({text:this.eg,s:this.yw,x:this.Cw,y:this.Dw,font:this.Cr}),this.j.g(this.Ro),this.Nd=!1);break;case "secondary":this.Od&&
(this.$o=new U({text:this.dx,s:this.Mr,x:this.ex,y:this.fx,font:this.Nr}),this.j.g(this.$o),this.Zo=new U({text:this.hg,s:this.cx,x:this.gx,y:this.hx,font:this.Lr}),this.j.g(this.Zo),this.Od=!1)}};
a.K=function(){sj.Bb.K.call(this);var b,c=this;this.uc=new am({y:this.cq,ra:[this.sb,{k:"show",duration:99999999},this.Ua,{k:"show",duration:9999999999}]});for(var d=0;d<this.vk.length;d++)switch(this.vk[d]){case "stars":for(b=0;3>b;b++)this.Vt(this.j,rn,b);this.Md=!1;break;case "score":this.Md?(this.Pf=this.yd.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.yd.toString(),this.Eb("primary")):this.Od&&(this.hg=this.yd.toString(),this.Eb("secondary"));break;case "time":this.Md?(this.Pf=this.time.toString(),
this.Eb("emphasized")):this.Nd?(this.eg=this.time.toString(),this.Eb("primary")):this.Od&&(this.hg=this.time.toString(),this.Eb("secondary"));break;case "moves":this.Md?(this.Pf=this.gk.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.gk.toString(),this.Eb("primary")):this.Od&&(this.hg=this.gk.toString(),this.Eb("secondary"));break;case "highscore":this.Md?(this.Pf=this.Ii.toString(),this.Eb("emphasized")):this.Nd?(this.eg=this.Ii.toString(),this.Eb("primary")):this.Od&&(this.hg=this.Ii.toString(),
this.Eb("secondary"))}this.JA&&(b=new $({c:this.ro,x:this.NB,y:this.OB,Qb:this.Wv,m:function(b){c.m&&c.m(c,b.Qb)}}),this.j.g(b));this.hv&&(b=new $({c:this.Rw,x:this.Sw,y:this.Tw,Qb:this.Qw,m:function(b){c.m&&c.m(c,b.Qb)}}),this.j.g(b));this.Hq&&(this.zn=new U({text:this.Bu,s:this.kl,x:this.Cu,y:this.sq,font:this.rq}),this.j.g(this.zn));if(this.h)for(b=0;b<this.h.length;b+=1)this.j.g(this.h[b])};a.oa=function(){this.ic();this.uc=this.zn=this.Zo=this.$o=this.Ro=this.So=this.xn=this.yn=this.Ye=void 0};
a.Wa=function(){};O.I.QO={c:null,color:"white",duration:2,h:[],mC:null,Gk:null};function vj(b){this.name="SplashScreen";this.q(O.I.QO);this.i(O.Vr);void 0!==b&&this.i(b)}gm(vj,hm);vj.prototype.na=function(){this.w()};vj.prototype.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;this.c&&(this.Ql=new Z({c:this.c}),this.Ql.i(this.mC),this.g(this.Ql));this.gj=new $l({interval:this.duration,repeat:1,Qi:function(){c.w()}});this.gj.i(this.Gk);this.g(this.gj);for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};
vj.prototype.oa=function(){this.ic();this.gj=this.Ql=void 0};vj.prototype.Wa=function(){this.color&&(na(p,R.tg),p.clearColor(this.color),na(p,R.A))};
O.I.$K={x:void 0,y:void 0,width:P(480),height:P(480),backgroundImage:wc,sh:null,mh:null,zg:P(0),uh:P(-100),AA:void 0,Gz:P(0),Hz:P(276),EF:P(0),FF:P(100),DF:P(300),BF:0,Zl:null,sb:{k:Jl,duration:.2,Te:0,D:function(b,c,d,e){return Wb(b,c,d,e)}},Ua:{k:Jl,duration:.2,vi:0,D:Xb},hb:!1,Qj:null,Bn:60,Ie:P(200),h:[],Hh:null,bc:null,Tt:null,wb:null,th:null,jn:null,CF:null};function Pj(b){this.name="LoadScreen";this.q(O.I.$K);this.i(O.aL);void 0!==b&&this.i(b)}gm(Pj,hm);
Pj.prototype.na=function(){this.Ca();X(this.j,2)};
Pj.prototype.K=function(){var b,c=this;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);this.hb&&(this.pi=new cm({width:R.A.width,height:R.A.height}),this.pi.i(this.bc),this.g(this.pi));null!==this.Qj&&(b=function(b,e,g){b.x=c.Ie/2*Math.sin(2*Math.PI*g/c.Bn);b.y=c.Ie/2*-Math.cos(2*Math.PI*g/c.Bn)},this.Rj=new W({ra:{k:b,duration:9999999}}),this.Rj.Zv=function(){c.Qj.hu(0,-c.x-c.Ie/2,-c.y-c.Ie/2,p.width+c.Ie,p.height+c.Ie,1)},this.g(this.Rj));this.j=new am({ra:[this.sb,
{k:"show",duration:99999999},this.Ua],Mg:function(b,e){e===c.Ua&&c.hb&&dm(c.pi,c.pi.duration,c.j.ra[2].duration-c.pi.duration)},Td:function(){c.w()}});this.j.i(this.Tt);this.g(this.j);this.backgroundImage&&(this.background=new Z({c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height}),this.background.i(this.wb),this.j.g(this.background));b=Math.min(1,this.width/this.sh.width,this.height/2/this.sh.height);
this.AA&&(b=this.AA);this.zb=new Z({x:this.zg,y:this.uh,pb:b,Cb:b,c:this.sh});this.zb.i(this.th);this.j.g(this.zb);this.$e=new Z({x:this.Gz,y:this.Hz,c:this.mh});this.$e.i(this.jn);this.j.g(this.$e);this.ht=new bm({x:this.EF,y:this.FF,width:this.DF,height:this.BF,Zl:this.Zl,bw:function(){c.Hh&&c.Hh(c);Pj.prototype.na.call(c)}});this.ht.i(this.CF);this.j.g(this.ht);for(b=0;b<this.h.length;b+=1)this.j.g(this.h[b])};
Pj.prototype.oa=function(){this.ic();this.ht=this.$e=this.zb=this.Rj=this.pi=this.j=this.background=void 0};Pj.prototype.Wa=function(){};O.I.zP={backgroundImage:null,sh:null,Qu:{k:Gl,duration:.8,Ma:P(-500),bb:P(-100),D:dc,da:1.2},Ru:{k:Gl,duration:.8,Ma:P(-100),bb:P(-500),D:cc,da:1.2},mh:null,Gz:P(0),Hz:P(276),Ng:F,Mo:"",No:M,Vl:Mc,Og:P(0),Pg:P(100),Jh:P(300),Ih:P(0),ak:F,fo:Lc,ck:P(-300),dk:P(100),bk:P(0),$j:P(0),h:[],Ud:null,Kl:null,th:null,jn:null,Wl:null,Nv:null};
function Tj(b){this.name="TitleScreen";this.q(O.I.zP);this.i(O.tD);void 0!==b&&this.i(b)}gm(Tj,hm);Tj.prototype.na=function(){this.Ca();X(this.zb,2)};
Tj.prototype.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;this.zb=new Z({c:this.sh,ra:[this.Qu,{k:"show",duration:99999999},this.Ru],Td:function(){c.w()}});this.zb.i(this.th);this.g(this.zb);this.Oa=new $({c:this.Ng,x:this.Og,y:this.Pg,width:this.Jh,height:this.Ih,text:"PLAY",s:this.Mo,ya:this.No,qf:2,icon:this.Vl,Ja:"right",eb:P(30),Zd:14,m:function(){c.Ud&&c.Ud(c);c.Oa.w();c.Jg.w();Tj.prototype.na.call(c)}});this.Oa.i(this.Wl);this.g(this.Oa);this.Jg=new $({c:this.ak,x:this.ck,
y:this.dk,width:this.bk,height:this.$j,icon:this.fo,Ja:"center",eb:P(30),m:function(){c.Kl&&c.Kl(c)}});this.Jg.i(this.Nv);this.g(this.Jg);for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};Tj.prototype.oa=function(){this.ic();this.Jg=this.Oa=this.$e=this.zb=void 0};Tj.prototype.Wa=function(){this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A))};
O.I.ld={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:20,QA:30,Hb:30,Fd:20,ld:[],Mb:K,Wc:L,wC:zc,ro:yc,Bz:xc,MC:!0,interval:999999,Iw:!1,hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},h:[],bc:null,wb:null,Mc:null,pv:null,qP:null,Gk:null,gG:null,fG:null,UF:null};function xj(b){this.name="Tutorial";this.q(O.I.ld);this.i(O.vU);void 0!==b&&this.i(b)}gm(xj,hm);a=xj.prototype;
a.na=function(){this.Ca();X(this.j,2)};a.sk=function(b){var c;0>=this.ld.length||(0>b&&(b=0),b>=this.ld.length&&(b=this.ld.length-1),this.page=b,c=this.ld[b],this.title.i({s:c.xf}),this.title.Wd(),this.c.i({c:c.c}),void 0!==c.rb&&this.c.i({rb:c.rb}),this.message.i({s:c.pf}),this.message.Wd(),this.MC&&(0>=b?(this.Qo.i({alpha:.4}),this.Qo.Ca(0)):(this.Qo.i({alpha:1}),this.Qo.Db(0)),b>=this.ld.length-1?(this.qo.i({alpha:.4}),this.qo.Ca(0)):(this.qo.i({alpha:1}),this.qo.Db(0))),this.jb.reset())};
a.di=function(b,c,d,e){b=new b(c);void 0!==d&&b.i(d);void 0!==e&&b.i(e);this.g(b);return b};function zn(b,c,d,e){c=new c(d);void 0!==e&&c.i(e);b.h.push(c);return c}
a.K=function(){var b=this,c,d,e;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);this.hb&&(d=this.di(cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.di(Z,{c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:999999},this.Ua],Mg:function(c,e){e===b.Ua&&b.hb&&dm(d,d.duration,b.j.ra[2].duration-d.duration)},Td:function(){b.w()}},this.wb);
c=0===this.width?this.backgroundImage.width:this.width;c-=this.marginLeft+this.marginRight;e=0===this.height?this.backgroundImage.height:this.height;e-=this.marginTop+this.marginBottom;e=zn(this.j,Yl,{x:Math.round((this.marginLeft-this.marginRight)/2),y:Math.round((this.marginTop-this.marginBottom)/2),width:c,height:e,Pm:[!0,!1,!0,!1],Om:[!0,!1,!0,!0],dl:0,Kz:[Math.round(this.rc*e/100),Math.round(this.QA*e/100),Math.round(this.Hb*e/100),Math.round(this.Fd*e/100)]});this.title=zn(e,U,{font:this.Mb},
this.Mc);this.c=zn(e,Z,{},this.pv);this.message=zn(e,U,{font:this.Wc,Bc:!0},this.wd);this.MC&&(c=zn(e,Zl,{width:c-P(100),Pm:!1,Om:!1,Ip:"spread"}),this.Qo=zn(c,$,{c:this.wC,Zd:37,eb:P(20),Vi:!0,m:function(){xj.prototype.sk.call(b,b.page-1)}},this.gG),this.qo=zn(c,$,{c:this.ro,Zd:39,eb:P(20),Vi:!0,m:function(){xj.prototype.sk.call(b,b.page+1)}},this.fG),zn(c,$,{c:this.Bz,Zd:27,eb:P(20),Vi:!0,m:function(){xj.prototype.na.call(b)}},this.UF));this.jb=zn(this.j,$l,{pq:!0,interval:this.interval,repeat:this.ld.length,
Qi:function(){b.page>=b.ld.length-1?xj.prototype.na.call(b):xj.prototype.sk.call(b,b.page+1)}},this.Gk);this.Iw&&(this.jb.Ri=this.jb.Qi);for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){this.ic();this.qo=this.Qo=this.message=this.c=this.title=this.j=void 0};a.Wa=function(){this.sk(0)};O.I.gJ={CP:0,DP:P(-200),aK:0,bK:0,zL:0,AL:P(200),ld:[],Mb:K,Wc:L,interval:3,Iw:!0,hb:!0,iq:"white",on:.6,h:[],bc:null,Mc:null,pv:null,qP:null,Gk:null};
function An(b){this.name="GameTutorial";this.q(O.I.gJ);this.i(O.KR);void 0!==b&&this.i(b)}gm(An,hm);a=An.prototype;a.na=function(){this.Ca();this.jq?dm(this.jq,this.jq.duration,0):this.w()};a.sk=function(b){0>=this.ld.length||(0>b&&(b=0),b>=this.ld.length&&(b=this.ld.length-1),this.page=b,b=this.ld[b],this.ce.i({s:b.xf}),this.ce.Wd(),this.ov.i({c:b.c}),void 0!==b.rb&&this.ov.i({rb:b.rb}),this.Ov.i({s:b.pf}),this.Ov.Wd(),this.gj.reset())};
a.di=function(b,c,d,e){b=new b(c);void 0!==d&&b.i(d);void 0!==e&&b.i(e);this.g(b);return b};
a.K=function(){var b=this,c;this.x=R.A.width/2;this.y=R.A.height/2;this.hb&&(this.jq=this.di(cm,{width:R.A.width,height:R.A.height,iq:this.iq,on:this.on,dw:function(){b.w()}},this.bc));this.ce=this.di(U,{x:this.CP,y:this.DP,font:this.Mb},this.Mc);this.ov=this.di(Z,{x:this.aK,y:this.bK},this.pv);this.Ov=this.di(U,{x:this.zL,y:this.AL,width:R.A.width/2,height:R.A.height/4,font:this.Wc,Bc:!0,dd:!0},this.wd);this.gj=this.di($l,{pq:!0,interval:this.interval,repeat:this.ld.length,Qi:function(){b.page>=
b.ld.length-1?An.prototype.na.call(b):An.prototype.sk.call(b,b.page+1)}},this.Gk);this.Iw&&(this.gj.Ri=this.gj.Qi);for(c=0;c<this.h.length;c+=1)this.g(this.h[c])};a.oa=function(){this.ic();this.gj=this.Ov=this.ov=this.ce=this.jq=void 0};a.Wa=function(){this.sk(0)};
O.I.ZG={backgroundImage:null,Qt:null,Lz:"flowCompletionCongratulations",Mz:K,kH:0,lH:P(-100),iH:0,jH:0,eH:{k:Gl,duration:.8,Ma:P(-400),bb:P(-100),D:dc,da:1.2},fH:{k:Gl,duration:.8,Ma:P(-100),bb:P(-400),D:cc,da:1.2},Pz:F,oH:"flowCompletionContinue",Oz:M,qH:null,rH:"left",uH:P(0),vH:P(200),tH:P(400),pH:P(0),h:[],TB:null,hH:null,gH:null,sH:null};function Xj(b){this.name="CompletionScreen";this.q(O.I.ZG);this.i(O.aH);void 0!==b&&this.i(b)}gm(Xj,hm);Xj.prototype.na=function(){this.Ca();X(this.kn,2)};
Xj.prototype.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;this.kn=new am({x:this.kH,y:this.lH,ra:[this.eH,{k:"show",duration:99999999},this.fH],Td:function(){c.w()}});this.g(this.kn);this.Qt&&(this.St=new Z({c:this.Qt}),this.St.i(this.hH),this.kn.g(this.St));""!==this.Lz&&(this.Rt=new U({x:this.iH,y:this.jH,s:this.Lz,font:this.Mz}),this.Rt.i(this.gH),this.kn.g(this.Rt));this.dq=new $({c:this.Pz,x:this.uH,y:this.vH,width:this.tH,height:this.pH,text:"<CONTINUE>",s:this.oH,ya:this.Oz,
qf:2,icon:this.qH,Ja:this.rH,eb:P(30),Zd:14,m:function(){c.TB&&c.TB(c);c.dq.w();Xj.prototype.na.call(c)}});this.dq.i(this.sH);this.g(this.dq);for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};Xj.prototype.oa=function(){this.ic();this.dq=this.Rt=this.St=this.kn=void 0};Xj.prototype.Wa=function(){this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A))};
O.I.AP={backgroundImage:null,ZR:[],$R:[],sh:null,zg:P(0),uh:P(-500),Qu:{k:Gl,duration:.8,Ma:P(-500),bb:P(-135),D:dc,da:1.2},Ru:{k:Gl,duration:.8,Ma:P(-135),bb:P(-500),D:cc,da:1.2},Ng:F,Mo:"startScreenPlay",tw:"",No:M,Vl:Mc,Og:P(0),Pg:P(120),Jh:P(300),Ih:P(104),Sl:{k:Hl,duration:.5,jc:P(0),cc:P(1),D:bc,da:1},Tl:{k:Hl,duration:.5,jc:P(1),cc:P(0),D:bc,xR:0},Ul:{k:qn,duration:4,bj:1,wi:1.25,cj:1,xi:.9,da:1,name:"elastic"},ak:F,fo:Lc,ck:P(-300),dk:P(100),bk:P(0),$j:P(0),wL:"",vL:M,uL:"",IL:F,DL:["Easy",
"Medium","Hard"],EL:M,HL:"right",KL:[],GL:[Ec,Gc,Fc],ML:P(0),NL:P(200),LL:P(400),FL:P(0),GB:!1,EB:P(0),mh:Dd,hn:[{x:P(0),y:P(276)}],Fz:P(0),Ez:P(0),Pt:"http://www.tinglygames.com",vK:F,Av:[],yK:P(-300),zK:P(200),xK:P(0),uK:P(0),zv:!1,dB:P(0),vG:F,xG:P(200),tG:P(92),wG:"Buy",uG:je,yG:P(-200),zG:P(-400),CJ:!1,WI:Qd,YI:P(300),VI:P(100),ZI:P(0),$I:P(350),XI:"Gallery",HJ:!1,FQ:!1,uO:!1,IA:!1,KJ:!1,WL:Qd,TL:"Random Match",UL:M,YL:P(0),MB:P(138),XL:P(420),VL:P(104),h:[],Ud:null,Kl:null,cw:null,$B:null,SB:null,
gw:null,TS:null,XB:null,fC:null,YB:null,th:null,jn:null,Wl:null,Nv:null,JL:null,wK:null};function Gj(b){this.name="TitleScreen";this.q(O.I.AP);this.i(O.tD);void 0!==b&&this.i(b)}gm(Gj,hm);a=Gj.prototype;a.na=function(){this.Ca();void 0!==this.Oa&&X(this.Oa,3);void 0!==this.Jg&&this.Jg.w();void 0!==this.zb&&X(this.zb,2);void 0!==this.mo&&this.mo.w();void 0!==this.yh&&this.yh.w()};
a.mw=function(){var b=this,c;O.r.OC&&(O.r.Tn?(c=new Hj(O.r.Tn),c.m=function(b,c){Rb();b.Dj(c)},c.ub=function(){b.yh.icon=zk(yk.Ee);b.yh.Wd()},Pb(),c.show()):console.log("No languageScreenProperties can be found"))};function Bn(){var b;O.r.SC&&(O.r.yP?(b=new Cj(O.r.yP),b.m=function(){},b.ub=function(){Rb()},Pb(),b.show()):console.log("No titleMenuProperties can be found"))}function Cn(b){for(var c=yk.Ag(),d=yk.Ee,e=0;e<c.length;e++)b.Av.push(zk(c[e])),c[e]===d&&(b.dB=e)}
a.Hy=function(b){b.sort(function(b,d){return b.d-d.d});this.Ay(b)};a.Ay=function(b){console.log(b);for(var c=0;c<b.length;c++)this.h.push(b[c])};a.nA=function(){var b=this;Tm.Dl?(this.Ai.w(),this.Bi.show(),this.Bi.Db()):Sm(function(){console.log("Fb Success");b.Ai.w();b.Bi.show();b.Bi.Db()},function(){console.log("Fb Fail")})};a.AG=function(){console.log("Buy Callback Success")};
a.K=function(){var b,c=this;this.x=R.A.width/2;this.y=R.A.height/2;window.addEventListener("orientationchange",function(){console.log(window.availHeight+"  OR   "+window.innerHeight);R.j.style.height=window.availHeight||window.innerHeight},!1);this.zb=new Z({c:this.sh,y:this.uh,x:this.zg,ra:[this.Qu,{k:"show",duration:99999999},this.Ru],Td:function(){c.w()}});this.zb.i(this.th);this.g(this.zb);this.IA||(this.Oa=new $({c:this.Ng,x:this.Og,y:this.Pg,width:this.Jh,height:this.Ih,text:this.tw,s:this.Mo,
ya:this.No,qf:2,ra:[this.Sl,this.Ul,{k:"show",duration:99999999},this.Tl],icon:this.Vl,Ja:"right",eb:P(30),Zd:14,ag:function(b,e){"elastic"===e.name&&X(c.Oa,1)},m:function(){c.Ud&&c.Ud("play");Gj.prototype.na.call(c)}}),this.Oa.i(this.Wl),this.g(this.Oa));this.IA&&(this.Uv=new $({c:this.WL,x:this.YL,y:this.MB,ra:[this.Sl,this.Ul,{k:"show",duration:99999999},this.Tl],s:this.TL,width:this.XL,height:this.VL,ya:this.UL,ag:function(b,e){"elastic"===e.name&&X(c.Uv,1)},m:function(){c.gw&&c.gw(c);c.Ca()}}),
this.g(this.Uv));this.HJ&&(this.UI=new $({c:this.WI,width:this.YI,height:this.VI,x:this.ZI,y:this.$I,text:this.XI,m:function(){c.YB&&c.YB("gallery")}}),this.g(this.UI));this.jB=new on({});this.uO&&(this.Ai=new $({c:s_button_default_facebook,icon:s_button_default_icon_facebook,x:P(0),y:P(185),marginRight:P(0),marginLeft:P(50),pe:P(2),text:"Login to Facebook",ya:NotSoStoutDeco,width:P(400),height:P(104),m:function(){c.nA&&c.nA()}}),this.g(this.Ai),this.Bi=new $({c:s_button_default_green,text:"Challenge a friend",
width:P(400),height:P(104),ya:NotSoStoutDeco,x:P(0),y:P(185),m:function(){c.XB&&c.XB()}}),this.g(this.Bi));this.Jg=new $({c:this.ak,text:this.wL,ya:this.vL,s:this.uL,x:this.ck,y:this.dk,width:this.bk,height:this.$j,icon:this.fo,Ja:"center",eb:P(30),m:function(){c.Kl?c.Kl(c):Bn()}});this.Jg.i(this.Nv);this.jB.g(this.Jg);this.g(this.jB);this.GB&&(this.mo=new $({c:this.IL,icon:this.GL,Ja:this.HL,text:this.KL,s:this.DL,ya:this.EL,qf:2,x:this.ML,y:this.NL,width:this.LL,height:this.FL,kb:this.EB,Yh:!0,
m:function(b){c.$B&&c.$B(c);this.EB=b.kb}}),this.mo.i(this.JL),this.g(this.mo));this.CJ&&(this.sG=new $({c:this.vG,icon:this.uG,width:this.xG,height:this.tG,x:this.yG,y:this.zG,text:this.wG,m:function(){v.LM(c.AG)}}),this.g(this.sG));this.zv&&(0===this.Av.length&&Cn(this),this.yh=new $({c:this.vK,icon:this.Av[this.dB],x:this.yK,y:this.zK,width:this.xK,height:this.uK,m:function(){c.cw?c.cw(c):c.mw()}}),this.yh.i(this.wK),this.g(this.yh));this.am=new on({Kp:new k(1,0)});this.KJ&&(this.MD=new $({c:s_button_drop_right,
icon:je,text:"0",ya:NotSoStoutDeco,x:P(-100),y:P(580),width:P(153),height:P(114),m:function(){c.fC&&c.fC()}}),this.am.g(this.MD),this.g(this.am));if("[object Array]"===Object.prototype.toString.call(this.mh))for(b=0;b<this.mh.length;b++)this.$e=new Z({c:this.mh[b],x:this.hn[b].x,y:this.hn[b].y,width:this.Fz,height:this.Ez,link:this.Pt[b],WJ:b,m:function(){c.SB?c.SB[this.WJ].call():""!==this.link&&window.open(this.link)}}),this.$e.i(this.jn),this.am.g(this.$e),this.g(this.am);else this.$e=new Z({c:this.mh,
x:this.hn[0].x,y:this.hn[0].y,width:this.Fz,height:this.Ez,link:this.Pt,m:function(){""!==this.link&&window.open(this.link,"_blank")}}),this.$e.i(this.jn),this.am.g(this.$e),this.g(this.am);this.zv&&(this.yh.icon=zk(yk.Ee),this.yh.Wd());for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.ic();this.MD=this.Bi=this.Uv=this.Ai=this.yh=this.mo=this.$e=this.Jg=this.Oa=this.$e=this.zb=void 0};
a.Wa=function(){this.backgroundImage&&(na(p,R.tg),ua(this.backgroundImage,0,0),na(p,R.A));Tm&&this.Ai&&(Tm.Dl?this.Ai.w():this.Bi.w())};a.Mf=function(){Tm&&this.Ai&&(Tm.Dl?this.Ai.w():this.Bi.w())};a.wo=function(){yk.Oh(yk.Ee);this.Oa&&this.Oa.Wd()};O.I.BK={Wp:P(500),Vp:P(500),cn:[],Aj:P(0),Vm:[],Wm:[],bd:[],h:[],$w:null};function Hj(b){this.name="LanguageScreen";this.q(O.I.an);this.i(O.I.BK);this.i(O.xP);void 0!==b&&this.i(b)}gm(Hj,lm);a=Hj.prototype;a.na=function(){this.Ca();X(this.j,2)};
function Dn(b,c,d){c=new Rl(c);void 0!==d&&c.i(d);b.g(c)}a.ts=function(b,c,d,e,g){b=new c(d);void 0!==e&&b.i(e);void 0!==g&&b.i(g);this.cn.push(b)};
a.Xe=function(b,c,d,e,g,h){var l=this;return this.ts(b,$m,{x:e,y:g,width:h,height:0,c:void 0===c.c?this.ge:c.c,text:this.Wm[d],vl:this.bd[d],s:void 0===c.key?"":c.key,icon:this.Vm[d],Ja:"left",font:void 0===c.font?this.ih:c.font,Qb:void 0===c.id?d:c.id,zj:void 0===c.w?this.jh:c.w,tc:!1,qf:2,threshold:P(1.5),m:function(b){b.zj&&lm.prototype.na.call(l);l.m&&l.m(l,b.Qb)}},this.kh,c.Jw)};a.Dj=function(b){yk.Oh(yk.Ag()[b]);this.Ca();X(this.j,2)};
a.Nn=function(){this.bd=yk.Ag();for(var b=0;b<this.bd.length;b++)this.Vm.push(zk(this.bd[b])),this.Wm.push(Ak(this.bd[b]))};
a.K=function(){var b=this,c,d,e,g=[],h=[],l=[];c=[];var m,n,s,w,y,D;void 0===this.x&&(this.x=R.A.width/2);void 0===this.y&&(this.y=R.A.height/2);m=0===this.width?this.backgroundImage.width:this.width;n=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);h[0]=Math.round(-n/2+this.marginTop);c[0]=Math.round(this.rc*(n-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);h[1]=Math.round(h[0]+c[0]);c[1]=Math.round(this.Hb*(n-this.marginTop-this.marginBottom)/100);this.Ia&&(l[2]=this.Ia.width,g[2]=g[1]+l[1]-l[2],h[2]=h[1],c[2]=c[1],l[1]-=l[2]+P(32),"left"===this.Ja&&(g[2]=g[1],g[1]+=l[2]+P(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Pc&&(g[3]=Math.round(-this.Pc/2),l[3]=this.Pc);h[3]=Math.round(h[1]+c[1]);c[3]=Math.round(this.Fd*(n-this.marginTop-this.marginBottom)/100);this.hb&&
(D=this.Ta(this,cm,{width:R.A.width,height:R.A.height},this.bc));this.j=this.Ta(this,Z,{c:this.backgroundImage,Tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,ra:[this.sb,{k:"show",duration:this.oc},this.Ua],Mg:function(c,d){d===b.Ua&&b.hb&&dm(D,D.duration,b.j.ra[2].duration-D.duration)},Td:function(){b.w()}},this.wb);this.pd&&(this.j.Ri=function(){b.ab&&b.ab(b);lm.prototype.na.call(b)});this.rc&&this.Ta(this.j,U,{x:Math.round(g[0]+
l[0]/2),y:Math.round(h[0]+c[0]/2),width:l[0],height:c[0],text:this.Zc,s:this.Dc,font:this.Mb,dd:!0,Bc:!1,Ea:P(20)},this.Mc);this.Hb&&this.Ta(this.j,U,{x:Math.round(g[1]+l[1]/2),y:Math.round(h[1]+c[1]/2),width:l[1],height:c[1],text:this.Qd,s:this.vd,font:this.Wc,dd:!0,Bc:!0,Ea:P(20)},this.wd);this.Hb&&this.Ia&&this.Ta(this.j,Z,{c:this.Ia,x:Math.round(g[2]+l[2]/2),y:Math.round(h[2]+c[2]/2)},this.Lc);this.Ub&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.lc/2),n=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.Qc/2),this.Ta(this.j,$,{x:m,y:n,width:this.lc,height:this.Qc,c:uc,m:function(){b.ab&&b.ab(b);lm.prototype.na.call(b)}},this.je));this.Nn();if(this.Fd){m=this.ji?[this.buttons]:this.buttons;d=this.ge.height;n=d+this.od;h=Math.round(h[3]+d/2);switch(this.ki){case "top":break;case "bottom":h+=c[3]-m.length*n-this.od;break;default:h+=Math.round((c[3]-m.length*n-this.od)/2)}for(c=e=0;c<m.length;c+=1)if("[object Array]"===Object.prototype.toString.call(m[c]))for(y=
Math.round((l[3]-this.Lf*(m[c].length-1))/m[c].length),w=y+this.Lf,s=Math.round(g[3]+y/2),this.Aj+=n+this.od,d=0;d<m[c].length;d+=1)this.Xe(this.j,m[c][d],e,s+d*w,h+c*n,y),e+=1;else this.Xe(this.j,m[c],e,Math.round(g[3]+l[3]/2),h+c*n,l[3]),e+=1}Dn(this.j,{cm:!1,az:0,bz:0,width:this.Wp,height:this.Vp,$a:this.ge.width,Ga:this.Aj,h:this.cn},this.$w);for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){Hj.Bb.oa.call(this)};
O.I.BM={bg:[],Fo:[{x:P(0),y:P(-180)},{x:P(0),y:P(-80)},{x:P(0),y:P(20)},{x:P(0),y:P(120)},{x:P(0),y:P(220)}],xc:P(0),yc:P(0),vl:void 0,jf:M,pA:void 0,DI:P(0),EI:P(0),Ct:Qd,yz:M,At:"optionsTutorial",Et:P(400),Bt:P(92),Dt:"",rG:null,rx:Cc,sx:Dc,tx:P(400),px:P(92),qx:Ic,yx:Cc,zx:Dc,Ax:P(400),wx:P(92),xx:Kc,wt:Qd,xz:M,ut:"optionsMoreGames",zt:P(400),vt:P(92),xt:"",eG:null,yt:"http://www.coolgames.com/",rt:Qd,qz:M,pt:"optionsAbout_title",tt:P(400),qt:P(92),st:"",QF:null,TF:Qd,$Q:M,RF:"Close",WF:P(400),
SF:P(92),VF:"",aR:null,ZF:Qd,bR:M,tz:"optionsExit",aG:P(400),YF:P(92),$F:"",cR:null,XF:!1,oG:Qd,hR:M,mG:"optionsResume",qG:P(400),nG:P(92),pG:"",iR:null,jG:Qd,fR:M,hG:"optionsQuit",lG:P(400),iG:P(92),kG:"",gR:null,GN:"",IN:P(0),JN:P(-120),HN:P(400),FN:P(200),EN:"optionsRestartConfirmationText",yC:L,AT:"",BT:P(0),CT:P(-80),yT:"If you quit now you will \n lose all progress made \n during this level. Are you \n sure you want to quit?",zT:M,MN:Qd,PN:P(0),QN:P(120),ON:P(400),LN:P(92),NN:"",KN:"optionsQuitConfirmBtn_Yes",
Mw:"",yN:Qd,BN:P(0),CN:P(220),AN:P(400),xN:P(92),zN:"",wN:"optionsQuitConfirmBtn_No",cG:Qd,uz:[],vz:[],wz:0,bd:[],dG:P(400),bG:P(92),hq:void 0,jM:Qd,iM:[Xd,Wd],kM:P(200),hM:P(92),fM:Qd,eM:[ae,$d],gM:P(200),dM:P(92),BJ:!1,Si:null,jk:null,zo:null,kk:null,Co:null,Ll:null,Hl:null,ab:null,$v:null,cC:null,bC:null,Ao:null,YS:null,ii:null,Sc:null,Rg:null,by:null,nr:null,Sr:null,AK:null,Pv:null,Ts:null,RG:null,lI:null,YN:null,DN:null};
function Cj(b){this.name="OptionScreen";this.q(O.I.an);this.i(O.I.BM);void 0!==b&&this.i(b)}gm(Cj,lm);a=Cj.prototype;a.na=function(){this.Ca();X(this.j,2)};a.mw=function(){var b;O.r.OC&&(O.r.Tn?(b=new Hj(O.r.Tn),b.m=function(b,d){Rb();b.Dj(d)},Pb(),b.show()):console.log("No languageScreenProperties can be found"))};a.nw=function(){var b;O.r.mx&&(O.r.ay?(b=new xj(O.r.ay),b.m=function(){Rb()},Pb(),b.show()):console.log("No tutorialMenuProperties can be found"))};
a.lw=function(){var b;b=new wj({backgroundImage:this.Wk,Ub:!0});b.ub=function(){Rb()};Pb();b.show()};a.wj=function(b){this.xc=this.Fo[b].x;this.yc=this.Fo[b].y};a.Dj=function(b){this.vl=b;var c=yk.Ag();yk.Oh(c[b]);jj.Oh(c[b])};a.Nn=function(){var b=yk.Ee;this.bd=yk.Ag();for(var c=0;c<this.bd.length;c++)this.uz.push(zk(this.bd[c])),this.vz.push(Ak(this.bd[c])),b===this.bd[c]&&(this.wz=c)};
a.K=function(){var b=this,c,d=0;Cj.Bb.K.call(this);this.Sc=new am({});this.Rg=new am({});this.pA&&(this.CI=new Z({c:this.pA,x:this.DI,y:this.EI}),this.Sc.g(this.CI));for(c=0;c<this.bg.length;c++)if(v.Vu()||"moregames"!==this.bg[c])if(void 0===v.CA||!v.CA()||"audio"!==this.bg[c]&&"oldSound"!==this.bg[c])switch(this.wj(c-d),this.bg[c]){case "tutorial":this.Hk=new $({c:this.Ct,ya:this.jf,x:this.xc,y:this.yc,width:this.Et,height:this.Bt,text:this.Dt,s:this.At,m:function(){b.Si?b.Si(b):b.nw()}});this.Hk.i(this.by);
this.Sc.g(this.Hk);break;case "music":this.Kg=new em({icon:this.qx,za:this.rx,Pd:this.sx,x:this.xc,y:this.yc,width:this.tx,height:this.px,Il:function(c,d){b.zo?b.zo(b):pl(S,d/100)},Jl:function(){b.jk&&b.jk(b)}});this.Kg.i(this.nr);this.Sc.g(this.Kg);break;case "audio":this.Tg=new em({icon:this.xx,za:this.yx,Pd:this.zx,x:this.xc,y:this.yc,width:this.Ax,height:this.wx,Il:function(c,d){b.Co?b.Co(b):ol(S,d/100)},Jl:function(){b.kk&&b.kk(b)}});this.Tg.i(this.Sr);this.Sc.g(this.Tg);break;case "oldSound":var e=
this.xc/2,g=2*this.xc;0===e&&(e=this.hq?-this.hq:P(-100));0===g&&(g=this.hq?this.hq:P(100));var h=uk(jj),l=1;h.qh||(l=0);var m=1;h.Fh||(m=0);this.Kg=new $({c:this.jM,x:e,y:this.yc,icon:this.iM,Ja:"center",ya:this.jf,width:this.kM,height:this.hM,kb:m,Yh:!0,m:function(c){b.jk&&b.jk(b);switch(c.kb){case 0:tl(S);Sk(void 0,!1);break;case 1:sl(S),Sk(void 0,!0)}}});this.Kg.i(this.nr);this.Sc.g(this.Kg);this.Tg=new $({c:this.fM,x:g,y:this.yc,icon:this.eM,Ja:"center",ya:this.jf,width:this.gM,height:this.dM,
kb:l,Yh:!0,m:function(c){b.kk&&b.kk(b);switch(c.kb){case 0:rl(S);Sk(!1,void 0);break;case 1:ql(S),Sk(!0,void 0)}}});this.Tg.i(this.Sr);this.Sc.g(this.Tg);break;case "oldLanguage":this.Nn();e=new $({c:this.cG,icon:this.uz,Ja:"left",marginLeft:P(40),text:this.vz,kb:this.wz,width:this.dG,height:this.bG,x:this.xc,y:this.yc,ya:this.jf,Yh:!0,m:function(c){b.Dj(c.kb)}});this.Sc.g(e);break;case "moregames":this.ek=new $({c:this.wt,x:this.xc,y:this.yc,width:this.zt,height:this.vt,text:this.xt,link:this.yt,
s:this.ut,ya:this.jf,m:function(){b.Ll?b.Ll():void 0!==v.Cq()&&window.open(v.Cq())}});this.ek.i(this.Pv);this.Sc.g(this.ek);break;case "about":this.uj=new $({c:this.rt,x:this.xc,y:this.yc,width:this.tt,height:this.qt,text:this.st,s:this.pt,ya:this.jf,m:function(){b.Hl?b.Hl(b):b.lw()}});this.uj.i(this.Ts);this.Sc.g(this.uj);break;case "close":this.Lt=new $({c:this.TF,x:this.xc,y:this.yc,width:this.WF,height:this.SF,text:this.VF,s:this.RF,ya:this.jf,Qb:this.Mw,m:function(c){b.BJ?(b.na(),b.Ao&&b.Ao(b,
c.Qb)):b.ab&&b.ab(b)}});this.Lt.i(this.RG);this.Sc.g(this.Lt);break;case "exit":this.Au=new $({c:this.ZF,x:this.xc,y:this.yc,width:this.aG,height:this.YF,text:this.$F,s:this.tz,ya:this.jf,m:function(){b.$v?b.$v(b):b.XF&&Cj.prototype.na.call(b)}});this.Au.i(this.lI);this.Sc.g(this.Au);break;case "resume":this.Uw=new $({c:this.oG,x:this.xc,y:this.yc,width:this.qG,height:this.nG,text:this.pG,s:this.mG,ya:this.jf,m:function(){b.cC?b.cC(b):b.na()}});this.Uw.i(this.YN);this.Sc.g(this.Uw);break;case "quit":this.Lw=
new $({c:this.jG,x:this.xc,y:this.yc,width:this.lG,height:this.iG,text:this.kG,s:this.hG,ya:this.jf,m:function(){b.bC?b.bC(b):(b.Sc.w(),b.Rg.show(),b.Rg.Db())}}),this.Lw.i(this.DN),this.Sc.g(this.Lw),e=new U({text:this.GN,s:this.EN,x:this.IN,y:this.JN,width:this.HN,height:this.FN,font:this.yC,Bc:!0,dd:!0}),this.Rg.g(e),e=new $({c:this.MN,x:this.PN,y:this.QN,width:this.ON,height:this.LN,s:this.KN,ya:this.jf,text:this.NN,Qb:this.Mw,m:function(c){b.na();b.Ao&&b.Ao(b,c.Qb)}}),this.Rg.g(e),e=new $({c:this.yN,
x:this.BN,y:this.CN,width:this.AN,height:this.xN,s:this.wN,ya:this.jf,text:this.zN,m:function(){b.Rg.w();b.Sc.show();b.Sc.Db()}}),this.Rg.g(e),this.j.g(this.Rg)}else d++;else d++;this.j.g(this.Sc);for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.Wa=function(){this.Rg.w()};a.oa=function(){Cj.Bb.oa.call(this);this.Lw=this.Uw=this.Au=this.Lt=this.uj=this.ek=this.Tg=this.Kg=this.Hk=void 0};
O.I.NK={uC:bi,Vc:0,mode:O.xa.Wt,WR:0,AR:[],kS:null,XA:!1,Zc:"",sU:"",vD:"",Mb:K,Ng:Qd,Vl:Mc,Og:P(0),Pg:P(200),Jh:P(300),Ih:P(92),RM:"rigth",tw:"",Mo:"startScreenPlay",No:M,ZO:!0,dP:[pd,rd,td],hD:[{x:P(-177),y:P(-117)},{x:P(0),y:P(-140)},{x:P(177),y:P(-114)}],xI:qd,yI:P(-177),zI:P(-117),iO:sd,jO:P(0),kO:P(-140),uP:ud,vP:P(177),wP:P(-117),qK:"",Sn:"Goal",rK:P(0),sK:P(20),aB:K,ul:"",xv:"",yv:P(0),Rq:P(60),bB:P(500),ZA:P(400),Qq:L,ZT:!0,h:[],Ud:null};
function zj(b){this.name="LevelPopUp";this.q(O.I.an);this.i(O.I.NK);this.i(O.rB);void 0!==b&&this.i(b)}gm(zj,lm);zj.prototype.na=function(){this.Ca();X(this.j,2)};zj.prototype.UM=function(){this.Ca();X(this.j,2)};
function En(b){var c=gn(),d=Qk(jj,b.mode,b.Vc);if(b.ZO){for(var d=d.Xf,e=0;3>e;e++){var g=new Z({c:b.dP[e],x:b.hD[e].x,y:b.hD[e].y});b.j.g(g)}0<d&&(e=new Z({c:b.xI,x:b.yI,y:b.zI}),b.j.g(e));1<d&&(e=new Z({c:b.iO,x:b.jO,y:b.kO}),b.j.g(e));2<d&&(e=new Z({c:b.uP,x:b.vP,y:b.wP}),b.j.g(e))}b.Oa=new $({c:b.Ng,x:b.Og,y:b.Pg,width:b.Jh,height:b.Ih,icon:b.Vl,Ja:b.RM,text:b.tw,s:b.Mo,ya:b.No,qf:2,Qb:b.Vc,m:function(){zj.prototype.UM.call(b);b.XA=!0}});b.j.g(b.Oa);d=void 0;switch(c.hc[b.Vc-1].C.mode){case "points":e=
c.hc[b.Vc-1].R.Z;b.ul=xk("GoalText_01").replace("<TARGET>",e.toString());b.Sn="LevelTheme_01";d=oi;break;case "type":e=c.hc[b.Vc-1].type.V;c=c.hc[b.Vc-1].type.aa;b.ul=xk("GoalText_02").replace("<TARGET>",e.toString());b.Sn="LevelTheme_02";switch(c){case "BIGCORNER":d=mh;break;case "BIGSQUARE":d=nh;break;case "DASH":d=oh;break;case "DOT":d=ph;break;case "FRIKANDEL":d=qh;break;case "KROKET":d=rh;break;case "LINE":d=sh;break;case "MINICORNER":d=th;break;case "SQUARE":d=vh}break;case "counter":e=c.hc[b.Vc-
1].B.X.length,b.ul=xk("GoalText_03").replace("<TARGET>",e.toString()),b.Sn="LevelTheme_03",d=pi}d&&(c=new Z({c:d,x:P(0),y:P(113)}),b.j.g(c));b.$A=new U({x:b.rK,y:b.sK,text:b.qK,s:b.Sn,font:b.aB});b.j.g(b.$A);b.tl=new U({x:b.yv,y:b.Rq,text:b.ul,s:b.xv,font:b.Qq});b.j.g(b.tl)}
zj.prototype.K=function(){var b=this,c;this.backgroundImage=this.uC;this.Zc=xk(this.vD).replace("<VALUE>",this.Vc.toString());this.marginTop=P(20);zj.Bb.K.call(this);En(this);this.j.ub=function(){b.Ud&&b.XA&&b.Ud(b,b.Vc)};for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};zj.prototype.oa=function(){wj.Bb.oa.call(this);this.$A=this.tl=this.Oa=void 0};
O.I.AE={Wk:bi,Us:"optionsAbout_header_publisher",Ws:"",Vs:K,Xs:P(0),Ys:P(-250),Ls:Ed,Ns:P(0),Os:P(-100),Ms:"http://www.coolgames.com/",Ps:"",yE:"optionsAbout_text",Qs:P(0),Rs:P(100),Ss:"http://www.coolgames.com/",zE:L,Gs:Qd,Hs:"",Ds:"optionsAbout_backBtn",Es:M,Js:P(0),Ks:P(200),Is:P(400),Fs:P(92),BP:P(0),xo:null,h:[],Mc:null,mC:null,iS:null,eR:null};function wj(b){this.name="AboutScreen";this.q(O.I.an);this.i(O.I.AE);this.i(O.CM);void 0!==b&&this.i(b)}gm(wj,lm);
wj.prototype.na=function(){this.Ca();X(this.j,2)};
wj.prototype.rv=function(){var b=this;this.ce=new U({text:this.Ws,s:this.Us,x:this.Xs,y:this.Ys,font:this.Vs,width:this.Wk.width-this.BP});this.j.g(this.ce);this.Ql=new Z({c:this.Ls,x:this.Ns,y:this.Os,url:this.Ms,m:function(){var b=this.url;b&&window.open(b)}});this.j.g(this.Ql);this.cB=new U({text:this.Ps,s:this.yE,x:this.Qs,y:this.Rs,url:this.Ss,font:this.zE,m:function(){var b=this.url;b&&window.open(b)}});this.j.g(this.cB);this.sz=new $({c:this.Gs,x:this.Js,y:this.Ks,width:this.Is,height:this.Fs,
text:this.Hs,s:this.Ds,ya:this.Es,m:function(){b.xo?b.xo(b):b.na()}});this.j.g(this.sz)};wj.prototype.K=function(){var b;this.backgroundImage=this.Wk;wj.Bb.K.call(this);this.rv();for(b=0;b<this.h.length;b+=1)this.j.g(this.h[b])};wj.prototype.oa=function(){tgfDialog.zQ.Bb.oa.call(this);this.sz=this.cB=this.Ql=this.ce=void 0};
O.I.pL={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:25,Hb:75,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Gl,duration:.8,Ma:P(0),bb:P(-500),D:cc,da:1.2},oc:9999999999,pd:!1,h:[],ab:null,pn:"undefined"!==typeof s_avatar140?s_avatar140:void 0,Vd:P(130),gd:L,jm:void 0,Zg:void 0,Zr:"Guest",sp:P(-235),tp:P(-97),Go:void 0,cg:void 0,rw:"Guest",Io:P(235),Jo:P(-97),
DG:"undefined"!==typeof s_button_default_green?s_button_default_green:void 0,EG:"Cancel",GG:P(0),HG:P(190),FG:P(200),CG:P(104),BG:"undefined"!==typeof NotSoStoutDeco?NotSoStoutDeco:void 0,Az:!1,ew:null,OS:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};function Bj(b){this.name="MatchMaking";this.Fb=null;this.Pk={Ap:0,ZD:1,aE:2};this.gl;this.vw;this.Eo;this.uw=-1;this.Kc;this.Rb;this.Vo="";this.oL=this.Vw=!1;this.q(O.I.pL);this.i(O.hp);void 0!==b&&this.i(b);this.Jn()}gm(Bj,mm);a=Bj.prototype;
a.Jn=function(){if(this.Fb=Nj.Jn()){var b=Nj;this.Kc={Ew:b.lA,Fw:b.mA,info:b.zu};this.gl=this.Pk.Ap;Fn(this)}else console.log("NO FIREBASE REFERENCE SET")};function Fn(b){b.Fb.kw("value",function(c){c.DJ("game")||b.Fb.ie("game").set({WH:0});Gn(b)})}
function Gn(b){var c,d=b.Fb.ie("game");d.kw("value",function(e){var g=e.MS();e.forEach(function(e){var l=e.pm();if(0<l.xa&&2>l.xa)return void 0!==b.Kc.info?l.mT.uid===b.Kc.info.uid?(e=d.push({xa:0}),e=e.key(),Hn(b,e)):(c=e.key(),Hn(b,c)):(c=e.key(),Hn(b,c)),!0;g--;if(0===g)return e=d.push({xa:0}),e=e.key(),Hn(b,e),!0})})}
function Hn(b,c){b.Fb.ie("game/"+c+"/player0/online").rr("value",function(d){null===d.pm()&&b.gl===b.Pk.Ap&&In(b,0,c)});b.Fb.ie("game/"+c+"/player1/online").rr("value",function(d){null===d.pm()&&b.gl===b.Pk.Ap&&In(b,1,c)});b.Fb.ie("game/"+c+"/game").rr("value",function(c){2===c.pm()&&(b.Vw=!0,Jn(b))})}
function In(b,c,d){b.gl=b.Pk.ZD;b.Fb.ie("game/"+d+"/player"+c+"/online").transaction(function(b){if(null===b)return!0},function(e,g){g?(b.gl=b.Pk.aE,b.Fb.ie("game/"+d+"/player"+c).transaction(function(){var c="guest123456789";void 0!==b.Kc.info&&(c=b.Kc.info.uid);var e="GUEST123";void 0!==b.Kc.info&&(e=b.Kc.info.name);var g="noUrl";void 0!==b.Kc.Ew&&(g=b.Kc.Ew);var n="noUrl";void 0!==b.Kc.Fw&&(n=b.Kc.Fw);c={fT:!0,uid:c,name:e,url:g,om:n};b.Vo=d;return c}),Kn(b,c,d)):b.gl=b.Pk.Ap})}
function Jn(b){var c=0;b.Vw&&(b.Eo.rr("value",function(d){b.Rb=d.pm();null===b.Rb||1<=c||(console.log("runs once"),b.Rb&&(b.Rb.om&&"noUrl"!==b.Rb.om&&(b.gC=Nm(b.Rb.om,b.Vd),b.ow=Nm(b.Rb.url,Lm)),b.Rb.name&&(b.Nl,d=b.Rb.name.indexOf(" "),b.Nl=-1!==d?b.Rb.name.substr(0,d):b.Rb.name)),c++)}),b.zz.w(),b.qD.w(),b.Vw=!1)}
function Kn(b,c,d){var e=0;b.uw=c;b.vw=b.Fb.ie("game/"+d+"/player"+c);b.Eo=b.Fb.ie("game/"+d+"/player"+(1-c));b.Fb.ie("game/"+d+"/game").transaction(function(b){return b+1});b.Eo.rr("value",function(c){b.Rb=c.pm();if(!(null===b.Rb||1<=e)){console.log("runs once");b.Rb&&(b.Rb.om&&"noUrl"!==b.Rb.om&&(b.gC=Nm(b.Rb.om,b.Vd),b.ow=Nm(b.Rb.url,Lm)),b.Rb.name&&(b.Nl,c=b.Rb.name.indexOf(" "),b.Nl=-1!==c?b.Rb.name.substr(0,c):b.Rb.name));c=b.Nl;var d=b.gC;void 0!==d&&(b.cg.c=d);void 0!==c&&(b.Ho.text=c,b.Ho.Wd());
b.oL=!0;b.ew&&b.ew({Fb:b.Fb,uw:b.uw,vw:b.vw,Eo:b.Eo,Rb:b.Rb,Vo:b.Vo,Nl:b.Nl,ow:b.ow,Kc:b.Kc,FS:b});e++}})}
a.ix=function(){var b=this;this.Zg=this.jm?Nm(this.jm,this.Vd):this.pn;this.Zg=new Z({c:this.Zg,x:this.sp,y:this.tp,width:this.Vd,height:this.Vd});this.j.g(this.Zg);this.Yx=new U({text:this.Zr,x:this.sp,y:this.tp+125,font:this.gd});this.j.g(this.Yx);this.cg=this.Go?Nm(this.Go,this.Vd):this.pn;this.cg=new Z({c:this.cg,x:this.Io,y:this.Jo,width:this.Vd,height:this.Vd});this.j.g(this.cg);this.Ho=new U({text:this.rw,x:this.Io,y:this.Jo+125,font:this.gd});this.j.g(this.Ho);this.zz=new $({c:this.DG,x:this.GG,
y:this.HG,width:this.FG,height:this.CG,text:this.EG,ya:this.BG,m:function(){b.Az=!0;b.Fb.ie("game/"+b.Vo).NS();b.Fb.ie("game/"+b.Vo).remove();b.w()}});this.j.g(this.zz);this.qD=new Z({c:s_throbber,rb:10,x:P(0),y:P(-90)});this.j.g(this.qD)};a.na=function(){Bj.Bb.na.call(this)};a.K=function(){Bj.Bb.K.call(this);gn();this.Kc.Ew&&(this.jm=this.Kc.Fw);if(this.Kc.info){var b=this.Kc.info.name.indexOf(" ");this.Zr=-1!==b?this.Kc.info.name.substr(0,b):this.Kc.info.name}this.ix()};a.oa=function(){};
O.I.nL={x:void 0,y:void 0,backgroundImage:"undefined"!==typeof s_overlay_matchmaking?s_overlay_matchmaking:void 0,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:25,Hb:75,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Gl,duration:.8,Ma:P(0),bb:P(-500),D:cc,da:1.2},oc:9999999999,pd:!1,h:[],ab:null,pn:"undefined"!==typeof s_avatar140?s_avatar140:void 0,Vd:P(130),gd:L,jm:void 0,Zg:void 0,Zr:"Guest",
sp:P(-235),tp:P(-97),Go:void 0,cg:void 0,rw:"NAME",Io:P(235),Jo:P(-97),PJ:"undefined"!==typeof s_button_default_red?s_button_default_red:void 0,QJ:"Home",SJ:P(0),TJ:P(190),RJ:P(200),OJ:P(104),NJ:"undefined"!==typeof NotSoStoutDeco?NotSoStoutDeco:void 0,home:!1,DT:!1,ZB:null,ZS:null,BR:null,Fb:null,bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};function Ln(b){this.name="MatchEnd";this.q(O.I.nL);this.i(O.hp);void 0!==b&&this.i(b)}gm(Ln,mm);a=Ln.prototype;a.Jn=function(){this.Fb=Nj.Jn()};
a.ix=function(){var b=this;void 0===this.Zg&&(this.Zg=this.jm?Nm(this.jm,this.Vd):this.pn);this.Zg=new Z({c:this.Zg,x:this.sp,y:this.tp,width:this.Vd,height:this.Vd});this.j.g(this.Zg);this.Yx=new U({text:this.Zr,x:this.sp,y:this.tp+125,font:this.gd});this.j.g(this.Yx);this.cg&&(this.cg=this.Go?Nm(this.Go,this.Vd):this.pn);this.cg=new Z({c:this.cg,x:this.Io,y:this.Jo,width:this.Vd,height:this.Vd});this.j.g(this.cg);this.Ho=new U({text:this.rw,x:this.Io,y:this.Jo+125,font:this.gd});this.j.g(this.Ho);
this.MJ=new $({c:this.PJ,x:this.SJ,y:this.TJ,width:this.RJ,height:this.OJ,text:this.QJ,ya:this.NJ,m:function(c){b.ZB&&b.ZB(c);b.home=!0;b.na()}});this.j.g(this.MJ)};a.na=function(){Bj.Bb.na.call(this)};a.w=function(){Bj.Bb.w.call(this)};a.K=function(){Bj.Bb.K.call(this);this.ix()};Bj.prototype.ne=function(){};Bj.prototype.oa=function(){};function on(b){this.q();this.cS;this.width=P(200);this.height=P(200);void 0!==b&&this.i(b);this.Kp||(this.Kp=new k(0,0))}V(on,W);
on.prototype.setPosition=function(){var b=R.ij+R.Nk*this.Kp.x,c=R.jj+R.yp*this.Kp.y;this.parent?(this.x=this.parent.Xd(b,c),this.y=this.parent.Yd(b,c)):(this.x=b,this.y=c)};on.prototype.Hd=function(){this.setPosition()};on.prototype.K=function(){this.setPosition()};
O.W.RP={backgroundImage:"undefined"!==typeof me?me:void 0,nl:"undefined"!==typeof we?we:void 0,Mj:function(b,c,d,e){return c+d*(1+-1*(1-Math.cos((e-b)/e*Math.PI/2)))},tn:.5,NC:!0,xC:"#00AEEF",eK:"#BBDDFF",oz:!0,NF:9999999,nz:.5,MF:"#FFED93",fp:"undefined"!==typeof ne?ne:void 0,$O:"undefined"!==typeof oe?oe:void 0,fD:"undefined"!==typeof a_ui_star_empty?a_ui_star_empty:void 0,gD:"undefined"!==typeof a_ui_star_filled?a_ui_star_filled:void 0,dD:"undefined"!==typeof s_ui_star_animation_filled?s_ui_star_animation_filled:
void 0,eD:"undefined"!==typeof s_ui_star_animation_filled?s_ui_star_animation_filled:void 0,YO:10,WO:!0,XO:!0,L:[20,50,90],Xr:void 0,VH:!0,uF:!0,oK:!0,ul:"",xv:"",yv:0,Rq:P(80),bB:P(80),ZA:P(64),Qq:L,pK:void 0,ur:void 0,tr:void 0,eC:void 0,dC:void 0,h:[]};function Mn(b){this.name="UiProgressRound";this.q(O.W.RP);void 0!==b&&this.i(b)}V(Mn,W);a=Mn.prototype;
a.zd=function(b,c){var d=b,e=this.Kb;0>d&&(d=0);100<d&&(d=100);this.nk=this.Ui;this.Ui=d;this.To=0;if(c||void 0===this.Mj)this.nk=this.Ui;this.Kb=this.nk;100===this.Kb&&100!==e&&this.ur&&this.ur(this);0===this.Kb&&0!==e&&this.tr&&this.tr(this)};
a.K=function(){var b;this.width=this.nl.width;this.height=this.nl.height;this.oK&&(this.tl=new U({x:this.yv,y:this.Rq,width:this.bB,height:this.ZA,text:this.ul,s:this.xv,font:this.Qq,dd:!0,align:"center",xb:"middle"}),this.tl.i(this.pK),this.g(this.tl));if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.tl=void 0};
a.Wa=function(){this.To=this.Kb=this.Ui=this.nk=0;var b;this.ob=[];for(b=0;b<this.L.length;b+=1)this.ob.push({Pl:this.L[b],filled:!1,Ed:!1,lb:void 0,Jf:0,vj:0});this.Ym=0;this.$k=!1;this.Rp=0};
a.qd=function(b){var c=this.Kb;this.To+=b/1E3;this.To>=this.tn?this.Kb=this.nk=this.Ui:void 0!==this.Mj&&this.Kb!==this.Ui&&(this.Kb=this.Mj(this.To,this.nk,this.Ui-this.nk,this.tn),this.Kb=Math.max(0,Math.min(100,this.Kb)),100===this.Kb&&100!==c&&this.ur&&this.ur(this),0===this.Kb&&0!==c&&this.tr&&this.tr(this));var c=b/1E3,d,e;for(d=0;d<this.ob.length;d+=1)if(e=this.ob[d],e.Ed&&(e.Jf+=c,e.vj=Math.floor(e.Jf*this.YO),e.vj>=e.lb.Y&&(e.Ed=!1,e.lb=void 0,e.df=e.filled)),this.uF)if(e.Pl>this.Kb){e=d;
var g=void 0;0>e||e>=this.ob.length||(g=this.ob[e],g.filled&&(g.filled=!1,g.df=!1,void 0!==this.dD&&(g.Ed=!0,g.lb=this.dD,g.Jf=0,this.WO&&(g.df=!0)),this.fD&&S.play(this.fD),this.dC&&this.dC(this,e+1)))}else e=d,g=void 0,0>e||e>=this.ob.length||(g=this.ob[e],g.filled||(g.filled=!0,g.df=!0,void 0!==this.eD&&(g.Ed=!0,g.lb=this.eD,g.Jf=0,this.XO&&(g.df=!1)),this.gD&&S.play(this.gD),this.eC&&this.eC(this,e+1)));!this.$k&&100<=this.Kb&&(this.$k=!0);this.$k&&100>this.Kb&&(this.$k=!1,this.Ym=0);this.$k&&
(this.Rp+=b/1E3,this.Rp>=this.NF?this.Ym=0:(b=this.Rp%this.nz/this.nz+.5,this.Ym=(Math.cos(b*Math.PI*2)+1)/2))};a.oj=function(b,c,d,e){b&&(b instanceof wa?b.ma(d,e):b.ma(c,d,e))};
a.Ic=function(){var b=p.context,c=this.nl.width/2-P(4),d=Math.PI,e,g,h,l;b.save();this.oj(this.backgroundImage,0,0,0);this.NC&&this.Kb<this.Ui&&(b.beginPath(),b.arc(0,0,c,-.5*d+2*d*this.Kb/100,-.5*d+2*d*this.Ui/100,!1),b.lineTo(0,0),b.fillStyle=this.eK,b.fill());b.beginPath();b.arc(0,0,c,-.5*d,-.5*d+2*d*this.Kb/100,!1);b.lineTo(0,0);b.fillStyle=this.xC;b.fill();this.oz&&this.$k&&0<this.Ym&&(e=b.globalAlpha,b.globalAlpha*=this.Ym,b.beginPath(),b.arc(0,0,c,-.5*d,-.5*d+2*d*this.Kb/100,!1),b.lineTo(0,
0),b.fillStyle=this.MF,b.fill(),b.globalAlpha=e);if(this.VH)for(b.strokeStyle="white",b.lineWidth=P(2),e=0;e<this.ob.length;e+=1)g=-.5*d+this.ob[e].Pl/100*d*2,b.beginPath(),b.moveTo(0,0),b.lineTo(Math.round(Math.cos(g)*c),Math.round(Math.sin(g)*c)),b.stroke();this.oj(this.nl,0,0,0);for(e=0;e<this.ob.length;e+=1)h=this.ob[e].df?this.$O:this.fp,g=-.5*d+this.ob[e].Pl/100*d*2,l=void 0!==this.Xr?this.Xr:.65*c,this.oj(h,0,Math.round(Math.cos(g)*l),Math.round(Math.sin(g)*l));b.restore()};
a.Nf=function(){var b=this.nl.width/2-P(4),c=Math.PI,d,e,g,h;for(d=0;d<this.ob.length;d+=1)h=this.ob[d],h.Ed&&(e=-.5*c+h.Pl/100*c*2,g=void 0!==this.Xr?this.Xr:.65*b,this.oj(h.lb,h.vj,Math.round(Math.cos(e)*g),Math.round(Math.sin(e)*g)))};
O.W.UP={backgroundImage:void 0,wb:void 0,width:P(100),height:P(80),margin:P(8),Ia:void 0,mf:0,qe:P(-16),Lc:void 0,Pe:"",Zf:"",Gl:0,$f:P(-16),gd:L,Vv:void 0,valueType:"number",$h:0,We:0,md:P(16),Bf:L,gQ:void 0,wp:",",Tm:1,Um:0,lF:!1,Mj:Ub,tn:1,ku:.1,YH:0,cr:!1,WA:!1,Wy:!1,Jp:!1,CE:!1,jI:0,Do:void 0,jw:void 0,h:[]};function Nn(b){this.name="UiValue";this.q(O.W.UP);void 0!==b&&this.i(b)}V(Nn,W);a=Nn.prototype;a.tk=function(b,c){this.Vk(b,c)};a.fe=function(b,c){this.Vk(this.Gb()+b,c)};a.Gb=function(){return this.ng};
a.ws=function(){this.value=this.ng=this.$g=this.$h;this.Kk=0;this.gy=!1;On(this)};a.Vk=function(b,c){(" number"===this.valueType||"time"===this.valueType)&&0>b&&!this.lF&&(b=0);if(this.ng!==b){this.$g=this.value;this.ng=b;this.Kk=0;if(c||void 0===this.Mj||"number"!==this.valueType&&"time"!==this.valueType||Math.abs(b-this.$g)<=this.YH)this.$g=this.ng;On(this)}};
function On(b){var c=b.Ya.text,d=Math.round(b.value),e,g;switch(b.valueType){case "number":e=d.toString();b.Ya.text="";for(g=0;g<e.length;g+=1)0===(e.length-g)%3&&0!==g&&(b.Ya.text+=b.wp),b.Ya.text+=e.charAt(g);b.cr&&(b.Hv.text=b.WA?b.Gh.text+" "+b.Ya.text:b.Ya.text+" "+b.Gh.text,b.Hv.Wd());break;case "time":e=d;b.Ya.text="";3600<=d?(b.Ya.text+=Math.floor(e/3600).toString()+b.wp,e%=3600):b.Wy&&b.Jp&&(b.Ya.text+="0"+b.wp);600<=d?(b.Ya.text+=Math.floor(e/600).toString(),e%=600):b.Wy&&b.Jp&&(b.Ya.text+=
"0");60<=d?(b.Ya.text+=Math.floor(e/60).toString()+b.wp,e%=60):b.Jp&&(b.Ya.text+="0"+b.wp);10<=d?(b.Ya.text+=Math.floor(e/10).toString(),e%=10):b.Jp&&(b.Ya.text+="0");b.Ya.text+=e.toString();break;default:b.Ya.text=d}c!==b.Ya.text&&(b.Ya.Wd(),b.Do&&b.Do(b,d))}a.vs=function(){this.Kf=0;this.ft=!0};a.Cs=function(b){this.ft&&0!==this.Um&&(this.Kf+=b,this.Kf>this.Tm&&(this.fe(this.Um),this.Kf-=this.Tm))};
a.K=function(){var b;!this.width&&this.backgroundImage&&(this.width=this.backgroundImage.width);!this.height&&this.backgroundImage&&(this.height=this.backgroundImage.height);this.backgroundImage&&(this.Ye=new Z({x:0,y:0,width:this.width,height:this.height,c:this.backgroundImage,Tb:!0}),this.Ye.i(this.wb),this.g(this.Ye));this.Ia&&(this.Vj=new Z({x:this.mf,y:this.qe,c:this.Ia}),this.Vj.i(this.Lc),this.g(this.Vj));b="";b=this.WA?this.name+" "+this.value:this.value+" "+this.name;this.Hv=new U({x:this.We,
y:this.md,width:this.width-2*this.margin,height:this.height/2,text:b,s:this.Zf,font:this.Bf,dd:!0});this.cr&&this.g(this.Hv);if(""!==this.Pe||""!==this.Zf)this.Gh=new U({x:this.Gl,y:this.$f,width:this.width-2*this.margin,height:this.height/2,text:this.Pe,s:this.Zf,font:this.gd,dd:!0,align:"center",xb:"middle"}),this.Gh.i(this.Vv),this.cr||this.g(this.Gh);this.Ya=new U({x:this.We,y:this.md,width:this.width-2*this.margin,height:this.height/2,text:"",s:"",font:this.Bf,dd:!0,align:"center",xb:"middle"});
this.Ya.i(this.gQ);this.cr||this.g(this.Ya);if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.Gh=this.Ya=this.Vj=this.Ye=void 0};a.Wa=function(){this.ws();this.vs()};
a.qd=function(b){a:{var c=this.value,d=this.Kk;if("number"===this.valueType||"time"===this.valueType){this.Kk+=b/1E3;if(this.Kk>=this.tn)this.value=this.$g=this.ng;else{if(Math.floor(0!==this.ku&&this.Kk/this.ku)===Math.floor(d/this.ku)||void 0===this.Mj||this.value===this.ng)break a;this.value=this.Mj(this.Kk,this.$g,this.ng-this.$g,this.tn)}Math.round(this.value)!==Math.round(c)&&On(this)}}this.Cs(b/1E3);this.CE&&(b=Math.max(0,Math.ceil((this.jI-u.Hg)/1E3)),this.$g=this.value,this.value=this.ng=
b,On(this));this.gy||this.$g!==this.ng?this.$g!==this.ng&&(this.gy=!1):(this.jw&&this.jw(this,this.ng),this.gy=!0)};
O.W.OP={backgroundImage:void 0,wb:void 0,width:P(100),height:P(80),margin:P(8),Ia:void 0,mf:0,qe:P(-16),Lc:void 0,Pe:"",Zf:"",Gl:0,$f:P(-16),gd:L,Vv:void 0,tO:!0,eQ:"undefined"!==typeof s_ui_value_empty?s_ui_value_empty:void 0,fQ:"undefined"!==typeof s_ui_value_filled?s_ui_value_filled:void 0,GD:void 0,HD:void 0,ED:void 0,FD:void 0,cQ:30,zU:!1,AU:!1,hy:3,$h:0,We:0,md:P(16),bQ:"center",dQ:"middle",ls:P(32),ms:P(0),Tm:1,Um:0,Do:void 0,h:[]};
function Pn(b){this.name="UiImageValue";this.q(O.W.OP);void 0!==b&&this.i(b)}V(Pn,W);a=Pn.prototype;a.tk=function(b){this.Vk(b)};a.fe=function(b){this.Vk(this.Gb()+b)};a.Gb=function(){return this.value};
a.ws=function(){var b,c,d,e,g,h,l,m;this.images=[];for(b=0;b<this.hy;b+=1)this.images.push({filled:!1,Ed:!1,lb:void 0,Jf:0,vj:0});l=g=1E6;e=h=-1E6;for(b=d=c=0;b<this.images.length;b+=1)m=this.images[b],m.mj=c,m.nj=d,g=Math.min(g,c),h=Math.max(h,c),l=Math.min(l,d),e=Math.max(e,d),c+=this.ls[b%this.ls.length],d+=this.ms[b%this.ms.length];c=h-g;e-=l;for(b=0;b<this.images.length;b+=1){m=this.images[b];switch(this.bQ){case "left":m.mj+=this.We-g;break;case "right":m.mj+=this.We-g-c;break;default:m.mj+=
this.We-g-Math.round(c/2)}switch(this.dQ){case "top":m.nj+=this.md-l;break;case "bottom":m.nj+=this.md-l-e;break;default:m.nj+=this.md-l-Math.round(e/2)}}this.Vk(this.$h)};
a.Vk=function(b){var c,d=this.value;0>b&&(b=0);b>this.hy&&(b=this.hy);this.value=b;for(b=0;b<this.images.length;b+=1)c=this.images[b],b+1<=this.value?c.filled||(c.filled=!0,c.df=!0,void 0!==this.FD&&(c.lb=this.FD,c.Ed=!0,c.Jf=0,this.YR&&(c.df=!1)),this.HD&&S.play(this.HD)):c.filled&&(c.filled=!1,c.df=!1,void 0!==this.ED&&(c.lb=this.ED,c.Ed=!0,c.Jf=0,this.XR&&(c.df=!0)),this.GD&&S.play(this.GD));this.value!==d&&this.Do&&this.Do(this,this.value)};a.vs=function(){this.Kf=0;this.ft=!0};
a.Cs=function(b){this.ft&&0!==this.Um&&(this.Kf+=b,this.Kf>this.Tm&&(this.fe(this.Um),this.Kf-=this.Tm))};
a.K=function(){var b;!this.width&&this.backgroundImage&&(this.width=this.backgroundImage.width);!this.height&&this.backgroundImage&&(this.height=this.backgroundImage.height);this.ls=[].concat(this.ls);this.ms=[].concat(this.ms);this.backgroundImage&&(this.Ye=new Z({x:0,y:0,width:this.width,height:this.height,c:this.backgroundImage,Tb:!0}),this.Ye.i(this.wb),this.g(this.Ye));this.Ia&&(this.Vj=new Z({x:this.mf,y:this.qe,c:this.Ia}),this.Vj.i(this.Lc),this.g(this.Vj));if(""!==this.Pe||""!==this.Zf)this.Gh=
new U({x:this.Gl,y:this.$f,width:this.width-2*this.margin,height:this.height/2,text:this.Pe,s:this.Zf,font:this.gd,dd:!0,align:"center",xb:"middle"}),this.Gh.i(this.Vv),this.g(this.Gh);if(this.h)for(b=0;b<this.h.length;b+=1)this.g(this.h[b])};a.oa=function(){this.Gh=this.Vj=this.Ye=void 0};a.Wa=function(){this.ws();this.vs()};
a.qd=function(b){this.Cs(b/1E3);b/=1E3;var c,d;for(c=0;c<this.images.length;c+=1)d=this.images[c],d.Ed&&(d.Jf+=b,d.vj=Math.floor(d.Jf*this.cQ),d.vj>=d.lb.Y&&(d.Ed=!1,d.lb=void 0,d.df=d.filled))};a.oj=function(b,c,d,e){b&&(b instanceof wa?b.ma(d,e):b.ma(c,d,e))};a.Nf=function(){var b,c,d;for(b=0;b<this.images.length;b+=1)if(c=this.images[b],c.df||this.tO)d=c.df?this.fQ:this.eQ,this.oj(d,b,c.mj,c.nj);for(b=0;b<this.images.length;b+=1)c=this.images[b],c.Ed&&void 0!==c.lb&&this.oj(c.lb,c.vj,c.mj,c.nj)};
O.I.NP={d:-900,x:void 0,y:void 0,width:void 0,height:void 0,backgroundImage:"undefined"!==typeof le?le:void 0,ez:!1,vF:"left",wF:"middle",zF:!1,ir:P(32),zB:P(32),sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},h:[],wb:null,Gk:null};function Qn(b){this.name="UiEmpty";this.q(O.I.NP);this.i(O.wU);void 0!==b&&this.i(b)}gm(Qn,hm);a=Qn.prototype;a.na=function(){this.Ca();X(this.j,2)};
function Rn(b,c,d,e,g){c=new c(d);void 0!==e&&c.i(e);void 0!==g&&c.i(g);b.j?(b.j.g(c),b.j.nb&&c.show(),b.j.F&&c.Db()):b.h.push(c);return c}
a.vy=function(){var b,c,d,e;if(this.ez){this.zF?(b=R.ij,c=R.ij+R.Nk,d=R.jj,e=R.jj+R.yp):(b=R.Mh,c=R.Mh+R.we,d=R.Nh,e=R.Nh+R.gg);switch(this.vF){case "left":b=b+Math.round(this.width/2)+this.ir;break;case "right":b=c-Math.round(this.width/2)-this.ir;break;case "center":b=Math.round((b+c)/2);break;default:b=b+Math.round(this.width/2)+this.ir}switch(this.wF){case "top":d=d+Math.round(this.height/2)+this.zB;break;case "bottom":d=e-Math.round(this.height/2)-this.zB;break;case "middle":d=Math.round((d+
e)/2);break;default:b=d=Math.round((d+e)/2)}if(this.x!==b||this.y!==d)this.x=b,this.y=d}};
a.K=function(){var b=this,c;if(void 0===this.width||0===this.width)this.width=void 0===this.backgroundImage?0:this.backgroundImage.width;if(void 0===this.height||0===this.height)this.height=void 0===this.backgroundImage?0:this.backgroundImage.height;void 0===this.x&&(this.x=R.Mh+Math.round(this.width/2)+this.ir);void 0===this.y&&(this.y=R.Nh+Math.round(R.gg/2));this.j=new Z({c:this.backgroundImage,Tb:!0,width:this.width,height:this.height,ra:[this.sb,{k:"show",duration:9999999},this.Ua],Td:function(){b.w()}});
this.j.i(this.wb);this.g(this.j);this.ez&&(this.jb=new $l({pq:!0,interval:.05,repeat:999999999,Qi:function(){Qn.prototype.vy.call(b)}}),this.jb.i(this.Gk),this.g(this.jb));for(c=0;c<this.h.length;c+=1)this.j.g(this.h[c])};a.oa=function(){this.ic();this.jb=this.j=void 0};a.Wa=function(){this.vy()};function Jj(){uj(O,{be:{name:"<UNKNOWN>",id:"<UNKNOWN>",version:"1.0"},r:{}})}Q=Q||{};Q["nl-nl"]=Q["nl-nl"]||{};Q["nl-nl"].GameScore="Score:";Q["nl-nl"].GoalTitle="Doel";Q["nl-nl"].GameMoves="Zetten:";
Q["nl-nl"].GoalText_01="Scoor <TARGET> punten om het level te halen!";Q["nl-nl"].GoalText_02="Verzamel <TARGET> ijsjes!";Q["nl-nl"].GoalText_03="Verwijder <TARGET> ingepakte ijsjes!";Q["nl-nl"].FailedPopup_Text_02="Geen zetten meer!";Q["nl-nl"].FailedPopup_Text_01="Je zetten zijn op!";Q["nl-nl"].FailedPopup_Text_03="Probeer het nog eens";Q["nl-nl"].LevelTheme_01="Punten voor ijs";Q["nl-nl"].LevelTheme_02="Ontbrekende ijsjes";Q["nl-nl"].LevelTheme_03="Ingepakte ijsjes";Q["nl-nl"].ObjectiveUI_02="Verwijder:";
Q["nl-nl"].ObjectiveUI_01="Verzamel:";Q["nl-nl"].LevelHeader="Level <VALUE>";Q["nl-nl"].TutorialHeader_01="IJs ";Q["nl-nl"].TutorialText_01="Scoor punten door de ijsjes over het veld te slepen.";Q["nl-nl"].Tutorial_Header_02="IJsjes ";Q["nl-nl"].TutorialText_02="Vul horizontale en verticale lijnen om punten te scoren!";Q["nl-nl"].Tutorial_Header_03="Hindernis";Q["nl-nl"].TutorialText_03="Ingepakte ijsjes moeten meerdere keren verwijderd worden.";Q["nl-nl"].Tutorial_Header_04="Doelen";
Q["nl-nl"].TutorialText_04="Elk level heeft een ander doel. Voltooi het doel om het level te winnen!";Q["nl-nl"].Tutorial_Header_05="Doelen";Q["nl-nl"].TutorialText_05="Scoor genoeg punten om deze levels te winnen.";Q["nl-nl"].Tutorial_Header_06="Doelen";Q["nl-nl"].TutorialText_06="Verzamel een bepaalde hoeveelheid van het aangegeven ijs.";Q["nl-nl"].Tutorial_Header_07="Doelen";Q["nl-nl"].TutorialText_07="Verwijder alle ingepakte ijsjes in het level.";Q["nl-nl"].TutorialText_08="Je hebt maar een beperkt aantal zetten. Voltooi het level voor je zetten op zijn!";
Q["nl-nl"].Tutorial_Header_08="Zetten";Q["nl-nl"].Tutorial_Header_09="Power-ups";Q["nl-nl"].TutorialText_09="Verwijder drie lijnen tegelijk om een power-up te verdienen!";Q["nl-nl"].Tutorial_Header_10="Power-ups";Q["nl-nl"].TutorialText_10="De kleurenbom verwijdert alle ijsjes met dezelfde kleur.";Q["nl-nl"].Tutorial_Header_11="Power-ups";Q["nl-nl"].TutorialText_11="Deze bom verwijdert horizontale en verticale lijnen.";Q["nl-nl"].EndScore="Totaalscore:";Q["nl-nl"].HighScore="Topscore:";
Q["nl-nl"].LevelFailedHeader="Helaas";Q["nl-nl"].Floater_01="yummy!";Q["nl-nl"].Floater_02="flurry-luscious";Q["nl-nl"].Floater_03="cold'n Sweet";Q["nl-nl"].Floater_04="creamy";Q["nl-nl"].TownName_01="Springfield";Q["nl-nl"].TownName_02="Clay Valley";Q["nl-nl"].TownName_03="Palm Beach";Q["nl-nl"].TownName_04="Tundra Town";Q["nl-nl"].ComingSoonText="Binnenkort Beschikbaar";Q["en-us"]=Q["en-us"]||{};Q["en-us"].GameScore="Score:";Q["en-us"].GoalTitle="Goal";Q["en-us"].GameMoves="Moves:";
Q["en-us"].GoalText_01="Score <TARGET> points to complete the level!";Q["en-us"].GoalText_02="Collect <TARGET> ice creams!";Q["en-us"].GoalText_03="Clear <TARGET> wrapped ice creams!";Q["en-us"].FailedPopup_Text_02="Out of moves!";Q["en-us"].FailedPopup_Text_01="No moves left!";Q["en-us"].FailedPopup_Text_03="Try again";Q["en-us"].LevelTheme_01="Points for ice cream";Q["en-us"].LevelTheme_02="Missing ice creams";Q["en-us"].LevelTheme_03="Wrapped ice creams";Q["en-us"].ObjectiveUI_02="Clear:";
Q["en-us"].ObjectiveUI_01="Collect:";Q["en-us"].LevelHeader="Level  <VALUE>";Q["en-us"].TutorialHeader_01="Ice cream";Q["en-us"].TutorialText_01="Score points by dragging the ice creams across the grid.";Q["en-us"].Tutorial_Header_02="Ice cream";Q["en-us"].TutorialText_02="Fill up horizontal and vertical lines to clear them and score points!";Q["en-us"].Tutorial_Header_03="Obstacle ";Q["en-us"].TutorialText_03="Wrapped ice creams have to be cleared multiple times.";Q["en-us"].Tutorial_Header_04="Goals ";
Q["en-us"].TutorialText_04="Each level has a different goal. Complete the goal to win the level!";Q["en-us"].Tutorial_Header_05="Goals ";Q["en-us"].TutorialText_05="Score enough points to win these levels.";Q["en-us"].Tutorial_Header_06="Goals ";Q["en-us"].TutorialText_06="Collect a number of a specified ice cream. ";Q["en-us"].Tutorial_Header_07="Goals ";Q["en-us"].TutorialText_07="Clear all the wrapped ice creams in the level.";Q["en-us"].TutorialText_08="You only have a limited number of moves left. Complete the level before you run out!";
Q["en-us"].Tutorial_Header_08="Moves";Q["en-us"].Tutorial_Header_09="Power-ups";Q["en-us"].TutorialText_09="Clear three lines at once to earn a power-up!";Q["en-us"].Tutorial_Header_10="Power-ups";Q["en-us"].TutorialText_10="The colour bomb clears all ice creams of the same colour.";Q["en-us"].Tutorial_Header_11="Power-ups";Q["en-us"].TutorialText_11="The clear-line bomb clears horizontal and vertical lines.";Q["en-us"].EndScore="Total score:";Q["en-us"].HighScore="High score:";
Q["en-us"].LevelFailedHeader="Level failed";Q["en-us"].Floater_01="yummy!";Q["en-us"].Floater_02="flurry-luscious";Q["en-us"].Floater_03="cold'n Sweet";Q["en-us"].Floater_04="creamy";Q["en-us"].TownName_01="Springfield";Q["en-us"].TownName_02="Clay Valley";Q["en-us"].TownName_03="Palm Beach";Q["en-us"].TownName_04="Tundra Town";Q["en-us"].ComingSoonText="Coming Soon";Q["en-gb"]=Q["en-gb"]||{};Q["en-gb"].GameScore="Score";Q["en-gb"].GoalTitle="Goal";Q["en-gb"].GameMoves="Moves:";
Q["en-gb"].GoalText_01="Score <TARGET> points to complete the level!";Q["en-gb"].GoalText_02="Collect <TARGET> ice creams!";Q["en-gb"].GoalText_03="Clear <TARGET> wrapped ice creams!";Q["en-gb"].FailedPopup_Text_02="Out of moves!";Q["en-gb"].FailedPopup_Text_01="No moves left!";Q["en-gb"].FailedPopup_Text_03="Try again";Q["en-gb"].LevelTheme_01="Points for ice cream";Q["en-gb"].LevelTheme_02="Missing ice creams";Q["en-gb"].LevelTheme_03="Wrapped ice creams";Q["en-gb"].ObjectiveUI_02="Clear:";
Q["en-gb"].ObjectiveUI_01="Collect:";Q["en-gb"].LevelHeader="Level <VALUE>";Q["en-gb"].TutorialHeader_01="Ice cream";Q["en-gb"].TutorialText_01="Score points by dragging the ice creams across the grid.";Q["en-gb"].Tutorial_Header_02="Ice cream";Q["en-gb"].TutorialText_02="Fill up horizontal and vertical lines to clear them and score points!";Q["en-gb"].Tutorial_Header_03="Obstacle ";Q["en-gb"].TutorialText_03="Wrapped ice creams have to be cleared multiple times.";Q["en-gb"].Tutorial_Header_04="Goals ";
Q["en-gb"].TutorialText_04="Each level has a different goal. Complete the goal to win the level!";Q["en-gb"].Tutorial_Header_05="Goals ";Q["en-gb"].TutorialText_05="Score enough points to win these levels.";Q["en-gb"].Tutorial_Header_06="Goals ";Q["en-gb"].TutorialText_06="Collect a number of a specified ice cream. ";Q["en-gb"].Tutorial_Header_07="Goals ";Q["en-gb"].TutorialText_07="Clear all the wrapped ice creams in the level.";Q["en-gb"].TutorialText_08="You only have a limited number of moves left. Complete the level before you run out!";
Q["en-gb"].Tutorial_Header_08="Moves";Q["en-gb"].Tutorial_Header_09="Power-ups";Q["en-gb"].TutorialText_09="Clear three lines at once to earn a power-up!";Q["en-gb"].Tutorial_Header_10="Power-ups";Q["en-gb"].TutorialText_10="The colour bomb clears all ice creams of the same colour.";Q["en-gb"].Tutorial_Header_11="Power-ups";Q["en-gb"].TutorialText_11="The clear-line bomb clears horizontal and vertical lines.";Q["en-gb"].EndScore="Total score:";Q["en-gb"].HighScore="High score:";
Q["en-gb"].LevelFailedHeader="Level failed";Q["en-gb"].Floater_01="yummy!";Q["en-gb"].Floater_02="flurry-luscious";Q["en-gb"].Floater_03="cold'n Sweet";Q["en-gb"].Floater_04="creamy";Q["en-gb"].TownName_01="Springfield";Q["en-gb"].TownName_02="Clay Valley";Q["en-gb"].TownName_03="Palm Beach";Q["en-gb"].TownName_04="Tundra Town";Q["en-gb"].ComingSoonText="Coming Soon";Q["de-de"]=Q["de-de"]||{};Q["de-de"].GameScore="Punkte:";Q["de-de"].GoalTitle="Ziel";Q["de-de"].GameMoves="Z\u00fcge:";
Q["de-de"].GoalText_01="Erziele <TARGET> Punkte, um das Level abzuschlie\u00dfen.";Q["de-de"].GoalText_02="Sammle <TARGET> Eis ein!";Q["de-de"].GoalText_03="Entferne <TARGET> verpackte Eis!";Q["de-de"].FailedPopup_Text_02="Keine Z\u00fcge mehr!";Q["de-de"].FailedPopup_Text_01="Keine weiteren Z\u00fcge!";Q["de-de"].FailedPopup_Text_03="Noch mal";Q["de-de"].LevelTheme_01="Punkte f\u00fcr Eis";Q["de-de"].LevelTheme_02="Fehlendes Eis";Q["de-de"].LevelTheme_03="Verpacktes Eis";
Q["de-de"].ObjectiveUI_02="Entfernen:";Q["de-de"].ObjectiveUI_01="Sammeln:";Q["de-de"].LevelHeader="Level <VALUE>";Q["de-de"].TutorialHeader_01="Eis";Q["de-de"].TutorialText_01="Scheffle Punkte, indem du Eis \u00fcber das Rasterfeld ziehst.";Q["de-de"].Tutorial_Header_02="Eis";Q["de-de"].TutorialText_02="F\u00fclle horizontale und vertikale Reihen, um sie zu entfernen und Punkte zu scheffeln!";Q["de-de"].Tutorial_Header_03="Hindernis";Q["de-de"].TutorialText_03="Verpacktes Eis muss mehrmals entfernt werden.";
Q["de-de"].Tutorial_Header_04="Ziele";Q["de-de"].TutorialText_04="Die Levels haben unterschiedliche Zielaufgaben. Erledige die jeweilige Aufgabe, um ein Level erfolgreich abzuschlie\u00dfen.";Q["de-de"].Tutorial_Header_05="Ziele";Q["de-de"].TutorialText_05="Erziele gen\u00fcgend Punkte, um diese Levels erfolgreich abzuschlie\u00dfen.";Q["de-de"].Tutorial_Header_06="Ziele";Q["de-de"].TutorialText_06="Sammle eine gewisse Menge einer bestimmten Eissorte ein. ";Q["de-de"].Tutorial_Header_07="Ziele";
Q["de-de"].TutorialText_07="Entferne in so einem Level jedes Eis, das verpackt ist.";Q["de-de"].TutorialText_08="Du hast nur noch eine begrenzte Anzahl an Z\u00fcgen. Schlie\u00df das Level ab, bevor alle Z\u00fcge verbraucht sind.";Q["de-de"].Tutorial_Header_08="Z\u00fcge";Q["de-de"].Tutorial_Header_09="Extras";Q["de-de"].TutorialText_09="Entferne drei Reihen gleichzeitig, um ein Extra zu erhalten!";Q["de-de"].Tutorial_Header_10="Extras";Q["de-de"].TutorialText_10="Die Farbbombe entfernt alles Eis derselben Farbe.";
Q["de-de"].Tutorial_Header_11="Extras";Q["de-de"].TutorialText_11="Die Reihenentfernungsbombe entfernt horizontale und vertikale Reihen.";Q["de-de"].EndScore="Punkte insg.:";Q["de-de"].HighScore="Highscore:";Q["de-de"].LevelFailedHeader="Level nicht geschafft";Q["de-de"].Floater_01="yummy!";Q["de-de"].Floater_02="flurry-luscious";Q["de-de"].Floater_03="cold'n Sweet";Q["de-de"].Floater_04="creamy";Q["de-de"].TownName_01="Springfield";Q["de-de"].TownName_02="Clay Valley";Q["de-de"].TownName_03="Palm Beach";
Q["de-de"].TownName_04="Tundra Town";Q["de-de"].ComingSoonText="bald erh\u00e4ltlich";Q["fr-fr"]=Q["fr-fr"]||{};Q["fr-fr"].GameScore="Score :";Q["fr-fr"].GoalTitle="Objectif";Q["fr-fr"].GameMoves="Mouvements:";Q["fr-fr"].GoalText_01="Marquez <TARGET> points pour terminer le niveau!";Q["fr-fr"].GoalText_02="R\u00e9cup\u00e9rez <TARGET> cr\u00e8mes glac\u00e9es !";Q["fr-fr"].GoalText_03="Faites dispara\u00eetre <TARGET> cr\u00e8mes glac\u00e9es emball\u00e9es!";Q["fr-fr"].FailedPopup_Text_02="\u00c0 court de mouvements!";
Q["fr-fr"].FailedPopup_Text_01="Plus de mouvements!";Q["fr-fr"].FailedPopup_Text_03="R\u00e9essayer";Q["fr-fr"].LevelTheme_01="Points pour cr\u00e8mes glac\u00e9es";Q["fr-fr"].LevelTheme_02="Cr\u00e8mes glac\u00e9es manquantes";Q["fr-fr"].LevelTheme_03="Cr\u00e8mes glac\u00e9es emball\u00e9es";Q["fr-fr"].ObjectiveUI_02="Faire dispara\u00eetre:";Q["fr-fr"].ObjectiveUI_01="R\u00e9cup\u00e9rer:";Q["fr-fr"].LevelHeader="Niveau  <VALUE>";Q["fr-fr"].TutorialHeader_01="Cr\u00e8me glac\u00e9e";
Q["fr-fr"].TutorialText_01="Marquez des points en faisant glisser des cr\u00e8mes glac\u00e9es sur la grille.";Q["fr-fr"].Tutorial_Header_02="Cr\u00e8me glac\u00e9e";Q["fr-fr"].TutorialText_02="Remplissez les lignes horizontalement et verticalement pour les faire dispara\u00eetre et marquer des points !";Q["fr-fr"].Tutorial_Header_03="Obstacle ";Q["fr-fr"].TutorialText_03="Les cr\u00e8mes glac\u00e9es emball\u00e9es doivent dispara\u00eetre plusieurs fois. ";Q["fr-fr"].Tutorial_Header_04="Objectifs";
Q["fr-fr"].TutorialText_04="Chaque niveau a un objectif diff\u00e9rent. Terminez un objectif pour terminer un niveau !";Q["fr-fr"].Tutorial_Header_05="Objectifs";Q["fr-fr"].TutorialText_05="Marquez assez de points pour terminer ces niveaux.";Q["fr-fr"].Tutorial_Header_06="Objectifs";Q["fr-fr"].TutorialText_06="R\u00e9cup\u00e9rez un certain nombre de cr\u00e8mes glac\u00e9es du m\u00eame type.";Q["fr-fr"].Tutorial_Header_07="Objectifs";Q["fr-fr"].TutorialText_07="Faites dispara\u00eetre toutes les cr\u00e8mes glac\u00e9es emball\u00e9es du niveau.";
Q["fr-fr"].TutorialText_08="Il vous reste un nombre limit\u00e9 de mouvements. Terminez le niveau avant d'\u00eatre \u00e0 court !";Q["fr-fr"].Tutorial_Header_08="Mouvements";Q["fr-fr"].Tutorial_Header_09="Am\u00e9liorations";Q["fr-fr"].TutorialText_09="Faites dispara\u00eetre trois lignes d'un coup pour gagner une am\u00e9lioration !";Q["fr-fr"].Tutorial_Header_10="Am\u00e9liorations";Q["fr-fr"].TutorialText_10="La bombe de couleur fait dispara\u00eetre toutes les cr\u00e8mes glac\u00e9es de la m\u00eame couleur.";
Q["fr-fr"].Tutorial_Header_11="Am\u00e9liorations";Q["fr-fr"].TutorialText_11="La bombe totale fait dispara\u00eetre les lignes horizontales et verticales.";Q["fr-fr"].EndScore="Score total :";Q["fr-fr"].HighScore="Meilleur score :";Q["fr-fr"].LevelFailedHeader="\u00c9chec niveau";Q["fr-fr"].Floater_01="yummy!";Q["fr-fr"].Floater_02="flurry-luscious";Q["fr-fr"].Floater_03="cold'n Sweet";Q["fr-fr"].Floater_04="creamy";Q["fr-fr"].TownName_01="Springfield";Q["fr-fr"].TownName_02="Clay Valley";
Q["fr-fr"].TownName_03="Palm Beach";Q["fr-fr"].TownName_04="Tundra Town";Q["fr-fr"].ComingSoonText="venir bient\u00f4t";Q["pt-br"]=Q["pt-br"]||{};Q["pt-br"].GameScore="Pontua\u00e7\u00e3o:";Q["pt-br"].GoalTitle="Objetivo";Q["pt-br"].GameMoves="Jogadas:";Q["pt-br"].GoalText_01="Marque <TARGET> pontos para completar o n\u00edvel!";Q["pt-br"].GoalText_02="Pegue <TARGET> sorvetes!";Q["pt-br"].GoalText_03="Remova <TARGET> sorvetes embrulhados!";Q["pt-br"].FailedPopup_Text_02="Sem jogadas!";
Q["pt-br"].FailedPopup_Text_01="Nenhuma jogada restante!";Q["pt-br"].FailedPopup_Text_03="Tentar de novo";Q["pt-br"].LevelTheme_01="Pontos por sorvete";Q["pt-br"].LevelTheme_02="Sorvetes desaparecidos";Q["pt-br"].LevelTheme_03="Sorvetes embrulhados";Q["pt-br"].ObjectiveUI_02="Remova:";Q["pt-br"].ObjectiveUI_01="Pegue:";Q["pt-br"].LevelHeader="N\u00edvel <VALUE>";Q["pt-br"].TutorialHeader_01="Sorvete";Q["pt-br"].TutorialText_01="Marque pontos arrastando os sorvetes pela grade.";
Q["pt-br"].Tutorial_Header_02="Sorvete";Q["pt-br"].TutorialText_02="Preencha linhas horizontais e verticais para remov\u00ea-las e marcar pontos!";Q["pt-br"].Tutorial_Header_03="Obst\u00e1culo ";Q["pt-br"].TutorialText_03="Sorvetes embrulhados precisam ser removidos v\u00e1rias vezes.";Q["pt-br"].Tutorial_Header_04="Objetivos ";Q["pt-br"].TutorialText_04="Cada n\u00edvel possui um objetivo diferente. Complete o objetivo para vencer a fase!";Q["pt-br"].Tutorial_Header_05="Objetivos ";
Q["pt-br"].TutorialText_05="Marque pontos suficientes para vencer estas fases.";Q["pt-br"].Tutorial_Header_06="Objetivos ";Q["pt-br"].TutorialText_06="Pegue um certo n\u00famero de sorvetes espec\u00edficos. ";Q["pt-br"].Tutorial_Header_07="Objetivos ";Q["pt-br"].TutorialText_07="Remova todos os sorvetes embrulhados do n\u00edvel.";Q["pt-br"].TutorialText_08="Resta apenas um n\u00famero limitado de jogadas. Complete o n\u00edvel antes que acabem!";Q["pt-br"].Tutorial_Header_08="Jogadas";
Q["pt-br"].Tutorial_Header_09="Poderes";Q["pt-br"].TutorialText_09="Remova tr\u00eas linhas ao mesmo tempo para ganhar um poder!";Q["pt-br"].Tutorial_Header_10="Poderes";Q["pt-br"].TutorialText_10="A bomba colorida remove todos os sorvetes da mesma cor.";Q["pt-br"].Tutorial_Header_11="Poderes";Q["pt-br"].TutorialText_11="A bomba de linha remove linhas horizontais e verticais.";Q["pt-br"].EndScore="Pontua\u00e7\u00e3o total:";Q["pt-br"].HighScore="Recorde:";Q["pt-br"].LevelFailedHeader="N\u00edvel fracassado";
Q["pt-br"].Floater_01="yummy!";Q["pt-br"].Floater_02="flurry-luscious";Q["pt-br"].Floater_03="cold'n Sweet";Q["pt-br"].Floater_04="creamy";Q["pt-br"].TownName_01="Springfield";Q["pt-br"].TownName_02="Clay Valley";Q["pt-br"].TownName_03="Palm Beach";Q["pt-br"].TownName_04="Tundra Town";Q["pt-br"].ComingSoonText="Dispon\u00edvel Em Breve";Q["es-es"]=Q["es-es"]||{};Q["es-es"].GameScore="Puntuaci\u00f3n:";Q["es-es"].GoalTitle="Objetivo";Q["es-es"].GameMoves="Turnos:";Q["es-es"].GoalText_01="\u00a1Gana <TARGET> puntos para completar el nivel!";
Q["es-es"].GoalText_02="\u00a1Consigue <TARGET> helados!";Q["es-es"].GoalText_03="\u00a1Despeja <TARGET> helados envueltos!";Q["es-es"].FailedPopup_Text_02="\u00a1No quedan turnos!";Q["es-es"].FailedPopup_Text_01="\u00a1Turnos agotados!";Q["es-es"].FailedPopup_Text_03="Int\u00e9ntalo otra vez";Q["es-es"].LevelTheme_01="Puntos por helado";Q["es-es"].LevelTheme_02="Helados desaparecidos";Q["es-es"].LevelTheme_03="Helados envueltos";Q["es-es"].ObjectiveUI_02="Despeja:";Q["es-es"].ObjectiveUI_01="Consigue:";
Q["es-es"].LevelHeader="Nivel <VALUE>";Q["es-es"].TutorialHeader_01="Helado";Q["es-es"].TutorialText_01="Gana puntos arrastrando helados por la cuadr\u00edcula.";Q["es-es"].Tutorial_Header_02="Helado";Q["es-es"].TutorialText_02="\u00a1Llena filas horizontales y verticales para despejarlas y ganar puntos!";Q["es-es"].Tutorial_Header_03="Obst\u00e1culo";Q["es-es"].TutorialText_03="Los helados envueltos hay que despejarlos varias veces.";Q["es-es"].Tutorial_Header_04="Objetivos";
Q["es-es"].TutorialText_04="Cada nivel tiene un objetivo distinto. \u00a1Compl\u00e9talo para pasar de nivel!";Q["es-es"].Tutorial_Header_05="Objetivos";Q["es-es"].TutorialText_05="Gana suficientes puntos para superar estos niveles.";Q["es-es"].Tutorial_Header_06="Objetivos";Q["es-es"].TutorialText_06="Consigue una cantidad de un helado concreto.";Q["es-es"].Tutorial_Header_07="Objetivos";Q["es-es"].TutorialText_07="Despeja todos los helados envueltos del nivel.";Q["es-es"].TutorialText_08="Tienes un n\u00famero limitado de turnos. \u00a1Termina el nivel antes de que se acaben!";
Q["es-es"].Tutorial_Header_08="Turnos";Q["es-es"].Tutorial_Header_09="Potenciadores";Q["es-es"].TutorialText_09="\u00a1Despeja tres l\u00edneas a la vez para ganar un potenciador!";Q["es-es"].Tutorial_Header_10="Potenciadores";Q["es-es"].TutorialText_10="La bomba de color despeja todos los helados del mismo color.";Q["es-es"].Tutorial_Header_11="Potenciadores";Q["es-es"].TutorialText_11="La bomba de l\u00ednea despeja l\u00edneas verticales y horizontales.";Q["es-es"].EndScore="Puntuaci\u00f3n total:";
Q["es-es"].HighScore="R\u00e9cord:";Q["es-es"].LevelFailedHeader="Nivel fallido";Q["es-es"].Floater_01="yummy!";Q["es-es"].Floater_02="flurry-luscious";Q["es-es"].Floater_03="cold'n Sweet";Q["es-es"].Floater_04="creamy";Q["es-es"].TownName_01="Springfield";Q["es-es"].TownName_02="Clay Valley";Q["es-es"].TownName_03="Palm Beach";Q["es-es"].TownName_04="Tundra Town";Q["es-es"].ComingSoonText="pronto disponible";Q["tr-tr"]=Q["tr-tr"]||{};Q["tr-tr"].GameScore="Puan:";Q["tr-tr"].GoalTitle="Ama\u00e7";
Q["tr-tr"].GameMoves="Hamle:";Q["tr-tr"].GoalText_01="B\u00f6l\u00fcm\u00fc bitirmek i\u00e7in <TARGET> puan topla!";Q["tr-tr"].GoalText_02="<TARGET> dondurma topla!";Q["tr-tr"].GoalText_03="<TARGET> sar\u0131l\u0131 dondurma temizle!";Q["tr-tr"].FailedPopup_Text_02="Hamle kalmad\u0131!";Q["tr-tr"].FailedPopup_Text_01="Hamle say\u0131n bitti!";Q["tr-tr"].FailedPopup_Text_03="Tekrar dene";Q["tr-tr"].LevelTheme_01="Dondurma i\u00e7in puan";Q["tr-tr"].LevelTheme_02="Kaybolan dondurmalar";
Q["tr-tr"].LevelTheme_03="Sar\u0131l\u0131 dondurmalar";Q["tr-tr"].ObjectiveUI_02="Biti\u015f:";Q["tr-tr"].ObjectiveUI_01="Toplanan:";Q["tr-tr"].LevelHeader="B\u00f6l\u00fcm <VALUE>";Q["tr-tr"].TutorialHeader_01="Dondurma";Q["tr-tr"].TutorialText_01="Dondurmalar\u0131 hareket ettirerek puan topla.";Q["tr-tr"].Tutorial_Header_02="Dondurma";Q["tr-tr"].TutorialText_02="Dikey ve yatay olarak doldurarak temizle ve puan topla!";Q["tr-tr"].Tutorial_Header_03="Engel";Q["tr-tr"].TutorialText_03="Sar\u0131l\u0131 dondurmalar birden fazla temizlenmeli.";
Q["tr-tr"].Tutorial_Header_04="Ama\u00e7lar";Q["tr-tr"].TutorialText_04="Her b\u00f6l\u00fcm\u00fcn amac\u0131 farkl\u0131d\u0131r. Amaca ula\u015farak b\u00f6l\u00fcm\u00fc kazan!";Q["tr-tr"].Tutorial_Header_05="Ama\u00e7lar";Q["tr-tr"].TutorialText_05="B\u00f6l\u00fcmleri kazanmak i\u00e7in yeterli puan topla!";Q["tr-tr"].Tutorial_Header_06="Ama\u00e7lar";Q["tr-tr"].TutorialText_06="Belirli dondurmalardan belli say\u0131da topla.";Q["tr-tr"].Tutorial_Header_07="Ama\u00e7lar";
Q["tr-tr"].TutorialText_07="T\u00fcm sar\u0131l\u0131 dondurmalar\u0131 temizle.";Q["tr-tr"].TutorialText_08="S\u0131n\u0131rl\u0131 say\u0131da hamlen kald\u0131. Hamlesiz kalmadan b\u00f6l\u00fcm\u00fc bitir!";Q["tr-tr"].Tutorial_Header_08="Hamleler";Q["tr-tr"].Tutorial_Header_09="G\u00fc\u00e7ler";Q["tr-tr"].TutorialText_09="Bir hamlede \u00fc\u00e7 sat\u0131r temizleyerek g\u00fc\u00e7 kazan!";Q["tr-tr"].Tutorial_Header_10="G\u00fc\u00e7ler";Q["tr-tr"].TutorialText_10="Renk bombas\u0131, o renge ait t\u00fcm dondurmalar\u0131 temizler.";
Q["tr-tr"].Tutorial_Header_11="G\u00fc\u00e7ler";Q["tr-tr"].TutorialText_11="Sat\u0131r-silen bomba dikey ve yatay sat\u0131rlar\u0131 temizler.";Q["tr-tr"].EndScore="Toplam puan:";Q["tr-tr"].HighScore="En y\u00fcksek puan:";Q["tr-tr"].LevelFailedHeader="Kaybettin";Q["tr-tr"].Floater_01="yummy!";Q["tr-tr"].Floater_02="flurry-luscious";Q["tr-tr"].Floater_03="cold'n Sweet";Q["tr-tr"].Floater_04="creamy";Q["tr-tr"].TownName_01="Springfield";Q["tr-tr"].TownName_02="Clay Valley";
Q["tr-tr"].TownName_03="Palm Beach";Q["tr-tr"].TownName_04="Tundra Town";Q["tr-tr"].ComingSoonText="Yak\u0131nda Mevcut";Q["ru-ru"]=Q["ru-ru"]||{};Q["ru-ru"].GameScore="Score:";Q["ru-ru"].GoalTitle="Goal";Q["ru-ru"].GameMoves="Moves:";Q["ru-ru"].GoalText_01="Score <TARGET> points to complete the level!";Q["ru-ru"].GoalText_02="Collect <TARGET> ice creams!";Q["ru-ru"].GoalText_03="Clear <TARGET> wrapped ice creams!";Q["ru-ru"].FailedPopup_Text_02="Out of moves!";Q["ru-ru"].FailedPopup_Text_01="No moves left!";
Q["ru-ru"].FailedPopup_Text_03="Try again";Q["ru-ru"].LevelTheme_01="Points for ice cream";Q["ru-ru"].LevelTheme_02="Missing ice creams";Q["ru-ru"].LevelTheme_03="Wrapped ice creams";Q["ru-ru"].ObjectiveUI_02="Clear:";Q["ru-ru"].ObjectiveUI_01="Collect:";Q["ru-ru"].LevelHeader="Level  <VALUE>";Q["ru-ru"].TutorialHeader_01="Ice cream";Q["ru-ru"].TutorialText_01="Score points by dragging the ice creams across the grid.";Q["ru-ru"].Tutorial_Header_02="Ice cream";Q["ru-ru"].TutorialText_02="Fill up horizontal and vertical lines to clear them and score points!";
Q["ru-ru"].Tutorial_Header_03="Obstacle ";Q["ru-ru"].TutorialText_03="Wrapped ice creams have to be cleared multiple times.";Q["ru-ru"].Tutorial_Header_04="Goals ";Q["ru-ru"].TutorialText_04="Each level has a different goal. Complete the goal to win the level!";Q["ru-ru"].Tutorial_Header_05="Goals ";Q["ru-ru"].TutorialText_05="Score enough points to win these levels.";Q["ru-ru"].Tutorial_Header_06="Goals ";Q["ru-ru"].TutorialText_06="Collect a number of a specified ice cream. ";
Q["ru-ru"].Tutorial_Header_07="Goals ";Q["ru-ru"].TutorialText_07="Clear all the wrapped ice creams in the level.";Q["ru-ru"].TutorialText_08="You only have a limited number of moves left. Complete the level before you run out!";Q["ru-ru"].Tutorial_Header_08="Moves";Q["ru-ru"].Tutorial_Header_09="Power-ups";Q["ru-ru"].TutorialText_09="Clear three lines at once to earn a power-up!";Q["ru-ru"].Tutorial_Header_10="Power-ups";Q["ru-ru"].TutorialText_10="The colour bomb clears all ice creams of the same colour.";
Q["ru-ru"].Tutorial_Header_11="Power-ups";Q["ru-ru"].TutorialText_11="The clear-line bomb clears horizontal and vertical lines.";Q["ru-ru"].EndScore="Total score:";Q["ru-ru"].HighScore="High score:";Q["ru-ru"].LevelFailedHeader="Level failed";Q["ru-ru"].Floater_01="yummy!";Q["ru-ru"].Floater_02="flurry-luscious";Q["ru-ru"].Floater_03="cold'n Sweet";Q["ru-ru"].Floater_04="creamy";Q["ru-ru"].TownName_01="Springfield";Q["ru-ru"].TownName_02="Clay Valley";Q["ru-ru"].TownName_03="Palm Beach";
Q["ru-ru"].TownName_04="Tundra Town";Q["ru-ru"].ComingSoonText="Coming Soon";Q["ar-eg"]=Q["ar-eg"]||{};Q["ar-eg"].GameScore="Score:";Q["ar-eg"].GoalTitle="Goal";Q["ar-eg"].GameMoves="Moves:";Q["ar-eg"].GoalText_01="Score <TARGET> points to complete the level!";Q["ar-eg"].GoalText_02="Collect <TARGET> ice creams!";Q["ar-eg"].GoalText_03="Clear <TARGET> wrapped ice creams!";Q["ar-eg"].FailedPopup_Text_02="Out of moves!";Q["ar-eg"].FailedPopup_Text_01="No moves left!";
Q["ar-eg"].FailedPopup_Text_03="Try again";Q["ar-eg"].LevelTheme_01="Points for ice cream";Q["ar-eg"].LevelTheme_02="Missing ice creams";Q["ar-eg"].LevelTheme_03="Wrapped ice creams";Q["ar-eg"].ObjectiveUI_02="Clear:";Q["ar-eg"].ObjectiveUI_01="Collect:";Q["ar-eg"].LevelHeader="Level  <VALUE>";Q["ar-eg"].TutorialHeader_01="Ice cream";Q["ar-eg"].TutorialText_01="Score points by dragging the ice creams across the grid.";Q["ar-eg"].Tutorial_Header_02="Ice cream";Q["ar-eg"].TutorialText_02="Fill up horizontal and vertical lines to clear them and score points!";
Q["ar-eg"].Tutorial_Header_03="Obstacle ";Q["ar-eg"].TutorialText_03="Wrapped ice creams have to be cleared multiple times.";Q["ar-eg"].Tutorial_Header_04="Goals ";Q["ar-eg"].TutorialText_04="Each level has a different goal. Complete the goal to win the level!";Q["ar-eg"].Tutorial_Header_05="Goals ";Q["ar-eg"].TutorialText_05="Score enough points to win these levels.";Q["ar-eg"].Tutorial_Header_06="Goals ";Q["ar-eg"].TutorialText_06="Collect a number of a specified ice cream. ";
Q["ar-eg"].Tutorial_Header_07="Goals ";Q["ar-eg"].TutorialText_07="Clear all the wrapped ice creams in the level.";Q["ar-eg"].TutorialText_08="You only have a limited number of moves left. Complete the level before you run out!";Q["ar-eg"].Tutorial_Header_08="Moves";Q["ar-eg"].Tutorial_Header_09="Power-ups";Q["ar-eg"].TutorialText_09="Clear three lines at once to earn a power-up!";Q["ar-eg"].Tutorial_Header_10="Power-ups";Q["ar-eg"].TutorialText_10="The colour bomb clears all ice creams of the same colour.";
Q["ar-eg"].Tutorial_Header_11="Power-ups";Q["ar-eg"].TutorialText_11="The clear-line bomb clears horizontal and vertical lines.";Q["ar-eg"].EndScore="Total score:";Q["ar-eg"].HighScore="High score:";Q["ar-eg"].LevelFailedHeader="Level failed";Q["ar-eg"].Floater_01="yummy!";Q["ar-eg"].Floater_02="flurry-luscious";Q["ar-eg"].Floater_03="cold'n Sweet";Q["ar-eg"].Floater_04="creamy";Q["ar-eg"].TownName_01="Springfield";Q["ar-eg"].TownName_02="Clay Valley";Q["ar-eg"].TownName_03="Palm Beach";
Q["ar-eg"].TownName_04="Tundra Town";Q["ar-eg"].ComingSoonText="Coming Soon";Q["ko-kr"]=Q["ko-kr"]||{};Q["ko-kr"].GameScore="Score:";Q["ko-kr"].GoalTitle="Goal";Q["ko-kr"].GameMoves="Moves:";Q["ko-kr"].GoalText_01="Score <TARGET> points to complete the level!";Q["ko-kr"].GoalText_02="Collect <TARGET> ice creams!";Q["ko-kr"].GoalText_03="Clear <TARGET> wrapped ice creams!";Q["ko-kr"].FailedPopup_Text_02="Out of moves!";Q["ko-kr"].FailedPopup_Text_01="No moves left!";
Q["ko-kr"].FailedPopup_Text_03="Try again";Q["ko-kr"].LevelTheme_01="Points for ice cream";Q["ko-kr"].LevelTheme_02="Missing ice creams";Q["ko-kr"].LevelTheme_03="Wrapped ice creams";Q["ko-kr"].ObjectiveUI_02="Clear:";Q["ko-kr"].ObjectiveUI_01="Collect:";Q["ko-kr"].LevelHeader="Level  <VALUE>";Q["ko-kr"].TutorialHeader_01="Ice cream";Q["ko-kr"].TutorialText_01="Score points by dragging the ice creams across the grid.";Q["ko-kr"].Tutorial_Header_02="Ice cream";Q["ko-kr"].TutorialText_02="Fill up horizontal and vertical lines to clear them and score points!";
Q["ko-kr"].Tutorial_Header_03="Obstacle ";Q["ko-kr"].TutorialText_03="Wrapped ice creams have to be cleared multiple times.";Q["ko-kr"].Tutorial_Header_04="Goals ";Q["ko-kr"].TutorialText_04="Each level has a different goal. Complete the goal to win the level!";Q["ko-kr"].Tutorial_Header_05="Goals ";Q["ko-kr"].TutorialText_05="Score enough points to win these levels.";Q["ko-kr"].Tutorial_Header_06="Goals ";Q["ko-kr"].TutorialText_06="Collect a number of a specified ice cream. ";
Q["ko-kr"].Tutorial_Header_07="Goals ";Q["ko-kr"].TutorialText_07="Clear all the wrapped ice creams in the level.";Q["ko-kr"].TutorialText_08="You only have a limited number of moves left. Complete the level before you run out!";Q["ko-kr"].Tutorial_Header_08="Moves";Q["ko-kr"].Tutorial_Header_09="Power-ups";Q["ko-kr"].TutorialText_09="Clear three lines at once to earn a power-up!";Q["ko-kr"].Tutorial_Header_10="Power-ups";Q["ko-kr"].TutorialText_10="The colour bomb clears all ice creams of the same colour.";
Q["ko-kr"].Tutorial_Header_11="Power-ups";Q["ko-kr"].TutorialText_11="The clear-line bomb clears horizontal and vertical lines.";Q["ko-kr"].EndScore="Total score:";Q["ko-kr"].HighScore="High score:";Q["ko-kr"].LevelFailedHeader="Level failed";Q["ko-kr"].Floater_01="yummy!";Q["ko-kr"].Floater_02="flurry-luscious";Q["ko-kr"].Floater_03="cold'n Sweet";Q["ko-kr"].Floater_04="creamy";Q["ko-kr"].TownName_01="Springfield";Q["ko-kr"].TownName_02="Clay Valley";Q["ko-kr"].TownName_03="Palm Beach";
Q["ko-kr"].TownName_04="Tundra Town";Q["ko-kr"].ComingSoonText="Coming Soon";Q["jp-jp"]=Q["jp-jp"]||{};Q["jp-jp"].GameScore="\u30b9\u30b3\u30a2\uff1a";Q["jp-jp"].GoalTitle="\u30b4\u30fc\u30eb";Q["jp-jp"].GameMoves="\u79fb\u52d5\uff1a";Q["jp-jp"].GoalText_01="<TARGET> \u30dd\u30a4\u30f3\u30c8\u30b2\u30c3\u30c8\u3057\u3066\n\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u3088\u3046\uff01";Q["jp-jp"].GoalText_02="<TARGET> \u500b\u30a2\u30a4\u30b9\u3092\u96c6\u3081\u3088\u3046\uff01";
Q["jp-jp"].GoalText_03="<TARGET> \u500b\u888b\u5165\u308a\u306e\u30a2\u30a4\u30b9\u3092\u6d88\u305d\u3046\uff01";Q["jp-jp"].FailedPopup_Text_02="\u3082\u3046\u79fb\u52d5\u3067\u304d\u306a\u3044\u3088\uff01";Q["jp-jp"].FailedPopup_Text_01="\u3082\u3046\u79fb\u52d5\u3067\u304d\u306a\u3044\u3088\uff01";Q["jp-jp"].FailedPopup_Text_03="\u3082\u3046\u4e00\u5ea6\u30c8\u30e9\u30a4";Q["jp-jp"].LevelTheme_01="\u30a2\u30a4\u30b9\u3092\u72d9\u3048";Q["jp-jp"].LevelTheme_02="\u5931\u308f\u308c\u305f\u30a2\u30a4\u30b9";
Q["jp-jp"].LevelTheme_03="\u888b\u5165\u308a\u306e\u30a2\u30a4\u30b9";Q["jp-jp"].ObjectiveUI_02="\u30af\u30ea\u30a2\uff1a";Q["jp-jp"].ObjectiveUI_01="\u7372\u5f97\uff1a";Q["jp-jp"].LevelHeader="\u30ec\u30d9\u30eb <VALUE>";Q["jp-jp"].TutorialHeader_01="\u30a2\u30a4\u30b9\u30af\u30ea\u30fc\u30e0";Q["jp-jp"].TutorialText_01="\u30a2\u30a4\u30b9\u3092\u30de\u30b9\u76ee\u306b\n\u30c9\u30e9\u30c3\u30b0or\u30b9\u30ef\u30a4\u30d7\u3057\u3066\n\u5f97\u70b9\u3092\u7a3c\u3054\u3046";
Q["jp-jp"].Tutorial_Header_02="\u30a2\u30a4\u30b9\u30af\u30ea\u30fc\u30e0";Q["jp-jp"].TutorialText_02="\u7e26or\u6a2a\u306b\u4e00\u5217\u63c3\u3048\u3070\n\u5f97\u70b9\u3092\u30b2\u30c3\u30c8";Q["jp-jp"].Tutorial_Header_03="\u969c\u5bb3\u7269";Q["jp-jp"].TutorialText_03="\u888b\u5165\u308a\u306e\u30a2\u30a4\u30b9\u306f\n\u4f55\u5ea6\u304b\u63c3\u3048\u306a\u3044\u3068\n\u6d88\u3048\u306a\u3044\u3088";Q["jp-jp"].Tutorial_Header_04="\u30b4\u30fc\u30eb";Q["jp-jp"].TutorialText_04="\u30ec\u30d9\u30eb\u6bce\u306b\u7570\u306a\u308b\n\u30b4\u30fc\u30eb\u3092\u9054\u6210\u3057\u3066\n\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u3088\u3046\uff01";
Q["jp-jp"].Tutorial_Header_05="\u30b4\u30fc\u30eb";Q["jp-jp"].TutorialText_05="\u30dd\u30a4\u30f3\u30c8\u3092\u5341\u5206\u306b\u30b2\u30c3\u30c8\u3057\u3066\n\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u3088\u3046";Q["jp-jp"].Tutorial_Header_06="\u30b4\u30fc\u30eb";Q["jp-jp"].TutorialText_06="\u6c7a\u3081\u3089\u308c\u305f\u6570\u306e\n\u30a2\u30a4\u30b9\u3092\u96c6\u3081\u3088\u3046";Q["jp-jp"].Tutorial_Header_07="\u30b4\u30fc\u30eb";Q["jp-jp"].TutorialText_07="\u888b\u5165\u308a\u306e\u30a2\u30a4\u30b9\u3092\n\u5168\u3066\u6d88\u3057\u3066\n\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u3088\u3046";
Q["jp-jp"].TutorialText_08="\u79fb\u52d5\u56de\u6570\u306b\u9650\u308a\u304c\u3042\u308b\u306e\u3067\n\u306a\u304f\u306a\u308b\u524d\u306b\n\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u3088\u3046\uff01";Q["jp-jp"].Tutorial_Header_08="\u79fb\u52d5";Q["jp-jp"].Tutorial_Header_09="\u30d1\u30ef\u30fc\u30a2\u30c3\u30d7";Q["jp-jp"].TutorialText_09="\u4e00\u5ea6\u306b3\u5217\u63c3\u3048\u308b\u3068\n\u30d1\u30ef\u30fc\u30a2\u30c3\u30d7\u304c\n\u624b\u306b\u5165\u308a\u307e\u3059";
Q["jp-jp"].Tutorial_Header_10="\u30d1\u30ef\u30fc\u30a2\u30c3\u30d7";Q["jp-jp"].TutorialText_10="\u30ab\u30e9\u30fc\u7206\u5f3e\u306f\n\u540c\u3058\u8272\u306e\u30a2\u30a4\u30b9\u3092\n\u3044\u3063\u307a\u3093\u306b\u6d88\u3057\u307e\u3059";Q["jp-jp"].Tutorial_Header_11="\u30d1\u30ef\u30fc\u30a2\u30c3\u30d7";Q["jp-jp"].TutorialText_11="\u30e9\u30a4\u30f3\u7206\u5f3e\u306f\n\u7e26or\u6a2a\u4e00\u5217\u3092\u6d88\u3057\u307e\u3059";Q["jp-jp"].EndScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2\uff1a";
Q["jp-jp"].HighScore="\u30cf\u30a4\u30b9\u30b3\u30a2\uff1a";Q["jp-jp"].LevelFailedHeader="\u30c1\u30e3\u30ec\u30f3\u30b8\u5931\u6557";Q["jp-jp"].Floater_01="\u304a\u3044\u3057\u301c\u3044\uff01";Q["jp-jp"].Floater_02="\u3081\u304f\u308b\u3081\u304f\u304a\u3044\u3057\u3055\uff01";Q["jp-jp"].Floater_03="\u3064\u3081\u305f\u304f\u3066\u7518\u301c\u3044\uff01";Q["jp-jp"].Floater_04="\u30af\u30ea\u30fc\u30df\u30fc";Q["jp-jp"].TownName_01="\u30b9\u30d7\u30ea\u30f3\u30b0\u30d5\u30a3\u30fc\u30eb\u30c9";
Q["jp-jp"].TownName_02="\u30af\u30ec\u30a4\u30d0\u30ec\u30fc";Q["jp-jp"].TownName_03="\u30d1\u30fc\u30e0\u30d3\u30fc\u30c1";Q["jp-jp"].TownName_04="\u30c4\u30f3\u30c9\u30e9\u30bf\u30a6\u30f3";Q["jp-jp"].ComingSoonText="Coming Soon";
function gn(){var b={},b={FI:{QG:["Yummy!","Flurry-licious!","Creamy!"]},fonts:{lR:{o:N.o,fontSize:22,fillColor:"#d0853e"},ER:{o:vi.o,fontSize:36,fillColor:"white",strokeColor:"#007bee"},FR:{o:vi.o,fontSize:36,fillColor:"white",strokeColor:"#fc3a6c"},GR:{o:vi.o,fontSize:36,fillColor:"white",strokeColor:"#98512a"},HR:{o:vi.o,fontSize:36,fillColor:"white",strokeColor:"#ec6f00"},OR:{o:N.o,fontSize:18,fillColor:"#452f5a"},PR:{o:vi.o,fontSize:48,fillColor:"#ea8c9d"},qS:{o:N.o,fontSize:18,fillColor:"#452f5a"},
rS:{o:vi.o,fontSize:36,fillColor:"#ea8c9d"},zS:{o:vi.o,fontSize:48,fillColor:"#e9deda"},AS:{o:vi.o,fontSize:36,fillColor:"#ea8c9d"},BS:{o:N.o,fontSize:24,fillColor:"#120825"},CS:{o:N.o,fontSize:24,fillColor:"#ea8c9d"},iT:{o:N.o,fontSize:22,fillColor:"#592902"},VT:{o:vi.o,fontSize:48,fillColor:"#e9deda"},gU:{o:N.o,fontSize:22,fillColor:"#8f7c64"},tU:{o:N.o,fontSize:22,fillColor:"#d0853e"},dy:{o:vi.o,fontSize:30,fillColor:"#110723"},zD:{fontSize:30,fillColor:"#100723",o:vi.o},PP:{fontSize:18,fillColor:"#ea8c9d",
o:N.o},QP:{fontSize:18,fillColor:"#110723",o:N.o},vp:{fillColor:"#e9deda",fontSize:18,o:N.o},SP:{fontSize:18,fillColor:"#ea8c9d",o:N.o},TP:{fontSize:18,fillColor:"#110723",o:N.o},CU:{o:vi.o,fontSize:48,fillColor:"#e9deda"},DU:{o:N.o,fontSize:24,fillColor:"#120825"},EU:{o:N.o,fontSize:24,fillColor:"#ea8c9d"}},C:{nt:[ph,oh,rh,sh,qh,th,mh,vh,nh],UK:2E3,aM:500,cO:100,WT:35},f:{height:10,offsetX:355,offsetY:105,width:10},Kh:{Jv:3,KB:50,LB:50,hU:1,kU:1,SO:1,bD:30,cD:20,mU:1,yD:.35},yd:{VK:1,sN:2,tN:10,
uN:2,tT:300},Yb:{JF:-150,KF:-150,HH:-150,UH:-150,cA:50,TI:-150,nK:-150,WK:-150,tL:90,BL:-150,JB:150,po:.2,RO:-150,sQ:915,vQ:175,wQ:325,xQ:475},Fa:{jR:9,JG:111,KG:-11,LG:111,mR:-11,nR:111,oR:{fontSize:17,fillColor:"white",o:"arial",fontWeight:"bold"},pR:9,Cz:111,zH:4,AH:75,RR:{o:vi.o,fontSize:30,fillColor:"#110723"},Kn:24,Xu:108,VJ:75,jS:{fontSize:18,fillColor:"#110723",o:"open sans",fontWeight:"bold"},KS:{fontSize:18,fillColor:"#110723",o:"open sans",fontWeight:"bold"},QL:-35,LS:{fontSize:18,fillColor:"#110723",
o:"open sans",fontWeight:"bold"},RL:-14,nT:{fillColor:"white",fontSize:20,o:"arial",fontWeight:"bold"},nN:"#00aeef",oN:1,pN:-201,OT:{fontSize:18,fillColor:"#110723",o:"open sans",fontWeight:"bold"},Xw:-87,ST:{fontSize:18,fillColor:"#110723",o:"open sans",fontWeight:"bold"},Yw:-69,lU:-5,Wr:-127,nU:35,bP:2,cP:73,LP:221,MP:345},rm:{Ch:[20,40,61]}};b.l={template10_10:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),
y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},
{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),
y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),
id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},
{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),
y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,
b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd2v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:1},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),
id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),
y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:1},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:1},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),
id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,
a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:1},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:1},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),
y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:1},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),
id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:1}]},template10_10_odd3v:{width:P(560),height:P(560),items:[{x:P(32),
y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),
y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:1},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:1},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,
b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:1},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:1},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},
{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),
y:P(336),id:0,b:0,a:1},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:1},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:1},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:1},{x:P(368),y:P(384),
id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},
{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd12v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,
b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),
id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:1},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:1},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,
a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),
y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:1},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:1},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),
id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},
{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:1},{x:P(176),y:P(480),id:0,b:0,a:1},{x:P(224),y:P(480),id:0,b:0,a:1},{x:P(272),y:P(480),id:0,b:0,a:1},{x:P(320),y:P(480),id:0,b:0,a:1},{x:P(368),y:P(480),id:0,b:0,a:1},{x:P(416),y:P(480),id:0,b:0,a:1},{x:P(464),
y:P(480),id:0,b:0,a:1}]},template10_10_odd14v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:1},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),
y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:1},{x:P(416),y:P(96),id:0,b:0,a:1},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,
a:1},{x:P(464),y:P(144),id:0,b:0,a:1},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),
y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),
id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:1},{x:P(80),y:P(384),id:0,b:0,a:1},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},
{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:1},{x:P(80),y:P(432),id:0,b:0,a:1},{x:P(128),y:P(432),id:0,b:0,a:1},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),
y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:1},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd10v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:1},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},
{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,
b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),
y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:1},{x:P(272),y:P(240),id:0,b:0,a:1},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),
id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:1},{x:P(272),y:P(288),id:0,b:0,a:1},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,
a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),
y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),
id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:1}]},template10_10_odd13v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:1},{x:P(80),y:P(48),id:0,b:0,a:1},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),
id:0,b:0,a:1},{x:P(80),y:P(96),id:0,b:0,a:1},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:1},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:1},{x:P(80),y:P(144),id:0,b:0,a:1},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),
y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:1},{x:P(464),y:P(144),id:0,b:0,a:1},{x:P(32),y:P(192),id:0,b:0,a:1},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:1},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,
b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},
{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:1},{x:P(272),y:P(336),id:0,b:0,a:1},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),
y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:1},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:1},{x:P(272),y:P(432),id:0,b:0,a:1},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),
id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:1},{x:P(272),y:P(480),id:0,b:0,a:1},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd15v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),
y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:1},{x:P(368),
y:P(96),id:0,b:0,a:1},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:1},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(416),y:P(144),id:0,b:0,a:1},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,
b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:10},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:1},{x:P(416),y:P(192),id:0,b:0,a:1},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},
{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:1},{x:P(128),y:P(336),id:0,b:0,a:1},{x:P(176),
y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:1},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:1},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),
id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:1},{x:P(176),y:P(432),id:0,b:0,a:1},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},
{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd16v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:1},{x:P(80),y:P(48),id:0,b:0,a:1},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:1},{x:P(272),y:P(48),id:0,b:0,a:1},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,
b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:1},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),
id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,
a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:1},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),
y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:1},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),
id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:1},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},
{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:1},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:1},{x:P(464),y:P(480),id:0,b:0,a:1}]},template10_10_odd9v:{width:P(560),
height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),
y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:10},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,
b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:1},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:1},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:1},
{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:1},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),
y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:1},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:1},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),
id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:1},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},
{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd11v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:1},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,
b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:1},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),
id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,
a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),
y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),
id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},
{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:1},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:1},{x:P(416),
y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd6v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:1},{x:P(272),y:P(48),id:0,b:0,a:1},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),
y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:1},{x:P(272),y:P(96),id:0,b:0,a:1},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:1},{x:P(272),y:P(144),id:0,b:0,a:1},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,
a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:1},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:1},{x:P(32),y:P(240),id:0,b:0,a:1},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),
y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:1},{x:P(32),y:P(288),id:0,b:0,a:1},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),
id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:1},{x:P(32),y:P(336),id:0,b:0,a:1},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:1},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},
{x:P(224),y:P(384),id:0,b:0,a:1},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:1},{x:P(272),y:P(432),id:0,b:0,a:1},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),
y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:1},{x:P(272),y:P(480),id:0,b:0,a:1},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd5v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},
{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,
b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),
y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),
id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},
{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:1},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),
y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),
id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd7v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),
id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:1},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),
y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:1},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),
id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,
a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:1},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),
y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:1},{x:P(368),y:P(384),id:0,b:0,a:1},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:1},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),
id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:0},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd4v:{width:P(560),height:P(560),items:[{x:P(32),
y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:0},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:0},{x:P(416),y:P(48),id:0,b:0,a:0},{x:P(464),y:P(48),id:0,b:0,a:0},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:1},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),
y:P(96),id:0,b:0,a:1},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:0},{x:P(464),y:P(96),id:0,b:0,a:0},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:0},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,
b:0,a:1},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:1},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},
{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:1},{x:P(128),
y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:1},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:0},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),
id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:0},{x:P(80),y:P(432),id:0,b:0,a:0},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:1},{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:1},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),y:P(480),id:0,b:0,a:0},{x:P(80),y:P(480),id:0,b:0,a:0},{x:P(128),y:P(480),id:0,b:0,a:0},
{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:0},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd1v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:1},{x:P(80),y:P(48),id:0,b:0,a:1},{x:P(128),y:P(48),id:0,b:0,a:1},{x:P(176),y:P(48),id:0,b:0,a:0},{x:P(224),y:P(48),id:0,b:0,a:0},{x:P(272),y:P(48),id:0,b:0,a:0},{x:P(320),y:P(48),id:0,
b:0,a:0},{x:P(368),y:P(48),id:0,b:0,a:1},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:1},{x:P(80),y:P(96),id:0,b:0,a:1},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:0},{x:P(272),y:P(96),id:0,b:0,a:0},{x:P(320),y:P(96),id:0,b:0,a:0},{x:P(368),y:P(96),id:0,b:0,a:0},{x:P(416),y:P(96),id:0,b:0,a:1},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:1},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),
id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(416),y:P(144),id:0,b:0,a:0},{x:P(464),y:P(144),id:0,b:0,a:1},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,
a:0},{x:P(416),y:P(192),id:0,b:0,a:0},{x:P(464),y:P(192),id:0,b:0,a:0},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),
y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:0},{x:P(80),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),
id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:1},{x:P(80),y:P(384),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:1},{x:P(32),y:P(432),id:0,b:0,a:1},{x:P(80),y:P(432),id:0,b:0,a:1},{x:P(128),y:P(432),id:0,b:0,a:0},{x:P(176),y:P(432),id:0,b:0,a:0},
{x:P(224),y:P(432),id:0,b:0,a:0},{x:P(272),y:P(432),id:0,b:0,a:0},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:1},{x:P(464),y:P(432),id:0,b:0,a:1},{x:P(32),y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:1},{x:P(176),y:P(480),id:0,b:0,a:0},{x:P(224),y:P(480),id:0,b:0,a:0},{x:P(272),y:P(480),id:0,b:0,a:0},{x:P(320),y:P(480),id:0,b:0,a:0},{x:P(368),y:P(480),id:0,b:0,a:1},{x:P(416),y:P(480),id:0,b:0,a:1},{x:P(464),
y:P(480),id:0,b:0,a:1}]},template10_10_odd8v:{width:P(560),height:P(560),items:[{x:P(32),y:P(48),id:0,b:0,a:0},{x:P(80),y:P(48),id:0,b:0,a:0},{x:P(128),y:P(48),id:0,b:0,a:1},{x:P(176),y:P(48),id:0,b:0,a:1},{x:P(224),y:P(48),id:0,b:0,a:1},{x:P(272),y:P(48),id:0,b:0,a:1},{x:P(320),y:P(48),id:0,b:0,a:1},{x:P(368),y:P(48),id:0,b:0,a:1},{x:P(416),y:P(48),id:0,b:0,a:1},{x:P(464),y:P(48),id:0,b:0,a:1},{x:P(32),y:P(96),id:0,b:0,a:0},{x:P(80),y:P(96),id:0,b:0,a:0},{x:P(128),y:P(96),id:0,b:0,a:0},{x:P(176),
y:P(96),id:0,b:0,a:0},{x:P(224),y:P(96),id:0,b:0,a:1},{x:P(272),y:P(96),id:0,b:0,a:1},{x:P(320),y:P(96),id:0,b:0,a:1},{x:P(368),y:P(96),id:0,b:0,a:1},{x:P(416),y:P(96),id:0,b:0,a:1},{x:P(464),y:P(96),id:0,b:0,a:1},{x:P(32),y:P(144),id:0,b:0,a:0},{x:P(80),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:1},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(416),y:P(144),id:0,b:0,
a:1},{x:P(464),y:P(144),id:0,b:0,a:1},{x:P(32),y:P(192),id:0,b:0,a:0},{x:P(80),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(416),y:P(192),id:0,b:0,a:1},{x:P(464),y:P(192),id:0,b:0,a:1},{x:P(32),y:P(240),id:0,b:0,a:0},{x:P(80),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),
y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(416),y:P(240),id:0,b:0,a:0},{x:P(464),y:P(240),id:0,b:0,a:0},{x:P(32),y:P(288),id:0,b:0,a:0},{x:P(80),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(416),y:P(288),id:0,b:0,a:0},{x:P(464),y:P(288),
id:0,b:0,a:0},{x:P(32),y:P(336),id:0,b:0,a:1},{x:P(80),y:P(336),id:0,b:0,a:1},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(416),y:P(336),id:0,b:0,a:0},{x:P(464),y:P(336),id:0,b:0,a:0},{x:P(32),y:P(384),id:0,b:0,a:1},{x:P(80),y:P(384),id:0,b:0,a:1},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:1},{x:P(224),y:P(384),id:0,b:0,a:0},
{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0},{x:P(416),y:P(384),id:0,b:0,a:0},{x:P(464),y:P(384),id:0,b:0,a:0},{x:P(32),y:P(432),id:0,b:0,a:1},{x:P(80),y:P(432),id:0,b:0,a:1},{x:P(128),y:P(432),id:0,b:0,a:1},{x:P(176),y:P(432),id:0,b:0,a:1},{x:P(224),y:P(432),id:0,b:0,a:1},{x:P(272),y:P(432),id:0,b:0,a:1},{x:P(320),y:P(432),id:0,b:0,a:0},{x:P(368),y:P(432),id:0,b:0,a:0},{x:P(416),y:P(432),id:0,b:0,a:0},{x:P(464),y:P(432),id:0,b:0,a:0},{x:P(32),
y:P(480),id:0,b:0,a:1},{x:P(80),y:P(480),id:0,b:0,a:1},{x:P(128),y:P(480),id:0,b:0,a:1},{x:P(176),y:P(480),id:0,b:0,a:1},{x:P(224),y:P(480),id:0,b:0,a:1},{x:P(272),y:P(480),id:0,b:0,a:1},{x:P(320),y:P(480),id:0,b:0,a:1},{x:P(368),y:P(480),id:0,b:0,a:1},{x:P(416),y:P(480),id:0,b:0,a:0},{x:P(464),y:P(480),id:0,b:0,a:0}]},template10_10_odd2:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:0},
{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:1},{x:P(176),y:P(128),id:0,
b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:1},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),
y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),
id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:1},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:1},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:0},
{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:1},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),
y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,
b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:1}]},template10_10_odd3:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,
b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:1},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),
y:P(176),id:0,b:0,a:1},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:1},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),
id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:1},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},
{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:1},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:1},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:1},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),
y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),
id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:1},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd5:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),
y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),
y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:1},{x:P(176),y:P(128),id:0,b:0,a:1},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:1},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:1},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),
id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,
a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:1},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:1},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),
y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:1},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:1},{x:P(368),y:P(368),id:0,b:0,a:1},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),
id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},
{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:1},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd7:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,
a:1},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:1},{x:P(176),y:P(128),id:0,b:0,a:1},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),
id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:1},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},
{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),
y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:1},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:1},{x:P(368),y:P(368),
id:0,b:0,a:1},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:0},
{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd9:{width:P(560),
height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),
y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,
b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:1},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),
y:P(272),id:0,b:0,a:1},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:1},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),
id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},
{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),
y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:1}]},template10_10_odd8:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:1},{x:P(224),y:P(32),id:0,b:0,a:1},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),
y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:1},{x:P(368),y:P(80),id:0,b:0,a:1},{x:P(416),y:P(80),id:0,b:0,a:1},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},
{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),id:0,b:0,a:1},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:1},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),
y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),
id:0,b:0,a:1},{x:P(80),y:P(320),id:0,b:0,a:1},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:1},{x:P(80),y:P(368),id:0,b:0,a:1},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:1},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,
a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:1},{x:P(128),y:P(416),id:0,b:0,a:1},{x:P(176),y:P(416),id:0,b:0,a:1},{x:P(224),y:P(416),id:0,b:0,a:1},{x:P(272),y:P(416),id:0,b:0,a:1},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),
y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,a:1},{x:P(320),y:P(464),id:0,b:0,a:1},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:1},{x:P(272),y:P(80),id:0,b:0,a:1},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:1},{x:P(320),y:P(128),id:0,b:0,a:1},{x:P(272),y:P(176),id:0,
b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd6:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:1},{x:P(224),y:P(32),id:0,b:0,a:1},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,
b:0,a:1},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:1},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:1},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),
y:P(176),id:0,b:0,a:1},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:1},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:1},{x:P(32),y:P(272),id:0,b:0,a:1},{x:P(80),y:P(272),id:0,
b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:1},{x:P(32),y:P(320),id:0,b:0,a:1},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:1},{x:P(272),y:P(320),id:0,b:0,a:1},{x:P(320),y:P(320),id:0,b:0,a:0},
{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:1},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:1},{x:P(272),y:P(368),id:0,b:0,a:1},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),
y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:1},{x:P(272),y:P(416),id:0,b:0,a:1},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,a:1},{x:P(320),y:P(464),id:0,b:0,a:1},{x:P(368),y:P(464),
id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:1},{x:P(272),y:P(80),id:0,b:0,a:1},{x:P(272),y:P(128),id:0,b:0,a:1},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:1},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd4:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),
id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:1},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:1},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),
y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:1},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:1},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:1},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,
b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:1},{x:P(32),y:P(272),id:0,b:0,a:1},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},
{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:1},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:1},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:1},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),
y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:1},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:1},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),
id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,a:1},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:1},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},
{x:P(320),y:P(80),id:0,b:0,a:1},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd1:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:1},{x:P(80),y:P(80),id:0,b:0,a:1},
{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:1},{x:P(416),y:P(80),id:0,b:0,a:1},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:1},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),id:0,b:0,a:1},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),
id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,
a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:1},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),
y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:1},{x:P(80),y:P(368),id:0,b:0,a:1},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),
id:0,b:0,a:1},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:1},{x:P(128),y:P(416),id:0,b:0,a:1},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:1},{x:P(464),y:P(416),id:0,b:0,a:1},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:0},
{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd10:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,
b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:1},{x:P(224),y:P(32),id:0,b:0,a:1},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:1},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),
id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,
a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:1},{x:P(272),y:P(224),id:0,b:0,a:1},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:1},{x:P(272),
y:P(272),id:0,b:0,a:1},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),
id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,
a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:1},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,a:1},{x:P(320),y:P(464),id:0,b:0,a:1},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:1},{x:P(272),
y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd16:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),
y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:1},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},
{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:1},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:1},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),
y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:1},{x:P(32),y:P(272),id:0,b:0,a:1},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:1},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:1},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,
b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},
{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:1},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),
y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,
b:0,a:0}]},template10_10_odd11:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:1},{x:P(176),y:P(32),id:0,b:0,a:1},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,
b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:1},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:0},{x:P(464),y:P(128),id:0,b:0,a:1},{x:P(32),y:P(176),id:0,b:0,a:1},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:1},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),
y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,
b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:1},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:1},{x:P(368),y:P(320),id:0,b:0,a:0},
{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:1},{x:P(32),y:P(368),id:0,b:0,a:1},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:1},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),
y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:1},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),
id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd14:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),
id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:1},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,a:1},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:1},{x:P(416),y:P(80),id:0,b:0,a:1},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),
y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),id:0,b:0,a:1},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:1},{x:P(416),y:P(176),id:0,b:0,a:1},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,
b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},
{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:1},{x:P(80),y:P(320),id:0,b:0,a:1},{x:P(128),y:P(320),id:0,b:0,a:1},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:1},{x:P(80),y:P(368),id:0,b:0,a:1},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:1},{x:P(224),
y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:1},{x:P(80),y:P(416),id:0,b:0,a:1},{x:P(128),y:P(416),id:0,b:0,a:1},{x:P(176),y:P(416),id:0,b:0,a:1},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),
id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:1},{x:P(320),y:P(80),id:0,b:0,a:1},
{x:P(320),y:P(128),id:0,b:0,a:1},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd15:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},
{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:1},{x:P(416),y:P(80),id:0,b:0,a:1},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:1},{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),
id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:1},{x:P(416),y:P(176),id:0,b:0,a:1},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,
a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:1},{x:P(128),y:P(320),id:0,b:0,a:1},{x:P(176),y:P(320),id:0,b:0,a:1},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),
y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:1},{x:P(128),y:P(368),id:0,b:0,a:1},{x:P(176),y:P(368),id:0,b:0,a:1},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),
id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:1},{x:P(128),y:P(416),id:0,b:0,a:1},{x:P(176),y:P(416),id:0,b:0,a:1},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(464),id:0,b:0,
a:0},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:1},{x:P(320),y:P(128),id:0,b:0,a:1},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:1}]},template10_10_odd12:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:0},{x:P(80),y:P(32),
id:0,b:0,a:0},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:0},{x:P(464),y:P(32),id:0,b:0,a:0},{x:P(32),y:P(80),id:0,b:0,a:0},{x:P(80),y:P(80),id:0,b:0,a:0},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:0},{x:P(464),y:P(80),id:0,b:0,a:0},{x:P(32),y:P(128),id:0,b:0,a:0},{x:P(80),
y:P(128),id:0,b:0,a:0},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),id:0,b:0,a:0},{x:P(32),y:P(176),id:0,b:0,a:0},{x:P(80),y:P(176),id:0,b:0,a:1},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:0},{x:P(32),y:P(224),
id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,
a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:1},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:1},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),
y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:0},{x:P(272),y:P(416),id:0,b:0,a:0},{x:P(320),y:P(416),
id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:1},{x:P(80),y:P(464),id:0,b:0,a:1},{x:P(128),y:P(464),id:0,b:0,a:1},{x:P(176),y:P(464),id:0,b:0,a:1},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,a:1},{x:P(320),y:P(464),id:0,b:0,a:1},{x:P(368),y:P(464),id:0,b:0,a:1},{x:P(416),y:P(464),id:0,b:0,a:1},{x:P(464),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},
{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0}]},template10_10_odd13:{width:P(560),height:P(560),items:[{x:P(32),y:P(32),id:0,b:0,a:1},{x:P(80),y:P(32),id:0,b:0,a:1},{x:P(128),y:P(32),id:0,b:0,a:0},{x:P(176),y:P(32),id:0,b:0,a:0},{x:P(224),y:P(32),id:0,b:0,a:0},{x:P(368),y:P(32),id:0,b:0,a:0},{x:P(416),y:P(32),id:0,b:0,a:1},{x:P(464),y:P(32),id:0,b:0,
a:1},{x:P(32),y:P(80),id:0,b:0,a:1},{x:P(80),y:P(80),id:0,b:0,a:1},{x:P(128),y:P(80),id:0,b:0,a:0},{x:P(176),y:P(80),id:0,b:0,a:0},{x:P(224),y:P(80),id:0,b:0,a:0},{x:P(368),y:P(80),id:0,b:0,a:0},{x:P(416),y:P(80),id:0,b:0,a:1},{x:P(464),y:P(80),id:0,b:0,a:1},{x:P(32),y:P(128),id:0,b:0,a:1},{x:P(80),y:P(128),id:0,b:0,a:1},{x:P(128),y:P(128),id:0,b:0,a:0},{x:P(176),y:P(128),id:0,b:0,a:0},{x:P(224),y:P(128),id:0,b:0,a:0},{x:P(368),y:P(128),id:0,b:0,a:0},{x:P(416),y:P(128),id:0,b:0,a:1},{x:P(464),y:P(128),
id:0,b:0,a:1},{x:P(32),y:P(176),id:0,b:0,a:1},{x:P(80),y:P(176),id:0,b:0,a:0},{x:P(128),y:P(176),id:0,b:0,a:0},{x:P(176),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(176),id:0,b:0,a:0},{x:P(368),y:P(176),id:0,b:0,a:0},{x:P(416),y:P(176),id:0,b:0,a:0},{x:P(464),y:P(176),id:0,b:0,a:1},{x:P(32),y:P(224),id:0,b:0,a:0},{x:P(80),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(368),y:P(224),id:0,b:0,a:0},{x:P(416),y:P(224),id:0,b:0,a:0},{x:P(464),y:P(224),id:0,b:0,a:0},
{x:P(32),y:P(272),id:0,b:0,a:0},{x:P(80),y:P(272),id:0,b:0,a:0},{x:P(128),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:1},{x:P(272),y:P(272),id:0,b:0,a:1},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(368),y:P(272),id:0,b:0,a:0},{x:P(416),y:P(272),id:0,b:0,a:0},{x:P(464),y:P(272),id:0,b:0,a:0},{x:P(32),y:P(320),id:0,b:0,a:0},{x:P(80),y:P(320),id:0,b:0,a:0},{x:P(128),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:1},{x:P(272),
y:P(320),id:0,b:0,a:1},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(368),y:P(320),id:0,b:0,a:0},{x:P(416),y:P(320),id:0,b:0,a:0},{x:P(464),y:P(320),id:0,b:0,a:0},{x:P(32),y:P(368),id:0,b:0,a:0},{x:P(80),y:P(368),id:0,b:0,a:0},{x:P(128),y:P(368),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:1},{x:P(272),y:P(368),id:0,b:0,a:1},{x:P(320),y:P(368),id:0,b:0,a:0},{x:P(368),y:P(368),id:0,b:0,a:0},{x:P(416),y:P(368),id:0,b:0,a:0},{x:P(464),y:P(368),id:0,b:0,a:0},{x:P(32),y:P(416),
id:0,b:0,a:0},{x:P(80),y:P(416),id:0,b:0,a:0},{x:P(128),y:P(416),id:0,b:0,a:0},{x:P(176),y:P(416),id:0,b:0,a:0},{x:P(224),y:P(416),id:0,b:0,a:1},{x:P(272),y:P(416),id:0,b:0,a:1},{x:P(320),y:P(416),id:0,b:0,a:0},{x:P(368),y:P(416),id:0,b:0,a:0},{x:P(416),y:P(416),id:0,b:0,a:0},{x:P(464),y:P(416),id:0,b:0,a:0},{x:P(32),y:P(464),id:0,b:0,a:0},{x:P(80),y:P(464),id:0,b:0,a:0},{x:P(128),y:P(464),id:0,b:0,a:0},{x:P(176),y:P(464),id:0,b:0,a:0},{x:P(224),y:P(464),id:0,b:0,a:1},{x:P(272),y:P(464),id:0,b:0,
a:1},{x:P(320),y:P(464),id:0,b:0,a:0},{x:P(368),y:P(464),id:0,b:0,a:0},{x:P(416),y:P(464),id:0,b:0,a:0},{x:P(464),y:P(464),id:0,b:0,a:0},{x:P(272),y:P(32),id:0,b:0,a:0},{x:P(272),y:P(80),id:0,b:0,a:0},{x:P(272),y:P(128),id:0,b:0,a:0},{x:P(320),y:P(32),id:0,b:0,a:0},{x:P(320),y:P(80),id:0,b:0,a:0},{x:P(320),y:P(128),id:0,b:0,a:0},{x:P(272),y:P(176),id:0,b:0,a:0},{x:P(320),y:P(176),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(128),y:P(224),id:0,b:0,a:0}]},template4_4:{width:P(560),
height:P(560),items:[{x:P(176),y:P(224),id:0,b:0,a:0},{x:P(224),y:P(224),id:0,b:0,a:0},{x:P(272),y:P(224),id:0,b:0,a:0},{x:P(320),y:P(224),id:0,b:0,a:0},{x:P(176),y:P(272),id:0,b:0,a:0},{x:P(224),y:P(272),id:0,b:0,a:0},{x:P(272),y:P(272),id:0,b:0,a:0},{x:P(320),y:P(272),id:0,b:0,a:0},{x:P(176),y:P(320),id:0,b:0,a:0},{x:P(224),y:P(320),id:0,b:0,a:0},{x:P(272),y:P(320),id:0,b:0,a:0},{x:P(320),y:P(320),id:0,b:0,a:0},{x:P(176),y:P(368),id:0,b:0,a:0},{x:P(224),y:P(368),id:0,b:0,a:0},{x:P(272),y:P(368),
id:0,b:0,a:0},{x:P(320),y:P(368),id:0,b:0,a:0}]},template9_9:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,
b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},
{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),
y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),
id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,
a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd1:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:1},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:1},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,
b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:1},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),
y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),
id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:1},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,
a:0},{x:P(448),y:P(304),id:0,b:0,a:1},{x:P(64),y:P(352),id:0,b:0,a:1},{x:P(112),y:P(352),id:0,b:0,a:1},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:1},{x:P(448),y:P(352),id:0,b:0,a:1},{x:P(64),y:P(400),id:0,b:0,a:1},{x:P(112),y:P(400),id:0,b:0,a:1},{x:P(160),y:P(400),id:0,b:0,a:1},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),
y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:1},{x:P(400),y:P(400),id:0,b:0,a:1},{x:P(448),y:P(400),id:0,b:0,a:1},{x:P(64),y:P(448),id:0,b:0,a:1},{x:P(112),y:P(448),id:0,b:0,a:1},{x:P(160),y:P(448),id:0,b:0,a:1},{x:P(208),y:P(448),id:0,b:0,a:1},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:1},{x:P(352),y:P(448),id:0,b:0,a:1},{x:P(400),y:P(448),id:0,b:0,a:1},{x:P(448),y:P(448),id:0,b:0,a:1}]},template9_9_odd3:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},
{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:1},{x:P(256),y:P(64),id:0,b:0,a:1},{x:P(304),y:P(64),id:0,b:0,a:1},{x:P(352),y:P(64),id:0,b:0,a:1},{x:P(400),y:P(64),id:0,b:0,a:1},{x:P(448),y:P(64),id:0,b:0,a:1},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:1},{x:P(352),y:P(112),id:0,b:0,a:1},{x:P(400),y:P(112),
id:0,b:0,a:1},{x:P(448),y:P(112),id:0,b:0,a:1},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:1},{x:P(448),y:P(160),id:0,b:0,a:1},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,
a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),
y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:1},{x:P(112),y:P(352),id:0,b:0,a:1},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),
id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:1},{x:P(112),y:P(400),id:0,b:0,a:1},{x:P(160),y:P(400),id:0,b:0,a:1},{x:P(208),y:P(400),id:0,b:0,a:1},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:1},{x:P(112),y:P(448),id:0,b:0,a:1},{x:P(160),y:P(448),id:0,b:0,a:1},{x:P(208),y:P(448),id:0,b:0,a:1},{x:P(256),y:P(448),id:0,b:0,a:1},{x:P(304),y:P(448),id:0,b:0,
a:1},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd2:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:1},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:1},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,
b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},
{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),
y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),
id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,
a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:1},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:1},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template8_9_odd2v:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:1},{x:P(112),y:P(64),id:0,b:0,a:1},{x:P(160),y:P(64),id:0,b:0,a:1},{x:P(208),y:P(64),id:0,b:0,a:1},{x:P(256),y:P(64),
id:0,b:0,a:1},{x:P(304),y:P(64),id:0,b:0,a:1},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:1},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:1},{x:P(112),y:P(160),id:0,b:0,a:0},
{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:1},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),
y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:1},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:1},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:1},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:1},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),
id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:1},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:1},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,
a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:1},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:1},{x:P(304),y:P(448),id:0,b:0,a:1},{x:P(352),y:P(448),id:0,b:0,a:1},{x:P(400),y:P(448),id:0,b:0,a:1},{x:P(448),y:P(448),id:0,b:0,a:1}]},
template9_9_blocked2:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,
a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:1},{x:P(208),y:P(160),id:0,b:0,a:1},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:1},{x:P(352),y:P(160),id:0,b:0,a:1},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),
y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),
id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:1},{x:P(208),y:P(352),id:0,b:0,a:1},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,
a:1},{x:P(352),y:P(352),id:0,b:0,a:1},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),
y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_blocked1:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},
{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),
y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:1},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),
id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:1},{x:P(256),y:P(256),id:0,b:0,a:1},{x:P(304),y:P(256),id:0,b:0,a:1},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:1},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,
a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),
y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd5:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},
{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),
id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:1},{x:P(256),y:P(208),id:0,b:0,a:1},{x:P(304),y:P(208),id:0,b:0,
a:1},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:1},{x:P(256),y:P(256),id:0,b:0,a:1},{x:P(304),y:P(256),id:0,b:0,a:1},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),
y:P(304),id:0,b:0,a:1},{x:P(256),y:P(304),id:0,b:0,a:1},{x:P(304),y:P(304),id:0,b:0,a:1},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),
id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,
a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd10:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,
b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},
{x:P(64),y:P(208),id:0,b:0,a:1},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:1},{x:P(64),y:P(256),id:0,b:0,a:1},{x:P(112),y:P(256),id:0,b:0,a:1},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),
y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:1},{x:P(448),y:P(256),id:0,b:0,a:1},{x:P(64),y:P(304),id:0,b:0,a:1},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:1},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),
id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,
a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd6:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,
b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),
y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),
id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:1},{x:P(112),y:P(304),id:0,b:0,a:1},{x:P(160),y:P(304),id:0,b:0,a:1},{x:P(208),y:P(304),id:0,b:0,a:1},{x:P(256),y:P(304),id:0,b:0,a:1},{x:P(304),y:P(304),id:0,b:0,a:1},{x:P(352),y:P(304),id:0,b:0,
a:1},{x:P(400),y:P(304),id:0,b:0,a:1},{x:P(448),y:P(304),id:0,b:0,a:1},{x:P(64),y:P(352),id:0,b:0,a:1},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:1},{x:P(64),y:P(400),id:0,b:0,a:1},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),
y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:1},{x:P(64),y:P(448),id:0,b:0,a:1},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:1}]},template9_9_odd7:{width:P(560),height:P(560),items:[{x:P(64),
y:P(64),id:0,b:0,a:0},{x:P(112),y:P(64),id:0,b:0,a:0},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,
a:1},{x:P(400),y:P(112),id:0,b:0,a:1},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:1},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),
y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),
id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,
a:1},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:1},{x:P(160),y:P(400),id:0,b:0,a:1},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),
y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:0},{x:P(448),y:P(448),id:0,b:0,a:0}]},template9_9_odd8:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:1},{x:P(112),y:P(64),id:0,b:0,a:1},{x:P(160),y:P(64),id:0,b:0,a:0},{x:P(208),y:P(64),id:0,b:0,a:0},{x:P(256),y:P(64),id:0,b:0,a:0},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:1},{x:P(448),y:P(64),id:0,b:0,a:1},{x:P(64),y:P(112),id:0,b:0,a:0},{x:P(112),
y:P(112),id:0,b:0,a:0},{x:P(160),y:P(112),id:0,b:0,a:0},{x:P(208),y:P(112),id:0,b:0,a:0},{x:P(256),y:P(112),id:0,b:0,a:0},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:0},{x:P(112),y:P(160),id:0,b:0,a:0},{x:P(160),y:P(160),id:0,b:0,a:0},{x:P(208),y:P(160),id:0,b:0,a:0},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),
id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:1},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:1},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,
a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:1},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),y:P(304),id:0,b:0,a:1},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),
y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:0},{x:P(352),y:P(352),id:0,b:0,a:0},{x:P(400),y:P(352),id:0,b:0,a:0},{x:P(448),y:P(352),id:0,b:0,a:0},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:0},{x:P(304),y:P(400),id:0,b:0,a:0},{x:P(352),y:P(400),id:0,b:0,a:0},{x:P(400),y:P(400),id:0,b:0,a:0},{x:P(448),y:P(400),
id:0,b:0,a:0},{x:P(64),y:P(448),id:0,b:0,a:1},{x:P(112),y:P(448),id:0,b:0,a:1},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:0},{x:P(304),y:P(448),id:0,b:0,a:0},{x:P(352),y:P(448),id:0,b:0,a:0},{x:P(400),y:P(448),id:0,b:0,a:1},{x:P(448),y:P(448),id:0,b:0,a:1}]},template9_9_odd9:{width:P(560),height:P(560),items:[{x:P(64),y:P(64),id:0,b:0,a:1},{x:P(112),y:P(64),id:0,b:0,a:1},{x:P(160),y:P(64),id:0,b:0,a:1},{x:P(208),y:P(64),id:0,b:0,a:1},{x:P(256),
y:P(64),id:0,b:0,a:1},{x:P(304),y:P(64),id:0,b:0,a:0},{x:P(352),y:P(64),id:0,b:0,a:0},{x:P(400),y:P(64),id:0,b:0,a:0},{x:P(448),y:P(64),id:0,b:0,a:0},{x:P(64),y:P(112),id:0,b:0,a:1},{x:P(112),y:P(112),id:0,b:0,a:1},{x:P(160),y:P(112),id:0,b:0,a:1},{x:P(208),y:P(112),id:0,b:0,a:1},{x:P(256),y:P(112),id:0,b:0,a:1},{x:P(304),y:P(112),id:0,b:0,a:0},{x:P(352),y:P(112),id:0,b:0,a:0},{x:P(400),y:P(112),id:0,b:0,a:0},{x:P(448),y:P(112),id:0,b:0,a:0},{x:P(64),y:P(160),id:0,b:0,a:1},{x:P(112),y:P(160),id:0,
b:0,a:1},{x:P(160),y:P(160),id:0,b:0,a:1},{x:P(208),y:P(160),id:0,b:0,a:1},{x:P(256),y:P(160),id:0,b:0,a:0},{x:P(304),y:P(160),id:0,b:0,a:0},{x:P(352),y:P(160),id:0,b:0,a:0},{x:P(400),y:P(160),id:0,b:0,a:0},{x:P(448),y:P(160),id:0,b:0,a:0},{x:P(64),y:P(208),id:0,b:0,a:0},{x:P(112),y:P(208),id:0,b:0,a:0},{x:P(160),y:P(208),id:0,b:0,a:0},{x:P(208),y:P(208),id:0,b:0,a:0},{x:P(256),y:P(208),id:0,b:0,a:0},{x:P(304),y:P(208),id:0,b:0,a:0},{x:P(352),y:P(208),id:0,b:0,a:0},{x:P(400),y:P(208),id:0,b:0,a:0},
{x:P(448),y:P(208),id:0,b:0,a:0},{x:P(64),y:P(256),id:0,b:0,a:0},{x:P(112),y:P(256),id:0,b:0,a:0},{x:P(160),y:P(256),id:0,b:0,a:0},{x:P(208),y:P(256),id:0,b:0,a:0},{x:P(256),y:P(256),id:0,b:0,a:0},{x:P(304),y:P(256),id:0,b:0,a:0},{x:P(352),y:P(256),id:0,b:0,a:0},{x:P(400),y:P(256),id:0,b:0,a:0},{x:P(448),y:P(256),id:0,b:0,a:0},{x:P(64),y:P(304),id:0,b:0,a:0},{x:P(112),y:P(304),id:0,b:0,a:0},{x:P(160),y:P(304),id:0,b:0,a:0},{x:P(208),y:P(304),id:0,b:0,a:0},{x:P(256),y:P(304),id:0,b:0,a:0},{x:P(304),
y:P(304),id:0,b:0,a:0},{x:P(352),y:P(304),id:0,b:0,a:0},{x:P(400),y:P(304),id:0,b:0,a:0},{x:P(448),y:P(304),id:0,b:0,a:0},{x:P(64),y:P(352),id:0,b:0,a:0},{x:P(112),y:P(352),id:0,b:0,a:0},{x:P(160),y:P(352),id:0,b:0,a:0},{x:P(208),y:P(352),id:0,b:0,a:0},{x:P(256),y:P(352),id:0,b:0,a:0},{x:P(304),y:P(352),id:0,b:0,a:1},{x:P(352),y:P(352),id:0,b:0,a:1},{x:P(400),y:P(352),id:0,b:0,a:1},{x:P(448),y:P(352),id:0,b:0,a:1},{x:P(64),y:P(400),id:0,b:0,a:0},{x:P(112),y:P(400),id:0,b:0,a:0},{x:P(160),y:P(400),
id:0,b:0,a:0},{x:P(208),y:P(400),id:0,b:0,a:0},{x:P(256),y:P(400),id:0,b:0,a:1},{x:P(304),y:P(400),id:0,b:0,a:1},{x:P(352),y:P(400),id:0,b:0,a:1},{x:P(400),y:P(400),id:0,b:0,a:1},{x:P(448),y:P(400),id:0,b:0,a:1},{x:P(64),y:P(448),id:0,b:0,a:0},{x:P(112),y:P(448),id:0,b:0,a:0},{x:P(160),y:P(448),id:0,b:0,a:0},{x:P(208),y:P(448),id:0,b:0,a:0},{x:P(256),y:P(448),id:0,b:0,a:1},{x:P(304),y:P(448),id:0,b:0,a:1},{x:P(352),y:P(448),id:0,b:0,a:1},{x:P(400),y:P(448),id:0,b:0,a:1},{x:P(448),y:P(448),id:0,b:0,
a:1}]},template5_5:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),
id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0}]},template5_5_odd3:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:1},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),
y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:1},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:1},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),
id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:1},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:1},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:1},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,
a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0}]},template5_5_odd1:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:1},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),
id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:1},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:1}]},template5_5_odd2:{width:P(560),
height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),
id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:1}]},template6_6_odd1:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),
y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),
id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:1},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,
a:0},{x:P(320),y:P(384),id:0,b:0,a:1},{x:P(368),y:P(384),id:0,b:0,a:1}]},template6_6_odd7:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:1},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),
id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:1},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,
a:0},{x:P(400),y:P(288),id:0,b:0,a:1},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(112),
y:P(432),id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:1},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0}]},template6_6_odd5:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,
a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),
y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:1},{x:P(176),y:P(384),id:0,b:0,a:1},{x:P(224),y:P(384),id:0,b:0,a:1},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:1},{x:P(368),y:P(384),id:0,b:0,a:1}]},template6_6_odd2:{width:P(560),height:P(560),items:[{x:P(128),
y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:1},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:1},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),
id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:1},{x:P(128),y:P(288),id:0,b:0,a:1},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:1},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,
a:1},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0}]},template6_6_odd6:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:1},{x:P(176),y:P(144),id:0,b:0,a:1},{x:P(224),y:P(144),id:0,b:0,a:1},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:1},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),
id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,
a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:1},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:1},{x:P(368),y:P(384),id:0,b:0,a:1}]},template6_6_odd8:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),
id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:1},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,
a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),
y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0}]},template6_6_odd3:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,a:1},{x:P(272),y:P(144),id:0,b:0,a:1},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,
a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:0},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:0},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),
y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:1},{x:P(272),y:P(384),id:0,b:0,a:1},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0}]},template6_6_odd4:{width:P(560),height:P(560),items:[{x:P(128),y:P(144),id:0,b:0,a:0},{x:P(176),y:P(144),id:0,b:0,a:0},{x:P(224),y:P(144),id:0,b:0,
a:0},{x:P(272),y:P(144),id:0,b:0,a:0},{x:P(320),y:P(144),id:0,b:0,a:0},{x:P(368),y:P(144),id:0,b:0,a:0},{x:P(128),y:P(192),id:0,b:0,a:0},{x:P(176),y:P(192),id:0,b:0,a:0},{x:P(224),y:P(192),id:0,b:0,a:0},{x:P(272),y:P(192),id:0,b:0,a:0},{x:P(320),y:P(192),id:0,b:0,a:0},{x:P(368),y:P(192),id:0,b:0,a:0},{x:P(128),y:P(240),id:0,b:0,a:0},{x:P(176),y:P(240),id:0,b:0,a:0},{x:P(224),y:P(240),id:0,b:0,a:0},{x:P(272),y:P(240),id:0,b:0,a:1},{x:P(320),y:P(240),id:0,b:0,a:0},{x:P(368),y:P(240),id:0,b:0,a:0},{x:P(128),
y:P(288),id:0,b:0,a:0},{x:P(176),y:P(288),id:0,b:0,a:0},{x:P(224),y:P(288),id:0,b:0,a:1},{x:P(272),y:P(288),id:0,b:0,a:0},{x:P(320),y:P(288),id:0,b:0,a:0},{x:P(368),y:P(288),id:0,b:0,a:0},{x:P(128),y:P(336),id:0,b:0,a:0},{x:P(176),y:P(336),id:0,b:0,a:0},{x:P(224),y:P(336),id:0,b:0,a:0},{x:P(272),y:P(336),id:0,b:0,a:0},{x:P(320),y:P(336),id:0,b:0,a:0},{x:P(368),y:P(336),id:0,b:0,a:0},{x:P(128),y:P(384),id:0,b:0,a:0},{x:P(176),y:P(384),id:0,b:0,a:0},{x:P(224),y:P(384),id:0,b:0,a:0},{x:P(272),y:P(384),
id:0,b:0,a:0},{x:P(320),y:P(384),id:0,b:0,a:0},{x:P(368),y:P(384),id:0,b:0,a:0}]},template6_6:{width:P(560),height:P(560),items:[{x:P(128),y:P(112),id:0,b:0,a:0},{x:P(176),y:P(112),id:0,b:0,a:0},{x:P(224),y:P(112),id:0,b:0,a:0},{x:P(272),y:P(112),id:0,b:0,a:0},{x:P(320),y:P(112),id:0,b:0,a:0},{x:P(368),y:P(112),id:0,b:0,a:0},{x:P(128),y:P(160),id:0,b:0,a:0},{x:P(176),y:P(160),id:0,b:0,a:0},{x:P(224),y:P(160),id:0,b:0,a:0},{x:P(272),y:P(160),id:0,b:0,a:0},{x:P(320),y:P(160),id:0,b:0,a:0},{x:P(368),
y:P(160),id:0,b:0,a:0},{x:P(128),y:P(208),id:0,b:0,a:0},{x:P(176),y:P(208),id:0,b:0,a:0},{x:P(224),y:P(208),id:0,b:0,a:0},{x:P(272),y:P(208),id:0,b:0,a:0},{x:P(320),y:P(208),id:0,b:0,a:0},{x:P(368),y:P(208),id:0,b:0,a:0},{x:P(128),y:P(256),id:0,b:0,a:0},{x:P(176),y:P(256),id:0,b:0,a:0},{x:P(224),y:P(256),id:0,b:0,a:0},{x:P(272),y:P(256),id:0,b:0,a:0},{x:P(320),y:P(256),id:0,b:0,a:0},{x:P(368),y:P(256),id:0,b:0,a:0},{x:P(128),y:P(304),id:0,b:0,a:0},{x:P(176),y:P(304),id:0,b:0,a:0},{x:P(224),y:P(304),
id:0,b:0,a:0},{x:P(272),y:P(304),id:0,b:0,a:0},{x:P(320),y:P(304),id:0,b:0,a:0},{x:P(368),y:P(304),id:0,b:0,a:0},{x:P(128),y:P(352),id:0,b:0,a:0},{x:P(176),y:P(352),id:0,b:0,a:0},{x:P(224),y:P(352),id:0,b:0,a:0},{x:P(272),y:P(352),id:0,b:0,a:0},{x:P(320),y:P(352),id:0,b:0,a:0},{x:P(368),y:P(352),id:0,b:0,a:0}]},template7_7:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),
y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),
id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,
a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_odd1:{width:P(560),height:P(560),
items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},
{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:1},{x:P(192),y:P(288),id:0,b:0,a:1},{x:P(240),y:P(288),id:0,b:0,a:1},{x:P(288),y:P(288),id:0,b:0,a:1},{x:P(336),y:P(288),id:0,b:0,a:1},{x:P(384),y:P(288),id:0,b:0,a:1},{x:P(432),y:P(288),id:0,b:0,a:1},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),
y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),
id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_odd2:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:1},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:1},{x:P(432),y:P(144),id:0,b:0,a:1},{x:P(144),y:P(192),id:0,b:0,a:1},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),
y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),
id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,
a:0},{x:P(432),y:P(384),id:0,b:0,a:1},{x:P(144),y:P(432),id:0,b:0,a:1},{x:P(192),y:P(432),id:0,b:0,a:1},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:1}]},template7_7_odd3:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:1},{x:P(384),y:P(144),
id:0,b:0,a:1},{x:P(432),y:P(144),id:0,b:0,a:1},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:1},{x:P(384),y:P(192),id:0,b:0,a:1},{x:P(432),y:P(192),id:0,b:0,a:1},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:1},{x:P(432),y:P(240),id:0,b:0,
a:1},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:1},{x:P(192),y:P(336),id:0,b:0,a:1},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:1},{x:P(192),
y:P(384),id:0,b:0,a:1},{x:P(240),y:P(384),id:0,b:0,a:1},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:1},{x:P(192),y:P(432),id:0,b:0,a:1},{x:P(240),y:P(432),id:0,b:0,a:1},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_odd4:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,
a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:1},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:1},{x:P(336),y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),
y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),
id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:1},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:1},{x:P(336),y:P(432),id:0,b:0,
a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_blocked1:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),
y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:1},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:1},{x:P(288),y:P(288),id:0,b:0,a:1},{x:P(336),y:P(288),id:0,b:0,a:1},{x:P(384),y:P(288),
id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:1},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,
a:0},{x:P(144),y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_blocked2:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),
y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:1},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:1},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),
id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:1},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,
a:0},{x:P(240),y:P(384),id:0,b:0,a:1},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_blocked4:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:1},{x:P(192),
y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:1},{x:P(336),y:P(144),id:0,b:0,a:1},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:1},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:1},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),
id:0,b:0,a:0},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:1},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:0},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:1},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,
a:0},{x:P(336),y:P(336),id:0,b:0,a:0},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:1},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),y:P(432),id:0,b:0,a:1},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:1},{x:P(336),y:P(432),id:0,b:0,a:1},{x:P(384),
y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template7_7_blocked3:{width:P(560),height:P(560),items:[{x:P(144),y:P(144),id:0,b:0,a:0},{x:P(192),y:P(144),id:0,b:0,a:0},{x:P(240),y:P(144),id:0,b:0,a:0},{x:P(288),y:P(144),id:0,b:0,a:0},{x:P(336),y:P(144),id:0,b:0,a:0},{x:P(384),y:P(144),id:0,b:0,a:0},{x:P(432),y:P(144),id:0,b:0,a:0},{x:P(144),y:P(192),id:0,b:0,a:0},{x:P(192),y:P(192),id:0,b:0,a:0},{x:P(240),y:P(192),id:0,b:0,a:0},{x:P(288),y:P(192),id:0,b:0,a:0},{x:P(336),y:P(192),id:0,
b:0,a:0},{x:P(384),y:P(192),id:0,b:0,a:0},{x:P(432),y:P(192),id:0,b:0,a:0},{x:P(144),y:P(240),id:0,b:0,a:0},{x:P(192),y:P(240),id:0,b:0,a:0},{x:P(240),y:P(240),id:0,b:0,a:1},{x:P(288),y:P(240),id:0,b:0,a:0},{x:P(336),y:P(240),id:0,b:0,a:0},{x:P(384),y:P(240),id:0,b:0,a:0},{x:P(432),y:P(240),id:0,b:0,a:0},{x:P(144),y:P(288),id:0,b:0,a:0},{x:P(192),y:P(288),id:0,b:0,a:0},{x:P(240),y:P(288),id:0,b:0,a:0},{x:P(288),y:P(288),id:0,b:0,a:1},{x:P(336),y:P(288),id:0,b:0,a:0},{x:P(384),y:P(288),id:0,b:0,a:0},
{x:P(432),y:P(288),id:0,b:0,a:0},{x:P(144),y:P(336),id:0,b:0,a:0},{x:P(192),y:P(336),id:0,b:0,a:0},{x:P(240),y:P(336),id:0,b:0,a:0},{x:P(288),y:P(336),id:0,b:0,a:0},{x:P(336),y:P(336),id:0,b:0,a:1},{x:P(384),y:P(336),id:0,b:0,a:0},{x:P(432),y:P(336),id:0,b:0,a:0},{x:P(144),y:P(384),id:0,b:0,a:0},{x:P(192),y:P(384),id:0,b:0,a:0},{x:P(240),y:P(384),id:0,b:0,a:0},{x:P(288),y:P(384),id:0,b:0,a:0},{x:P(336),y:P(384),id:0,b:0,a:0},{x:P(384),y:P(384),id:0,b:0,a:0},{x:P(432),y:P(384),id:0,b:0,a:0},{x:P(144),
y:P(432),id:0,b:0,a:0},{x:P(192),y:P(432),id:0,b:0,a:0},{x:P(240),y:P(432),id:0,b:0,a:0},{x:P(288),y:P(432),id:0,b:0,a:0},{x:P(336),y:P(432),id:0,b:0,a:0},{x:P(384),y:P(432),id:0,b:0,a:0},{x:P(432),y:P(432),id:0,b:0,a:0}]},template8_8:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},
{x:P(448),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),
y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),
id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,
a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:0},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:0}]},template8_8_odd1:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:1},{x:P(160),y:P(144),id:0,b:0,a:1},{x:P(208),y:P(144),
id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:1},{x:P(448),y:P(144),id:0,b:0,a:1},{x:P(112),y:P(192),id:0,b:0,a:1},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:1},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,
a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:1},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),
y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:1},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),
id:0,b:0,a:1},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:1},{x:P(112),y:P(480),id:0,b:0,a:1},{x:P(160),y:P(480),id:0,b:0,a:1},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:1},{x:P(448),y:P(480),id:0,b:0,
a:1}]},template8_8_odd2:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),
id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:1},{x:P(256),y:P(240),id:0,b:0,a:1},{x:P(304),y:P(240),id:0,b:0,a:1},{x:P(352),y:P(240),id:0,b:0,a:1},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,
a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:1},{x:P(256),y:P(384),id:0,b:0,a:1},{x:P(304),
y:P(384),id:0,b:0,a:1},{x:P(352),y:P(384),id:0,b:0,a:1},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:0},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),
id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:0}]},template8_8_odd3:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),
y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:1},{x:P(400),y:P(192),id:0,b:0,a:1},{x:P(448),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:1},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),
id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,
a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:1},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:1},{x:P(208),y:P(432),id:0,b:0,a:1},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),
y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:0},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:0}]},template8_8_odd4:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:1},{x:P(304),y:P(144),id:0,b:0,
a:1},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),
y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:1},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),
id:0,b:0,a:1},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,
a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:0},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:1},{x:P(304),y:P(480),id:0,b:0,a:1},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:0}]},template8_8_odd5:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),
id:0,b:0,a:1},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:1},{x:P(112),y:P(192),id:0,b:0,a:1},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,
a:1},{x:P(112),y:P(240),id:0,b:0,a:1},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:1},{x:P(112),y:P(288),id:0,b:0,a:1},{x:P(160),y:P(288),id:0,b:0,a:1},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:1},{x:P(448),
y:P(288),id:0,b:0,a:1},{x:P(112),y:P(336),id:0,b:0,a:1},{x:P(160),y:P(336),id:0,b:0,a:1},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:1},{x:P(448),y:P(336),id:0,b:0,a:1},{x:P(112),y:P(384),id:0,b:0,a:1},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),
id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:1},{x:P(112),y:P(432),id:0,b:0,a:1},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:1},{x:P(112),y:P(480),id:0,b:0,a:1},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,
a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:1}]},template8_8_odd7:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:1},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:1},{x:P(112),y:P(192),id:0,b:0,a:1},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),
id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:1},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,
a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:0},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),
y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:1},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:1},{x:P(112),y:P(480),id:0,b:0,a:1},{x:P(160),y:P(480),
id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,a:1}]},template8_8_odd6:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:0},{x:P(160),y:P(144),id:0,b:0,a:0},{x:P(208),y:P(144),id:0,b:0,a:0},{x:P(256),y:P(144),id:0,b:0,a:0},{x:P(304),y:P(144),id:0,b:0,a:0},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:1},{x:P(448),
y:P(144),id:0,b:0,a:1},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:1},{x:P(448),y:P(192),id:0,b:0,a:1},{x:P(112),y:P(240),id:0,b:0,a:1},{x:P(160),y:P(240),id:0,b:0,a:1},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),
id:0,b:0,a:1},{x:P(448),y:P(240),id:0,b:0,a:1},{x:P(112),y:P(288),id:0,b:0,a:1},{x:P(160),y:P(288),id:0,b:0,a:1},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:1},{x:P(448),y:P(288),id:0,b:0,a:1},{x:P(112),y:P(336),id:0,b:0,a:1},{x:P(160),y:P(336),id:0,b:0,a:1},{x:P(208),y:P(336),id:0,b:0,a:0},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,
a:0},{x:P(400),y:P(336),id:0,b:0,a:1},{x:P(448),y:P(336),id:0,b:0,a:1},{x:P(112),y:P(384),id:0,b:0,a:1},{x:P(160),y:P(384),id:0,b:0,a:1},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),id:0,b:0,a:1},{x:P(160),y:P(432),id:0,b:0,a:1},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:10},
{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:1},{x:P(160),y:P(480),id:0,b:0,a:1},{x:P(208),y:P(480),id:0,b:0,a:1},{x:P(256),y:P(480),id:0,b:0,a:1},{x:P(304),y:P(480),id:0,b:0,a:1},{x:P(352),y:P(480),id:0,b:0,a:1},{x:P(400),y:P(480),id:0,b:0,a:1},{x:P(448),y:P(480),id:0,b:0,a:1}]},template8_9_odd2:{width:P(560),height:P(560),items:[{x:P(112),y:P(144),id:0,b:0,a:1},{x:P(160),y:P(144),id:0,b:0,a:1},{x:P(208),y:P(144),
id:0,b:0,a:1},{x:P(256),y:P(144),id:0,b:0,a:1},{x:P(304),y:P(144),id:0,b:0,a:1},{x:P(352),y:P(144),id:0,b:0,a:0},{x:P(400),y:P(144),id:0,b:0,a:0},{x:P(448),y:P(144),id:0,b:0,a:0},{x:P(112),y:P(192),id:0,b:0,a:0},{x:P(160),y:P(192),id:0,b:0,a:0},{x:P(208),y:P(192),id:0,b:0,a:0},{x:P(256),y:P(192),id:0,b:0,a:0},{x:P(304),y:P(192),id:0,b:0,a:0},{x:P(352),y:P(192),id:0,b:0,a:0},{x:P(400),y:P(192),id:0,b:0,a:0},{x:P(448),y:P(192),id:0,b:0,a:0},{x:P(112),y:P(240),id:0,b:0,a:0},{x:P(160),y:P(240),id:0,b:0,
a:0},{x:P(208),y:P(240),id:0,b:0,a:0},{x:P(256),y:P(240),id:0,b:0,a:0},{x:P(304),y:P(240),id:0,b:0,a:0},{x:P(352),y:P(240),id:0,b:0,a:0},{x:P(400),y:P(240),id:0,b:0,a:0},{x:P(448),y:P(240),id:0,b:0,a:0},{x:P(112),y:P(288),id:0,b:0,a:0},{x:P(160),y:P(288),id:0,b:0,a:0},{x:P(208),y:P(288),id:0,b:0,a:0},{x:P(256),y:P(288),id:0,b:0,a:0},{x:P(304),y:P(288),id:0,b:0,a:0},{x:P(352),y:P(288),id:0,b:0,a:0},{x:P(400),y:P(288),id:0,b:0,a:0},{x:P(448),y:P(288),id:0,b:0,a:0},{x:P(112),y:P(336),id:0,b:0,a:0},{x:P(160),
y:P(336),id:0,b:0,a:0},{x:P(208),y:P(336),id:0,b:0,a:1},{x:P(256),y:P(336),id:0,b:0,a:0},{x:P(304),y:P(336),id:0,b:0,a:0},{x:P(352),y:P(336),id:0,b:0,a:1},{x:P(400),y:P(336),id:0,b:0,a:0},{x:P(448),y:P(336),id:0,b:0,a:0},{x:P(112),y:P(384),id:0,b:0,a:0},{x:P(160),y:P(384),id:0,b:0,a:0},{x:P(208),y:P(384),id:0,b:0,a:0},{x:P(256),y:P(384),id:0,b:0,a:0},{x:P(304),y:P(384),id:0,b:0,a:0},{x:P(352),y:P(384),id:0,b:0,a:0},{x:P(400),y:P(384),id:0,b:0,a:0},{x:P(448),y:P(384),id:0,b:0,a:0},{x:P(112),y:P(432),
id:0,b:0,a:0},{x:P(160),y:P(432),id:0,b:0,a:0},{x:P(208),y:P(432),id:0,b:0,a:0},{x:P(256),y:P(432),id:0,b:0,a:0},{x:P(304),y:P(432),id:0,b:0,a:0},{x:P(352),y:P(432),id:0,b:0,a:0},{x:P(400),y:P(432),id:0,b:0,a:0},{x:P(448),y:P(432),id:0,b:0,a:0},{x:P(112),y:P(480),id:0,b:0,a:0},{x:P(160),y:P(480),id:0,b:0,a:0},{x:P(208),y:P(480),id:0,b:0,a:0},{x:P(256),y:P(480),id:0,b:0,a:0},{x:P(304),y:P(480),id:0,b:0,a:0},{x:P(352),y:P(480),id:0,b:0,a:0},{x:P(400),y:P(480),id:0,b:0,a:0},{x:P(448),y:P(480),id:0,b:0,
a:0},{x:P(112),y:P(528),id:0,b:0,a:0},{x:P(160),y:P(528),id:0,b:0,a:0},{x:P(208),y:P(528),id:0,b:0,a:0},{x:P(256),y:P(528),id:0,b:0,a:1},{x:P(304),y:P(528),id:0,b:0,a:1},{x:P(352),y:P(528),id:0,b:0,a:1},{x:P(400),y:P(528),id:0,b:0,a:1},{x:P(448),y:P(528),id:0,b:0,a:1}]},pw:"template10_10 template10_10_odd2v template10_10_odd3v template10_10_odd12v template10_10_odd14v template10_10_odd10v template10_10_odd13v template10_10_odd15v template10_10_odd16v template10_10_odd9v template10_10_odd11v template10_10_odd6v template10_10_odd5v template10_10_odd7v template10_10_odd4v template10_10_odd1v template10_10_odd8v template10_10_odd2 template10_10_odd3 template10_10_odd5 template10_10_odd7 template10_10_odd9 template10_10_odd8 template10_10_odd6 template10_10_odd4 template10_10_odd1 template10_10_odd10 template10_10_odd16 template10_10_odd11 template10_10_odd14 template10_10_odd15 template10_10_odd12 template10_10_odd13 template4_4 template9_9 template9_9_odd1 template9_9_odd3 template9_9_odd2 template8_9_odd2v template9_9_blocked2 template9_9_blocked1 template9_9_odd5 template9_9_odd10 template9_9_odd6 template9_9_odd7 template9_9_odd8 template9_9_odd9 template5_5 template5_5_odd3 template5_5_odd1 template5_5_odd2 template6_6_odd1 template6_6_odd7 template6_6_odd5 template6_6_odd2 template6_6_odd6 template6_6_odd8 template6_6_odd3 template6_6_odd4 template6_6 template7_7 template7_7_odd1 template7_7_odd2 template7_7_odd3 template7_7_odd4 template7_7_blocked1 template7_7_blocked2 template7_7_blocked4 template7_7_blocked3 template8_8 template8_8_odd1 template8_8_odd2 template8_8_odd3 template8_8_odd4 template8_8_odd5 template8_8_odd7 template8_8_odd6 template8_9_odd2".split(" ")};
b.hc=[{name:"level_01_4x4",l:[b.l.template4_4],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[1,2,2]]},C:{H:188,mode:"points",ea:25,fa:[!0,!0,!1,!1,!1,!0,!1,!1,!1],L:[20,50,80]},f:{height:4,ga:[],O:[],width:4},R:{Z:100},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_02",l:[b.l.template5_5],
ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:250,mode:"points",ea:25,fa:[!0,!0,!1,!1,!1,!0,!1,!1,!1],L:[20,50,80]},f:{height:5,ga:[],O:[],width:5},R:{Z:100},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_03_5x5",l:[b.l.template5_5_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,
0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:313,mode:"points",ea:30,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:200},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!1},type:{V:0,aa:"DASH"}},{name:"level_04_OddSize",l:[b.l.template6_6_odd5],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],
[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:438,mode:"points",ea:30,fa:[!0,!0,!1,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:5,ga:[],O:[],width:5},R:{Z:200},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_05",l:[b.l.template5_5_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],
[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:438,mode:"points",ea:30,fa:[!0,!0,!1,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:5,ga:[],O:[],width:5},R:{Z:200},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_06_lineclear",l:[b.l.template6_6_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"points",ea:30,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:200},N:{ca:[[1,2,2],[4,2,1]],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_07",l:[b.l.template5_5],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],
[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:500,mode:"points",ea:30,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:5,ga:[],O:[],width:5},R:{Z:200},N:{ca:[[2,2,2]],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_08",l:[b.l.template6_6_odd6],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,
0,0,0]]},B:{X:[]},C:{H:500,mode:"points",ea:30,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:200},N:{ca:[[4,4,0],[1,1,1]],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_09",l:[b.l.template6_6_odd1],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"points",
ea:35,fa:[!0,!0,!0,!1,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:350},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_10_colorbomb",l:[b.l.template6_6_odd4],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:563,mode:"points",ea:35,fa:[!0,!0,!0,!1,!1,!0,!0,!0,
!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:350},N:{ca:[],S:!1,P:!1,T:10,type:[[2,2,5],[3,3,2]],U:!0},type:{V:25,aa:"DOT"}},{name:"level_11",l:[b.l.template7_7],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:563,mode:"points",ea:35,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],
O:[],width:6},R:{Z:300},N:{ca:[],S:!1,P:!1,T:10,type:[[1,2,1],[4,3,7]],U:!0},type:{V:25,aa:"DOT"}},{name:"level_12",l:[b.l.template6_6_odd7],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:563,mode:"points",ea:35,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:300},N:{ca:[],
S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_13",l:[b.l.template6_6_odd8],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"points",ea:35,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:350},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},
{name:"level_14",l:[b.l.template6_6_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"points",ea:35,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:350},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_15_collorcollect",l:[b.l.template7_7_blocked2],
ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"type",ea:35,fa:[!1,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,40,60]},f:{height:7,ga:[],O:[],width:7},R:{Z:350},N:{ca:[[2,4,2],[4,2,2]],S:!0,P:!1,T:10,type:[],U:!1},type:{V:20,aa:"KROKET"}},{name:"level_16",l:[b.l.template6_6_odd4],ha:{ia:[[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:763,mode:"type",ea:40,fa:[!0,!0,!1,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:6,ga:[],O:[],width:6},R:{Z:410},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:15,aa:"LINE"}},{name:"level_17",l:[b.l.template8_8_odd1],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:850,mode:"type",ea:40,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:480},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:20,aa:"BIGCORNER"}},{name:"level_18",l:[b.l.template7_7_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,
0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:850,mode:"type",ea:40,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:480},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:15,aa:"SQUARE"}},{name:"level_19",l:[b.l.template7_7_odd1],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:538,mode:"points",ea:40,fa:[!0,!0,!1,!1,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:500},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,aa:"SQUARE"}},{name:"level_20",l:[b.l.template7_7_odd4],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,
0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:625,mode:"type",ea:40,fa:[!0,!0,!0,!1,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:600},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,aa:"BIGCORNER"}},{name:"level_21_blocked",l:[b.l.template7_7_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0]]},B:{X:[]},C:{H:900,mode:"points",ea:40,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:500},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_22",l:[b.l.template7_7_blocked3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:975,mode:"points",ea:40,
fa:[!0,!0,!0,!1,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:7,ga:[],O:[],width:7},R:{Z:480},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_23",l:[b.l.template8_8_odd5],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1113,mode:"type",ea:45,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},
f:{height:8,ga:[],O:[],width:8},R:{Z:590},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,aa:"MINICORNER"}},{name:"level_24",l:[b.l.template8_8_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1113,mode:"type",ea:45,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:8,ga:[],O:[],width:8},R:{Z:590},
N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,aa:"LINE"}},{name:"level_25",l:[b.l.template8_9_odd2v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1113,mode:"type",ea:45,fa:[!0,!0,!0,!0,!1,!0,!0,!1,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:590},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,
aa:"LINE"}},{name:"level_26",l:[b.l.template8_8_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1113,mode:"type",ea:45,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:8,ga:[],O:[],width:8},R:{Z:590},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:20,aa:"SQUARE"}},{name:"level_27",l:[b.l.template8_8_odd4],
ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1300,mode:"points",ea:45,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:8,ga:[],O:[],width:8},R:{Z:590},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_28",l:[b.l.template8_8_odd7],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1463,mode:"points",ea:45,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:8,ga:[],O:[],width:8},R:{Z:870},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_29",l:[b.l.template8_8_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1463,mode:"points",ea:45,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:8,ga:[],O:[],width:8},R:{Z:870},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_30_wrapped",l:[b.l.template9_9_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,
0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,4,2],[4,3,3],[4,5,3],[5,4,3],[3,4,3]]},C:{H:1700,mode:"counter",ea:50,fa:[!0,!0,!0,!1,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:100},N:{ca:[],S:!0,P:!1,T:2,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_31",l:[b.l.template9_9_odd3],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,
0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[0,2,2],[0,3,2],[8,5,2],[8,6,2],[4,4,2]]},C:{H:1450,mode:"counter",ea:50,fa:[!0,!0,!0,!1,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:660},N:{ca:[],S:!0,P:!1,T:2,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_32",l:[b.l.template9_9_odd1],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,2,2],[5,3,2],[4,4,2],[3,5,2],[4,6,2]]},C:{H:1675,mode:"counter",ea:50,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:740},N:{ca:[],S:!1,P:!1,T:2,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_33",l:[b.l.template9_9_blocked2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1675,mode:"points",ea:50,fa:[!0,!0,!0,!1,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[[3,3,2],[4,4,1],[5,5,2],[5,3,2],[3,5,2]],width:9},R:{Z:740},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_34",l:[b.l.template9_9_blocked1],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2075,mode:"points",ea:50,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:9,ga:[],O:[[2,4,2],[4,2,2],[6,4,2],[4,6,2]],width:9},R:{Z:1060},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_35",l:[b.l.template9_9_odd2],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],
[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,4,3],[2,2,2],[6,2,2],[2,6,2],[6,6,2]]},C:{H:1425,mode:"counter",ea:50,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:1060},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_36",l:[b.l.template9_9_odd9],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,
0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,2,2],[5,2,2],[3,6,2],[4,6,2],[3,7,2],[5,1,2]]},C:{H:1350,mode:"counter",ea:50,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:1E3},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_37",l:[b.l.template9_9_odd5],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1425,mode:"type",ea:50,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:740},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"BIGCORNER"}},{name:"level_38",l:[b.l.template9_9_odd10],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2075,mode:"type",ea:50,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:1300},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"BIGSQUARE"}},{name:"level_39",l:[b.l.template9_9_odd6],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,
0,0,0,0,0,0,0]]},B:{X:[[4,2,4],[3,2,3],[4,3,4],[5,2,3],[0,0,2],[8,0,2]]},C:{H:1838,mode:"counter",ea:50,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!0],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:1070},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"SQUARE"}},{name:"level_40",l:[b.l.template9_9_odd7],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[5,2,4],[2,3,2],[6,5,2],[3,6,4]]},C:{H:1188,mode:"counter",ea:50,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:9,ga:[],O:[],width:9},R:{Z:750},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_41",l:[b.l.template10_10],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,
0,0,0,0,0]]},B:{X:[]},C:{H:2788,mode:"type",ea:55,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1230},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"BIGCORNER"}},{name:"level_42",l:[b.l.template10_10_odd1v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2788,
mode:"type",ea:55,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1230},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"KROKET"}},{name:"level_43",l:[b.l.template10_10],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2500,mode:"points",ea:55,fa:[!0,!0,!0,!0,!0,!0,
!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[[7,2,2],[6,3,3],[5,4,3],[4,5,3],[3,6,3],[2,7,2]],width:10},R:{Z:1E3},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_44",l:[b.l.template10_10_odd3v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2088,mode:"points",ea:55,fa:[!0,!0,!0,
!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[2,2,2],[3,3,2],[3,6,2],[2,7,2],[7,2,2],[6,3,2],[6,6,2],[7,7,2]],width:10},R:{Z:870},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_45",l:[b.l.template10_10_odd4v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,4,4],[5,5,4],[2,7,
4],[7,2,4]]},C:{H:2088,mode:"counter",ea:55,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1E3},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_46",l:[b.l.template10_10_odd5v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[1,1,2],[8,2,2],[8,8,2],[1,
8,2],[4,4,2],[6,4,2],[4,6,2],[6,6,2]]},C:{H:2100,mode:"counter",ea:55,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1E3},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_47",l:[b.l.template10_10_odd7v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[3,
3,4],[8,1,4],[6,6,4],[8,1,4],[4,4,2],[5,5,2]]},C:{H:3E3,mode:"counter",ea:60,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1800},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_48",l:[b.l.template10_10_odd8v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},
B:{X:[]},C:{H:2500,mode:"points",ea:60,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[0,0,2],[1,0,2],[0,1,2],[0,2,2],[0,3,2],[8,9,2],[9,9,2],[9,8,2],[9,7,2],[9,6,2]],width:10},R:{Z:1400},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_49",l:[b.l.template10_10_odd9v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,
0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2500,mode:"points",ea:60,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[1,1,2],[2,2,3],[3,3,3],[5,5,3],[6,6,3],[7,7,2]],width:10},R:{Z:1400},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_50",l:[b.l.template10_10_odd1v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,
0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[0,3,2],[1,2,4],[2,1,4],[3,0,2],[6,9,2],[7,8,4],[8,7,4],[9,6,2]]},C:{H:2375,mode:"counter",ea:60,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1500},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}},{name:"level_51",l:[b.l.template10_10_odd2v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,
0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[4,4,4],[4,5,4],[5,5,4],[5,4,4],[1,1,2],[8,8,2]]},C:{H:2500,mode:"counter",ea:60,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1400},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_52",l:[b.l.template10_10_odd3v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2500,mode:"type",ea:60,fa:[!0,!0,!0,!0,!0,!0,!1,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1400},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"SQUARE"}},{name:"level_53",l:[b.l.template10_10_odd10v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,
0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2375,mode:"type",ea:60,fa:[!0,!0,!0,!0,!1,!0,!1,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1300},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"BIGSQUARE"}},{name:"level_54",l:[b.l.template10_10_odd11v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2375,mode:"points",ea:60,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[2,8,1],[3,7,2],[4,6,3],[5,6,3],[6,7,2],[7,8,1],[2,1,1],[3,2,2],[4,3,3],[5,3,3],[6,2,2],[7,1,1]],width:10},R:{Z:1400},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_55",l:[b.l.template10_10_odd12v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,
0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[2,3,4],[2,6,4],[7,2,4],[7,5,4],[3,3,2],[3,6,2],[6,2,2],[6,5,2]]},C:{H:3E3,mode:"counter",ea:65,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1800},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_56",l:[b.l.template10_10_odd13v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,
0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[[0,4,2],[1,3,3],[4,4,4],[5,4,4],[8,3,3],[9,4,2],[9,9,2],[0,9,2]]},C:{H:2500,mode:"counter",ea:65,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1400},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_57",l:[b.l.template10_10_odd14v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:3E3,mode:"type",ea:65,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1800},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"BIGCORNER"}},{name:"level_58",l:[b.l.template10_10_odd15v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,
0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:3E3,mode:"type",ea:65,fa:[!0,!0,!0,!0,!1,!0,!0,!0,!0],L:[20,50,80]},f:{height:10,ga:[],O:[],width:10},R:{Z:1800},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"MINICORNER"}},{name:"level_59",l:[b.l.template10_10_odd16v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:2375,mode:"points",ea:65,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[0,3,3],[1,4,2],[1,5,2],[0,6,3],[9,3,3],[8,4,2],[8,5,2],[9,7,3],[8,8,4],[1,1,4]],width:10},R:{Z:1400},N:{ca:[],S:!1,P:!1,T:10,type:[],U:!0},type:{V:25,aa:"DOT"}},{name:"level_60",l:[b.l.template10_10_odd11v],ha:{ia:[[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,
0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0,0]]},B:{X:[]},C:{H:1875,mode:"points",ea:65,fa:[!0,!0,!0,!0,!0,!0,!0,!0,!1],L:[20,50,80]},f:{height:10,ga:[],O:[[4,0,2],[5,0,1],[4,9,2],[5,9,2],[4,4,4],[5,5,4],[2,2,2],[7,7,2]],width:10},R:{Z:1E3},N:{ca:[],S:!0,P:!1,T:10,type:[],U:!1},type:{V:25,aa:"DOT"}}];return b}var mj=null;
function Ij(){uj(O,{xa:{name:"<UNKNOWN>",id:"<UNKNOWN>",version:"1.0",aA:"10x10",TR:!1,GS:[0,1,2],HS:["Easy","Medium","Difficult"],SR:!0,uS:!1,GK:9,HU:[9],IU:["World1"],VR:!0,RT:"numberUp",PT:!0,QT:!1,uU:[],WH:null},r:{},sg:{vA:"d98b5cb57f33944e7e6919d5a0e313f3",wA:"af51f785793a64e1ff0f52f1c4d3bf058370f4a2"}})}Ij.prototype.Bk=function(){mj=new Sn;Ib(mj);var b=mj,c=["play"],d,c=[].concat(c);void 0===b.sj&&(b.sj=[]);for(d=c.length-1;0<=d;d-=1)0>b.sj.indexOf(c[d])&&b.sj.push(c[d])};
function Sn(){this.ba=!1;this.visible=!0;this.canvas=R.A;this.depth=this.d=0;this.Qm=void 0;this.p=gn();this.tP=O.be;this.gc=O.xa.Fe;this.Vb=this.p.hc[this.gc-1];this.mode=O.xa.Wt;this.oh=this.so=this.pr=!1;this.Gt=!0;this.EA=this.gv=!1;this.ly;this.my;this.Vy=this.Lx=!1;this.G=new fc(this);this.Oo=Qk(jj,this.mode,this.gc);this.jy=!1}
function Tn(b){b.ba=!0;AudioController.aN();b.Fa=new Qn({x:b.VP,y:b.WP,backgroundImage:void 0,sb:{k:Bl},Ua:{k:Bl}});b.fg=Rn(b.Fa,Mn,{x:b.p.Fa.oN,y:b.p.Fa.pN,backgroundImage:void 0,nl:we,xC:b.p.Fa.nN,L:b.Vb.C.L,NC:!0,oz:!1});Rn(b.Fa,Nn,b.p.PK,b.tP.PK,{$f:b.Wr,Gl:-25,Pe:"Level",gd:b.p.fonts.zD,md:b.Wr,We:30,valueType:"number",Bf:b.p.fonts.zD,$h:b.gc});b.jr=Rn(b.Fa,Nn,{$f:b.p.Fa.QL,Pe:"Moves",Zf:"GameMoves",gd:b.p.fonts.PP,md:b.p.Fa.RL,valueType:"number",Bf:b.p.fonts.QP,$h:b.va.PL});b.Xb=Rn(b.Fa,Nn,
{$f:b.Xw,Pe:"Score",Zf:"GameScore",gd:b.p.fonts.SP,md:b.Yw,valueType:"number",Bf:b.p.fonts.TP,$h:0,jw:function(){0<b.f.Hi||(b.Ok=!0,b.f.Be=!0)}});Rn(b.Fa,$,{c:Od,x:P(0),y:P(190),m:function(){Vj()}});if("points"===b.va.mode)b.yJ=Rn(b.Fa,Nn,{$f:b.Kn,Pe:"Goal:",Zf:"GoalTitle",gd:b.p.fonts.dy,md:b.Xu,valueType:"number",Bf:b.p.fonts.vp,$h:b.va.vN}),Rn(b.Fa,Pn,{mf:b.p.Fa.bP,qe:b.p.Fa.cP,Ia:b.va.c});else if("type"===b.va.mode)b.rl=Rn(b.Fa,Pn,{$f:b.Kn,Pe:"Goal:",Zf:"GoalTitle",gd:b.p.fonts.dy,qe:b.p.Fa.VJ,
Ia:b.va.c,pb:.8,Cb:.8}),b.aq=Rn(b.Fa,Nn,{Gl:10,$f:b.p.Fa.Cz,Pe:"/"+b.va.Xy,gd:b.p.fonts.vp,We:-14,md:b.p.Fa.Cz,valueType:"number",Bf:b.p.fonts.vp,hQ:0});else if("counter"===b.va.mode){b.eq=Rn(b.Fa,Pn,{$f:b.Kn,Pe:"Goal:",Zf:"GoalTitle",gd:b.p.fonts.dy,qe:b.p.Fa.AH,Ia:wh,Lc:{fm:b.p.Fa.zH-1},pb:.8,Cb:.8});b.It=Rn(b.Fa,Nn,{Gl:10,$f:b.p.Fa.JG,Pe:"/ "+b.va.el.length,gd:b.p.fonts.vp,We:b.p.Fa.KG,md:b.p.Fa.LG,valueType:"number",Bf:b.p.fonts.vp,hQ:0});for(var c=0;c<b.va.el.length;c++)Un(b.f,b.va.el[c][0],
b.va.el[c][1],b.va.el[c][2])}b.Mp=b.Vb.N.ca;b.is=b.Vb.N.type;b.O=b.Vb.f.O;b.Sp=b.Vb.f.ga;for(c=0;c<b.Mp.length;c++)Vn(b.f,b.Mp[c][0],b.Mp[c][1],b.Mp[c][2]);for(c=0;c<b.is.length;c++)Wn(b.f,b.is[c][0],b.is[c][1],b.is[c][2]);if("counter"!==b.va.mode)for(c=0;c<b.O.length;c++)Un(b.f,b.O[c][0],b.O[c][1],b.O[c][2]);for(c=0;c<b.Sp.length;c++)Xn(b.f,b.Sp[c][0],b.Sp[c][1],b.Sp[c][2]);b.Fa.show();b.Lb=new Yn(b.f)}function Zn(b){for(var c=0,d=0;d<b.fg.L.length;d++)b.fg.Kb>=b.fg.L[d]&&(c+=1);return c}
function $n(b){var c=0,c=b.Oo.Ne;return c>b.Xb.Gb()?c:b.Xb.Gb()}a=Sn.prototype;
a.me=function(){na(p,R.tg);ua(kh,0,0);this.EM=new ao(this.gc);na(p,R.A);this.va=new bo(this.gc);this.f=new co(this.va,this);this.Kj=this.pa=-1;this.SO=1;this.cD=this.p.Kh.cD;this.bD=this.p.Kh.bD;this.VP=this.p.Fa.LP;this.WP=this.p.Fa.MP;this.Wr=this.p.Fa.Wr;this.TO=this.p.Fa.TO;this.Xw=this.p.Fa.Xw;this.Yw=this.p.Fa.Yw;this.Kn=this.p.Fa.Kn;this.Xu=this.p.Fa.Xu;this.qm=0;this.oh=this.gv=this.pr=this.so=!1;AudioController.WM();AudioController.VM();Wj.Bk("dialog",{width:P(602),height:P(273),backgroundImage:ve,
Xz:P(115),Yz:P(-60),Wz:{o:vi.o,fontSize:48,fillColor:"#ea8c9d"},Vz:"GoalTitle",Vc:this.gc,Uz:{o:N.o,fontSize:18,fillColor:"#452f5a",xb:"middle",align:"center"}},this.fI);Tn(this)};
a.fI=function(){this.f.Be=!0;var b=this.f;if(b.Ur){for(var c=0;c<b.width;c++)for(var d=0;d<b.height;d++)1==b.Ur[c][d]&&(b.f[d][c].a=!0,b.f[d][c].empty=!1);c=[];for(d=0;d<b.height;d++){for(var e=0;e<b.width;e++)b.f[e][d].a?b.f[e][d].a&&0<c.length&&(b.Qh.push(c),c=[]):c.push(b.f[e][d]);0<c.length&&(b.Qh.push(c),c=[])}c=[];for(d=0;d<b.width;d++){for(e=0;e<b.height;e++)b.f[d][e].a?b.f[d][e].a&&0<c.length&&(b.Ph.push(c),c=[]):c.push(b.f[d][e]);0<c.length&&(b.Ph.push(c),c=[])}}};
a.kf=function(){Sb(this.Fa);eo(this)};a.Ld=function(b,c,d){this.Gt=!1;if(c>this.Lb.lj-35&&(this.f.Be&&(this.Ok=this.f.Iv=!1,this.qm=0),120<d&&270>d&&!1===this.Lb.hd.sf&&this.f.Be?(this.pa=this.Lb.hd,this.pa.dg=!0,this.Kj=1):270<d&&420>d&&!1===this.Lb.Yc.sf&&this.f.Be?(this.pa=this.Lb.Yc,this.pa.dg=!0,this.Kj=2):420<d&&570>d&&!1===this.Lb.jd.sf&&this.f.Be&&(this.pa=this.Lb.jd,this.pa.dg=!0,this.Kj=3),-1!==this.pa))for(b=0;b<this.pa.Na.length;b++)Lb(this.pa.Na[b],-1E3),Mb(this.pa.Na[b],-1E3)};
a.kr=function(){if(this.Gt&&!this.oh){for(var b=[this.Lb.hd,this.Lb.Yc,this.Lb.jd],c=0;c<b.length;c++)if(!1===b[c].sf)for(var d=0;d<this.f.width;d++)for(var e=0;e<this.f.height;e++)if(fo(this.f,b[c],d,e))return this.so=!1,!0;this.so=this.Ok=!0;return!1}};
function go(b){var c=b.jr.Gb(),d=1,e=1250;b.G.sa=[];b.G.setTime(0);for(var g=0;g<c;g++){var h=b.p.yd.tN;lc(b.G,b,d,function(){this.jr.fe(-1,!0);new ho(320,275,h,300);this.Xb.fe(h);this.fg.zd(Math.min(this.Xb.Gb()/this.f.H*100,100))});d+=e;200<e&&(e*=.85)}lc(b.G,b,d+700,b.iI);b.Lx=!0}a.iI=function(){this.gv=!0};function io(b){return"points"===b.va.mode?b.Xb.Gb()>=b.yJ.Gb()?!0:!1:"type"===b.va.mode?b.aq.Gb()>=b.va.Xy?!0:!1:"counter"===b.va.mode?b.It.Gb()>=b.va.el.length?!0:!1:!1}
a.Tf=function(b,c,d){this.ly=c;this.my=d;var e;if(-1!==this.pa){b=Math.round((c-this.f.offsetX+this.pa.shape.yg-this.pa.uk*this.pa.Gg/2)/this.pa.Gg);e=Math.round((d-this.f.offsetY-(this.pa.$i-1)*this.pa.Ji/2)/this.pa.Ji);if(fo(this.f,this.pa,e,b)){c=this.f;d=this.pa;AudioController.YM();for(var g=0;g<d.Na.length;g++){var h=b+d.Na[g].Pa,l=e+d.Na[g].Ra;c.f[h][l].empty=!1;c.f[h][l].type=d.shape.type;c.f[h][l].Lo=!0;if(d.Na[g].ue){if("area"===d.Na[g].qa){c.f[h][l].c=d.shape.Ke;var m=c.offsetX+h*lh.width,
n=c.offsetY+l*lh.height;c.f[h][l].uf=new jo(m,n)}else"type"===d.Na[g].qa?(c.f[h][l].c=d.shape.Ke,m=c.offsetX+h*lh.width,n=c.offsetY+l*lh.height,c.f[h][l].uf=new ko(m,n)):"counter"===d.Na[g].qa&&(c.f[h][l].B=3,c.f[h][l].c=wh);c.f[h][l].ue=!0;c.f[h][l].qa=d.Na[g].qa}else c.f[h][l].c=d.shape.Ke}c.M.Xb.fe(c.NM*d.Na.length);if(c.M.Xb.Gb()>c.M.Oo.Ne&&!c.Iq&&0!==c.M.Oo.Ne){var s,g=Math.random(),g=Math.floor(g*(c.uq.length-1));0===g?s=xi:1===g?s=wi:2===g&&(s=zi);new wn("New High Score!",600,300,0,s,1,s.fillColor,
s.strokeColor);c.Iq=!0}c.M.fg.zd(Math.min(c.M.Xb.Gb()/c.H*100,100));d.sf=!0;g=lo(c);h=mo(c);c.Qe=[];s=0;m=!1;if(c.Ur){for(n=0;n<g.length;n++)for(l=0;l<g[n].length;l++){var w=Math.abs(l-b)+Math.abs(g[n][l].Ra-e);c.f[g[n][l].Pa][g[n][l].Ra].Tc||("none"===c.f[g[n][l].Pa][g[n][l].Ra].qa||"counter"===c.f[g[n][l].Pa][g[n][l].Ra].qa?(c.f[g[n][l].Pa][g[n][l].Ra].$=100*w,c.f[g[n][l].Pa][g[n][l].Ra].ed=!0,c.f[g[n][l].Pa][g[n][l].Ra].Tc=!0,c.fb.push(c.f[g[n][l].Pa][g[n][l].Ra]),s<=100*w&&(s=100*w)):(c.f[g[n][l].Pa][g[n][l].Ra].rf=
!0,no(c.f[g[n][l].Pa][g[n][l].Ra]),c.Qe.push(c.f[g[n][l].Pa][g[n][l].Ra])))}for(n=0;n<h.length;n++)for(l=0;l<h[n].length;l++)w=Math.abs(h[n][l].Pa-b)+Math.abs(l-e),c.f[h[n][l].Pa][h[n][l].Ra].Tc||("none"===c.f[h[n][l].Pa][h[n][l].Ra].qa||"counter"===c.f[h[n][l].Pa][h[n][l].Ra].qa?(c.f[h[n][l].Pa][h[n][l].Ra].$=100*w,c.f[h[n][l].Pa][h[n][l].Ra].ed=!0,c.f[h[n][l].Pa][h[n][l].Ra].Tc=!0,c.fb.push(c.f[h[n][l].Pa][h[n][l].Ra]),s<=100*w&&(s=100*w)):(c.f[h[n][l].Pa][h[n][l].Ra].rf=!0,no(c.f[h[n][l].Pa][h[n][l].Ra]),
c.Qe.push(c.f[h[n][l].Pa][h[n][l].Ra])))}else{for(n=0;n<g.length;n++)for(l=0;l<c.width;l++)w=Math.abs(l-b)+Math.abs(g[n]-e),c.f[l][g[n]].Tc||("none"===c.f[l][g[n]].qa||"counter"===c.f[l][g[n]].qa?(c.f[l][g[n]].$=100*w,c.f[l][g[n]].ed=!0,c.f[l][g[n]].Tc=!0,c.fb.push(c.f[l][g[n]]),s<=100*w&&(s=100*w)):(c.f[l][g[n]].rf=!0,c.Qe.push(c.f[l][g[n]])));for(n=0;n<h.length;n++)for(l=0;l<c.height;l++)w=Math.abs(h[n]-b)+Math.abs(l-e),c.f[h[n]][l].Tc||("none"===c.f[h[n]][l].qa||"counter"===c.f[h[n]][l].qa?(c.f[h[n]][l].$=
100*w,c.f[h[n]][l].ed=!0,c.f[h[n]][l].Tc=!0,c.fb.push(c.f[h[n]][l]),s<=100*w&&(s=100*w)):(c.f[h[n]][l].rf=!0,c.Qe.push(c.f[h[n]][l])))}for(n=0;n<c.fb.length;n++)c.fb[n].$!==s||m||(m=c.fb[n].Oq=!0);if(0<c.fb.length){oo(c,s+=1E3);c.Hi=s+=1E3;w=n=e=b=0;"type"===c.M.va.mode&&(n=c.M.rl.ug(0,0),w=c.M.rl.vg(0,0)+80);"counter"===c.M.va.mode&&(n=c.M.eq.ug(0,0),w=c.M.eq.vg(0,0)+80);for(var y=null,l=0;l<c.fb.length;l++){m=c.fb[l];if("type"===c.M.va.mode&&m.type===c.M.va.zf){b++;e=Math.max(e,m.$);var D=new po(m.c,
{pc:m.x,Ma:m.y,rd:n,bb:w,Rc:m.$,Sb:.25});if(null===y||qo(D)>qo(y))y=D}c.Be=!1;m.c===wh&&"counter"===c.va.mode&&1>m.B&&new po(wh,{pc:m.x,Ma:m.y,rd:n,bb:w,Rc:m.$,Sb:.25,value:1,gh:c.M.It});ro(m)}y&&(y.value=b,y.gh=c.M.aq);c.fb=[]}b=g.length+h.length;e=c.p.yd.VK;1===b&&(e=1);e*=(c.height*c.li*g.length+c.width*c.li*h.length)*b;c.M.Xb.fe(e);if(3<=b){var t;s=Math.random();s=Math.floor(s*c.uq.length);0===s?t=xi:1===s?t=yi:2===s?t=wi:3===s&&(t=zi);new wn(c.uq[s],600,400,0,t,1,t.fillColor,t.strokeColor)}else 0!==
b&&3>b&&(t=zi,f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?new wn("+"+e,c.M.ly-150,c.M.my-50,s-1200,t,1,t.fillColor,t.strokeColor,-900,-904):new wn("+"+e,c.M.ly,c.M.my-50,s-1200,t,1,t.fillColor,t.strokeColor,-900,-904));c.M.Xb.Gb()>c.M.Oo.Ne&&!c.Iq&&0!==c.M.Oo.Ne&&(s=Math.random(),s=Math.floor(s*(c.uq.length-1)),0===s?t=xi:1===s?t=wi:2===s&&(t=zi),new wn("New High Score!",600,300,0,t,1,t.fillColor,t.strokeColor),c.Iq=!0);c.M.fg.zd(Math.min(c.M.Xb.Gb()/c.H*100,100));c.yd+=c.width*c.li*b*b;b>=c.Jv&&(c.Hp=!0,
Math.random());c.Iv=!0;0<mo(c).length+lo(c).length?c.kj=0<c.Hi?c.Hi:c.p.C.UK:(c.kj=c.p.C.aM,c.Hi=0);c.ot++;Sb(d);this.jr.fe(-1,!0);!1===io(this)&&0>=this.jr.Gb()?(this.pr=!0,this.Ok||(this.f.kj+=1E3,this.Ok=!0)):io(this)&&1>this.f.sa.length&&(this.oh=!0)}else{AudioController.XM();this.pa.iu=!0;this.pa.Tz=c;for(t=0;t<this.pa.Na.length;t++)this.pa.Na[t].c=this.pa.shape.c,this.pa.Na[t].dg=!1;this.pa.Px=this.Lb.lj;so(this.pa);1===this.Kj?this.pa.rp=this.Lb.ny:2===this.Kj?this.pa.rp=this.Lb.oy:3===this.Kj&&
(this.pa.rp=this.Lb.py)}for(t=0;t<this.pa.Na.length;t++)Lb(this.pa.Na[t],0),Mb(this.pa.Na[t],0);this.pa.dg=!1;this.Kj=this.pa=-1}to(this.Lb)&&uo(this.Lb);this.Gt=!0;this.Lx&&(this.G.speed=3)};function eo(b){Sb(b.f);Sb(b.Lb);Sb(b.EM)}a.oe=function(b){ba&&(87===b&&Wj.jl(1E3,void 0,void 0,void 0,"dialog",{Dc:"<TitleWon>",vd:"<TextWon>"}),76===b&&Wj.Pj("dialog",{Dc:"<TitleLost>",vd:"<TextLost>"}),77===b&&tj(Wj))};
a.Ab=function(b){this.Lx&&this.G.lg(b);if(-1!==this.pa){this.pa.scale=1;this.pa.Px=u.Ec(0)-this.pa.uk*this.pa.Gg/2-this.pa.offsetX+this.pa.shape.yg;this.pa.rp=u.sc(0)-.5*this.pa.Ji*(this.pa.$i-1);for(var c=0;c<this.pa.Na.length;c++)this.pa.Na[c].c=this.pa.shape.Ke,this.pa.Na[c].dg=!0}if(this.f.Hp&&(this.va.U||this.va.S||this.va.P&&this.f.ot>=this.va.T)){var d,e,g;if(to(this.Lb))uo(this.Lb);else if(e=[],this.Lb.hd.sf||(e=e.concat(this.Lb.hd.Na)),this.Lb.Yc.sf||(e=e.concat(this.Lb.Yc.Na)),this.Lb.jd.sf||
(e=e.concat(this.Lb.jd.Na)),c=Math.floor(Math.random()*e.length),d=e[c],d.ue){g=!0;for(c=0;c<e.length;c++)!1===e[c].ue&&(g=!1),g||(c=e.length);if(!g)for(;d.ue;)c=Math.floor(Math.random()*e.length),d=e[c]}e=[];g||(this.va.S&&e.push("area"),this.va.U&&e.push("type"),this.va.P&&this.f.ot>=this.va.T&&e.push("counter"),g=1/e.length,c=Math.random(),d.qa=c<=g?e[0]:c<=2*g?e[1]:e[2],d.ue=!0,AudioController.ZM(),"type"===d.qa?d.c=Ih:"counter"===d.qa&&(d.c=Hh));this.f.Hp=!1}this.f.Iv&&(this.f.Iv=!1,this.Ok=
!0);this.Ok&&(this.qm+=b);this.so&&this.qm>this.f.kj&&!this.EA&&(this.f.kj+=1E3,this.EA=!0);if(io(this)&&!this.jy&&1>this.f.sa){this.oh=!0;b=this.f;d=[];for(e=c=0;e<b.height;e++)for(var h=0;h<b.width;h++)g=b.f[e][h],g.empty||g.Ki||g.bl?g.Ki&&(c=Math.max(g.$,c)):(g.gA=!0,d.push(g));c+=3E3;for(e=0;e<d.length;e++)d[e].$=c,c+=100,vo(d[e]);oo(b,c+=250,"END");b.Hi=c+250;this.Ok=!0;b=R.$a/2;d=R.Ga/2;new wn(xk("challengeEndScreenOutcomeMessage_WON"),b,d,1E3,xi,1,xi.fillColor,xi.strokeColor,-900,-905);this.jy=
!0}this.oh&&this.gv&&this.Vy?(this.jy=!0,Wj.jl(this.Xb.Gb(),void 0,Zn(this),void 0,"dialog",{yd:this.Xb.Gb(),ob:Zn(this),Ii:$n(this)}),AudioController.dN(),eo(this),this.gc+1!==this.p.rm.Ch[this.p.rm.Ch.length-1]&&(b=this.mode,d=this.gc+1,c=jj,g=Qk(c,b,d),g.Ik=!0,Rk(c,b,d,g),Ok(c))):!this.kr()&&this.qm>this.f.kj&&void 0!==this.kr()&&!this.oh&&1>this.f.sa?(AudioController.oC(),eo(this),Wj.Pj("dialog",{kl:"FailedPopup_Text_02"})):this.pr&&this.qm>this.f.kj&&!this.oh&&1>this.f.sa&&(AudioController.oC(),
eo(this),Wj.Pj("dialog",{kl:"FailedPopup_Text_01"}))};a.Uc=function(){};function wo(b,c){this.d=this.depth=0;this.ba=this.visible=!0;this.p=gn();this.type=b;this.qw=c;Ib(this)}
wo.prototype.me=function(){this.DM=new xo(this.type,this.qw);this.Ox=yo(this.DM);this.lP=this.Ox[0].length;this.kP=this.Ox.length;switch(this.type){case "DOT":this.c=Ah;this.Ke=ph;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.UH:25;break;case "DASH":this.c=zh;this.Ke=oh;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.HH:25;break;case "KROKET":this.c=Ch;this.Ke=rh;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.nK:25;break;case "LINE":this.c=Dh;this.Ke=sh;this.yg=f.Ba.kg||f.Ba.vf||
f.Ba.ve||f.Ib.og?this.p.Yb.WK:25;break;case "FRIKANDEL":this.c=Bh;this.Ke=qh;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.TI:25;break;case "MINICORNER":this.c=Eh;this.Ke=th;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.BL:25;break;case "BIGCORNER":this.c=xh;this.Ke=mh;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.JF:25;break;case "SQUARE":this.c=Fh;this.Ke=vh;this.yg=f.Ba.kg||f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.RO:25;break;case "BIGSQUARE":this.c=yh,this.Ke=nh,this.yg=f.Ba.kg||
f.Ba.vf||f.Ba.ve||f.Ib.og?this.p.Yb.KF:25}};
function zo(b,c,d,e,g,h){this.depth=100;this.d=0;this.ba=this.visible=!0;this.p=gn();this.Pa=b;this.Ra=c;this.offsetX=d;this.offsetY=e;this.height=this.width=50;this.x=this.offsetX+this.Pa*this.width;this.y=this.offsetY+this.Ra*this.height;this.Fq=g;this.Gq=h;this.B=-1;this.empty=!0;this.Ki=!1;this.qb=0;this.alpha=this.Cb=this.pb=1;this.G=new fc(this);this.Rz=this.$=this.lq=this.gb=0;this.af=1;this.Ut=1.8;this.Rl=this.fq=0;this.iy=this.Oq=this.a=this.rf=this.Tc=this.ed=this.Lo=!1;this.Xj="none";this.rQ=
this.x;this.uQ=this.y;this.Pr=0;this.pO=40;this.cu=!1;this.zC=new da;this.gA=this.hs=this.Nt=this.Sm=!1;this.cy=0;this.OF=ii;Ib(this)}a=zo.prototype;a.me=function(){this.ue=!1;this.empty=!0;this.qa=this.type="none";this.$=0};
function ro(b){var c;b.G.Ve=[];b.G.sa=[];!1===b.empty&&(b.Ki=!0,"counter"===b.qa&&(b.B--,console.log("counter--"),b.js=!0,b.G.setTime(0),c=gc(b.G,"function",b,function(b){this.Rz=Math.floor(b)}),hc(b.G,c,[{time:0,value:0},{time:400+b.$,value:0},{time:1E3+b.$,value:4.9}]),c=gc(b.G,"function",b,function(b){this.af=b}),hc(b.G,c,[{time:0+b.$,value:1},{time:700+b.$,value:b.Ut},{time:800+b.$,value:b.Ut},{time:1E3+b.$,value:1}]),Lb(b,-899),Mb(b,-900),c=ic(c),lc(b.G,b,c,b.VN),AudioController.cN(b.$+100),
b.ed=!1,b.Tc=!1,b.Ki=!1,b.rf=!1),0>b.B&&(b.bl=!0,b.ue=!1,b.G.setTime(0),b.hs?(c=gc(b.G,"function",b,function(b){this.cy=Math.floor(b)}),hc(b.G,c,[{time:0,value:0},{time:100+b.$,value:0},{time:600+b.$,value:6}]),lc(b.G,b,100+b.$,b.KP),lc(b.G,b,600+b.$,b.WN),c=gc(b.G,"alpha",b),hc(b.G,c,[{time:1E3+b.$,value:1},{time:1300+b.$,value:.25},{time:1301+b.$,value:0}]),c=gc(b.G,"function",b,function(b){this.lq=Math.floor(b)}),hc(b.G,c,[{time:1150+b.$,value:0},{time:1500+b.$,value:8}]),c=ic(c)-300,lc(b.G,b,
c,b.Hr),AudioController.qC(c+100)):(c=gc(b.G,"function",b,function(b){this.Cb=this.pb=b}),hc(b.G,c,[{time:0+b.$,value:1},{time:700+b.$,value:1.5}]),c=gc(b.G,"alpha",b),hc(b.G,c,[{time:0+b.$,value:1},{time:300+b.$,value:.25},{time:301+b.$,value:0}]),c=gc(b.G,"function",b,function(b){this.lq=Math.floor(b)}),hc(b.G,c,[{time:150+b.$,value:0},{time:500+b.$,value:8}]),c=ic(c)-300,lc(b.G,b,c,b.Hr)),"type"===b.Xj?AudioController.bN(b.$+100):"area"===b.Xj?(c=gc(b.G,"function",b,function(b){this.af=b}),hc(b.G,
c,[{time:0+b.$-50,value:1},{time:400+b.$-50,value:b.Ut},{time:700+b.$-50,value:1}]),AudioController.PM(b.$+100)):AudioController.qC(b.$+100),b.qa="none",b.type="none"))}
function vo(b){var c;b.G.Ve=[];b.G.sa=[];b.empty||(b.bl=!0,b.ue=!1,b.G.setTime(0),c=gc(b.G,"function",b,function(b){this.Cb=this.pb=b}),hc(b.G,c,[{time:0+b.$,value:1},{time:700+b.$,value:1.5}]),c=gc(b.G,"alpha",b),hc(b.G,c,[{time:0+b.$,value:1},{time:300+b.$,value:.25},{time:301+b.$,value:0}]),c=gc(b.G,"function",b,function(b){this.lq=Math.floor(b)}),hc(b.G,c,[{time:150+b.$,value:0},{time:500+b.$,value:8}]),lc(b.G,b,ic(c)-300,b.Hr),b.type="none")}a.KP=function(){this.Sm=!1;this.Nt=!0};
a.WN=function(){this.hs=this.Nt=!1};a.VN=function(){Lb(this,0);Mb(this,0)};function no(b){if("area"==b.qa||"type"==b.qa)b.cu=!0}
a.Hr=function(){this.hs=this.cu=this.iy=this.rf=this.Tc=this.ed=this.Oq=!1;this.cy=0;this.gA=this.Ki=!1;if("area"===this.Xj){var b=this.Pa,c=this.Ra,d=[],e=10/this.Gq,g=10/this.Fq,b=b+1,c=c+1;d.push(Math.abs((b-this.Gq)/this.Gq)/e);d.push(Math.abs(c/this.Fq)/g);d.push(Math.abs(b/this.Gq)/e);d.push(Math.abs((c-this.Fq)/this.Fq)/g);new Ao(this.x,this.y,d)}this.Xj="";void 0!==this.uf&&(Sb(this.uf),this.uf=void 0)};
a.Ab=function(b){this.bl&&this.Tr<this.$&&(this.Tr+=b);this.Tr>this.$&&(this.Tr=0,this.Hr());"type"===this.qa&&(this.wc++,10<this.wc&&(this.wc=0));this.G.lg(b);this.bl&&(this.gb+=b);this.G.Aq()<this.gb&&0<this.G.Aq()&&(this.gb=0,this.Cb=this.pb=this.alpha=1,this.Lo=this.bl=!1,this.a?this.empty=!1:(this.empty=!0,this.Ki=!1),this.G.Ve=[]);this.js&&(this.fq+=b);this.G.Aq()<this.fq&&(this.fq=0,this.js=!1,this.G.Ve=[]);void 0!==this.uf&&this.uf.Dx&&.99<this.uf.bf&&Sb(this.uf);this.Pr+=b;this.Pr>this.pO&&
this.cu?(this.x+=-10+ea(this.zC,20),this.y+=-10+ea(this.zC,20),this.Pr=0):(this.x=this.rQ,this.y=this.uQ);this.Lo&&(this.Rl+=b,this.af=bc(this.Rl,.5,.5,700,3),700<this.Rl&&(this.Rl=0,this.Lo=!1))};
a.Uc=function(){if(this.a)lh.Ha(0,this.x,this.y,1,1,0,0);else{lh.Ha(0,this.x,this.y,1,1,0,1);if(!1===this.empty)if("area"===this.qa)this.c.Ha(0,this.x,this.y,this.af,this.af,this.qb,this.alpha);else if("counter"===this.qa){var b;4!==this.B&&(2===this.B?b=Vh:1===this.B?b=Uh:0===this.B?b=Th:(b=Sh,this.js=!1));wh.Ha(this.B,this.x,this.y,this.af,this.af,this.qb,this.alpha);this.js&&b.Ha(this.Rz,this.x,this.y,this.af,this.af,this.qb,this.alpha)}else"type"!==this.qa&&this.bl&&this.gb>150+this.$&&(Rh.Ha(this.lq,
this.x,this.y,1,1,0,1),this.Rl=0,this.Lo=!1,this.af=1),this.c.Ha(0,this.x,this.y,this.af,this.af,this.qb,this.alpha);this.Sm&&this.OF.Ha(0,this.x,this.y,1,1,0,.6);this.Nt&&ji.Ha(this.cy,this.x,this.y,1,1,0,1)}};
function co(b,c){this.depth=100;this.d=0;this.ba=this.visible=!0;this.p=gn();this.M=c;this.Vb=this.p.hc[this.M.gc-1];this.width=this.Vb.f.width;this.height=this.Vb.f.height;this.offsetX=this.p.f.offsetX;this.offsetY=this.p.f.offsetY;this.yd=0;this.NM=this.p.yd.uN;this.li=this.p.yd.sN;this.Jv=this.p.Kh.Jv;this.Hp=!1;this.wc=0;this.Qe=[];this.va=b;this.ot=0;this.Iq=!1;this.HK=this.Vb.l[0].items;this.Ur=[];this.Qh=[];this.Ph=[];this.H=this.Vb.C.H;this.qq=new fc(this);this.sa=[];this.Hi=0;this.fb=[];
this.uq=this.p.FI.QG;this.va=b;this.Be=!1;Ib(this)}a=co.prototype;
a.me=function(){if(10>this.width){for(var b=10-this.width,c=0;c<b;c++)this.offsetX+=25;this.p.f.offsetX=this.offsetX}if(10>this.height){b=10-this.height;for(c=0;c<b;c++)this.offsetY+=25;this.p.f.offsetY=this.offsetY}this.f=[];for(b=0;b<this.width;b++)this.f[b]=[];for(b=0;b<this.width;b++)for(c=0;c<this.height;c++)this.f[b][c]=new zo(b,c,this.offsetX,this.offsetY,this.height,this.width);for(var b=this.width,d=0,c=0;c<this.height;c++){for(var e=[];d<b;d++)e.push(this.HK[d].a);this.Ur.push(e);d=b;b+=
this.width}};a.oe=function(b){ba&&u.Df[78]&&50==b&&(this.Hp=!0,Math.random())};function fo(b,c,d,e){var g;if(e+c.uk>b.width||d+c.$i>b.height||0>d||0>e)return!1;for(var h=0;h<c.Na.length;h++)if(g=b.f[e+c.Na[h].Pa][d+c.Na[h].Ra],!1===g.empty&&!1===g.Ki||g.a)return!1;return!0}
function mo(b){var c=[],d=!0;if(0<b.Ph.length)for(var e=0;e<b.Ph.length;e++){for(var g=0;g<b.Ph[e].length;g++)b.f[b.Ph[e][g].Pa][b.Ph[e][g].Ra].empty&&(d=!1),d||(g=b.Ph[e].length);d?c.push(b.Ph[e]):d=!0}else for(e=0;e<b.height;e++){for(g=0;g<b.width;g++)b.f[e][g].empty&&(d=!1),d||(g=b.width);d?c[c.length]=e:d=!0}return c}
function lo(b){var c=[],d=!0;if(0<b.Qh.length)for(var e=0;e<b.Qh.length;e++){for(var g=0;g<b.Qh[e].length;g++)b.f[b.Qh[e][g].Pa][b.Qh[e][g].Ra].empty&&(d=!1),d||(g=b.Qh[e].length);d?c.push(b.Qh[e]):d=!0}else for(e=0;e<b.width;e++){for(g=0;g<b.height;g++)b.f[g][e].empty&&(d=!1),d||(g=b.height);d?c[c.length]=e:d=!0}return c}
function Bo(b,c,d,e){var g=[],h=0,l=!1;b.Be=!1;b.fb=[];no(b.f[c][d]);b.f[c][d].iy=!0;b.f[c][d].Xj=b.f[c][d].qa;b.f[c][d].qa="none";b.f[c][d].Tc=!0;b.f[c][d].$=0;b.$x=[];for(var m=0;m<b.width;m++)for(var n=0;n<b.height;n++){var s=b.f[m][n];s.empty||s.Ki||(b.f[m][n].Sm=!0,b.$x.push(s),s.type===e&&(g.push(b.f[m][n]),b.M.Xb.fe(b.li),b.M.fg.zd(Math.min(b.M.Xb.Gb()/b.H*100,100))))}b.f[c][d].Sm=!1;g.sort(function(b,e){var g=b.Pa-c,h=b.Ra-d,l=e.Pa-c,m=e.Ra-d;return g*g+h*h-(l*l+m*m)});for(m=0;m<g.length;m++)"none"===
g[m].qa?g[m].ed||(g[m].Tc||(g[m].$=150*m,g[m].Tc=!0,g[m].ed=!0,g[m].Xj="type",h<=150*m&&(h=150*m)),g[m].ed=!0,b.fb.push(g[m])):g[m].rf||(g[m].rf=!0,no(g[m]),b.Qe.push(g[m]));for(m=0;m<b.fb.length;m++)b.fb[m].$!==h||l||(l=b.fb[m].Oq=!0);oo(b,h+1500,"TYPE");b.Hi=h+1500;l=h=g=e=0;"type"===b.M.va.mode&&(h=b.M.rl.ug(0,0),l=b.M.rl.vg(0,0)+80);m=null;for(n=0;n<b.fb.length;n++)b.fb[n].hs=!0,s=b.fb[n],"type"===b.M.va.mode&&s.type===b.M.va.zf&&(e++,g=Math.max(g,s.$),s=new po(s.c,{pc:s.x,Ma:s.y,rd:h,bb:l,Rc:s.$+
650,Sb:.25}),null===m||qo(s)>qo(m))&&(m=s),ro(b.fb[n]);m&&(m.value=e,m.gh=b.M.aq);b.fb=[]}
a.jN=function(b){switch(b){case "TYPE":for(b=0;b<this.$x.length;b++)this.$x[b].Sm=!1;break;case "END":this.Qe=[],this.M.Vy=!0,go(this.M)}if(0<this.Qe.length){b=this.Qe[0].Pa;var c=this.Qe[0].Ra;if("area"===this.f[b][c].qa){this.Be=!1;var d=0,e=!1;this.Be=!1;this.fb=[];no(this.f[b][c]);this.f[b][c].iy=!0;this.f[b][c].Xj=this.f[b][c].qa;this.f[b][c].qa="none";this.f[b][c].Tc=!0;for(var g=this.f[b][c].$=0;g<this.width;g++)if(!1===this.f[b][g].empty){var h=Math.abs(g-c)+Math.abs(this.f[b][g].Ra-g);"none"===
this.f[b][g].qa||"counter"===this.f[b][g].qa?this.f[b][g].ed||(this.f[b][g].Tc||(this.f[b][g].$=150*h,this.f[b][g].bu=h,this.f[b][g].ed=!0,this.f[b][g].Tc=!0,d<=150*h&&(d=150*h)),this.f[b][g].ed=!0,this.fb.push(this.f[b][g]),this.M.Xb.fe(this.li),this.M.fg.zd(Math.min(this.M.Xb.Gb()/this.H*100,100))):this.f[b][g].rf||this.f[b][g].ed||(this.f[b][g].rf=!0,no(this.f[b][g]),this.Qe.push(this.f[b][g]),this.M.Xb.fe(this.li),this.M.fg.zd(Math.min(this.M.Xb.Gb()/this.H*100,100)))}for(g=0;g<this.height;g++)!1===
this.f[g][c].empty&&(h=Math.abs(this.f[g][c].Pa-b)+Math.abs(g-g),"none"===this.f[g][c].qa||"counter"===this.f[g][c].qa?this.f[g][c].ed||(this.f[g][c].Tc||(this.f[g][c].$=150*h,this.f[g][c].bu=h,this.f[g][c].ed=!0,this.f[g][c].Tc=!0,d<=150*h&&(d=150*h)),this.f[g][c].ed=!0,this.fb.push(this.f[g][c]),this.M.Xb.fe(this.li),this.M.fg.zd(Math.min(this.M.Xb.Gb()/this.H*100,100))):this.f[g][c].rf||this.f[g][c].ed||(this.f[g][c].rf=!0,no(this.f[g][c]),this.Qe.push(this.f[g][c]),this.M.Xb.fe(this.li),this.M.fg.zd(Math.min(this.M.Xb.Gb()/
this.H*100,100))));for(g=0;g<this.fb.length;g++)this.fb[g].$!==d||e||(e=this.fb[g].Oq=!0);oo(this,d+=1E3);this.Hi=d+1E3;g=e=c=b=0;"type"===this.M.va.mode&&(e=this.M.rl.ug(0,0),g=this.M.rl.vg(0,0)+80);"counter"===this.M.va.mode&&(e=this.M.eq.ug(0,0),g=this.M.eq.vg(0,0)+80);for(var h=null,l=0;l<this.fb.length;l++){d=this.fb[l];if("type"===this.M.va.mode&&d.type===this.M.va.zf){b++;var c=Math.max(c,d.$),m=new po(d.c,{pc:d.x,Ma:d.y,rd:e,bb:g,Rc:d.$,Sb:.25});if(null===h||qo(m)>qo(h))h=m}d.c===wh&&"counter"===
this.va.mode&&1>d.B&&new po(wh,{pc:d.x,Ma:d.y,rd:e,bb:g,Rc:d.$,Sb:.25,value:1,gh:this.M.It});ro(this.fb[l])}h&&(h.value=b,h.gh=this.M.aq);this.fb=[]}else"type"===this.f[b][c].qa?(this.Be=!1,Bo(this,b,c,this.f[b][c].type)):"counter"===this.f[b][c].qa&&(ro(this.f[b][c]),0===this.f[b][c].B&&(this.f[b][c].qa="none"));this.Qe.splice(0,1)}else this.Be=!0;0<this.sa.length&&this.sa.splice(0,1);if(0===this.sa.length&&!this.M.oh){b=this.qq;var n,c=0;void 0===c&&(c=-99999999);void 0===n&&(n=99999999);for(d=
b.sa.length-1;0<=d;d-=1)b.sa[d].time>=c&&b.sa[d].time<=n&&b.sa.splice(d);jc(b)}};
function Un(b,c,d,e){var g=[];if(void 0===c||void 0===d){for(c=0;c<b.width;c++)for(d=0;d<b.height;d++)b.f[c][d].empty&&(g[g.length]=b.f[c][d]);if(0<g.length){c=Math.floor(Math.random()*g.length);d=g[c].Pa;var h=g[c].Ra;b.f[d][h]=g[c];b.f[d][h].empty=!1;b.f[d][h].B=e-1;b.f[d][h].ue=!0;b.f[d][h].qa="counter";b.f[d][h].type="none";b.f[d][h].c=wh}}else b.f[c][d].empty=!1,b.f[c][d].B=e-1,b.f[c][d].ue=!0,b.f[c][d].qa="counter",b.f[c][d].type="none",b.f[c][d].c=wh}
function Vn(b,c,d,e){var g=new da;ea(g,b.p.C.nt.length-1-0);b.f[c][d].empty=!1;b.f[c][d].ue=!0;b.f[c][d].qa="area";b.f[c][d].type=Co(e);b.f[c][d].c=b.p.C.nt[e];b.f[c][d].uf=new jo(b.f[c][d].x,b.f[c][d].y)}function Wn(b,c,d,e){b.f[c][d].empty=!1;b.f[c][d].ue=!0;b.f[c][d].qa="type";b.f[c][d].type=Co(e);b.f[c][d].c=b.p.C.nt[e];b.f[c][d].uf=new ko(b.f[c][d].x,b.f[c][d].y)}
function Xn(b,c,d,e){b.f[c][d].empty=!1;b.f[c][d].ue=!1;b.f[c][d].qa="none";b.f[c][d].type=Co(e);e=new wo(b.f[c][d].type,0);b.f[c][d].c=e.Ke}function Co(b){var c;switch(b){case 0:c="DOT";break;case 1:c="DASH";break;case 2:c="KROKET";break;case 3:c="LINE";break;case 4:c="FRIKADEL";break;case 5:c="MINICORNER";break;case 6:c="BIGCORNER";break;case 7:c="SQUARE";break;case 8:c="BIGSQUARE"}return c}
function oo(b,c,d){b.qq.setTime(0);0<b.sa.length&&(c+=b.sa[b.sa.length-1].time);c=lc(b.qq,b,c,b.jN,d);b.sa.push(c)}a.Ab=function(b){this.qq.lg(b);if(this.M.oh||this.M.pr||this.M.so)this.Be=!1};a.kf=function(){for(var b=0;b<this.width;b++)for(var c=0;c<this.height;c++)Sb(this.f[b][c]),void 0!==this.f[b][c].uf&&Sb(this.f[b][c].uf)};
function Do(b){this.d=this.depth=0;this.ba=this.visible=!0;this.types=[["DOT",1],["DASH",2],["KROKET",2],["LINE",2],["FRIKANDEL",2],["MINICORNER",4],["BIGCORNER",4],["SQUARE",1],["BIGSQUARE",1]];this.Yb=[];this.QB=0;this.gc=b;this.xj=[];this.p=gn();this.Vb=this.p.hc[this.gc-1];Ib(this)}
Do.prototype.me=function(){for(var b,c=this.PB=0;c<this.types.length;c++)this.PB+=this.types[c][1];for(c=0;c<this.types.length;c++)if(this.Vb.C.fa[c])for(this.QB++,b=this.xj.length,this.xj[b]=[],this.xj[b][0]=this.types[c][0],this.xj[b][1]=this.types[c][1],b=0;b<this.types[c][1];b++)this.Yb[this.Yb.length]=new wo(this.types[c][0],b);for(c=0;c<this.Yb.length;c++);};
function Eo(b){var c,d;c=Math.floor(Math.random()*b.xj.length);d=b.xj[c][0];b=Math.floor(b.xj[c][1]*Math.random());return new wo(d,b)}function xo(b,c){this.d=0;this.ba=this.visible=!0;this.type=b;this.index=c;Ib(this)}
xo.prototype.me=function(){this.qn=[];this.qn[0]=[[!0]];this.Zt=[];this.Zt[0]=[[!0],[!0]];this.Zt[1]=[[!0,!0]];this.wv=[];this.wv[0]=[[!0],[!0],[!0]];this.wv[1]=[[!0,!0,!0]];this.Gv=[];this.Gv[0]=[[!0],[!0],[!0],[!0]];this.Gv[1]=[[!0,!0,!0,!0]];this.Pu=[];this.Pu[0]=[[!0],[!0],[!0],[!0],[!0]];this.Pu[1]=[[!0,!0,!0,!0,!0]];this.lo=[];this.lo[0]=[[!0,!0],[!0,!1]];this.lo[1]=[[!0,!0],[!1,!0]];this.lo[2]=[[!0,!1],[!0,!0]];this.lo[3]=[[!1,!0],[!0,!0]];this.Xm=[];this.Xm[0]=[[!0,!0,!0],[!0,!1,!1],[!0,!1,
!1]];this.Xm[1]=[[!0,!0,!0],[!1,!1,!0],[!1,!1,!0]];this.Xm[2]=[[!0,!1,!1],[!0,!1,!1],[!0,!0,!0]];this.Xm[3]=[[!1,!1,!0],[!1,!1,!0],[!0,!0,!0]];this.aD=[];this.aD[0]=[[!0,!0],[!0,!0]];this.lz=[];this.lz[0]=[[!0,!0,!0],[!0,!0,!0],[!0,!0,!0]]};
function yo(b){if("DOT"===b.type)return b.qn[b.index];if("DASH"===b.type)return b.Zt[b.index];if("KROKET"===b.type)return b.wv[b.index];if("LINE"===b.type)return b.Gv[b.index];if("FRIKANDEL"===b.type)return b.Pu[b.index];if("MINICORNER"===b.type)return b.lo[b.index];if("BIGCORNER"===b.type)return b.Xm[b.index];if("SQUARE"===b.type)return b.aD[b.index];if("BIGSQUARE"===b.type)return b.lz[b.index];console.log("this should not happen. Have a look at Orientations.getStructure. type: "+b.type)}
function Fo(b,c,d,e,g,h,l,m){this.d=-901;this.depth=-902;this.ba=this.visible=!0;this.Pa=b;this.Ra=c;this.x=d;this.y=e;this.c=g;this.width=this.c.width;this.height=this.c.height;this.scale=h;this.offsetX=l;this.offsetY=m;this.ue=!1;this.qa="none";this.p=gn();this.dg=!1;this.Ek=1;this.gb=this.bf=0;this.hk=this.p.Kh.KB;this.xr=this.wc=0;this.FM=this.p.Kh.LB;this.alpha=this.p.Kh.yD;this.time=0;Ib(this)}
Fo.prototype.Uc=function(){var b=this.x+this.width*this.Pa-this.width*this.Pa*(1-this.scale),c=this.y+this.height*this.Ra-this.height*this.Ra*(1-this.scale);"counter"!==this.qa?this.c.Ha(0,b+this.offsetX,c,this.scale,this.scale,0,1):this.c.Ha(3,b+this.offsetX,c,this.scale,this.scale,0,1);"area"===this.qa&&(this.dg?(Mh.Ha(this.wc,b+this.offsetX,c,.7,.7,0,1),Jh.Ha(0,b+this.offsetX,c,1,1,0,this.bf)):Gh.Ha(0,b+this.offsetX,c,this.scale,this.scale,0,1));"type"===this.qa&&(this.dg?Ph.ui(this.xr,b+this.offsetX,
c,this.alpha):Ih.Ha(0,b+this.offsetX,c,this.scale,this.scale,0,1))};Fo.prototype.Ab=function(b){this.dg&&("area"===this.qa?(this.bf+=b/400*(this.Ek-this.bf),this.gb+=b,this.gb>this.hk&&(this.wc++,8<this.wc?this.wc=0:this.Ek=5<this.wc?this.bf=0:1,this.gb=0)):"type"===this.qa&&(this.time+=b,this.time>this.FM&&(this.xr++,this.time=0,this.xr>Ph.Y-1&&(this.xr=0))))};
function Yn(b){this.d=0;this.ba=this.visible=!0;this.p=gn();this.lj=this.p.Yb.sQ;this.ny=this.p.Yb.vQ;this.oy=this.p.Yb.wQ;this.py=this.p.Yb.xQ;this.f=b;this.gc=this.f.M.gc;this.mk;this.Ar;this.Br;this.po=this.p.Yb.po;Ib(this)}a=Yn.prototype;a.me=function(){this.yj=new Do(this.gc);uo(this)};a.Ab=function(){};a.kr=function(){for(var b=[this.hd,this.Yc,this.jd],c=0;c<b.length;c++)if(!1===b[c].sf)for(var d=0;d<this.f.width;d++)for(var e=0;e<this.f.height;e++)if(fo(this.f,b[c],d,e))return!0;return!1};
function uo(b,c){if(c)Sb(b.hd),Sb(b.Yc),Sb(b.jd),Go(b);else{for(Go(b);!Ho(b);)Sb(b.hd),Sb(b.Yc),Sb(b.jd),Go(b);b.mk=b.hd;b.Ar=b.Yc;b.Br=b.jd}}a.oe=function(b){ba&&u.Df[78]&&49==b&&uo(this,"s")};
function Go(b){b.hd=new Io(b.lj,b.ny,Eo(b.yj),1);if("undefined"!==typeof b.mk&&(Jo(b.hd,b.mk)||Jo(b.hd,b.Ar)||Jo(b.hd,b.Br))){var c=Math.random();c<b.po&&(Sb(b.hd),b.hd=new Io(b.lj,b.ny,Eo(b.yj),1))}b.Yc=new Io(b.lj,b.oy,Eo(b.yj),2);"undefined"!==typeof b.mk&&(Jo(b.Yc,b.mk)||Jo(b.Yc,b.Ar)||Jo(b.Yc,b.Br))&&(c=Math.random(),c<b.po&&(Sb(b.Yc),b.Yc=new Io(b.lj,b.oy,Eo(b.yj),2)));b.jd=new Io(b.lj,b.py,Eo(b.yj),3);"undefined"!==typeof b.mk&&(Jo(b.jd,b.mk)||Jo(b.jd,b.Ar)||Jo(b.jd,b.Br))&&(c=Math.random(),
c<b.po&&(Sb(b.jd),b.jd=new Io(b.lj,b.py,Eo(b.yj),3)))}function Jo(b,c){return b.shape.type===c.shape.type&&b.shape.qw===c.shape.qw?!0:!1}function Ho(b){return!b.kr()||b.hd.shape.type===b.Yc.shape.type&&b.Yc.shape.type===b.jd.shape.type&&1<b.yj.QB?!1:!0}function to(b){return b.hd.sf&&b.Yc.sf&&b.jd.sf?!0:!1}a.kf=function(){Sb(this.hd);Sb(this.Yc);Sb(this.jd)};
function Io(b,c,d,e){this.d=0;this.ba=this.visible=!0;this.p=gn();this.x=b;this.y=c;this.Mq=b;this.tv=c;this.Px=this.x;this.rp=this.y;this.shape=d;this.index=e;this.Na=[];this.dg=this.sf=!1;this.maxWidth=this.p.Yb.tL;this.uk=this.shape.lP;this.$i=this.shape.kP;this.Ji=this.Gg=50;this.iu=!1;this.Fu=!0;Ib(this)}
Io.prototype.me=function(){for(var b=0;b<this.uk;b++)for(var c=0;c<this.$i;c++)this.shape.Ox[c][b]&&(so(this),this.offsetX=1===this.uk?-.5*this.Gg+.5*this.Gg*this.scale+this.maxWidth/2-this.Gg*this.scale/2:-.5*this.Gg+.5*this.Gg*this.scale,this.offsetY=1===this.$i?-.5*this.Ji+.5*this.Ji*this.scale:.5*(this.$i-1)*this.Ji*this.scale,this.Na[this.Na.length]=new Fo(b,c,this.x,this.y,this.shape.c,this.scale,this.offsetX,this.offsetY))};
function so(b){b.scale=Math.min(1,b.maxWidth/(b.uk*b.Gg),b.maxWidth/(b.$i*b.Ji))}Io.prototype.kf=function(){for(var b=0;b<this.Na.length;b++)Sb(this.Na[b])};
Io.prototype.Ab=function(b){var c=1,d=Math.min(1,this.maxWidth/(this.uk*this.Gg),this.maxWidth/(this.$i*this.Ji));this.dg?(this.x+=b/this.p.Yb.cA*(this.Px-this.x),this.y+=b/this.p.Yb.cA*(this.rp-this.y)):this.iu&&(this.x+=b/this.p.Yb.JB*(this.Mq-this.x),this.y+=b/this.p.Yb.JB*(this.tv-this.y),b=1-Math.abs(this.x-this.Tz)/Math.abs(this.Mq-this.Tz),this.Fu?this.Fu=!1:c=this.scale,this.scale=(1-d)*b+d,this.scale<d&&(this.scale=d),1<this.scale&&(this.scale=1),1>=Math.abs(this.x-this.Mq)&&1>=Math.abs(this.y-
this.tv)&&(this.x=this.Mq,this.y=this.tv,this.iu=!1,this.Fu=!0,so(this)),this.scale>c&&(this.scale=c));for(c=0;c<this.Na.length;c++)this.Na[c].x=this.x,this.Na[c].y=this.y,this.Na[c].scale=this.scale};function ko(b,c){this.depth=99;this.d=0;this.ba=this.visible=!0;this.p=gn();this.x=b;this.y=c;this.c=Ph;this.wc=0;this.hk=this.p.Kh.LB;this.time=0;this.alpha=this.p.Kh.yD;Ib(this)}a=ko.prototype;a.me=function(){};a.kf=function(){};a.ne=function(){};
a.Ab=function(b){this.time+=b;this.time>this.hk&&(this.wc++,this.time=0,this.wc>this.c.Y-1&&(this.wc=0))};a.Uc=function(){this.c.ui(this.wc,this.x,this.y,this.alpha)};function jo(b,c){this.depth=-9E3;this.d=0;this.ba=this.visible=!0;this.p=gn();this.x=b;this.y=c;this.hk=this.p.Kh.KB;this.gb=0;this.Ek=1;this.bf=0;this.BE=!1;this.c=Mh;this.wc=0;this.Dx=!1;Ib(this)}a=jo.prototype;a.me=function(){};a.kf=function(){};a.ne=function(){};
a.Ab=function(b){this.bf+=b/400*(this.Ek-this.bf);this.gb+=b;this.gb>this.hk&&(this.wc++,8<this.wc?this.wc=0:5<this.wc?this.BE?this.Dx=!0:this.Ek=this.bf=0:this.Ek=1,this.gb=0)};a.Uc=function(){this.Dx||this.c.Ha(this.wc,this.x,this.y,.7,.7,0,1);Jh.Ha(0,this.x,this.y,1,1,0,this.bf)};
function bo(b){this.p=gn();this.gc=b-1;this.Vb=this.p.hc[this.gc];this.mode=this.Vb.C.mode;this.PL=this.Vb.C.ea;this.U=this.Vb.N.U;this.S=this.Vb.N.S;this.T=(this.P=this.Vb.N.P)?this.Vb.N.T:void 0;"points"===this.mode?(this.vN=this.Vb.R.Z,this.c=oi):"type"===this.mode?(this.zf=this.Vb.type.aa,this.Xy=this.Vb.type.V,"DOT"===this.zf?this.c=ph:"DASH"===this.zf?this.c=oh:"KROKET"===this.zf?this.c=rh:"LINE"===this.zf?this.c=sh:"FRIKANDEL"===this.zf?this.c=qh:"MINICORNER"===this.zf?this.c=th:"BIGCORNER"===
this.zf?this.c=mh:"SQUARE"===this.zf?this.c=vh:"BIGSQUARE"===this.zf?this.c=nh:console.log("this shape type does not exist")):this.el=this.Vb.B.X}function Ao(b,c,d){this.d=0;this.ba=this.visible=!0;this.p=new gn;this.x=b;this.y=c;this.scale=d;this.Ir=[0,90,180,270];this.c=Wh;this.Fg=0;this.$n;this.$J=this.p.C.cO;this.gb=0;Ib(this)}a=Ao.prototype;
a.me=function(){this.$n=this.c.Y;console.log(this.scale);.1<=this.scale[0]&&(this.scale[0]+=.1);.1>=this.scale[1]&&(this.scale[1]=0);.1>=this.scale[2]&&(this.scale[2]=0);.1<=this.scale[3]&&(this.scale[3]+=.1)};a.kf=function(){};a.ne=function(){};a.Dg=function(){};a.Ab=function(b){this.gb+=b;this.gb>this.$J&&(this.Fg++,this.gb=0);this.Fg==this.$n&&Sb(this)};
a.Uc=function(){this.c.Ha(this.Fg,this.x,this.y,this.scale[0],1,this.Ir[0],1);this.c.Ha(this.Fg,this.x,this.y,this.scale[1],1,this.Ir[1],1);this.c.Ha(this.Fg,this.x,this.y,this.scale[2],1,this.Ir[2],1);this.c.Ha(this.Fg,this.x,this.y,this.scale[3],1,this.Ir[3],1)};function ao(b){this.d=this.depth=-905;this.ba=this.visible=!0;this.gc=b;this.p=gn();this.Ch=this.p.rm.Ch;Ib(this)}
ao.prototype.Uc=function(){this.gc<=this.Ch[0]?ua(ei,0,0):this.gc<=this.Ch[1]?ua(fi,0,0):this.gc<=this.Ch[2]?ua(gi,0,0):ua(hi,0,0)};
AudioController={YM:function(){if(!AudioController.lk){AudioController.lk=[];for(var b in pc)AudioController.lk.push(pc[b]),AudioController.fB=-1}0!==AudioController.lk.length&&(b=Math.floor(Math.random()*AudioController.lk.length),1<AudioController.lk.length&&b===AudioController.fB&&(b=(b+1)%AudioController.lk.length),AudioController.fB=b,S.play(AudioController.lk[b]))},qC:function(b){if(!AudioController.pk){AudioController.pk=[];for(var c in qc)AudioController.pk.push(qc[c]),AudioController.gB=
-1}0!==AudioController.pk.length&&(c=Math.floor(Math.random()*AudioController.pk.length),1<AudioController.pk.length&&c===AudioController.gB&&(c=(c+1)%AudioController.pk.length),AudioController.gB=c,S.play(AudioController.pk[c],b))},oC:function(){S.play(Xi)},dN:function(){S.play(Wi)},kT:function(){S.play(Ui)},ZM:function(b){S.play(Vi,b)},cN:function(b){S.play(Si,b)},XM:function(){S.play(Ti)},WM:function(){0===pb("ingame").length&&(S.stop("music"),S.play(dj,0,1E3),S.em("music",!0))},lT:function(){0===
pb("map").length&&(S.stop("music"),S.play(ej),S.em("music",!0))},aN:function(){S.play(Yi,250)},VM:function(){S.play(Zi,500)},SM:function(b){S.play(cj,b)},QM:function(){S.play(bj)},bN:function(b){S.play(aj,b)},PM:function(b){S.play($i,b)}};function ho(b,c,d,e){this.d=-901;this.depth=-902;this.ba=this.visible=!0;this.x=b;this.y=c;this.$y=!1;this.gb=0;this.hk=50;this.Fg=0;this.$n;this.c=Yh;this.value=d;this.tq=e;this.XC=!1;Ib(this)}ho.prototype.me=function(){this.$y=!0;this.$n=this.c.Y;AudioController.QM()};
ho.prototype.Ab=function(b){this.gb+=b;this.gb>this.hk&&(this.Fg++,this.gb=0);this.Fg===this.$n&&(this.visible=!1,0>=this.tq&&Sb(this));this.tq-=b;if(0>=this.tq&&!this.XC){b=new da;b=0+ea(b,3);var c;0===b?c=xi:1===b?c=yi:2===b?c=wi:3===b&&(c=zi);b=this.x+10+40*Math.random();var d=this.y-45+40*Math.random();new wn("+"+this.value.toString(),b,d,0,c,1,c.fillColor,c.strokeColor,-902,-903);this.XC=!0}};ho.prototype.Uc=function(){this.$y&&this.c.Ha(this.Fg,this.x,this.y,1,1,0,1)};
function po(b,c){this.depth=50;this.d=-500;this.ba=this.visible=!0;this.pc=void 0===c.pc?0:c.pc;this.Ma=void 0===c.Ma?0:c.Ma;this.rd=void 0===c.rd?0:c.rd;this.bb=void 0===c.bb?0:c.bb;this.duration=void 0===c.duration?-1:c.duration;this.value=void 0===c.value?0:c.value;this.Xp=void 0===c.Xp?!0:c.Xp;this.zp=void 0===c.zp?-1:c.zp;this.Rc=void 0===c.Rc?0:c.Rc;this.Sb=void 0===c.Sb?1:c.Sb;this.gh=void 0===c.gh?null:c.gh;this.c=b;this.time=0;this.x=this.pc;this.y=this.Ma;this.$t=this.rd-this.pc;this.au=
this.bb-this.Ma;this.scale=1;this.SH=this.Sb-1;var d=Math.sqrt(this.$t*this.$t+this.au*this.au);-1===this.duration&&(this.duration=300+.8*d);-1===this.zp&&(this.zp=300+.5*d);this.qb=0;this.Xp&&(this.$N=(40*Math.random()+50)*(.5<Math.random()?1:-1));Ib(this)}function qo(b){return b.Rc+(b.duration-b.time)}
po.prototype.kf=function(){if(0!==this.value){this.gh&&this.gh.fe(this.value,!0);var b;b=[f_chickweed_floater2,f_chickweed_floater1,f_chickweed_floater4];b=b[Math.floor(Math.random()*b.length)];new wn("+"+this.value,this.x,this.y-30,0,b,1,b.fillColor,b.strokeColor);AudioController.SM(0)}};
po.prototype.Ab=function(b){0<this.Rc?this.Rc-=b:(this.Xp&&(this.qb+=b/1E3*this.$N),this.time+=b,b=Vb(this.time,0,1,this.duration,2),this.x=this.pc+b/1*this.$t,this.y=this.Ma+b/1*this.au,this.y+=this.zp*(b*b-b),this.scale=cc(this.time,1,this.SH,this.duration),this.time>=this.duration&&(this.x=this.rd,this.y=this.bb,Sb(this)))};po.prototype.Uc=function(){0<this.Rc||this.c.Ha(0,this.x,this.y,this.scale,this.scale,this.qb,1)};
function fn(){var b={},b={};b.Ni={grass_01:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Lg,d:0},{x:P(672),y:P(288),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(160),y:P(96),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(304),y:P(352),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(688),y:P(528),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(880),y:P(96),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(368),y:P(144),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(608),y:P(320),
id:"s_road_1",c:Je,d:0},{x:P(32),y:P(-48),id:"s_tree_1",c:G,d:1},{x:P(192),y:P(-16),id:"s_tree_3",c:I,d:3},{x:P(80),y:P(-16),id:"s_tree_2",c:H,d:1},{x:P(16),y:P(0),id:"s_tree_2",c:H,d:1},{x:P(64),y:P(16),id:"s_tree_1",c:G,d:1},{x:P(16),y:P(64),id:"s_tree_3",c:I,d:1},{x:P(112),y:P(64),id:"s_tree_2",c:H,d:1},{x:P(32),y:P(96),id:"s_tree_1",c:G,d:1},{x:P(16),y:P(160),id:"s_tree_2",c:H,d:1},{x:P(160),y:P(128),id:"s_house_grass_2",c:We,d:1},{x:P(176),y:P(160),id:"s_bush_1",c:Se,d:1},{x:P(64),y:P(192),id:"s_tree_3",
c:I,d:1},{x:P(0),y:P(208),id:"s_tree_1",c:G,d:1},{x:P(32),y:P(240),id:"s_tree_2",c:H,d:1},{x:P(224),y:P(176),id:"s_lamp",c:df,d:1},{x:P(112),y:P(240),id:"s_tree_1",c:G,d:1},{x:P(-16),y:P(256),id:"s_tree_1",c:G,d:1},{x:P(48),y:P(272),id:"s_tree_1",c:G,d:1},{x:P(16),y:P(320),id:"s_tree_2",c:H,d:1},{x:P(80),y:P(320),id:"s_tree_3",c:I,d:1},{x:P(48),y:P(352),id:"s_tree_4",c:hf,d:1},{x:P(16),y:P(368),id:"s_tree_3",c:I,d:1},{x:P(80),y:P(400),id:"s_tree_5",c:jf,d:1},{x:P(16),y:P(416),id:"s_tree_2",c:H,d:1},
{x:P(64),y:P(448),id:"s_tree_2",c:H,d:1},{x:P(16),y:P(480),id:"s_tree_1",c:G,d:1},{x:P(176),y:P(480),id:"s_tree_1",c:G,d:1},{x:P(224),y:P(544),id:"s_tree_2",c:H,d:1},{x:P(64),y:P(528),id:"s_tree_4",c:hf,d:1},{x:P(16),y:P(544),id:"s_tree_3",c:I,d:1},{x:P(80),y:P(544),id:"s_tree_2",c:H,d:1},{x:P(32),y:P(576),id:"s_tree_2",c:H,d:1},{x:P(128),y:P(608),id:"s_tree_1",c:G,d:1},{x:P(16),y:P(624),id:"s_tree_2",c:H,d:1},{x:P(80),y:P(624),id:"s_tree_3",c:I,d:1},{x:P(1120),y:P(-48),id:"s_tree_1",c:G,d:1},{x:P(1056),
y:P(-32),id:"s_tree_2",c:H,d:1},{x:P(1088),y:P(-48),id:"s_tree_1",c:G,d:1},{x:P(1024),y:P(0),id:"s_tree_3",c:I,d:1},{x:P(1072),y:P(0),id:"s_tree_4",c:hf,d:1},{x:P(1120),y:P(-16),id:"s_tree_1",c:G,d:1},{x:P(1024),y:P(32),id:"s_tree_3",c:I,d:1},{x:P(1104),y:P(32),id:"s_tree_2",c:H,d:1},{x:P(1072),y:P(80),id:"s_tree_2",c:H,d:1},{x:P(1136),y:P(48),id:"s_tree_3",c:I,d:1},{x:P(1120),y:P(96),id:"s_tree_2",c:H,d:1},{x:P(1024),y:P(112),id:"s_tree_1",c:G,d:1},{x:P(1152),y:P(128),id:"s_tree_3",c:I,d:1},{x:P(1088),
y:P(160),id:"s_tree_1",c:G,d:1},{x:P(1136),y:P(192),id:"s_tree_5",c:jf,d:1},{x:P(1024),y:P(208),id:"s_tree_4",c:hf,d:1},{x:P(1056),y:P(224),id:"s_tree_3",c:I,d:1},{x:P(1104),y:P(240),id:"s_tree_2",c:H,d:1},{x:P(1008),y:P(256),id:"s_tree_2",c:H,d:1},{x:P(1056),y:P(288),id:"s_tree_1",c:G,d:1},{x:P(1152),y:P(272),id:"s_tree_2",c:H,d:1},{x:P(992),y:P(320),id:"s_lamp",c:df,d:1},{x:P(1104),y:P(320),id:"s_tree_2",c:H,d:1},{x:P(1152),y:P(336),id:"s_tree_3",c:I,d:1},{x:P(1024),y:P(336),id:"s_tree_2",c:H,d:1},
{x:P(1008),y:P(384),id:"s_house_grass_2",c:We,d:1},{x:P(1120),y:P(368),id:"s_tree_2",c:H,d:1},{x:P(1072),y:P(384),id:"s_tree_1",c:G,d:1},{x:P(1008),y:P(416),id:"s_tree_3",c:I,d:1},{x:P(1120),y:P(432),id:"s_tree_4",c:hf,d:1},{x:P(880),y:P(464),id:"s_tree_3",c:I,d:1},{x:P(1040),y:P(464),id:"s_tree_2",c:H,d:1},{x:P(1088),y:P(496),id:"s_tree_1",c:G,d:1},{x:P(976),y:P(496),id:"s_tree_5",c:jf,d:1},{x:P(1008),y:P(544),id:"s_tree_4",c:hf,d:1},{x:P(1136),y:P(544),id:"s_tree_2",c:H,d:1},{x:P(1088),y:P(576),
id:"s_tree_3",c:I,d:1},{x:P(928),y:P(544),id:"s_tree_2",c:H,d:1},{x:P(1024),y:P(608),id:"s_tree_2",c:H,d:1},{x:P(827),y:P(585),id:"s_tree_1",c:G,d:8},{x:P(310),y:P(576),id:"s_tree_3",c:I,d:1},{x:P(176),y:P(656),id:"s_tree_1",c:G,d:1},{x:P(352),y:P(599),id:"s_tree_2",c:H,d:1},{x:P(896),y:P(32),id:"s_house_grass_5",c:Ze,d:2},{x:P(688),y:P(32),id:"s_tree_5",c:jf,d:2},{x:P(640),y:P(48),id:"s_tree_4",c:hf,d:3},{x:P(672),y:P(64),id:"s_tree_3",c:I,d:4},{x:P(608),y:P(96),id:"s_rock_3",c:gf,d:2},{x:P(500),
y:P(43),id:"s_tree_1",c:G,d:2},{x:P(448),y:P(64),id:"s_lamp",c:df,d:1},{x:P(541),y:P(105),id:"s_bush_1",c:Se,d:3},{x:P(560),y:P(112),id:"s_bush_1",c:Se,d:4},{x:P(464),y:P(144),id:"s_water_1",c:kf,d:2},{x:P(363),y:P(120),id:"s_tree_2",c:H,d:3},{x:P(400),y:P(160),id:"s_rock_1",c:ef,d:4},{x:P(380),y:P(176),id:"s_bush_2",c:Te,d:5},{x:P(464),y:P(192),id:"s_rock_2",c:ff,d:6},{x:P(240),y:P(272),id:"s_house_grass_6",c:$e,d:2},{x:P(240),y:P(368),id:"s_water_2",c:lf,d:4},{x:P(784),y:P(208),id:"s_house_grass_4",
c:Ye,d:1},{x:P(816),y:P(240),id:"s_tree_5",c:jf,d:4},{x:P(720),y:P(240),id:"s_bush_1",c:Se,d:2},{x:P(736),y:P(256),id:"s_bush_2",c:Te,d:3},{x:P(768),y:P(288),id:"s_rock_2",c:ff,d:3},{x:P(608),y:P(272),id:"s_tree_1",c:G,d:2},{x:P(656),y:P(288),id:"s_tree_2",c:H,d:3},{x:P(640),y:P(320),id:"s_tree_3",c:I,d:4},{x:P(768),y:P(336),id:"s_house_grass_7",c:af,d:6},{x:P(464),y:P(288),id:"s_lamp",c:df,d:5},{x:P(384),y:P(304),id:"s_tree_4",c:hf,d:2},{x:P(352),y:P(320),id:"s_tree_3",c:I,d:3},{x:P(608),y:P(368),
id:"s_firehydrant",c:Ue,d:6},{x:P(960),y:P(128),id:"s_firehydrant",c:Ue,d:6},{x:P(320),y:P(464),id:"s_firehydrant",c:Ue,d:6},{x:P(446),y:P(393),id:"s_speedbump_1",c:Me,d:2},{x:P(271),y:P(438),id:"s_tree_3",c:I,d:3},{x:P(356),y:P(240),id:"s_speedbump_2",c:Ne,d:2},{x:P(574),y:P(542),id:"gate",c:mi,d:15}]},grass_02:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Kg,d:0},{x:P(384),y:P(352),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(800),y:P(176),id:"s_background_pattern_grass",
c:Re,d:-1},{x:P(816),y:P(32),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(576),y:P(608),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(256),y:P(624),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(912),y:P(416),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(624),y:P(368),id:"s_background_pattern_grass",c:Re,d:-1},{x:P(584),y:P(320),id:"s_road_2",c:Ke,d:0},{x:P(100),y:P(-14),id:"s_tree_2",c:H,d:0},{x:P(51),y:P(20),id:"s_tree_3",c:I,d:0},{x:P(131),y:P(50),id:"s_tree_2",c:H,d:1},{x:P(195),y:P(-3),
id:"s_tree_3",c:I,d:1},{x:P(192),y:P(96),id:"s_rock_3",c:gf,d:1},{x:P(4),y:P(61),id:"s_tree_1",c:G,d:1},{x:P(-21),y:P(76),id:"s_tree_2",c:H,d:1},{x:P(88),y:P(38),id:"s_tree_2",c:H,d:1},{x:P(63),y:P(126),id:"s_tree_3",c:I,d:1},{x:P(256),y:P(128),id:"s_tree_4",c:hf,d:1},{x:P(192),y:P(176),id:"s_tree_5",c:jf,d:1},{x:P(16),y:P(160),id:"s_tree_3",c:I,d:1},{x:P(32),y:P(192),id:"s_tree_2",c:H,d:1},{x:P(96),y:P(224),id:"s_tree_3",c:I,d:1},{x:P(0),y:P(224),id:"s_tree_2",c:H,d:1},{x:P(48),y:P(240),id:"s_tree_1",
c:G,d:1},{x:P(160),y:P(272),id:"s_tree_3",c:I,d:1},{x:P(80),y:P(288),id:"s_tree_2",c:H,d:1},{x:P(16),y:P(304),id:"s_tree_2",c:H,d:1},{x:P(112),y:P(336),id:"s_tree_3",c:I,d:1},{x:P(0),y:P(352),id:"s_tree_3",c:I,d:1},{x:P(64),y:P(352),id:"s_tree_1",c:G,d:1},{x:P(16),y:P(400),id:"s_tree_2",c:H,d:1},{x:P(80),y:P(416),id:"s_tree_4",c:hf,d:1},{x:P(128),y:P(448),id:"s_tree_2",c:H,d:1},{x:P(48),y:P(464),id:"s_tree_5",c:jf,d:1},{x:P(0),y:P(480),id:"s_tree_2",c:H,d:1},{x:P(80),y:P(496),id:"s_tree_3",c:I,d:1},
{x:P(32),y:P(512),id:"s_tree_2",c:H,d:1},{x:P(96),y:P(544),id:"s_tree_1",c:G,d:1},{x:P(48),y:P(560),id:"s_tree_2",c:H,d:1},{x:P(0),y:P(560),id:"s_tree_3",c:I,d:1},{x:P(16),y:P(608),id:"s_tree_2",c:H,d:1},{x:P(80),y:P(608),id:"s_tree_1",c:G,d:1},{x:P(208),y:P(544),id:"s_tree_3",c:I,d:1},{x:P(912),y:P(-32),id:"s_tree_4",c:hf,d:1},{x:P(944),y:P(-16),id:"s_tree_3",c:I,d:1},{x:P(928),y:P(16),id:"s_bush_2",c:Te,d:1},{x:P(1142),y:P(-42),id:"s_tree_1",c:G,d:1},{x:P(1130),y:P(19),id:"s_tree_3",c:I,d:1},{x:P(1078),
y:P(-17),id:"s_tree_2",c:H,d:1},{x:P(1136),y:P(67),id:"s_tree_3",c:I,d:1},{x:P(1102),y:P(74),id:"s_tree_2",c:H,d:1},{x:P(1052),y:P(116),id:"s_house_grass_2",c:We,d:1},{x:P(1152),y:P(128),id:"s_tree_3",c:I,d:1},{x:P(1084),y:P(142),id:"s_tree_2",c:H,d:2},{x:P(176),y:P(576),id:"s_tree_3",c:I,d:2},{x:P(1136),y:P(176),id:"s_tree_3",c:I,d:3},{x:P(1095),y:P(217),id:"s_tree_1",c:G,d:4},{x:P(1008),y:P(240),id:"s_tree_5",c:jf,d:5},{x:P(1040),y:P(272),id:"s_tree_4",c:hf,d:6},{x:P(1008),y:P(288),id:"s_tree_3",
c:I,d:7},{x:P(1040),y:P(320),id:"s_bush_2",c:Te,d:8},{x:P(1013),y:P(351),id:"s_house_grass_8",c:bf,d:1},{x:P(1151),y:P(256),id:"s_tree_2",c:H,d:5},{x:P(1173),y:P(286),id:"s_tree_1",c:G,d:6},{x:P(1168),y:P(352),id:"s_tree_3",c:I,d:2},{x:P(1139),y:P(415),id:"s_tree_2",c:H,d:1},{x:P(1088),y:P(448),id:"s_tree_1",c:G,d:1},{x:P(1136),y:P(480),id:"s_tree_2",c:H,d:1},{x:P(1024),y:P(544),id:"s_tree_3",c:I,d:1},{x:P(1056),y:P(560),id:"s_tree_2",c:H,d:1},{x:P(1008),y:P(576),id:"s_house_grass_3",c:Xe,d:1},{x:P(1136),
y:P(544),id:"s_tree_2",c:H,d:1},{x:P(1120),y:P(576),id:"s_tree_1",c:G,d:1},{x:P(944),y:P(576),id:"s_tree_2",c:H,d:1},{x:P(1008),y:P(608),id:"s_tree_3",c:I,d:1},{x:P(720),y:P(-16),id:"s_tree_2",c:H,d:1},{x:P(672),y:P(16),id:"s_tree_3",c:I,d:1},{x:P(640),y:P(80),id:"s_rock_3",c:gf,d:1},{x:P(432),y:P(48),id:"s_house_grass_2",c:We,d:1},{x:P(432),y:P(96),id:"s_firehydrant",c:Ue,d:3},{x:P(208),y:P(48),id:"s_bush_1",c:Se,d:1},{x:P(976),y:P(448),id:"s_bush_1",c:Se,d:1},{x:P(368),y:P(80),id:"s_bush_2",c:Te,
d:2},{x:P(400),y:P(96),id:"s_lamp",c:df,d:4},{x:P(128),y:P(176),id:"s_rock_2",c:ff,d:1},{x:P(480),y:P(208),id:"s_lamp",c:df,d:1},{x:P(432),y:P(256),id:"s_tree_2",c:H,d:1},{x:P(464),y:P(288),id:"s_tree_1",c:G,d:2},{x:P(384),y:P(320),id:"s_watertower",c:nf,d:3},{x:P(336),y:P(384),id:"s_rock_3",c:gf,d:4},{x:P(432),y:P(384),id:"s_bush_1",c:Se,d:5},{x:P(416),y:P(400),id:"s_bush_1",c:Se,d:6},{x:P(352),y:P(432),id:"s_rock_2",c:ff,d:1},{x:P(944),y:P(48),id:"s_bush_1",c:Se,d:1},{x:P(816),y:P(144),id:"s_tree_2",
c:H,d:1},{x:P(782),y:P(192),id:"s_house_grass_7",c:af,d:3},{x:P(720),y:P(208),id:"s_tree_4",c:hf,d:4},{x:P(768),y:P(240),id:"s_bush_1",c:Se,d:5},{x:P(688),y:P(256),id:"s_firehydrant",c:Ue,d:1},{x:P(636),y:P(293),id:"s_lamp",c:df,d:1},{x:P(816),y:P(368),id:"s_tree_3",c:I,d:1},{x:P(304),y:P(576),id:"s_house_grass_9",c:cf,d:2},{x:P(960),y:P(64),id:"s_tree_3",c:I,d:2},{x:P(272),y:P(-16),id:"s_tree_5",c:jf,d:1},{x:P(887),y:P(398),id:"s_bush_2",c:Te,d:2},{x:P(624),y:P(432),id:"s_tree_3",c:I,d:1},{x:P(640),
y:P(464),id:"s_tree_2",c:H,d:2},{x:P(512),y:P(528),id:"s_tree_2",c:H,d:4},{x:P(554),y:P(560),id:"s_tree_3",c:I,d:5},{x:P(480),y:P(576),id:"s_bush_1",c:Se,d:6},{x:P(512),y:P(608),id:"s_firehydrant",c:Ue,d:1},{x:P(736),y:P(528),id:"s_rock_1",c:ef,d:1},{x:P(768),y:P(544),id:"s_bush_1",c:Se,d:2},{x:P(736),y:P(560),id:"s_bush_2",c:Te,d:3},{x:P(816),y:P(496),id:"s_lamp",c:df,d:1},{x:P(192),y:P(352),id:"s_lamp",c:df,d:1},{x:P(889),y:P(125),id:"s_speedbump_4",c:Pe,d:2},{x:P(519),y:P(457),id:"s_speedbump_3",
c:Oe,d:0},{x:P(649),y:P(513),id:"s_house_grass_6",c:$e,d:3}]},desert_01:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Jg,d:0},{x:P(240),y:P(304),id:"s_background_pattern_desert",c:of,d:-1},{x:P(736),y:P(288),id:"s_background_pattern_desert",c:of,d:-1},{x:P(416),y:P(144),id:"s_background_pattern_desert",c:of,d:-1},{x:P(512),y:P(464),id:"s_background_pattern_desert",c:of,d:-1},{x:P(608),y:P(320),id:"s_road_1",c:Je,d:0},{x:P(16),y:P(-32),id:"s_shiprock_3",c:Gf,d:1},{x:P(96),y:P(48),
id:"s_bush_4",c:pf,d:0},{x:P(224),y:P(-48),id:"s_house_desert_4",c:xf,d:1},{x:P(176),y:P(64),id:"s_bush_4",c:pf,d:1},{x:P(112),y:P(128),id:"s_tree_7",c:Jf,d:1},{x:P(144),y:P(160),id:"s_tree_6",c:If,d:2},{x:P(112),y:P(208),id:"s_bush_5",c:qf,d:3},{x:P(160),y:P(224),id:"s_rock_5",c:Cf,d:4},{x:P(80),y:P(272),id:"s_water_6",c:Mf,d:5},{x:P(16),y:P(272),id:"s_tree_6",c:If,d:6},{x:P(64),y:P(304),id:"s_tree_8",c:Kf,d:7},{x:P(16),y:P(336),id:"s_bush_5",c:qf,d:8},{x:P(272),y:P(304),id:"s_rock_4",c:Bf,d:8},
{x:P(16),y:P(512),id:"s_shiprock_2",c:Ff,d:9},{x:P(352),y:P(304),id:"s_cactus_1",c:rf,d:1},{x:P(320),y:P(336),id:"s_cactus_2",c:sf,d:2},{x:P(160),y:P(368),id:"s_bush_4",c:pf,d:1},{x:P(144),y:P(416),id:"s_rock_5",c:Cf,d:1},{x:P(240),y:P(448),id:"s_house_desert_5",c:yf,d:3},{x:P(192),y:P(496),id:"s_tree_8",c:Kf,d:4},{x:P(861),y:P(572),id:"s_tree_9",c:Lf,d:1},{x:P(480),y:P(448),id:"s_bush_4",c:pf,d:1},{x:P(464),y:P(464),id:"s_bush_4",c:pf,d:2},{x:P(512),y:P(480),id:"s_bush_5",c:qf,d:3},{x:P(1136),y:P(-48),
id:"s_shiprock_3",c:Gf,d:1},{x:P(1008),y:P(32),id:"s_bush_4",c:pf,d:1},{x:P(944),y:P(16),id:"s_house_desert_7",c:Af,d:2},{x:P(1040),y:P(48),id:"s_bush_4",c:pf,d:3},{x:P(1024),y:P(80),id:"s_campfire",c:tf,d:4},{x:P(1040),y:P(144),id:"s_rock_6",c:Df,d:5},{x:P(816),y:P(48),id:"s_rock_4",c:Bf,d:1},{x:P(656),y:P(48),id:"s_cactus_1",c:rf,d:1},{x:P(704),y:P(64),id:"s_cactus_2",c:sf,d:2},{x:P(688),y:P(96),id:"s_skull",c:Hf,d:3},{x:P(512),y:P(128),id:"s_rock_6",c:Df,d:1},{x:P(560),y:P(128),id:"s_well",c:Nf,
d:2},{x:P(432),y:P(96),id:"s_house_desert_3",c:wf,d:3},{x:P(528),y:P(160),id:"s_bush_4",c:pf,d:4},{x:P(512),y:P(176),id:"s_rock_5",c:Cf,d:5},{x:P(384),y:P(128),id:"s_tree_8",c:Kf,d:6},{x:P(432),y:P(160),id:"s_rock_4",c:Bf,d:7},{x:P(464),y:P(160),id:"s_bush_5",c:qf,d:8},{x:P(1056),y:P(256),id:"s_house_desert_1",c:uf,d:1},{x:P(1024),y:P(320),id:"s_bush_5",c:qf,d:2},{x:P(1072),y:P(352),id:"s_cactus_2",c:sf,d:0},{x:P(944),y:P(416),id:"s_tree_8",c:Kf,d:1},{x:P(1104),y:P(496),id:"s_shiprock_1",c:Ef,d:2},
{x:P(992),y:P(544),id:"s_shiprock_3",c:Gf,d:3},{x:P(288),y:P(592),id:"s_tree_8",c:Kf,d:1},{x:P(816),y:P(224),id:"s_tree_8",c:Kf,d:1},{x:P(736),y:P(288),id:"s_house_desert_4",c:xf,d:2},{x:P(768),y:P(336),id:"s_cactus_2",c:sf,d:3},{x:P(704),y:P(368),id:"s_bush_4",c:pf,d:4},{x:P(752),y:P(384),id:"s_rock_6",c:Df,d:1},{x:P(580),y:P(318),id:"s_cactus_1",c:rf,d:1},{x:P(626),y:P(343),id:"s_bush_5",c:qf,d:2},{x:P(640),y:P(272),id:"s_rock_5",c:Cf,d:1},{x:P(796),y:P(621),id:"s_rock_6",c:Df,d:2},{x:P(288),y:P(544),
id:"s_crack",c:Qg,d:0},{x:P(0),y:P(128),id:"s_crack",c:Qg,d:0},{x:P(561),y:P(549),id:"gate",c:li,d:15}]},desert_02:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Ig,d:0},{x:P(384),y:P(352),id:"s_background_pattern_desert",c:of,d:-1},{x:P(608),y:P(528),id:"s_background_pattern_desert",c:of,d:-1},{x:P(768),y:P(192),id:"s_background_pattern_desert",c:of,d:-1},{x:P(224),y:P(144),id:"s_background_pattern_desert",c:of,d:-1},{x:P(768),y:P(400),id:"s_background_pattern_desert",c:of,
d:-1},{x:P(224),y:P(496),id:"s_background_pattern_desert",c:of,d:-1},{x:P(584),y:P(320),id:"s_road_2",c:Ke,d:0},{x:P(368),y:P(64),id:"s_tree_9",c:Lf,d:1},{x:P(128),y:P(128),id:"s_shiprock_1",c:Ef,d:1},{x:P(32),y:P(160),id:"s_shiprock_3",c:Gf,d:2},{x:P(80),y:P(224),id:"s_bush_4",c:pf,d:3},{x:P(112),y:P(240),id:"s_bush_4",c:pf,d:4},{x:P(176),y:P(224),id:"s_bush_5",c:qf,d:5},{x:P(272),y:P(128),id:"s_skull",c:Hf,d:1},{x:P(48),y:P(304),id:"s_rock_4",c:Bf,d:1},{x:P(96),y:P(288),id:"s_rock_5",c:Cf,d:1},
{x:P(112),y:P(368),id:"s_house_desert_1",c:uf,d:2},{x:P(16),y:P(448),id:"s_tree_9",c:Lf,d:3},{x:P(192),y:P(480),id:"s_cactus_1",c:rf,d:1},{x:P(160),y:P(512),id:"s_cactus_2",c:sf,d:1},{x:P(96),y:P(528),id:"s_rock_6",c:Df,d:1},{x:P(672),y:P(48),id:"s_cactus_1",c:rf,d:1},{x:P(499),y:P(244),id:"s_tree_8",c:Kf,d:1},{x:P(384),y:P(352),id:"s_house_desert_2",c:vf,d:2},{x:P(352),y:P(416),id:"s_cactus_2",c:sf,d:3},{x:P(448),y:P(400),id:"s_rock_6",c:Df,d:1},{x:P(810),y:P(160),id:"s_house_desert_3",c:wf,d:1},
{x:P(784),y:P(208),id:"s_bush_4",c:pf,d:2},{x:P(736),y:P(208),id:"s_tree_8",c:Kf,d:3},{x:P(624),y:P(352),id:"s_cactus_1",c:rf,d:1},{x:P(640),y:P(400),id:"s_cactus_2",c:sf,d:2},{x:P(512),y:P(576),id:"s_bush_4",c:pf,d:1},{x:P(416),y:P(592),id:"s_rock_4",c:Bf,d:1},{x:P(352),y:P(592),id:"s_rock_5",c:Cf,d:2},{x:P(384),y:P(624),id:"s_rock_6",c:Df,d:3},{x:P(1008),y:P(64),id:"s_tree_8",c:Kf,d:1},{x:P(1056),y:P(80),id:"s_tree_7",c:Jf,d:2},{x:P(1056),y:P(256),id:"s_shiprock_2",c:Ff,d:3},{x:P(960),y:P(368),
id:"s_bush_5",c:qf,d:4},{x:P(976),y:P(384),id:"s_bush_4",c:pf,d:5},{x:P(1056),y:P(400),id:"s_bush_4",c:pf,d:6},{x:P(903),y:P(395),id:"s_rock_5",c:Cf,d:1},{x:P(905),y:P(294),id:"s_bush_5",c:qf,d:2},{x:P(846),y:P(361),id:"s_tree_8",c:Kf,d:4},{x:P(1099),y:P(465),id:"s_cactus_2",c:sf,d:1},{x:P(1056),y:P(512),id:"s_cactus_1",c:rf,d:2},{x:P(960),y:P(576),id:"s_tree_8",c:Kf,d:1},{x:P(1E3),y:P(488),id:"s_rock_6",c:Df,d:1},{x:P(80),y:P(608),id:"s_crack",c:Qg,d:0},{x:P(582),y:P(172),id:"s_crack",c:Qg,d:0},
{x:P(1136),y:P(576),id:"s_crack",c:Qg,d:0},{x:P(976),y:P(448),id:"s_crack",c:Qg,d:0},{x:P(636),y:P(512),id:"s_house_desert_3",c:wf,d:1},{x:P(698),y:P(546),id:"s_bush_5",c:qf,d:2}]},beach_01:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Hg,d:0},{x:P(720),y:P(272),id:"s_background_pattern_desert",c:of,d:-1},{x:P(416),y:P(128),id:"s_background_pattern_desert",c:of,d:-1},{x:P(448),y:P(480),id:"s_background_pattern_desert",c:of,d:-1},{x:P(304),y:P(336),id:"s_background_pattern_desert",
c:of,d:-1},{x:P(768),y:P(448),id:"s_background_pattern_desert",c:of,d:-1},{x:P(608),y:P(320),id:"s_road_1",c:Je,d:0},{x:P(96),y:P(304),id:"s_ocean_1_b",c:$f,d:1},{x:P(240),y:P(-32),id:"s_house_beach_2",c:Vf,d:2},{x:P(176),y:P(16),id:"s_parasol",c:cg,d:3},{x:P(202),y:P(46),id:"s_bed",c:Of,d:4},{x:P(181),y:P(113),id:"s_sandcastle",c:ig,d:2},{x:P(32),y:P(160),id:"s_rock_water_2",c:hg,d:2},{x:P(64),y:P(208),id:"s_rock_water",c:gg,d:2},{x:P(48),y:P(144),id:"s_starfish",c:jg,d:3},{x:P(96),y:P(400),id:"s_boat_1",
c:Pf,d:4},{x:P(48),y:P(368),id:"s_boat_2",c:Qf,d:5},{x:P(473),y:P(39),id:"s_tree_6",c:If,d:4},{x:P(436),y:P(30),id:"s_tree_7",c:Jf,d:5},{x:P(757),y:P(37),id:"s_tree_8",c:Kf,d:3},{x:P(463),y:P(149),id:"s_pool",c:dg,d:6},{x:P(592),y:P(112),id:"s_rock_5",c:Cf,d:1},{x:P(592),y:P(144),id:"s_rock_6",c:Df,d:2},{x:P(992),y:P(16),id:"s_house_beach_3",c:Wf,d:1},{x:P(880),y:P(16),id:"s_bush_8",c:Rf,d:1},{x:P(1056),y:P(48),id:"s_bush_4",c:pf,d:2},{x:P(1040),y:P(80),id:"s_parasol",c:cg,d:3},{x:P(1120),y:P(64),
id:"s_jacuzzi",c:sg,d:4},{x:P(1056),y:P(112),id:"s_bed",c:Of,d:5},{x:P(1088),y:P(128),id:"s_bed",c:Of,d:6},{x:P(1088),y:P(256),id:"s_tree_8",c:Kf,d:1},{x:P(1040),y:P(320),id:"s_house_beach_5",c:Yf,d:2},{x:P(1088),y:P(384),id:"s_tree_6",c:If,d:3},{x:P(1040),y:P(416),id:"s_tree_7",c:Jf,d:4},{x:P(1072),y:P(448),id:"s_tree_6",c:If,d:5},{x:P(944),y:P(448),id:"s_tree_8",c:Kf,d:1},{x:P(992),y:P(544),id:"s_tree_8",c:Kf,d:1},{x:P(1088),y:P(544),id:"s_rock_5",c:Cf,d:1},{x:P(1120),y:P(512),id:"s_rock_6",c:Df,
d:1},{x:P(937),y:P(592),id:"s_bush_9",c:Sf,d:1},{x:P(966),y:P(608),id:"s_bush_10",c:Tf,d:2},{x:P(854),y:P(565),id:"s_house_beach_5",c:Yf,d:1},{x:P(686),y:P(511),id:"s_tree_6",c:If,d:3},{x:P(478),y:P(443),id:"s_tree_8",c:Kf,d:1},{x:P(240),y:P(320),id:"s_house_beach_4",c:Xf,d:1},{x:P(272),y:P(384),id:"s_bush_10",c:Tf,d:2},{x:P(176),y:P(432),id:"s_tree_8",c:Kf,d:3},{x:P(240),y:P(544),id:"s_house_beach_3",c:Wf,d:1},{x:P(336),y:P(608),id:"s_rock_5",c:Cf,d:1},{x:P(80),y:P(544),id:"s_tree_7",c:Jf,d:2},{x:P(112),
y:P(576),id:"s_tree_6",c:If,d:3},{x:P(32),y:P(560),id:"s_tree_7",c:Jf,d:4},{x:P(800),y:P(243),id:"s_house_beach_1",c:Uf,d:1},{x:P(640),y:P(240),id:"s_tree_6",c:If,d:2},{x:P(672),y:P(272),id:"s_tree_7",c:Jf,d:3},{x:P(624),y:P(288),id:"s_tree_7",c:Jf,d:4},{x:P(656),y:P(352),id:"s_rock_4",c:Bf,d:5},{x:P(704),y:P(368),id:"s_rock_6",c:Df,d:1},{x:P(789),y:P(302),id:"s_bush_9",c:Sf,d:2},{x:P(544),y:P(304),id:"s_bush_8",c:Rf,d:1},{x:P(512),y:P(320),id:"s_bush_9",c:Sf,d:2},{x:P(992),y:P(160),id:"s_rock_6",
c:Df,d:1},{x:P(672),y:P(64),id:"s_rock_9",c:eg,d:1},{x:P(579),y:P(549),id:"gate",c:ki,d:15}]},beach_02:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Gg,d:0},{x:P(432),y:P(96),id:"s_background_pattern_desert",c:of,d:-1},{x:P(384),y:P(304),id:"s_background_pattern_desert",c:of,d:-1},{x:P(656),y:P(512),id:"s_background_pattern_desert",c:of,d:-1},{x:P(800),y:P(192),id:"s_background_pattern_desert",c:of,d:-1},{x:P(320),y:P(608),id:"s_background_pattern_desert",c:of,d:-1},{x:P(584),
y:P(320),id:"s_road_2",c:Ke,d:0},{x:P(96),y:P(336),id:"s_ocean_1_a",c:Zf,d:1},{x:P(1072),y:P(425),id:"s_ocean_2_b",c:bg,d:1},{x:P(158),y:P(548),id:"s_house_beach_3",c:Wf,d:2},{x:P(64),y:P(32),id:"s_rock_4",c:Bf,d:1},{x:P(192),y:P(-32),id:"s_tree_7",c:Jf,d:1},{x:P(160),y:P(0),id:"s_tree_6",c:If,d:2},{x:P(208),y:P(80),id:"s_jacuzzi",c:sg,d:3},{x:P(316),y:P(81),id:"s_house_beach_1",c:Uf,d:4},{x:P(254),y:P(129),id:"s_bush_10",c:Tf,d:5},{x:P(283),y:P(147),id:"s_bush_10",c:Tf,d:6},{x:P(236),y:P(150),id:"s_bush_9",
c:Sf,d:7},{x:P(176),y:P(208),id:"s_tree_8",c:Kf,d:3},{x:P(432),y:P(64),id:"s_rock_6",c:Df,d:0},{x:P(692),y:P(10),id:"s_tree_6",c:If,d:1},{x:P(665),y:P(60),id:"s_tree_8",c:Kf,d:2},{x:P(480),y:P(224),id:"s_rock_9",c:eg,d:1},{x:P(480),y:P(272),id:"s_bush_10",c:Tf,d:2},{x:P(400),y:P(336),id:"s_house_beach_2",c:Vf,d:1},{x:P(346),y:P(388),id:"s_bush_8",c:Rf,d:2},{x:P(354),y:P(432),id:"s_rock_6",c:Df,d:1},{x:P(384),y:P(448),id:"s_rock_6",c:Df,d:2},{x:P(325),y:P(533),id:"s_tree_6",c:If,d:1},{x:P(280),y:P(527),
id:"s_tree_7",c:Jf,d:2},{x:P(448),y:P(592),id:"s_bush_10",c:Tf,d:4},{x:P(416),y:P(608),id:"s_bush_8",c:Rf,d:5},{x:P(486),y:P(607),id:"s_bush_9",c:Sf,d:6},{x:P(752),y:P(480),id:"s_tree_7",c:Jf,d:1},{x:P(820),y:P(114),id:"s_tree_6",c:If,d:1},{x:P(752),y:P(144),id:"s_tree_6",c:If,d:2},{x:P(807),y:P(155),id:"s_tree_7",c:Jf,d:3},{x:P(716),y:P(250),id:"s_tree_8",c:Kf,d:6},{x:P(563),y:P(187),id:"s_rock_4",c:Bf,d:1},{x:P(768),y:P(224),id:"s_rock_6",c:Df,d:1},{x:P(643),y:P(335),id:"s_tree_6",c:If,d:4},{x:P(657),
y:P(378),id:"s_tree_7",c:Jf,d:5},{x:P(800),y:P(384),id:"s_rock_6",c:Df,d:1},{x:P(832),y:P(368),id:"s_rock_5",c:Cf,d:1},{x:P(928),y:P(368),id:"s_house_beach_2",c:Vf,d:1},{x:P(975),y:P(424),id:"s_bush_9",c:Sf,d:2},{x:P(944),y:P(0),id:"s_tree_6",c:If,d:1},{x:P(1008),y:P(16),id:"s_tree_6",c:If,d:2},{x:P(976),y:P(32),id:"s_tree_7",c:Jf,d:3},{x:P(904),y:P(29),id:"s_rock_4",c:Bf,d:3},{x:P(1008),y:P(96),id:"s_bush_8",c:Rf,d:4},{x:P(1073),y:P(157),id:"s_ocean_2_a",c:ag,d:1},{x:P(1129),y:P(69),id:"s_boat_1",
c:Pf,d:3},{x:P(1012),y:P(509),id:"s_sandcastle",c:ig,d:1},{x:P(1043),y:P(552),id:"s_starfish",c:jg,d:1},{x:P(1109),y:P(179),id:"s_rock_water_2",c:hg,d:2},{x:P(623),y:P(498),id:"s_house_beach_5",c:Yf,d:6},{x:P(531),y:P(546),id:"s_bed",c:Of,d:6},{x:P(655),y:P(554),id:"s_tree_8",c:Kf,d:6}]},snow_01:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Ng,d:0},{x:P(256),y:P(336),id:"s_background_snow",c:Rg,d:-1},{x:P(480),y:P(128),id:"s_background_snow",c:Rg,d:-1},{x:P(784),y:P(288),id:"s_background_snow",
c:Rg,d:-1},{x:P(448),y:P(464),id:"s_background_snow",c:Rg,d:-1},{x:P(720),y:P(560),id:"s_background_snow",c:Rg,d:-1},{x:P(864),y:P(544),id:"s_background_transition_snow_2",c:Pg,d:-2},{x:P(287),y:P(552),id:"s_background_transition_snow_1",c:Og,d:-2},{x:P(609),y:P(320),id:"s_road_1",c:Je,d:0},{x:P(160),y:P(-16),id:"s_tree_11",c:J,d:1},{x:P(224),y:P(-32),id:"s_tree_10",c:Ag,d:1},{x:P(48),y:P(-80),id:"s_icerock_2",c:rg,d:2},{x:P(160),y:P(32),id:"s_tree_13",c:Cg,d:3},{x:P(112),y:P(80),id:"s_tree_11",c:J,
d:4},{x:P(0),y:P(64),id:"s_bush_7",c:lg,d:4},{x:P(224),y:P(160),id:"s_lamp_snow",c:tg,d:1},{x:P(96),y:P(256),id:"s_water_4",c:Dg,d:1},{x:P(32),y:P(304),id:"s_tree_10",c:Ag,d:2},{x:P(96),y:P(320),id:"s_tree_13",c:Cg,d:3},{x:P(0),y:P(352),id:"s_tree_11",c:J,d:4},{x:P(48),y:P(368),id:"s_tree_13",c:Cg,d:5},{x:P(112),y:P(400),id:"s_tree_11",c:J,d:6},{x:P(304),y:P(304),id:"s_house_snow_2",c:ng,d:1},{x:P(240),y:P(352),id:"s_snowman",c:wg,d:2},{x:P(304),y:P(352),id:"s_bush_6",c:kg,d:3},{x:P(320),y:P(384),
id:"s_lamp_snow",c:tg,d:4},{x:P(144),y:P(464),id:"s_bush_7",c:lg,d:1},{x:P(16),y:P(496),id:"s_bush_7",c:lg,d:2},{x:P(80),y:P(512),id:"s_tree_11",c:J,d:1},{x:P(224),y:P(480),id:"s_tree_10",c:Ag,d:1},{x:P(272),y:P(528),id:"s_tree_11",c:J,d:2},{x:P(208),y:P(544),id:"s_tree_11",c:J,d:3},{x:P(496),y:P(432),id:"s_tree_11",c:J,d:2},{x:P(464),y:P(432),id:"s_tree_10",c:Ag,d:3},{x:P(720),y:P(544),id:"s_tree_10",c:Ag,d:1},{x:P(816),y:P(544),id:"s_rock_8",c:vg,d:2},{x:P(832),y:P(576),id:"s_rock_7",c:ug,d:3},
{x:P(432),y:P(128),id:"s_house_snow_1",c:mg,d:1},{x:P(384),y:P(144),id:"s_tree_11",c:J,d:2},{x:P(448),y:P(176),id:"s_bush_7",c:lg,d:2},{x:P(560),y:P(128),id:"s_woodpile",c:Fg,d:1},{x:P(624),y:P(112),id:"s_jacuzzi",c:sg,d:1},{x:P(784),y:P(16),id:"s_tree_10",c:Ag,d:1},{x:P(736),y:P(32),id:"s_tree_11",c:J,d:2},{x:P(816),y:P(192),id:"s_tree_13",c:Cg,d:1},{x:P(704),y:P(256),id:"s_tree_10",c:Ag,d:2},{x:P(768),y:P(288),id:"s_tree_11",c:J,d:3},{x:P(688),y:P(320),id:"s_tree_12",c:Bg,d:4},{x:P(784),y:P(336),
id:"s_bush_7",c:lg,d:4},{x:P(576),y:P(304),id:"s_bush_6",c:kg,d:4},{x:P(608),y:P(336),id:"s_rock_7",c:ug,d:1},{x:P(624),y:P(256),id:"s_lamp_snow",c:tg,d:1},{x:P(1040),y:P(48),id:"s_water_5",c:Eg,d:1},{x:P(896),y:P(48),id:"s_swing",c:xg,d:1},{x:P(960),y:P(112),id:"s_rock_7",c:ug,d:2},{x:P(1040),y:P(96),id:"s_tree_10",c:Ag,d:2},{x:P(1120),y:P(128),id:"s_tree_13",c:Cg,d:3},{x:P(1056),y:P(160),id:"s_tree_11",c:J,d:4},{x:P(992),y:P(240),id:"s_lamp_snow",c:tg,d:0},{x:P(1056),y:P(288),id:"s_house_snow_3",
c:og,d:1},{x:P(1056),y:P(336),id:"s_bush_6",c:kg,d:2},{x:P(1136),y:P(304),id:"s_tree_13",c:Cg,d:4},{x:P(1104),y:P(368),id:"s_tree_11",c:J,d:5},{x:P(992),y:P(464),id:"s_tree_11",c:J,d:1},{x:P(928),y:P(448),id:"s_tree_13",c:Cg,d:2},{x:P(960),y:P(496),id:"s_tree_10",c:Ag,d:3},{x:P(569),y:P(545),id:"gate",c:ni,d:15}]},snow_02:{width:P(1152),height:P(640),items:[{x:P(0),y:P(0),id:"background",c:Mg,d:0},{x:P(432),y:P(96),id:"s_background_snow",c:Rg,d:-1},{x:P(384),y:P(368),id:"s_background_snow",c:Rg,d:-1},
{x:P(800),y:P(192),id:"s_background_snow",c:Rg,d:-1},{x:P(640),y:P(560),id:"s_background_snow",c:Rg,d:-1},{x:P(864),y:P(368),id:"s_background_snow",c:Rg,d:-1},{x:P(240),y:P(512),id:"s_background_snow",c:Rg,d:-1},{x:P(584),y:P(320),id:"s_road_2",c:Ke,d:0},{x:P(16),y:P(-48),id:"s_tree_13",c:Cg,d:0},{x:P(64),y:P(-32),id:"s_tree_10",c:Ag,d:0},{x:P(224),y:P(0),id:"s_tree_11",c:J,d:1},{x:P(35),y:P(15),id:"s_tree_13",c:Cg,d:1},{x:P(128),y:P(64),id:"s_tree_10",c:Ag,d:1},{x:P(32),y:P(64),id:"s_tree_11",c:J,
d:1},{x:P(80),y:P(64),id:"s_tree_10",c:Ag,d:1},{x:P(48),y:P(112),id:"s_tree_13",c:Cg,d:1},{x:P(304),y:P(96),id:"s_house_snow_1",c:mg,d:1},{x:P(480),y:P(48),id:"s_lamp_snow",c:tg,d:1},{x:P(240),y:P(144),id:"s_woodpile",c:Fg,d:1},{x:P(672),y:P(16),id:"s_tree_11",c:J,d:1},{x:P(512),y:P(214),id:"s_tree_13",c:Cg,d:1},{x:P(472),y:P(242),id:"s_tree_10",c:Ag,d:2},{x:P(500),y:P(285),id:"s_tree_11",c:J,d:3},{x:P(416),y:P(224),id:"s_lamp_snow",c:tg,d:1},{x:P(400),y:P(320),id:"s_house_snow_2",c:ng,d:1},{x:P(432),
y:P(368),id:"s_tree_10",c:Ag,d:2},{x:P(400),y:P(400),id:"s_tree_11",c:J,d:3},{x:P(336),y:P(368),id:"s_tree_12",c:Bg,d:2},{x:P(96),y:P(144),id:"s_tree_10",c:Ag,d:1},{x:P(16),y:P(176),id:"s_tree_10",c:Ag,d:1},{x:P(160),y:P(192),id:"s_tree_11",c:J,d:1},{x:P(409),y:P(58),id:"s_tree_11",c:J,d:1},{x:P(16),y:P(240),id:"s_tree_11",c:J,d:1},{x:P(94),y:P(281),id:"s_icerock_1",c:qg,d:1},{x:P(160),y:P(384),id:"s_tree_10",c:Ag,d:2},{x:P(48),y:P(368),id:"s_bush_6",c:kg,d:2},{x:P(80),y:P(384),id:"s_bush_7",c:lg,
d:3},{x:P(112),y:P(416),id:"s_tree_11",c:J,d:4},{x:P(276),y:P(575),id:"s_house_snow_4",c:pg,d:1},{x:P(160),y:P(560),id:"s_tree_13",c:Cg,d:2},{x:P(64),y:P(544),id:"s_tree_10",c:Ag,d:3},{x:P(352),y:P(560),id:"s_lamp_snow",c:tg,d:1},{x:P(800),y:P(128),id:"s_tree_13",c:Cg,d:1},{x:P(752),y:P(160),id:"s_tree_10",c:Ag,d:2},{x:P(800),y:P(192),id:"s_tree_11",c:J,d:3},{x:P(736),y:P(224),id:"s_rock_8",c:vg,d:4},{x:P(688),y:P(272),id:"s_rock_7",c:ug,d:5},{x:P(576),y:P(464),id:"s_tree_11",c:J,d:1},{x:P(640),y:P(464),
id:"s_tree_10",c:Ag,d:2},{x:P(704),y:P(528),id:"s_tree_11",c:J,d:4},{x:P(784),y:P(528),id:"s_rock_7",c:ug,d:1},{x:P(432),y:P(576),id:"s_bush_6",c:kg,d:1},{x:P(464),y:P(592),id:"s_bush_7",c:lg,d:2},{x:P(704),y:P(288),id:"s_bush_7",c:lg,d:6},{x:P(805),y:P(362),id:"s_lamp_snow",c:tg,d:2},{x:P(928),y:P(32),id:"s_tree_11",c:J,d:1},{x:P(880),y:P(336),id:"s_house_snow_3",c:og,d:1},{x:P(886),y:P(383),id:"s_snowman",c:wg,d:3},{x:P(992),y:P(448),id:"s_tree_11",c:J,d:1},{x:P(1104),y:P(416),id:"s_tree_13",c:Cg,
d:1},{x:P(1120),y:P(464),id:"s_tree_10",c:Ag,d:2},{x:P(1072),y:P(480),id:"s_tree_10",c:Ag,d:3},{x:P(958),y:P(535),id:"s_tree_12",c:Bg,d:2},{x:P(768),y:P(16),id:"s_rock_7",c:ug,d:1},{x:P(320),y:P(144),id:"s_bush_7",c:lg,d:5},{x:P(591),y:P(538),id:"s_house_snow_2",c:ng,d:3},{x:P(551),y:P(559),id:"s_tree_12",c:Bg,d:5},{x:P(1135),y:P(-45),id:"s_tree_13",c:Cg,d:1},{x:P(1049),y:P(-22),id:"s_tree_11",c:J,d:1},{x:P(1088),y:P(-11),id:"s_tree_10",c:Ag,d:2},{x:P(1144),y:P(15),id:"s_tree_13",c:Cg,d:4},{x:P(1039),
y:P(34),id:"s_tree_13",c:Cg,d:5},{x:P(1090),y:P(74),id:"s_tree_11",c:J,d:6},{x:P(993),y:P(102),id:"s_tree_11",c:J,d:7},{x:P(1057),y:P(113),id:"s_tree_10",c:Ag,d:8},{x:P(1142),y:P(92),id:"s_tree_10",c:Ag,d:8},{x:P(1034),y:P(141),id:"s_tree_13",c:Cg,d:9},{x:P(1116),y:P(170),id:"s_tree_10",c:Ag,d:9},{x:P(975),y:P(229),id:"s_tree_11",c:J,d:10},{x:P(1156),y:P(193),id:"s_icerock_2",c:rg,d:11},{x:P(1022),y:P(325),id:"s_campfire",c:tf,d:12},{x:P(952),y:P(354),id:"s_tree_10",c:Ag,d:13},{x:P(1061),y:P(359),
id:"s_rock_7",c:ug,d:13},{x:P(1138),y:P(334),id:"s_bush_7",c:lg,d:13},{x:P(618),y:P(127),id:"s_rock_7",c:ug,d:0}]},pw:"grass_01 grass_02 desert_01 desert_02 beach_01 beach_02 snow_01 snow_02".split(" ")};return b}
function hn(){var b={},b={Ni:{page:{Qz:[{x:-182,y:118},{x:-5,y:101},{x:207,y:148},{x:341,y:21},{x:337,y:-129},{x:169,y:-172},{x:-39,y:-75},{x:-277,y:-133},{x:-239,y:-253},{x:-2,y:-276},{x:264,y:274},{x:294,y:148},{x:177,y:16},{x:337,y:-123},{x:79,y:-124},{x:-19,y:48},{x:-156,y:203},{x:-327,y:100},{x:-276,y:-61},{x:-57,y:-188}],yH:[{x:-182,y:118},{x:-5,y:101},{x:207,y:148},{x:341,y:21},{x:337,y:-129},{x:169,y:-172},{x:-39,y:-75},{x:-277,y:-133},{x:-239,y:-253},{x:-2,y:-276},{x:264,y:-366},{x:294,y:-496},
{x:177,y:-624},{x:337,y:-763},{x:79,y:-764},{x:-19,y:-592},{x:-156,y:-437},{x:-327,y:-540},{x:-276,y:-701},{x:-57,y:-828}],ps:[-30,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},pw:["page"]}};b.buttons={points:{images:[ch,dh,eh,fh,Ug],width:103,height:94},type:{images:[Vg,Wg,Xg,Yg,Ug],width:103,height:94},counter:{images:[Zg,$g,ah,bh,Ug],width:103,height:94}};return b}
O.I.MK={x:void 0,y:void 0,backgroundImage:wc,marginLeft:P(40),marginRight:P(40),marginTop:P(40),marginBottom:P(40),rc:25,Hb:75,Zc:"",Dc:"",Mb:K,Qd:"",vd:"",Wc:L,Ia:null,Ja:"right",Ub:!1,lc:P(96),Qc:P(96),hb:!0,sb:{k:Hl,duration:.5,jc:0,D:dc,da:1.2},Ua:{k:Hl,duration:.5,cc:0,D:cc,da:1.2},oc:4,pd:!0,h:[],ab:null,Vc:-1,Vz:"",Wz:L,Xz:P(0),Yz:P(0),gq:"",CH:"",Uz:L,FH:P(105),GH:P(-5),EH:P(200),DH:P(400),bc:null,wb:null,Mc:null,wd:null,Lc:null,je:null};
function Aj(b){this.name="LevelPlay";this.q(O.I.MK);this.i(O.hp);void 0!==b&&this.i(b)}gm(Aj,mm);
Aj.prototype.K=function(){Aj.Bb.K.call(this);var b=gn(),c=void 0;switch(b.hc[this.Vc-1].C.mode){case "points":var d=b.hc[this.Vc-1].R.Z;this.gq=xk("GoalText_01").replace("<TARGET>",d.toString());c=oi;break;case "type":d=b.hc[this.Vc-1].type.V;b=b.hc[this.Vc-1].type.aa;this.gq=xk("GoalText_02").replace("<TARGET>",d.toString());switch(b){case "BIGCORNER":c=mh;break;case "BIGSQUARE":c=nh;break;case "DASH":c=oh;break;case "DOT":c=ph;break;case "FRIKANDEL":c=qh;break;case "KROKET":c=rh;break;case "LINE":c=
sh;break;case "MINICORNER":c=th;break;case "SQUARE":c=vh}break;case "counter":d=b.hc[this.Vc-1].B.X.length,this.gq=xk("GoalText_03").replace("<TARGET>",d.toString()),c=pi}c&&(c=new Z({c:c,x:P(115),y:P(55)}),this.j.g(c));c=new U({s:this.Vz,font:this.Wz,x:this.Xz,y:this.Yz});d=new U({text:this.gq,s:this.CH,font:this.Uz,x:this.FH,y:this.GH,width:this.EH,height:this.DH,Bc:!0,dd:!0});this.j.g(d);this.j.g(c)};
function Ko(b,c){if(void 0===b)console.log("ANALYTICS WARNING: No ID passed");else{var d;d=[];for(var e="levelnumber;amount of stars;tutorialnumber;number of day;rewardname;booster name;gate number".split(";"),g=b,h=0;h<e.length;h++)b.TA(e[h])&&d.push(e[h]);if("[object Array]"===Object.prototype.toString.call(c)&&c.length===d.length)for(h=0;h<d.length;h++)g=g.replace(d[h],c[h].toString());else void 0!==c&&"[object Array]"!==Object.prototype.toString.call(c)&&1===d.length?g=b.replace(d[0],c.toString()):
void 0===c&&0===d.length||console.log("ANALYTICS WARNING: Some arguments are not correct!");d=g;console.log("ID SEND TO ANALYTICS: "+d);try{analytics.customEvent(d)}catch(l){console.log("error calling analytics.menu: "+l)}}}function Lo(){String.prototype.TA||(String.prototype.TA=function(b,c){"number"!==typeof c&&(c=0);return c+b.length>this.length?!1:-1!==this.indexOf(b,c)})}
var Mo=new function(){this.Nb={YD:"Initialize-loading",XD:"Initialize-finished",WD:"Game-loading",VD:"Game-finished",SK:"level-[levelnumber]-start",TK:"level-[levelnumber]-won-[amount of stars]",QK:"level-[levelnumber]-lost",Fv:"level-[levelnumber]-completeonce",RK:"level-[levelnumber]-restart",Gu:"firsttime-initialize",Hu:"firsttime-menu",Cn:"firsttime-play",AI:"firsttime-level-[levelnumber]-start",DR:"firsttime-tutorial[tutorialnumber]-step[step number]",BI:"firsttime-level-[levelnumber]-won-[amount of stars]",
rR:"dailyspin_counter reset_day[number of day]",sR:"dailyspin_day[number of day]\t",KT:"reward_[rewardname]",LT:"reward_no reward",MT:"reward_spin again",rT:"premiumspin_day[number of day]",qT:"premiumreward_[rewardname]",vT:"purchase_booster_[booster name]_[levelnumber]",yU:"use_booster_[booster name]_[levelnumber]",wT:"purchase_extramoves_[levelnumber]",xT:"purchase_gate unlock_[gate number]",uT:"purchase_adremoval"};Lo()},No=window.publisher,Oo=!1,Po=!1,Qo=!1,Ro=-1;
v.Uy=function(){new oc(No,v.tJ(),v.Ti,v.Se,v.Lh,this);this.fn(Mo.Nb.Gu)||(Ko(Mo.Nb.Gu),this.Yo(Mo.Nb.Gu));Ko(Mo.Nb.XD);Ko(Mo.Nb.WD)};
v.jz=function(){Ko(Mo.Nb.YD);var b=window.navigator.userAgent,c=!1,d=/Chrome/.test(window.navigator.userAgent)&&/Google Inc/.test(window.navigator.vendor),e=/SHL24|SHL23|SHL22|SHL25|SHL21/i.test(b)&&!d,b=/SH-01F/i.test(b)&&!d;if(window.ActiveXObject||"ActiveXObject"in window)Qo=c=!0;if(e||b)O.ol.Kq=!1,O.r.dr=["load","images","fonts"],O.r.er=["load","images"];if(c||b||e)O.ol.Kq=!1,O.r.dr=["load","images","fonts"],O.r.er=["load","images"];f.ja.Nx&&(O.ol.Kq=!1,O.r.dr=["load","images","fonts"],O.r.er=
["load","images"])};v.kz=function(){this.fn(Mo.Nb.Hu)||(Ko(Mo.Nb.Hu),this.Yo(Mo.Nb.Hu));Ko(Mo.Nb.VD);try{analytics.customEvent("menu")}catch(b){console.log("error calling analytics.menu: "+b)}};v.sC=function(b,c){var d=this;No.enableAds&&!Oo&&(setTimeout(function(){d.GA()},1E3*No.firstAd),setTimeout(function(){d.UO()},1E3*No.firstAd),Oo=!0);Ro=c?c:-1;this.fn(Mo.Nb.Cn)||(Ko(Mo.Nb.Cn),this.Yo(Mo.Nb.Cn));this.fn(Mo.Nb.Cn+"_"+Ro)||(Ko(Mo.Nb.AI,Ro),this.Yo(Mo.Nb.Cn+"_"+Ro));Ko(Mo.Nb.SK,Ro)};
v.UO=function(){var b=this;setInterval(function(){b.GA()},1E3*No.adFreq)};v.GA=function(){Po=!0};v.tC=function(b,c,d){void 0===d&&(d="undefined stars");Ko(Mo.Nb.TK,[Ro,d]);this.fn(Mo.Nb.Fv+"_"+Ro)||(Ko(Mo.Nb.Fv,Ro),Ko(Mo.Nb.BI,Ro),this.Yo(Mo.Nb.Fv+"_"+Ro))};v.rC=function(){Ko(Mo.Nb.RK,Ro)};v.pC=function(){Ko(Mo.Nb.QK,Ro)};
v.nC=function(b){try{var c=Pk(jj).hm;community.submitScore({score:c,callback:function(){if(Po)try{v.Ti(),adSense.showAdvertising({callback:v.Se}),Po=!1}catch(b){console.log("error calling adSense.showAdvertising: "+b),v.Se()}}});analytics.customEvent("score: "+c)}catch(d){console.log("error submitting highscore: "+c+", "+d)}if(b&&Po)try{v.Ti(),adSense.showAdvertising({callback:function(){v.Se()}}),Po=!1}catch(e){console.log("error calling adSense.showAdvertising: "+e),v.Se()}};
v.xA=function(b){if(b.failed)try{analytics.customEvent("levelFailed",b.level)}catch(c){console.log("error calling analytics.levelFailed: "+c)}else try{analytics.customEvent("level",b.level)}catch(d){console.log("error calling analytics.level: "+d)}if(Po)try{v.Ti(),adSense.showAdvertising({callback:function(){v.Se();v.Lh()}}),Po=!1}catch(e){console.log("error calling adSense.showAdvertising: "+e),v.Se(),v.Lh()}else v.Lh()};
v.XT=function(){if(Po)try{v.Ti(),adSense.showAdvertising({callback:function(){v.Se()}}),Po=!1}catch(b){console.log("error calling adSense.showAdvertising: "+b),v.Se()}};v.tJ=function(){return R.$a>R.Ga?"landscape":"portrait"};v.Vu=function(){return No.moreGames?!0:!1};v.Cq=function(){if("string"===typeof No.moreGamesURL&&""!==typeof No.moreGamesURL)return No.moreGamesURL;try{moregames.redirect()}catch(b){console.log("error calling moregames.redirect: "+b)}};v.DA=function(){return fj};
v.LM=function(b){freemium.purchase(void 0,"1.99$","test_item",b,void 0)};v.NQ=function(b,c){v.Ti();try{gj.OM(function(){b&&b();v.Se()},this)}catch(d){c&&c(),v.Se()}};v.bU=function(){};v.QQ=function(){};v.CA=function(){return Qo};v.fn=function(b){if(jj.n.vv(b))return!0;!1};v.Yo=function(b){jj.n.tk(b,"",!0)};
